/**
 * @license
 * Copyright 2019 The Emscripten Authors
 * SPDX-License-Identifier: MIT
 */

// wasm2js.js - enough of a polyfill for the WebAssembly object so that we can load
// wasm2js code that way.

// Emit "var WebAssembly" if definitely using wasm2js. Otherwise, in MAYBE_WASM2JS
// mode, we can't use a "var" since it would prevent normal wasm from working.
/** @suppress{duplicate, const} */
var
WebAssembly = {
  // Note that we do not use closure quoting (this['buffer'], etc.) on these
  // functions, as they are just meant for internal use. In other words, this is
  // not a fully general polyfill.
  Memory: function(opts) {
    this.buffer = new ArrayBuffer(opts['initial'] * 65536);
  },


  Module: function(binary) {
    // TODO: use the binary and info somehow - right now the wasm2js output is embedded in
    // the main JS
  },

  Instance: function(module, info) {
    // TODO: use the module and info somehow - right now the wasm2js output is embedded in
    // the main JS
    // This will be replaced by the actual wasm2js code.
    this.exports = (
// EMSCRIPTEN_START_ASM
function instantiate(mNa,nNa){function cNa(oNa){oNa.set=(function(pNa,qNa){this[pNa]=qNa});oNa.get=(function(pNa){return this[pNa]});return oNa}var a=new ArrayBuffer(16);var b=new Int32Array(a);var c=new Float32Array(a);var d=new Float64Array(a);function dNa(rNa){return b[rNa]}function eNa(rNa,sNa){b[rNa]=sNa}function fNa(){return d[0]}function gNa(sNa){d[0]=sNa}function hNa(sNa){c[2]=sNa}function iNa(){return c[2]}function jNa(tNa,uNa){var e=uNa.a;var f=e.buffer;e.grow=lNa;var g=new tNa.Int8Array(f);var h=new tNa.Int16Array(f);var i=new tNa.Int32Array(f);var j=new tNa.Uint8Array(f);var k=new tNa.Uint16Array(f);var l=new tNa.Uint32Array(f);var m=new tNa.Float32Array(f);var n=new tNa.Float64Array(f);var o=tNa.Math.imul;var p=tNa.Math.fround;var q=tNa.Math.abs;var r=tNa.Math.clz32;var s=tNa.Math.min;var t=tNa.Math.max;var u=tNa.Math.floor;var v=tNa.Math.ceil;var w=tNa.Math.sqrt;var x=uNa.abort;var y=tNa.NaN;var z=tNa.Infinity;var A=uNa.b;var B=uNa.c;var C=uNa.d;var D=uNa.e;var E=uNa.f;var F=uNa.g;var G=uNa.h;var H=uNa.i;var I=uNa.j;var J=uNa.k;var K=uNa.l;var L=uNa.m;var M=uNa.n;var N=uNa.o;var O=uNa.p;var P=uNa.q;var Q=uNa.r;var R=uNa.s;var S=uNa.t;var T=uNa.u;var U=uNa.v;var V=uNa.w;var W=uNa.x;var X=uNa.y;var Y=uNa.z;var Z=uNa.A;var _=uNa.B;var $=uNa.C;var aa=uNa.D;var ba=uNa.E;var ca=uNa.F;var da=uNa.G;var ea=uNa.H;var fa=uNa.I;var ga=uNa.J;var ha=uNa.K;var ia=uNa.L;var ja=uNa.M;var ka=uNa.N;var la=uNa.O;var ma=uNa.P;var na=uNa.Q;var oa=uNa.R;var pa=uNa.S;var qa=uNa.T;var ra=uNa.U;var sa=uNa.V;var ta=uNa.W;var ua=uNa.X;var va=uNa.Y;var wa=uNa.Z;var xa=uNa._;var ya=uNa.$;var za=uNa.aa;var Aa=uNa.ba;var Ba=uNa.ca;var Ca=uNa.da;var Da=uNa.ea;var Ea=uNa.fa;var Fa=uNa.ga;var Ga=uNa.ha;var Ha=uNa.ia;var Ia=uNa.ja;var Ja=uNa.ka;var Ka=uNa.la;var La=uNa.ma;var Ma=uNa.na;var Na=uNa.oa;var Oa=uNa.pa;var Pa=uNa.qa;var Qa=uNa.ra;var Ra=uNa.sa;var Sa=uNa.ta;var Ta=uNa.ua;var Ua=uNa.va;var Va=uNa.wa;var Wa=uNa.xa;var Xa=5707056;var Ya=0;var Za=0;var _a=0;
// EMSCRIPTEN_START_FUNCS
function _Ga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,m=0,n=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,H=0,K=0,M=0,O=0,P=0;d=Xa-608|0;Xa=d;pc(b);e=d+416|0;m=xFa(b,e);if(!m){ZP(e)}a:{b:{c:{if(!m){break c}if(!AQ(d+416|0)){break c}if(!wb(b,Vc(zQ(d+416|0),_a))){break c}if(!c){f=1;break c}md(a,32);g[d+415|0]=0;r=Oc(d+400|0);d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{I:{J:{if(i[d+416>>2]==778924148){i[114610]=0;D(624,a|0,16777216);e=i[114610];i[114610]=0;if((e|0)==1){break b}i[114610]=0;e=F(255,b|0)|0;f=i[114610];i[114610]=0;if((f|0)==1){break b}i[114610]=0;C(256,b|0,e+ -4|0)|0;e=i[114610];i[114610]=0;if((e|0)==1){break b}i[114610]=0;z=F(390,b|0)|0;e=i[114610];i[114610]=0;if((e|0)!=1){break J}break b}K:{L:{M:{N:{if((j[d+456|0]|j[d+457|0]<<8)>>>0<2185|(j[d+456|0]|j[d+457|0]<<8)>>>0>4095){break N}i[114610]=0;e=F(255,b|0)|0;f=i[114610];i[114610]=0;if((f|0)==1){break b}i[114610]=0;C(256,b|0,e+ -4|0)|0;e=i[114610];i[114610]=0;if((e|0)==1){break b}i[114610]=0;z=F(390,b|0)|0;e=i[114610];i[114610]=0;if((e|0)==1){break b}if(z>>>0<256){break N}i[114610]=0;e=F(255,b|0)|0;f=i[114610];i[114610]=0;if((f|0)==1){break b}if(z>>>0>=e>>>0){break N}i[114610]=0;e=C(256,b|0,z|0)|0;f=i[114610];i[114610]=0;if((f|0)==1){break b}if(!e){break N}i[114610]=0;e=C(625,b|0,13434)|0;f=i[114610];i[114610]=0;if((f|0)==1){break b}if(!e){break N}i[114610]=0;D(624,a|0,16777216);e=i[114610];i[114610]=0;if((e|0)==1){break b}if((j[d+456|0]|j[d+457|0]<<8)>>>0>=4096){i[114610]=0;b=C(626,d+224|0,13438)|0;c=i[114610];i[114610]=0;if((c|0)==1){break I}i[114610]=0;D(627,a|0,b|0);a=i[114610];i[114610]=0;if((a|0)!=1){eb(b);f=0;break d}f=B()|0;A()|0;eb(b);break a}if((j[d+456|0]|j[d+457|0]<<8)>>>0<2194){break N}i[114610]=0;e=C(626,d+224|0,13534)|0;f=i[114610];i[114610]=0;if((f|0)==1){break M}i[114610]=0;D(627,a|0,e|0);f=i[114610];i[114610]=0;if((f|0)==1){break L}eb(e)}if(i[a+480180>>2]!=32){break J}if(((j[d+456|0]|j[d+457|0]<<8)&61440)!=20480){break K}i[a+1074304>>2]=((j[d+456|0]|j[d+457|0]<<8)&4095)<<16;if(i[d+476>>2]!=1414548815){break J}g[d+415|0]=1;break J}f=B()|0;A()|0;break a}f=B()|0;A()|0;eb(e);break a}if(!((j[d+456|0]|j[d+457|0]<<8)!=2184?(j[d+458|0]|j[d+459|0]<<8)!=2184:0)){g[d+415|0]=1;i[a+1074304>>2]=18284544;break J}if(!((j[d+456|0]|j[d+457|0]<<8)!=535|(j[d+458|0]|j[d+459|0]<<8)!=512|(j[d+476|0]|j[d+477|0]<<8|(j[d+478|0]<<16|j[d+479|0]<<24)))){i[114610]=0;e=I(628,d+480|0,255,64)|0;f=i[114610];i[114610]=0;if((f|0)==1){break b}O:{if(e){i[a+1074304>>2]=18219008;i[114610]=0;e=C(2,d+224|0,13680)|0;f=i[114610];i[114610]=0;if((f|0)!=1){break O}f=B()|0;A()|0;break a}i[a+1074304>>2]=18284544;i[114610]=0;e=C(2,d+224|0,13708)|0;f=i[114610];i[114610]=0;if((f|0)==1){break H}}mb(r,e);eb(e);g[d+415|0]=1;break J}if(!((j[d+456|0]|j[d+457|0]<<8)!=532|(j[d+458|0]|j[d+459|0]<<8)!=514|(j[d+476|0]|j[d+477|0]<<8|(j[d+478|0]<<16|j[d+479|0]<<24)))){i[a+1074304>>2]=17367040;i[114610]=0;e=C(2,d+224|0,13744)|0;f=i[114610];i[114610]=0;if((f|0)!=1){mb(r,e);eb(e);g[d+415|0]=1;break J}f=B()|0;A()|0;break a}if((j[d+456|0]|j[d+457|0]<<8)!=768|(j[d+458|0]|j[d+459|0]<<8)!=768|(j[d+476|0]|j[d+477|0]<<8|(j[d+478|0]<<16|j[d+479|0]<<24)|(j[d+448|0]|j[d+449|0]<<8)!=256)){break J}if(j[d+469|0]|j[d+468|0]!=128){break J}i[a+1074304>>2]=18285088;g[d+415|0]=1}i[a+480208>>2]=i[a+480208>>2]&-17|(j[d+460|0]|j[d+461|0]<<8)<<1&16;i[a+480208>>2]=i[a+480208>>2]&-5|(j[d+460|0]|j[d+461|0]<<8)>>>2&4;i[a+480208>>2]=i[a+480208>>2]&-9|(j[d+460|0]|j[d+461|0]<<8)>>>2&8;i[a+480208>>2]=i[a+480208>>2]&-32769|(j[d+460|0]|j[d+461|0]<<8)<<3&32768;i[114610]=0;G(629,d+328|0,3,d+416|4);e=i[114610];i[114610]=0;if((e|0)==1){break G}i[114610]=0;D(415,d+224|0,d+328|0);e=i[114610];i[114610]=0;if((e|0)==1){break G}mb(a+1304400|0,d+224|0);eb(d+224|0);if(!(!(j[d+462|0]&4)|(l[a+1074304>>2]<18285314?i[a+1074304>>2]:0))){i[a+480216>>2]=j[d+446|0];i[a+480220>>2]=j[d+447|0]}e=j[d+464|0];i[a+480200>>2]=e>>>0>128?256:e<<1;if(j[d+466|0]){i[a+480196>>2]=j[d+466|0]}g[d+224|0]=31;e=j[d+467|0];i[114610]=0;g[d+328|0]=e;e=C(453,d+224|0,d+328|0)|0;f=i[114610];i[114610]=0;if((f|0)==1){break e}i[a+480204>>2]=o(j[e|0],1e4);e=j[d+465|0];i[114610]=0;g[d+224|0]=e;g[d+328|0]=128;e=C(391,d+224|0,d+328|0)|0;f=i[114610];i[114610]=0;if((f|0)==1){break f}i[a+480228>>2]=j[e|0];f=0;while(1){q=(d+416|0)+f|0;m=q- -64|0;P:{if(j[m|0]==255){break P}i[114610]=0;p=(f<<5)+a|0;e=p+480280|0;L(432,e|0);n=i[114610];i[114610]=0;if((n|0)==1){break F}O=p+480286|0,P=hd(j[q+128|0],0,64),h[O>>1]=P;if(g[m|0]<=-1){i[e>>2]=i[e>>2]|1024}m=j[m|0]&127;if(m>>>0<=64){h[p+480284>>1]=m<<2;break P}if((m|0)!=100){break P}i[e>>2]=i[e>>2]|256}f=f+1|0;if((f|0)!=64){continue}break}i[114610]=0;C(256,b|0,192)|0;e=i[114610];i[114610]=0;if((e|0)==1){break b}Q:{if(!(i[a+480180>>2]!=16777216|(j[d+456|0]|j[d+457|0]<<8)>>>0<2187|(j[d+456|0]|j[d+457|0]<<8)>>>0>2189)){f=0;i[114610]=0;e=F(357,b|0)|0;m=i[114610];i[114610]=0;if((m|0)==1){break E}if(e){break d}i[114610]=0;e=F(390,b|0)|0;m=i[114610];i[114610]=0;R:{if((m|0)==1){break R}if(e>>>0>k[i[19847]+12>>1]){break d}m=Db(a+484360|0);i[114610]=0;e=S(630,m|0,b|0,e|0,65535,65535)|0;m=i[114610];i[114610]=0;if((m|0)==1){break R}if(!e){break d}break Q}f=B()|0;A()|0;break a}e=Db(a+484360|0);f=j[d+448|0]|j[d+449|0]<<8;i[114610]=0;S(584,e|0,b|0,f|0,255,254)|0;e=i[114610];i[114610]=0;if((e|0)==1){break b}}y=fp(d+384|0);w=fp(d+368|0);t=fp(d+352|0);e=j[d+450|0]|j[d+451|0]<<8;f=0;i[114610]=0;e=I(631,b|0,y|0,e|0)|0;m=i[114610];i[114610]=0;S:{if((m|0)==1){break S}if(!e){break C}e=j[d+452|0]|j[d+453|0]<<8;i[114610]=0;e=I(631,b|0,w|0,e|0)|0;m=i[114610];i[114610]=0;if((m|0)==1){break S}if(!e){break C}e=j[d+454|0]|j[d+455|0]<<8;i[114610]=0;e=I(631,b|0,t|0,e|0)|0;m=i[114610];i[114610]=0;if((m|0)==1){break S}if(!e){break C}i[d+348>>2]=-1;O=d,P=Jb(y),i[O+224>>2]=P;O=d,P=Kb(y),i[O+328>>2]=P;if(!pb(d+224|0,d+328|0)){break D}while(1){e=i[d+224>>2];e=j[e|0]|j[e+1|0]<<8|(j[e+2|0]<<16|j[e+3|0]<<24);if(!(!e|e>>>0>=l[d+348>>2])){i[d+348>>2]=e}Gd(d+224|0);if(pb(d+224|0,d+328|0)){continue}break}break D}f=B()|0;A()|0;break g}f=B()|0;A()|0;break a}f=B()|0;A()|0;break a}f=B()|0;A()|0;break a}f=B()|0;A()|0;break a}f=B()|0;A()|0;break a}O=d,P=Jb(w),i[O+224>>2]=P;O=d,P=Kb(w),i[O+328>>2]=P;if(pb(d+224|0,d+328|0)){while(1){e=i[d+224>>2];e=j[e|0]|j[e+1|0]<<8|(j[e+2|0]<<16|j[e+3|0]<<24);if(!(!e|e>>>0>=l[d+348>>2])){i[d+348>>2]=e}Gd(d+224|0);if(pb(d+224|0,d+328|0)){continue}break}}O=d,P=Jb(t),i[O+224>>2]=P;O=d,P=Kb(t),i[O+328>>2]=P;if(pb(d+224|0,d+328|0)){while(1){e=i[d+224>>2];e=j[e|0]|j[e+1|0]<<8|(j[e+2|0]<<16|j[e+3|0]<<24);if(!(!e|e>>>0>=l[d+348>>2])){i[d+348>>2]=e}Gd(d+224|0);if(pb(d+224|0,d+328|0)){continue}break}}T:{U:{if(g[d+462|0]&1){e=j[d+472|0]|j[d+473|0]<<8|(j[d+474|0]<<16|j[d+475|0]<<24);i[114610]=0;i[d+224>>2]=e;e=C(632,d+348|0,d+224|0)|0;f=i[114610];i[114610]=0;if((f|0)==1){break U}i[d+348>>2]=i[e>>2]}f=0;V:{W:{X:{Y:{if((j[d+458|0]|j[d+459|0]<<8)!=532|(j[d+456|0]|j[d+457|0]<<8?(j[d+456|0]|j[d+457|0]<<8)!=532:0)|(j[d+447|0]|j[d+446|0])){break Y}if(j[d+460|0]&192|(j[d+469|0]|(j[d+476|0]|j[d+477|0]<<8|(j[d+478|0]<<16|j[d+479|0]<<24)))){break Y}Z:{if(!(j[d+452|0]|j[d+453|0]<<8)|(j[d+450|0]|j[d+451|0]<<8)){break Z}if((i[b+8>>2]+(qb(w)<<2)|0)+2>>>0>l[d+348>>2]){break Z}if(j[d+452|0]|j[d+453|0]<<8){e=0;while(1){i[114610]=0;f=F(390,b|0)|0;m=i[114610];i[114610]=0;_:{if((m|0)!=1){if(!f){break _}tg(b,(e<<2)+4|0);break Z}f=B()|0;A()|0;break g}e=e+1|0;if(e>>>0<(j[d+452|0]|j[d+453|0]<<8)>>>0){continue}break}}i[114610]=0;e=C(2,d+224|0,13772)|0;f=i[114610];i[114610]=0;if((f|0)==1){break W}mb(r,e);eb(e)}f=1;if(j[d+456|0]|j[d+457|0]<<8){break Y}i[114610]=0;e=C(2,d+224|0,13785)|0;m=i[114610];i[114610]=0;if((m|0)==1){break X}mb(r,e);eb(e)}$:{aa:{ba:{if(j[d+462|0]&2){i[114610]=0;e=F(357,b|0)|0;m=i[114610];i[114610]=0;if((m|0)==1){break $}i[114610]=0;m=e<<3;p=C(258,b|0,m|0)|0;q=i[114610];i[114610]=0;if((q|0)==1){break $}if(!(!p|m+i[b+8>>2]>>>0>l[d+348>>2])){i[114610]=0;m=a+1304500|0;D(633,m|0,e|0);p=i[114610];i[114610]=0;if((p|0)==1){break $}O=d,P=Jb(m),i[O+328>>2]=P;O=d,P=Kb(m),i[O+312>>2]=P;if(pb(d+328|0,d+312|0)){while(1){m=i[d+328>>2];i[114610]=0;C(634,b|0,d+224|0)|0;p=i[114610];i[114610]=0;if((p|0)==1){break aa}i[114610]=0;D(635,d+224|0,m|0);m=i[114610];i[114610]=0;if((m|0)==1){break aa}i[d+328>>2]=i[d+328>>2]+48;if(pb(d+328|0,d+312|0)){continue}break}}if(!(!e&f)){break ba}if(j[d+462|0]&4){i[114610]=0;e=C(2,d+224|0,13796)|0;f=i[114610];i[114610]=0;if((f|0)!=1){mb(r,e);eb(e);break ba}f=B()|0;A()|0;break g}i[114610]=0;e=C(2,d+224|0,13813)|0;f=i[114610];i[114610]=0;if((f|0)!=1){mb(r,e);eb(e);break ba}f=B()|0;A()|0;break g}tg(b,2);break ba}if(!f|(j[d+462|0]|j[d+463|0]<<8)>>>0>1){break ba}i[114610]=0;e=F(357,b|0)|0;f=i[114610];i[114610]=0;if((f|0)==1){break V}if(!e){i[114610]=0;e=C(2,d+224|0,13772)|0;f=i[114610];i[114610]=0;if((f|0)!=1){mb(r,e);eb(e);break ba}f=B()|0;A()|0;break g}tg(b,2)}ca:{if(j[d+462|0]&8?0:!(j[d+460|0]&128)){break ca}i[114610]=0;e=a+901404|0;f=C(636,b|0,e|0)|0;m=i[114610];i[114610]=0;if((m|0)==1){break h}if(!f){break ca}i[114610]=0;L(637,e|0);e=i[114610];i[114610]=0;if((e|0)==1){break h}}if((j[d+456|0]|j[d+457|0]<<8)>>>0<=531){i[114610]=0;L(638,a+901404|0);e=i[114610];i[114610]=0;if((e|0)==1){break h}}i[114610]=0;H=F(277,d+328|0)|0;e=i[114610];i[114610]=0;da:{ea:{fa:{ga:{ha:{ia:{ja:{if((e|0)!=1){i[114610]=0;e=C(621,b|0,13819)|0;f=i[114610];i[114610]=0;if((f|0)==1){break ja}if(e){i[114610]=0;e=F(390,b|0)|0;f=i[114610];i[114610]=0;if((f|0)==1){break ia}i[114610]=0;G(341,d+224|0,b|0,e|0);e=i[114610];i[114610]=0;if((e|0)==1){break ia}Cd(H,d+224|0);hb(d+224|0)}h[a+480188>>1]=1;i[114610]=0;e=C(621,b|0,13824)|0;f=i[114610];i[114610]=0;if((f|0)==1){break ja}if(e){i[114610]=0;e=F(390,b|0)|0;f=i[114610];i[114610]=0;if((f|0)==1){break ha}i[114610]=0;G(341,d+224|0,b|0,e|0);e=i[114610];i[114610]=0;if((e|0)==1){break ha}i[114610]=0;e=F(255,d+224|0)|0;f=i[114610];i[114610]=0;if((f|0)==1){break ga}i[114610]=0;h[d+312>>1]=(e>>>0)/20;e=C(477,13830,d+312|0)|0;f=i[114610];i[114610]=0;if((f|0)==1){break ga}e=k[e>>1];h[a+480188>>1]=e;if(e){f=0;while(1){i[114610]=0;I(639,d+224|0,((f<<5)+a|0)+480289|0,20)|0;m=i[114610];i[114610]=0;if((m|0)==1){break ga}f=f+1|0;if((e|0)!=(f|0)){continue}break}}hb(d+224|0)}if(l[d+348>>2]<l[b+8>>2]){break fa}e=i[d+348>>2]-i[b+8>>2]|0;break ea}f=B()|0;A()|0;break g}f=B()|0;A()|0;break i}f=B()|0;A()|0;break i}f=B()|0;A()|0;break i}f=B()|0;A()|0;hb(d+224|0);break i}i[114610]=0;e=F(548,b|0)|0;f=i[114610];i[114610]=0;if((f|0)==1){break da}}i[114610]=0;G(341,d+312|0,b|0,e|0);e=i[114610];i[114610]=0;if((e|0)==1){break da}i[114610]=0;M=C(640,a|0,d+312|0)|0;e=i[114610];i[114610]=0;ka:{la:{if((e|0)==1){break la}if(!(g[d+462|0]&1)|!(j[d+470|0]|j[d+471|0]<<8)){break ka}e=j[d+472|0]|j[d+473|0]<<8|(j[d+474|0]<<16|j[d+475|0]<<24);i[114610]=0;e=C(256,b|0,e|0)|0;f=i[114610];i[114610]=0;if((f|0)==1){break la}if(!e){break ka}e=j[d+470|0]|j[d+471|0]<<8;i[114610]=0;N(587,a+1304424|0,b|0,e|0,4)|0;e=i[114610];i[114610]=0;if((e|0)!=1){break ka}}f=B()|0;A()|0;break j}h[a+480192>>1]=0;ma:{if(j[d+460|0]&4){e=j[d+450|0]|j[d+451|0]<<8;i[114610]=0;h[d+224>>1]=e;h[d+208>>1]=255;e=C(477,d+224|0,d+208|0)|0;f=i[114610];i[114610]=0;if((f|0)==1){break ma}h[a+480192>>1]=k[e>>1]}na:{oa:{if(k[a+480192>>1]){f=0;while(1){e=vb(y,f);pa:{if(!(j[e|0]|j[e+1|0]<<8|(j[e+2|0]<<16|j[e+3|0]<<24))){break pa}e=vb(y,f);e=j[e|0]|j[e+1|0]<<8|(j[e+2|0]<<16|j[e+3|0]<<24);i[114610]=0;e=C(256,b|0,e|0)|0;m=i[114610];i[114610]=0;if((m|0)==1){break na}if(!e){break pa}i[114610]=0;e=C(258,b|0,554)|0;m=i[114610];i[114610]=0;if((m|0)==1){break na}if(!e){break pa}i[114610]=0;e=I(454,a|0,f+1&65535,0)|0;m=i[114610];i[114610]=0;if((m|0)==1){break oa}if(!e){break pa}m=j[d+458|0]|j[d+459|0]<<8;i[114610]=0;N(641,a|0,b|0,e|0,m|0)|0;m=i[114610];i[114610]=0;if((m|0)==1){break oa}g[e+33|0]=j[d+469|0]}f=f+1|0;if(f>>>0<k[a+480192>>1]){continue}break}}i[d+308>>2]=0;if(j[d+452|0]|j[d+453|0]<<8){e=vb(w,(j[d+452|0]|j[d+453|0]<<8)+ -1|0);i[d+308>>2]=(j[e|0]|j[e+1|0]<<8|(j[e+2|0]<<16|j[e+3|0]<<24))+80}e=j[d+452|0]|j[d+453|0]<<8;i[114610]=0;h[d+224>>1]=e;h[d+208>>1]=3999;e=C(477,d+224|0,d+208|0)|0;f=i[114610];i[114610]=0;if((f|0)!=1){h[a+480190>>1]=k[e>>1];p=0;qa:{if(k[a+480190>>1]){q=c&2;u=d+244|0;f=0;while(1){e=vb(w,f);ra:{if(!(j[e|0]|j[e+1|0]<<8|(j[e+2|0]<<16|j[e+3|0]<<24))){break ra}e=vb(w,f);e=j[e|0]|j[e+1|0]<<8|(j[e+2|0]<<16|j[e+3|0]<<24);i[114610]=0;e=C(256,b|0,e|0)|0;m=i[114610];i[114610]=0;sa:{ta:{ua:{va:{wa:{xa:{ya:{if((m|0)==1){break ya}if(!e){break ra}i[114610]=0;e=C(642,b|0,d+224|0)|0;m=i[114610];i[114610]=0;if((m|0)==1){break ya}if(!e){break ra}i[114610]=0;n=f+1|0;e=o(n,104)+a|0;m=e+484380|0;v=C(643,d+224|0,m|0)|0;s=i[114610];i[114610]=0;if((s|0)==1){break xa}i[114610]=0;G(629,d+192|0,3,u|0);s=i[114610];i[114610]=0;if((s|0)==1){break wa}i[114610]=0;D(415,d+208|0,d+192|0);s=i[114610];i[114610]=0;if((s|0)==1){break wa}i[114610]=0;C(369,((n<<5)+a|0)+946300|0,d+208|0)|0;s=i[114610];i[114610]=0;if((s|0)==1){break va}eb(d+208|0);i[114610]=0;v=C(256,b|0,v|0)|0;s=i[114610];i[114610]=0;if((s|0)==1){break xa}if(!v){break ra}e=k[e+484414>>1];if(!(e&512)){break ua}i[114610]=0;e=C(644,b|0,d+208|0)|0;n=i[114610];i[114610]=0;if((n|0)!=1){if(!e){break ta}i[114610]=0;i[d+16>>2]=i[d+216>>2];e=i[d+212>>2];i[d+8>>2]=i[d+208>>2];i[d+12>>2]=e;G(645,m|0,1,d+8|0);e=i[114610];i[114610]=0;if((e|0)!=1){break ta}}f=B()|0;A()|0;break j}f=B()|0;A()|0;break j}f=B()|0;A()|0;break j}f=B()|0;A()|0;break j}f=B()|0;A()|0;eb(d+208|0);break j}if(!(e&16384)){e=j[d+456|0]|j[d+457|0]<<8;i[114610]=0;G(646,d+208|0,d+224|0,e|0);e=i[114610];i[114610]=0;if((e|0)==1){break k}za:{if(q){e=0;i[114610]=0;I(400,d+208|0,m|0,b|0)|0;n=i[114610];i[114610]=0;if((n|0)!=1){break za}break k}e=1;n=j[d+211|0];if(n>>>0>18){break za}n=1<<n;Aa:{if(!(n&126991)){if(n&396800){break Aa}break za}if(!j[d+208|0]){break za}}e=i[m>>2];i[114610]=0;n=C(647,d+208|0,e|0)|0;e=i[114610];i[114610]=0;if((e|0)==1){break k}e=0;i[114610]=0;C(338,b|0,n|0)|0;n=i[114610];i[114610]=0;if((n|0)==1){break k}}if(j[d+211|0]!=1){break sa}p=i[m>>2]!=0|p;break sa}i[114610]=0;C(648,b|0,d+188|0)|0;e=i[114610];i[114610]=0;if((e|0)==1){break l}e=i[d+188>>2];if(!(!q|!e)){e=Ab(d+208|0);i[114610]=0;I(481,b|0,e|0,i[d+188>>2])|0;m=i[114610];i[114610]=0;Ba:{Ca:{Da:{Ea:{Fa:{Ga:{Ha:{Ia:{Ja:{if((m|0)!=1){i[114610]=0;m=C(2,d+160|0,13832)|0;v=i[114610];i[114610]=0;if((v|0)==1){break Ja}i[114610]=0;D(219,d+176|0,m|0);v=i[114610];i[114610]=0;if((v|0)==1){break Ia}i[114610]=0;i[d+156>>2]=n;G(13,d+144|0,0,e|0);n=i[114610];i[114610]=0;if((n|0)==1){break Ha}i[114610]=0;J(649,d+192|0,d+176|0,d+156|0,d+144|0);n=i[114610];i[114610]=0;if((n|0)==1){break Ga}i[114610]=0;G(650,a|0,2,d+192|0);n=i[114610];i[114610]=0;if((n|0)==1){break Fa}eb(d+192|0);eb(d+144|0);ob(d+176|0);eb(m);eb(e);break ta}f=B()|0;A()|0;break Ba}f=B()|0;A()|0;break Ba}f=B()|0;A()|0;break Ca}f=B()|0;A()|0;break Da}f=B()|0;A()|0;break Ea}f=B()|0;A()|0;eb(d+192|0)}eb(d+144|0)}ob(d+176|0)}eb(m)}eb(e);break j}i[114610]=0;C(338,b|0,e|0)|0;e=i[114610];i[114610]=0;if((e|0)==1){break l}}e=0}m=i[b+8>>2];i[114610]=0;i[d+208>>2]=m;m=C(651,d+308|0,d+208|0)|0;n=i[114610];i[114610]=0;if((n|0)==1){break qa}i[d+308>>2]=i[m>>2];K=(e|0)!=0}f=f+1|0;if(f>>>0<k[a+480190>>1]){continue}break}}h[d+224>>1]=1;e=k[a+480190>>1];i[114610]=0;h[d+208>>1]=e;e=C(452,d+224|0,d+208|0)|0;f=i[114610];i[114610]=0;if((f|0)!=1){h[a+480190>>1]=k[e>>1];Ka:{La:{if(!(p&1)|(j[d+456|0]|j[d+457|0]<<8)!=516|(j[d+462|0]|j[d+463|0]<<8|(j[d+458|0]|j[d+459|0]<<8)!=512)){break La}if(j[d+476|0]|j[d+477|0]<<8|(j[d+478|0]<<16|j[d+479|0]<<24)|((j[d+460|0]|j[d+461|0]<<8)&65527)!=21|(j[d+464|0]!=128|j[d+465|0]!=48)){break La}if(j[d+469|0]|j[d+468|0]!=128|(j[d+470|0]|j[d+471|0]<<8)){break La}m=d+544|0;e=d+480|0;f=1;while(1){f=(j[e|0]|128)!=160?0:f;e=e+1|0;if((m|0)!=(e|0)){continue}break}m=d+608|0;e=d+544|0;while(1){f=j[e|0]==64&f;e=e+1|0;if((m|0)!=(e|0)){continue}break}e=20;while(1){f=!j[(d+e|0)+420|0]&f;e=e+1|0;if(e>>>0<26){continue}break}if(!f){break La}i[114610]=0;e=C(2,d+224|0,13910)|0;f=i[114610];i[114610]=0;if((f|0)==1){break Ka}mb(r,e);eb(e)}i[a+480260>>2]=0;i[a+480264>>2]=2147483647;O=d,P=qb(t),h[O+224>>1]=P;e=i[a+8>>2];i[114610]=0;e=C(477,d+224|0,e+10|0)|0;f=i[114610];i[114610]=0;Ma:{Na:{Oa:{Pa:{Qa:{Ra:{Sa:{Ta:{Ua:{if((f|0)!=1){e=k[e>>1];h[d+188>>1]=e;if((qb(t)|0)!=(e|0)){i[114610]=0;D(509,d+208|0,13924);e=i[114610];i[114610]=0;if((e|0)==1){break Ua}e=qb(t);i[114610]=0;i[d+192>>2]=e;J(652,d+128|0,d+208|0,d+192|0,d+188|0);e=i[114610];i[114610]=0;if((e|0)==1){break Ta}i[114610]=0;e=C(653,d+224|0,d+128|0)|0;f=i[114610];i[114610]=0;if((f|0)==1){break Sa}i[114610]=0;D(627,a|0,e|0);f=i[114610];i[114610]=0;if((f|0)==1){break Ra}eb(e);eb(d+128|0);ob(d+208|0)}if(c&1){break Oa}h[d+188>>1]=0;break Na}f=B()|0;A()|0;break j}f=B()|0;A()|0;break j}f=B()|0;A()|0;break Pa}f=B()|0;A()|0;break Qa}f=B()|0;A()|0;eb(e)}eb(d+128|0)}ob(d+208|0);break j}if(!k[d+188>>1]){break Na}e=0;while(1){c=vb(t,e);Va:{if(!(j[c|0]|j[c+1|0]<<8|(j[c+2|0]<<16|j[c+3|0]<<24))){break Va}c=vb(t,e);c=j[c|0]|j[c+1|0]<<8|(j[c+2|0]<<16|j[c+3|0]<<24);i[114610]=0;c=C(256,b|0,c|0)|0;f=i[114610];i[114610]=0;if((f|0)==1){break Ma}if(!c){break Va}i[114610]=0;c=F(357,b|0)|0;f=i[114610];i[114610]=0;if((f|0)==1){break m}i[114610]=0;p=F(357,b|0)|0;f=i[114610];i[114610]=0;if((f|0)==1){break n}if((p+ -1&65535)>>>0>1023){break Va}i[114610]=0;f=C(338,b|0,4)|0;m=i[114610];i[114610]=0;if((m|0)==1){break n}if(!f){break Va}i[114610]=0;G(341,d+224|0,b|0,c|0);c=i[114610];i[114610]=0;if((c|0)==1){break o}c=0;f=k[a+480188>>1];i[114610]=0;m=C(654,d+208|0,f|0)|0;f=i[114610];i[114610]=0;if((f|0)==1){break q}while(1){Wa:{i[114610]=0;f=C(258,d+224|0,1)|0;q=i[114610];i[114610]=0;Xa:{Ya:{if((q|0)!=1){if(!f){break Wa}i[114610]=0;f=F(387,d+224|0)|0;q=i[114610];i[114610]=0;if((q|0)==1){break r}q=f<<24>>24;if(q){break Ya}c=c+1|0;break Xa}break r}Za:{f=q&127;n=f?f+ -1|0:0;f=n&65535;if(f>>>0<rc(m)>>>0){break Za}i[114610]=0;g[d+192|0]=0;G(655,m|0,f+1|0,d+192|0);u=i[114610];i[114610]=0;if((u|0)!=1){break Za}break r}if((q|0)<=-1){i[114610]=0;q=F(387,d+224|0)|0;u=i[114610];i[114610]=0;if((u|0)==1){break r}O=dc(m,f),P=q,g[O|0]=P}if(!(!(j[dc(m,f)|0]&15)|f>>>0<k[a+480188>>1])){h[a+480188>>1]=n+1}if(g[dc(m,f)|0]&1){i[114610]=0;C(338,d+224|0,1)|0;q=i[114610];i[114610]=0;if((q|0)==1){break r}}if(j[dc(m,f)|0]&2){i[114610]=0;C(338,d+224|0,1)|0;q=i[114610];i[114610]=0;if((q|0)==1){break r}}if(j[dc(m,f)|0]&4){i[114610]=0;C(338,d+224|0,1)|0;q=i[114610];i[114610]=0;if((q|0)==1){break r}}if(!(j[dc(m,f)|0]&8)){break Xa}i[114610]=0;C(338,d+224|0,2)|0;f=i[114610];i[114610]=0;if((f|0)==1){break r}}if(c>>>0<p>>>0){continue}}break}c=i[b+8>>2];i[114610]=0;i[d+192>>2]=c;c=C(651,d+308|0,d+192|0)|0;f=i[114610];i[114610]=0;if((f|0)==1){break r}i[d+308>>2]=i[c>>2];Md(m);hb(d+224|0)}e=e+1|0;if(e>>>0<k[d+188>>1]){continue}break}}_a:{$a:{c=i[d+308>>2];if(!c){break $a}i[114610]=0;C(256,b|0,c|0)|0;c=i[114610];i[114610]=0;if((c|0)==1){break s}if(!K){break $a}while(1){ab:{i[114610]=0;c=C(258,b|0,4)|0;e=i[114610];i[114610]=0;if((e|0)==1){break ab}if(!c){break $a}i[114610]=0;c=C(621,b|0,14016)|0;e=i[114610];i[114610]=0;if((e|0)==1){break ab}bb:{if(!c){i[114610]=0;c=C(621,b|0,14021)|0;e=i[114610];i[114610]=0;if((e|0)==1){break ab}if(!c){break bb}}i[114610]=0;c=F(390,b|0)|0;e=i[114610];i[114610]=0;if((e|0)==1){break _a}tg(b,8);if(c&-2139062144){break bb}if(c&1616928864){break $a}}i[114610]=0;c=F(357,b|0)|0;e=i[114610];i[114610]=0;if((e|0)==1){break ab}i[114610]=0;C(338,b|0,c|0)|0;c=i[114610];i[114610]=0;if((c|0)!=1){continue}}break}f=B()|0;A()|0;break j}i[114610]=0;c=C(656,a|0,b|0)|0;e=i[114610];i[114610]=0;if((e|0)==1){break s}c=c|j[d+415|0];g[d+415|0]=c;if(!(!c|M)){Rs(a+1074308|0);i[a+1074368>>2]=0}i[114610]=0;J(657,a|0,b|0,0,d+415|0);c=i[114610];i[114610]=0;if((c|0)==1){break s}i[114610]=0;u=a+484344|0;D(401,u|0,k[d+188>>1]);c=i[114610];i[114610]=0;if((c|0)==1){break s}h[d+156>>1]=0;if(!k[d+188>>1]){break T}f=0;while(1){cb:{db:{c=vb(t,f&65535);eb:{if(j[c|0]|j[c+1|0]<<8|(j[c+2|0]<<16|j[c+3|0]<<24)){c=vb(t,k[d+156>>1]);c=j[c|0]|j[c+1|0]<<8|(j[c+2|0]<<16|j[c+3|0]<<24);i[114610]=0;c=C(256,b|0,c|0)|0;e=i[114610];i[114610]=0;if((e|0)==1){break eb}if(c){break db}}i[114610]=0;c=I(402,u|0,k[d+156>>1],64)|0;e=i[114610];i[114610]=0;if((e|0)==1){break eb}if(!c){i[114610]=0;D(509,d+208|0,14026);c=i[114610];i[114610]=0;fb:{gb:{hb:{ib:{jb:{if((c|0)!=1){i[114610]=0;G(658,d+112|0,d+208|0,d+156|0);c=i[114610];i[114610]=0;if((c|0)==1){break jb}i[114610]=0;c=C(653,d+224|0,d+112|0)|0;e=i[114610];i[114610]=0;if((e|0)==1){break ib}i[114610]=0;D(627,a|0,c|0);e=i[114610];i[114610]=0;if((e|0)==1){break hb}eb(c);eb(d+112|0);ob(d+208|0);break T}f=B()|0;A()|0;break j}f=B()|0;A()|0;break fb}f=B()|0;A()|0;break gb}f=B()|0;A()|0;eb(c)}eb(d+112|0)}ob(d+208|0);break j}c=Fb(u,k[d+156>>1]);i[114610]=0;D(659,c|0,H|0);c=i[114610];i[114610]=0;if((c|0)!=1){break cb}}f=B()|0;A()|0;break j}i[114610]=0;c=F(357,b|0)|0;e=i[114610];i[114610]=0;kb:{lb:{if((e|0)!=1){i[114610]=0;v=F(357,b|0)|0;e=i[114610];i[114610]=0;if((e|0)==1){break lb}i[114610]=0;e=C(338,b|0,4)|0;f=i[114610];i[114610]=0;if((f|0)==1){break lb}if(!e){break cb}i[114610]=0;e=I(402,u|0,k[d+156>>1],v|0)|0;f=i[114610];i[114610]=0;if((f|0)==1){break lb}if(e){break kb}break cb}f=B()|0;A()|0;break j}f=B()|0;A()|0;break j}i[114610]=0;G(341,d+224|0,b|0,c|0);c=i[114610];i[114610]=0;if((c|0)!=1){c=Fb(u,k[d+156>>1]);i[114610]=0;D(659,c|0,H|0);c=i[114610];i[114610]=0;mb:{if((c|0)!=1){c=k[a+480188>>1];i[114610]=0;n=C(654,d+208|0,c|0)|0;c=i[114610];i[114610]=0;if((c|0)!=1){c=k[a+480188>>1];Tg(d+176|0);i[114610]=0;q=I(660,d+192|0,c|0,d+176|0)|0;c=i[114610];i[114610]=0;nb:{if((c|0)!=1){O=d,P=Jb(Fb(u,k[d+156>>1])),i[O+144>>2]=P;s=0;ob:{if(!v){break ob}while(1){i[114610]=0;c=C(258,d+224|0,1)|0;e=i[114610];i[114610]=0;pb:{if((e|0)!=1){qb:{if(!c){break ob}i[114610]=0;c=F(387,d+224|0)|0;e=i[114610];i[114610]=0;rb:{if((e|0)!=1){c=c<<24>>24;if(c){break rb}vQ(d+144|0,k[a+480188>>1]);s=s+1|0;break pb}break qb}sb:{e=c&127;p=e?e+ -1&65535:0;if(p>>>0<rc(n)>>>0){break sb}i[114610]=0;g[d+176|0]=0;e=p+1|0;G(655,n|0,e|0,d+176|0);f=i[114610];i[114610]=0;if((f|0)==1){break qb}Tg(d+176|0);i[114610]=0;G(661,q|0,e|0,d+176|0);e=i[114610];i[114610]=0;if((e|0)!=1){break sb}break qb}if((c|0)<=-1){i[114610]=0;c=F(387,d+224|0)|0;e=i[114610];i[114610]=0;if((e|0)==1){break qb}O=dc(n,p),P=c,g[O|0]=P}Tg(d+176|0);e=d+176|0;if(p>>>0<k[a+480188>>1]){e=uc(d+144|0,p)}if(j[dc(n,p)|0]&16){O=e,P=j[uc(q,p)|0],g[O|0]=P}if(j[dc(n,p)|0]&32){O=e,P=j[uc(q,p)+1|0],g[O+1|0]=P}if(j[dc(n,p)|0]&64){O=e,P=j[uc(q,p)+2|0],g[O+2|0]=P;O=e,P=j[uc(q,p)+4|0],g[O+4|0]=P}if(g[dc(n,p)|0]<=-1){O=e,P=j[uc(q,p)+3|0],g[O+3|0]=P;O=e,P=j[uc(q,p)+5|0],g[O+5|0]=P}if(g[dc(n,p)|0]&1){i[114610]=0;c=F(387,d+224|0)|0;f=i[114610];i[114610]=0;K=e;tb:{ub:{if((f|0)!=1){c=c+(((c^-1)&128)>>>7|0)|0;if(!(i[a+480180>>2]&16777216)){break ub}f=c;break tb}break qb}f=253;if((c+ -121&255)>>>0<132){break tb}f=(c&255)==253?0:c}g[K|0]=f;O=uc(q,p),P=f,g[O|0]=P}if(j[dc(n,p)|0]&2){i[114610]=0;c=F(387,d+224|0)|0;f=i[114610];i[114610]=0;if((f|0)==1){break qb}g[e+1|0]=c;O=uc(q,p),P=c,g[O+1|0]=P}if(j[dc(n,p)|0]&4){i[114610]=0;c=F(387,d+224|0)|0;f=i[114610];i[114610]=0;vb:{wb:{if((f|0)!=1){if(c>>>0>64){break wb}g[e+4|0]=c;g[e+2|0]=1;break vb}break qb}if(!(c<<24>>24>-1|c>>>0>192)){g[e+2|0]=2;g[e+4|0]=c^128;break vb}if(c>>>0<=74){g[e+2|0]=5;g[e+4|0]=c+ -65;break vb}if(c>>>0<=84){g[e+2|0]=6;g[e+4|0]=c+ -75;break vb}if(c>>>0<=94){g[e+2|0]=3;g[e+4|0]=c+ -85;break vb}if(c>>>0<=104){g[e+2|0]=4;g[e+4|0]=c+ -95;break vb}if(c>>>0<=114){g[e+2|0]=13;g[e+4|0]=c+ -105;break vb}if(c>>>0<=124){g[e+2|0]=12;g[e+4|0]=c+ -115;break vb}f=c+63|0;if((f&255)>>>0<=9){g[e+4|0]=f;g[e+2|0]=11;break vb}f=c+53|0;m=f&255;if(m>>>0<=9){g[e+4|0]=f;g[e+2|0]=8;if(!m|!i[a+1074304>>2]|l[a+1074304>>2]>18285140){break vb}g[e+2|0]=7;break vb}c=c+33|0;if((c&255)>>>0>9){break vb}g[e+4|0]=c;g[e+2|0]=15}c=j[e+2|0];O=uc(q,p),P=c,g[O+2|0]=P;c=j[e+4|0];O=uc(q,p),P=c,g[O+4|0]=P}if(!(j[dc(n,p)|0]&8)){break pb}i[114610]=0;D(472,d+104|0,d+224|0);c=i[114610];i[114610]=0;if((c|0)!=1){xb:{c=Nc(d+104|0);g[e+3|0]=j[d+104|0];g[e+5|0]=j[c|0];i[114610]=0;D(662,e|0,1);c=i[114610];i[114610]=0;if((c|0)==1){break xb}c=j[e+3|0];O=uc(q,p),P=c,g[O+3|0]=P;c=j[e+5|0];O=uc(q,p),P=c,g[O+5|0]=P;break pb}}}}f=B()|0;A()|0;kl(q);break nb}if(s>>>0<v>>>0){continue}break}}kl(q);Md(n);hb(d+224|0);break cb}f=B()|0;A()|0}Md(n);break mb}f=B()|0;A()|0;break mb}f=B()|0;A()|0}hb(d+224|0);break j}f=B()|0;A()|0;break j}f=k[d+156>>1]+1|0;h[d+156>>1]=f;if((f&65535)>>>0<k[d+188>>1]){continue}break}break T}f=B()|0;A()|0;break j}f=B()|0;A()|0;break j}f=B()|0;A()|0;break j}f=B()|0;A()|0;break j}f=B()|0;A()|0;break j}f=B()|0;A()|0;break j}f=B()|0;A()|0;break j}f=B()|0;A()|0;break j}f=B()|0;A()|0;break j}f=B()|0;A()|0;break i}f=B()|0;A()|0;break g}f=B()|0;A()|0;break g}f=B()|0;A()|0;break g}f=B()|0;A()|0;break g}f=B()|0;A()|0;break g}f=B()|0;A()|0;break g}c=a+1074304|0;yb:{zb:{if(!i[a+1074304>>2]){Ab:{if((j[d+456|0]|j[d+457|0]<<8)==2184){i[c>>2]=18284544;f=18284544;break Ab}f=i[c>>2]}if(!f){break zb}}if(!Cc(r)){break zb}i[114610]=0;e=C(2,d+208|0,14078)|0;f=i[114610];i[114610]=0;Bb:{Cb:{Db:{Eb:{Fb:{Gb:{if((f|0)!=1){i[114610]=0;D(242,d+192|0,c|0);f=i[114610];i[114610]=0;if((f|0)==1){break Gb}i[114610]=0;G(3,d+224|0,e|0,d+192|0);f=i[114610];i[114610]=0;if((f|0)==1){break Fb}mb(r,d+224|0);eb(d+224|0);eb(d+192|0);eb(e);if(i[d+476>>2]==1414548815|((j[d+456|0]|j[d+457|0]<<8)&61440)!=20480){break Bb}i[114610]=0;c=C(2,d+224|0,14087)|0;e=i[114610];i[114610]=0;if((e|0)==1){break Db}i[114610]=0;C(192,r|0,c|0)|0;e=i[114610];i[114610]=0;if((e|0)==1){break Cb}eb(c);break yb}f=B()|0;A()|0;break j}f=B()|0;A()|0;break Eb}f=B()|0;A()|0;eb(d+192|0)}eb(e);break j}f=B()|0;A()|0;break j}f=B()|0;A()|0;eb(c);break j}if(!zB(c)){break yb}i[114610]=0;c=C(2,d+224|0,14111)|0;e=i[114610];i[114610]=0;Hb:{if((e|0)!=1){i[114610]=0;C(192,r|0,c|0)|0;e=i[114610];i[114610]=0;if((e|0)==1){break Hb}eb(c);break yb}f=B()|0;A()|0;break j}f=B()|0;A()|0;eb(c);break j}Ib:{switch((j[d+456|0]|j[d+457|0]<<8)>>>12|0){case 0:if(M){i[114610]=0;c=C(2,d+224|0,14125)|0;e=i[114610];i[114610]=0;if((e|0)!=1){mb(r,c);eb(c);break yb}f=B()|0;A()|0;break j}Jb:{if((j[d+456|0]|j[d+457|0]<<8)!=532|(j[d+458|0]|j[d+459|0]<<8)!=512|(j[d+462|0]|j[d+463|0]<<8|(j[d+460|0]|j[d+461|0]<<8)!=9)){break Jb}if(j[d+447|0]|j[d+446|0]|(j[d+450|0]|j[d+451|0]<<8|((j[d+454|0]|j[d+455|0]<<8)+1|0)!=(j[d+448|0]|j[d+449|0]<<8))){break Jb}if(j[d+464|0]!=128|j[d+465|0]!=100|(j[d+466|0]!=1|j[d+468|0]!=128)){break Jb}if(j[d+469|0]|(j[d+470|0]|j[d+471|0]<<8)|(j[d+472|0]|j[d+473|0]<<8|(j[d+474|0]<<16|j[d+475|0]<<24)|(j[d+476|0]|j[d+477|0]<<8|(j[d+478|0]<<16|j[d+479|0]<<24)))){break Jb}i[114610]=0;c=C(2,d+224|0,14137)|0;e=i[114610];i[114610]=0;if((e|0)!=1){mb(r,c);eb(c);break yb}f=B()|0;A()|0;break j}Kb:{if((j[d+456|0]|j[d+457|0]<<8)!=532|(j[d+458|0]|j[d+459|0]<<8)!=512|(j[d+447|0]|j[d+446|0])){break Kb}if(j[d+476|0]|j[d+477|0]<<8|(j[d+478|0]<<16|j[d+479|0]<<24)){break Kb}i[c>>2]=16777381;i[114610]=0;c=C(2,d+224|0,14156)|0;e=i[114610];i[114610]=0;if((e|0)!=1){mb(r,c);eb(c);g[d+415|0]=1;break yb}f=B()|0;A()|0;break j}if(!((j[d+456|0]|j[d+457|0]<<8)!=532|(j[d+458|0]|j[d+459|0]<<8)!=532|i[d+476>>2]!=1229080643)){i[114610]=0;c=C(2,d+224|0,14179)|0;e=i[114610];i[114610]=0;if((e|0)!=1){mb(r,c);eb(c);i[114610]=0;C(479,a+1074308|0,38)|0;c=i[114610];i[114610]=0;if((c|0)==1){break s}break yb}f=B()|0;A()|0;break j}Lb:{if((j[d+456|0]|j[d+457|0]<<8)!=532|(j[d+458|0]|j[d+459|0]<<8)!=532|(j[d+469|0]|(j[d+462|0]|j[d+463|0]<<8)>>>0>1)){break Lb}if(!k[a+480190>>1]|(j[d+476|0]|j[d+477|0]<<8|(j[d+478|0]<<16|j[d+479|0]<<24)|((j[d+460|0]|j[d+461|0]<<8)&4294)!=4)){break Lb}i[114610]=0;c=C(85,d+224|0,14192)|0;e=i[114610];i[114610]=0;Mb:{Nb:{if((e|0)!=1){i[114610]=0;e=C(663,a+484527|0,c|0)|0;f=i[114610];i[114610]=0;if((f|0)==1){break Nb}eb(c);if(!e){break Lb}i[114610]=0;c=C(2,d+224|0,14205)|0;e=i[114610];i[114610]=0;if((e|0)==1){break Mb}mb(r,c);eb(c);break yb}f=B()|0;A()|0;break j}f=B()|0;A()|0;eb(c);break j}f=B()|0;A()|0;break j}Ob:{if(j[d+456|0]|j[d+457|0]<<8){break Ob}if(!Cc(r)){break Ob}i[114610]=0;c=C(2,d+224|0,14219)|0;e=i[114610];i[114610]=0;if((e|0)!=1){mb(r,c);eb(c);break yb}f=B()|0;A()|0;break j}if((j[d+458|0]|j[d+459|0]<<8)>>>0>767){break yb}if(!Cc(r)){break yb}Pb:{Qb:{Rb:{Sb:{Tb:{Ub:{Vb:{if((j[d+458|0]|j[d+459|0]<<8)>>>0>=533){i[114610]=0;c=C(2,d+224|0,14227)|0;e=i[114610];i[114610]=0;if((e|0)!=1){mb(r,c);break Vb}f=B()|0;A()|0;break j}if((j[d+456|0]|j[d+457|0]<<8)>>>0>=533){i[114610]=0;c=C(2,d+88|0,14248)|0;e=i[114610];i[114610]=0;Wb:{Xb:{Yb:{if((e|0)!=1){i[114610]=0;D(219,d+208|0,c|0);e=i[114610];i[114610]=0;if((e|0)==1){break Yb}e=j[d+456|0]|j[d+457|0]<<8;i[114610]=0;i[d+192>>2]=e+ -532;G(245,d+224|0,d+208|0,d+192|0);e=i[114610];i[114610]=0;if((e|0)==1){break Xb}mb(r,d+224|0);eb(d+224|0);ob(d+208|0);break Vb}f=B()|0;A()|0;break j}f=B()|0;A()|0;break Wb}f=B()|0;A()|0;ob(d+208|0)}eb(c);break j}i[114610]=0;c=C(2,d+72|0,14272)|0;e=i[114610];i[114610]=0;if((e|0)==1){break Ub}i[114610]=0;D(219,d+208|0,c|0);e=i[114610];i[114610]=0;if((e|0)==1){break Tb}i[d+176>>2]=j[d+457|0]&15;e=j[d+456|0];i[114610]=0;i[d+144>>2]=e;D(664,d+192|0,d+144|0);e=i[114610];i[114610]=0;if((e|0)==1){break Sb}i[114610]=0;J(649,d+224|0,d+208|0,d+176|0,d+192|0);e=i[114610];i[114610]=0;if((e|0)==1){break Rb}mb(r,d+224|0);eb(d+224|0);eb(d+192|0);ob(d+208|0)}eb(c);c=a+1304500|0;if(!Uc(c)|!(j[d+476|0]|j[d+477|0]<<8|(j[d+478|0]<<16|j[d+479|0]<<24))){break yb}e=j[d+456|0]|j[d+457|0]<<8;f=j[d+476|0]|j[d+477|0]<<8|(j[d+478|0]<<16|j[d+479|0]<<24);i[114610]=0;e=C(665,e|0,f|0)|0;f=i[114610];i[114610]=0;if((f|0)==1){break v}f=mp(d+224|0);i[f+44>>2]=e;i[114610]=0;D(666,c|0,f|0);c=i[114610];i[114610]=0;if((c|0)!=1){break yb}f=B()|0;A()|0;break j}f=B()|0;A()|0;break j}f=B()|0;A()|0;break Pb}f=B()|0;A()|0;break Qb}f=B()|0;A()|0;eb(d+192|0)}ob(d+208|0)}eb(c);break j;case 1:c=j[d+456|0]|j[d+457|0]<<8;e=j[d+476|0]|j[d+477|0]<<8|(j[d+478|0]<<16|j[d+479|0]<<24);i[114610]=0;G(667,d+224|0,c|0,e|0);c=i[114610];i[114610]=0;Zb:{if((c|0)!=1){mb(r,d+224|0);eb(d+224|0);if(6092<=(j[d+456|0]|j[d+457|0]<<8)){break Zb}i[114610]=0;C(479,a+1074308|0,7)|0;c=i[114610];i[114610]=0;if((c|0)!=1){break Zb}break s}f=B()|0;A()|0;break j}if(6562<=(j[d+456|0]|j[d+457|0]<<8)){break yb}i[114610]=0;C(479,a+1074308|0,38)|0;c=i[114610];i[114610]=0;if((c|0)==1){break s}break yb;case 4:i[114610]=0;c=C(2,d+56|0,14294)|0;e=i[114610];i[114610]=0;_b:{$b:{ac:{bc:{cc:{if((e|0)!=1){i[114610]=0;D(219,d+208|0,c|0);e=i[114610];i[114610]=0;if((e|0)==1){break cc}i[d+176>>2]=j[d+457|0]&15;e=j[d+456|0];i[114610]=0;i[d+144>>2]=e;D(664,d+192|0,d+144|0);e=i[114610];i[114610]=0;if((e|0)==1){break bc}i[114610]=0;J(649,d+224|0,d+208|0,d+176|0,d+192|0);e=i[114610];i[114610]=0;if((e|0)==1){break ac}mb(r,d+224|0);eb(d+224|0);eb(d+192|0);ob(d+208|0);eb(c);break yb}f=B()|0;A()|0;break j}f=B()|0;A()|0;break _b}f=B()|0;A()|0;break $b}f=B()|0;A()|0;eb(d+192|0)}ob(d+208|0)}eb(c);break j;case 6:i[114610]=0;c=C(2,d+224|0,14125)|0;e=i[114610];i[114610]=0;if((e|0)!=1){mb(r,c);eb(c);break yb}f=B()|0;A()|0;break j;case 7:if(!((j[d+456|0]|j[d+457|0]<<8)!=32767|(j[d+458|0]|j[d+459|0]<<8)!=533)){i[114610]=0;c=C(2,d+224|0,14305)|0;e=i[114610];i[114610]=0;if((e|0)!=1){mb(r,c);eb(c);break yb}f=B()|0;A()|0;break j}i[114610]=0;c=C(2,d+40|0,14314)|0;e=i[114610];i[114610]=0;dc:{ec:{fc:{if((e|0)!=1){i[114610]=0;D(219,d+208|0,c|0);e=i[114610];i[114610]=0;if((e|0)==1){break fc}i[d+192>>2]=j[d+457|0]&15;i[d+176>>2]=(j[d+456|0]|j[d+457|0]<<8)>>>4&15;e=j[d+456|0]|j[d+457|0]<<8;i[114610]=0;i[d+144>>2]=e&15;T(239,d+224|0,d+208|0,d+192|0,d+176|0,d+144|0);e=i[114610];i[114610]=0;if((e|0)==1){break ec}mb(r,d+224|0);eb(d+224|0);ob(d+208|0);eb(c);break yb}f=B()|0;A()|0;break j}f=B()|0;A()|0;break dc}f=B()|0;A()|0;ob(d+208|0)}eb(c);break j;case 13:break Ib;default:break yb}}i[114610]=0;c=C(2,d+224|0,14329)|0;e=i[114610];i[114610]=0;if((e|0)==1){break u}mb(r,c);eb(c)}gc:{if(i[a+480180>>2]!=16777216|(j[d+456|0]|j[d+457|0]<<8)>>>0<2186){break gc}i[114610]=0;c=C(256,b|0,z|0)|0;e=i[114610];i[114610]=0;if((e|0)==1){break s}if(!c){break gc}c=j[d+456|0]|j[d+457|0]<<8;i[114610]=0;G(668,a|0,b|0,c|0);b=i[114610];i[114610]=0;if((b|0)==1){break s}}c=i[a+480180>>2];hc:{if((c|0)==16777216){i[114610]=0;C(2,d+224|0,14336)|0;b=i[114610];i[114610]=0;if((b|0)!=1){break hc}f=B()|0;A()|0;break j}i[114610]=0;b=C(2,d+24|0,14272)|0;e=i[114610];i[114610]=0;if((e|0)==1){break B}i[114610]=0;D(219,d+208|0,b|0);e=i[114610];i[114610]=0;if((e|0)==1){break A}i[d+176>>2]=j[d+459|0];e=j[d+458|0];i[114610]=0;i[d+144>>2]=e;D(664,d+192|0,d+144|0);e=i[114610];i[114610]=0;if((e|0)==1){break z}i[114610]=0;J(649,d+224|0,d+208|0,d+176|0,d+192|0);e=i[114610];i[114610]=0;if((e|0)==1){break y}}mb(a+1304436|0,d+224|0);eb(d+224|0);if((c|0)!=16777216){eb(d+192|0);ob(d+208|0);eb(d+24|0)}ic:{if(i[a+480180>>2]==16777216){i[114610]=0;C(2,d+224|0,14349)|0;b=i[114610];i[114610]=0;if((b|0)!=1){break ic}break t}i[114610]=0;C(2,d+224|0,14354)|0;b=i[114610];i[114610]=0;if((b|0)==1){break t}}mb(a+1304448|0,d+224|0);eb(d+224|0);mb(a+1304460|0,r);i[a+1304496>>2]=i[a+1074304>>2]?7:4;hb(d+312|0);hb(H);f=1}gi(t);gi(w);gi(y);break d}f=B()|0;A()|0;break j}f=B()|0;A()|0;break w}f=B()|0;A()|0;break x}f=B()|0;A()|0;eb(d+192|0)}ob(d+208|0)}eb(b);break j}f=B()|0;A()|0;break j}f=B()|0;A()|0;break j}f=B()|0;A()|0;break j}f=B()|0;A()|0;break j}f=B()|0;A()|0;Md(m);break p}f=B()|0;A()|0}hb(d+224|0);break j}f=B()|0;A()|0;break j}f=B()|0;A()|0;break j}f=B()|0;A()|0;break j}f=B()|0;A()|0;break j}f=B()|0;A()|0}hb(d+312|0)}hb(H);break g}f=B()|0;A()|0}gi(t);gi(w);gi(y);break a}f=B()|0;A()|0;break a}f=B()|0;A()|0;break a}eb(r)}Xa=d+608|0;return f|0}f=B()|0;A()|0}eb(r);E(f|0);x()}function DCa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,m=0,n=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,K=0,M=0,O=0,P=0,Q=0,R=0,U=0,V=0,W=0,X=0,Z=0;e=Xa-1584|0;Xa=e;pc(b);a:{b:{if(!Se(b,e+1576|0)){break b}if(!YO(e+1576|0)){break b}if(!c){f=1;break b}g[e+1575|0]=j[e+1576|3];d=e+1576|4;m=j[d|0]|j[d+1|0]<<8|(j[d+2|0]<<16|j[d+3|0]<<24);d=-1;if(j[e+1575|0]>=5){d=Cf(b);if(!wb(b,d)){break b}}Q=cz(e+1560|0,m);n=i[Q>>2];i[114610]=0;m=I(835,b|0,n|0,m|0)|0;n=i[114610];i[114610]=0;c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{if((n|0)==1){break y}if(!m){break u}if(j[e+1575|0]>=5){i[114610]=0;C(256,b|0,d+12|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break y}}i[114610]=0;D(447,a|0,0);d=i[114610];i[114610]=0;if((d|0)==1){break y}i[114610]=0;L(476,a|0);d=i[114610];i[114610]=0;if((d|0)==1){break y}i[114610]=0;D(836,e+1536|0,Q|0);m=i[114610];i[114610]=0;d=a;z:{A:{B:{C:{if((m|0)==1){break C}i[114610]=0;r=I(837,e+1544|0,e+1536|0,0)|0;m=i[114610];i[114610]=0;if((m|0)==1){break C}i[114610]=0;I(600,r|0,a+1304400|0,-1)|0;m=i[114610];i[114610]=0;if((m|0)==1){break B}i[114610]=0;I(600,r|0,a+1304424|0,-1)|0;m=i[114610];i[114610]=0;if((m|0)==1){break B}i[114610]=0;m=C(838,r|0,e+1112|0)|0;n=i[114610];i[114610]=0;if((n|0)==1){break e}if(!m|!j[e+1112|0]|g[e+1112|0]<0){break v}m=e+1121|0;if((j[m|0]|j[m+1|0]<<8)>>>0>255){break v}n=e+1123|0;if((j[n|0]|j[n+1|0]<<8)>>>0>3999){break v}h[a+480188>>1]=j[e+1112|0];q=a+484360|0;p=e+1112|3;Fe(Db(q),j[p|0]|j[p+1|0]<<8);h[a+480192>>1]=j[m|0]|j[m+1|0]<<8;h[a+480190>>1]=j[n|0]|j[n+1|0]<<8;m=e+1125|0;if(j[m|0]){break A}m=6;break z}d=B()|0;A()|0;break c}d=B()|0;A()|0;break d}m=j[m|0]}i[d+480196>>2]=m;d=a;n=e+1126|0;m=125;D:{if(!j[n|0]){break D}m=j[n|0]}i[d+480204>>2]=o(m,1e4);v=e+1127|0;E:{if(g[v+1|0]&1){i[114610]=0;D(624,a|0,32);d=i[114610];i[114610]=0;if((d|0)!=1){break E}break e}if(j[v|0]&2){i[114610]=0;D(624,a|0,2);d=i[114610];i[114610]=0;if((d|0)==1){break e}break E}if(j[v|0]&128){i[114610]=0;D(624,a|0,1);d=i[114610];i[114610]=0;if((d|0)==1){break e}break E}if(j[v|0]&8){i[114610]=0;D(624,a|0,16);d=i[114610];i[114610]=0;if((d|0)==1){break e}break E}i[114610]=0;D(624,a|0,4);d=i[114610];i[114610]=0;if((d|0)==1){break e}}if(g[v|0]&1){i[a+480208>>2]=i[a+480208>>2]|16}if(!(!(j[v|0]&16)|i[a+480180>>2]!=2)){i[a+480208>>2]=i[a+480208>>2]|65536}if(!(!(j[v|0]&4)|i[a+480180>>2]!=2)){i[a+480208>>2]=i[a+480208>>2]|2}if(!(j[v+1|0]&8|i[a+480180>>2]!=32)){i[a+480208>>2]=i[a+480208>>2]|4}if(!(j[v+1|0]&4|i[a+480180>>2]!=32)){i[a+480208>>2]=i[a+480208>>2]|8}if(j[v+2|0]&32){i[a+480208>>2]=i[a+480208>>2]|32768}if(j[v+2|0]&8){i[114610]=0;I(478,a+1074308|0,5,1)|0;d=i[114610];i[114610]=0;if((d|0)==1){break e}}F:{d=i[a+480180>>2];G:{if((d|0)!=2){if((d|0)!=32){break G}d=j[e+1131|0];i[114610]=0;g[e+208|0]=d;g[e+136|0]=128;d=C(391,e+208|0,e+136|0)|0;m=i[114610];i[114610]=0;if((m|0)==1){break x}i[a+480200>>2]=j[d|0]<<1;break G}d=j[e+1131|0];i[114610]=0;g[e+208|0]=d;g[e+136|0]=64;d=C(391,e+208|0,e+136|0)|0;m=i[114610];i[114610]=0;if((m|0)==1){break F}i[a+480200>>2]=j[d|0]<<2}V=a+480188|0;n=e+1133|0;m=g[n|0];d=a;if(g[n|0]<=-1){m=m+52|0}else{U=tv(+(m|0)*.15500000000000003);H:{if(U<4294967296&U>=0){m=~~U>>>0;break H}m=0}m=m+51|0}i[d+480228>>2]=m;i[114610]=0;h[e+208>>1]=64;d=C(477,V|0,e+208|0)|0;m=i[114610];i[114610]=0;if((m|0)!=1){I:{m=k[d>>1];if(m){while(1){d=i[a+480180>>2];if((d|0)==32){d=j[(e+f|0)+1134|0];i[114610]=0;g[e+208|0]=d;g[e+136|0]=64;d=C(391,e+208|0,e+136|0)|0;n=i[114610];i[114610]=0;if((n|0)==1){break I}h[((f<<5)+a|0)+480286>>1]=j[d|0];d=i[a+480180>>2]}J:{if((d|0)==4){break J}d=(e+f|0)+1198|0;if(j[d|0]==127){i[((f<<5)+a|0)+480280>>2]=256;break J}if(j[d|0]==255){h[((f<<5)+a|0)+480284>>1]=256;break J}h[((f<<5)+a|0)+480284>>1]=j[d|0]}f=f+1|0;if((m|0)!=(f|0)){continue}break}}d=0;f=0;p=0;while(1){f=j[(e+p|0)+1262|0]!=0|f;p=p+1|0;if((p|0)!=16){continue}break}while(1){f=j[((d<<1)+e|0)+1279|0]!=0|f;d=d+1|0;if((d|0)!=128){continue}break}if(f&1){f=0;while(1){K:{d=(e+f|0)+1262|0;if(j[d|0]){i[114610]=0;D(509,e+136|0,15162);m=i[114610];i[114610]=0;L:{M:{N:{O:{P:{if((m|0)!=1){d=j[d|0];i[114610]=0;i[e+160>>2]=d+ -1;D(839,e+1096|0,e+160|0);d=i[114610];i[114610]=0;if((d|0)==1){break P}i[114610]=0;G(511,e+208|0,e+136|0,e+1096|0);d=i[114610];i[114610]=0;if((d|0)==1){break O}i[114610]=0;D(512,e+1080|0,((f<<5)+a|0)+901692|0);d=i[114610];i[114610]=0;if((d|0)==1){break N}i[114610]=0;C(470,e+1080|0,e+208|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break N}eb(e+208|0);eb(e+1096|0);ob(e+136|0);break K}d=B()|0;A()|0;break d}d=B()|0;A()|0;break L}d=B()|0;A()|0;break M}d=B()|0;A()|0;eb(e+208|0)}eb(e+1096|0)}ob(e+136|0);break d}i[114610]=0;m=C(85,e+208|0,15170)|0;d=i[114610];i[114610]=0;Q:{if((d|0)!=1){i[114610]=0;D(512,e+136|0,((f<<5)+a|0)+901692|0);d=i[114610];i[114610]=0;if((d|0)==1){break Q}i[114610]=0;C(470,e+136|0,m|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break Q}eb(m);break K}d=B()|0;A()|0;break d}d=B()|0;A()|0;eb(m);break d}f=f+1|0;if((f|0)!=16){continue}break}f=0;while(1){d=(e+1112|0)+(f<<1)|0;m=d;R:{if(j[d+167|0]){i[114610]=0;D(509,e+136|0,15171);n=i[114610];i[114610]=0;S:{T:{U:{V:{W:{X:{Y:{if((n|0)!=1){m=j[m+167|0];i[114610]=0;i[e+112>>2]=m+ -1;D(839,e+1096|0,e+112|0);m=i[114610];i[114610]=0;if((m|0)==1){break Y}d=j[d+166|0];i[114610]=0;g[e+1064|0]=d;D(840,e+1080|0,e+1064|0);d=i[114610];i[114610]=0;if((d|0)==1){break X}i[114610]=0;J(841,e+208|0,e+136|0,e+1096|0,e+1080|0);d=i[114610];i[114610]=0;if((d|0)==1){break W}i[114610]=0;D(512,e+160|0,((f<<5)+a|0)+902204|0);d=i[114610];i[114610]=0;if((d|0)==1){break V}i[114610]=0;C(470,e+160|0,e+208|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break V}eb(e+208|0);eb(e+1080|0);eb(e+1096|0);ob(e+136|0);break R}d=B()|0;A()|0;break d}d=B()|0;A()|0;break S}d=B()|0;A()|0;break T}d=B()|0;A()|0;break U}d=B()|0;A()|0;eb(e+208|0)}eb(e+1080|0)}eb(e+1096|0)}ob(e+136|0);break d}i[114610]=0;m=C(85,e+208|0,15170)|0;d=i[114610];i[114610]=0;Z:{if((d|0)!=1){i[114610]=0;D(512,e+136|0,((f<<5)+a|0)+902204|0);d=i[114610];i[114610]=0;if((d|0)==1){break Z}i[114610]=0;C(470,e+136|0,m|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break Z}eb(m);break R}d=B()|0;A()|0;break d}d=B()|0;A()|0;eb(m);break d}f=f+1|0;if((f|0)!=128){continue}break}}d=Db(q);m=e+1112|1;m=j[m|0]|j[m+1|0]<<8;i[114610]=0;S(584,d|0,r|0,m|0,255,254)|0;d=i[114610];i[114610]=0;_:{$:{aa:{ba:{ca:{da:{if((d|0)!=1){m=e+1112|5;d=j[m|0]|j[m+1|0]<<8;n=j[e+1112|0];i[114610]=0;G(341,e+1096|0,r|0,o(d,n)<<1);d=i[114610];i[114610]=0;if((d|0)==1){break da}d=j[m|0]|j[m+1|0]<<8;i[114610]=0;G(341,e+1080|0,r|0,d<<1);d=i[114610];i[114610]=0;if((d|0)==1){break ca}d=e+1112|7;d=j[d|0]|j[d+1|0]<<8;i[114610]=0;P=C(395,e+1064|0,d|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break ba}X=e,Z=Jb(P),i[X+136>>2]=Z;X=e,Z=Kb(P),i[X+160>>2]=Z;if(pb(e+136|0,e+160|0)){while(1){d=i[e+136>>2];i[114610]=0;n=F(390,r|0)|0;f=i[114610];i[114610]=0;if((f|0)==1){break aa}i[114610]=0;G(341,e+208|0,r|0,n|0);n=i[114610];i[114610]=0;if((n|0)==1){break $}Cd(d,e+208|0);hb(e+208|0);vf(e+136|0);if(pb(e+136|0,e+160|0)){continue}break}}d=i[a+480180>>2];q=1;s=c&1;if(!s){break _}n=j[m|0]|j[m+1|0]<<8;i[114610]=0;D(401,a+484344|0,n|0);n=i[114610];i[114610]=0;if((n|0)!=1){break _}d=B()|0;A()|0;break h}d=B()|0;A()|0;break d}d=B()|0;A()|0;break d}d=B()|0;A()|0;break f}d=B()|0;A()|0;break g}d=B()|0;A()|0;break h}d=B()|0;A()|0;break h}ea:{fa:{ga:{ha:{ia:{ja:{if(j[m|0]|j[m+1|0]<<8){y=(d|0)==16?14:(d|0)==32?1:13;z=a+484344|0;while(1){i[114610]=0;d=F(357,e+1080|0)|0;n=i[114610];i[114610]=0;if((n|0)==1){break ea}i[e+136>>2]=d;ka:{if(!s){break ka}i[114610]=0;d=I(402,z|0,u&65535,d|0)|0;n=i[114610];i[114610]=0;if((n|0)==1){break ea}if(!d){break ka}w=0;if(!j[e+1112|0]){break ka}while(1){i[114610]=0;d=F(357,e+1096|0)|0;n=i[114610];i[114610]=0;if((n|0)==1){break fa}la:{if(Wc(P)>>>0<=d>>>0){break la}M=_b(P,d);pc(M);d=Fb(z,u);i[114610]=0;f=I(471,d|0,0,w&65535)|0;d=i[114610];i[114610]=0;if((d|0)==1){break i}n=0;if(!i[e+136>>2]){break la}while(1){i[114610]=0;K=F(387,M|0)|0;d=i[114610];i[114610]=0;ma:{na:{if((d|0)!=1){if(!K){break la}Tg(e+208|0);p=0;O=K&15;if(O){break na}break ma}d=B()|0;A()|0;break h}while(1){oa:{i[114610]=0;C(842,M|0,e+160|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break oa}pa:{qa:{ra:{sa:{ta:{ua:{va:{wa:{xa:{ya:{za:{Aa:{Ba:{Ca:{Da:{Ea:{Fa:{Ga:{Ha:{Ia:{Ja:{d=j[e+160|0];switch(d+ -1|0){case 2:case 3:case 4:case 7:case 8:case 9:case 11:case 12:case 13:case 16:case 18:case 21:case 22:case 23:case 24:case 25:case 27:case 32:break ra;case 33:break va;case 30:case 31:break wa;case 29:break xa;case 28:break ya;case 26:break za;case 19:case 20:break Aa;case 17:break Ba;case 15:break Ca;case 14:break Da;case 10:break Ea;case 6:break Fa;case 5:break Ga;case 1:break Ha;case 0:break Ia;default:break Ja}}switch(d+ -48|0){case 4:break sa;case 1:case 2:break ta;case 0:break ua;default:break ra}}d=j[e+161|0];g[e+208|0]=d;Ka:{if(d>>>0<=119){g[e+208|0]=d+y;break Ka}La:{switch(d+ -254|0){case 1:g[e+208|0]=255;break Ka;case 0:g[e+208|0]=254;break Ka;default:break La}}g[e+208|0]=253}i[114610]=0;d=F(614,e+208|0)|0;t=i[114610];i[114610]=0;if((t|0)==1){break oa}q=d&q;break pa}g[e+209|0]=j[e+161|0]+1;break pa}Ma:{if(j[e+210|0]){break Ma}d=i[a+480180>>2];if((d|0)!=32){if((d|0)!=4){break Ma}d=j[e+161|0];if(d&15){break Ma}g[e+210|0]=11;g[e+212|0]=d>>>4;break pa}d=0;t=j[e+161|0];while(1){if((t|0)==j[d+20816|0]){g[e+212|0]=d;g[e+210|0]=11;break pa}d=d+1|0;if((d|0)!=10){continue}break}}g[e+211|0]=4;g[e+213|0]=j[e+161|0];break pa}d=j[e+161|0];if(!(j[e+210|0]|d>>>0>9|i[a+480180>>2]!=32)){g[e+212|0]=d;g[e+210|0]=8;break pa}g[e+213|0]=d;g[e+211|0]=5;break pa}Na:{if(j[e+210|0]){break Na}Oa:{d=i[a+480180>>2];if((d|0)!=4){if((d|0)!=32){break Na}d=j[e+161|0];if((d|0)!=255){break Oa}g[e+212|0]=64;g[e+210|0]=2;break pa}d=j[e+161|0];if(d&15){break Na}break qa}if(!(d&3)){break qa}}g[e+211|0]=9;g[e+213|0]=j[e+161|0];break pa}d=j[e+161|0];if(!(j[e+210|0]|d>>>0>64|i[a+480180>>2]==1)){g[e+212|0]=d;g[e+210|0]=1;break pa}g[e+213|0]=d;g[e+211|0]=13;break pa}g[e+211|0]=14;d=j[e+161|0];g[e+213|0]=d;if(i[a+480180>>2]==32){break pa}g[e+213|0]=o((d&240)>>>4|0,10)+(d&15);break pa}d=j[e+161|0];g[e+213|0]=d;if(d>>>0<=31){g[e+211|0]=16;break pa}g[e+211|0]=17;break pa}t=j[e+161|0];if(t>>>0>=16){g[e+212|0]=t>>>4;g[e+210|0]=(d|0)==20?3:5;break pa}g[e+212|0]=t;g[e+210|0]=(d|0)==20?4:6;break pa}d=j[e+161|0];if(d>>>0>=16){g[e+210|0]=10;g[e+212|0]=d>>>4;break pa}g[e+212|0]=d;g[e+210|0]=9;break pa}g[e+211|0]=28;g[e+213|0]=j[e+161|0]|16;break pa}g[e+211|0]=28;g[e+213|0]=j[e+161|0]|32;break pa}g[e+212|0]=j[e+161|0];g[e+210|0]=j[d+15184|0];break pa}g[e+213|0]=j[e+161|0];d=j[e+211|0];g[e+211|0]=(d|0)==4?6:(d|0)==5?7:11;break pa}d=j[e+161|0];g[e+212|0]=(d>>>0)%10;if(d>>>0<=9){g[e+210|0]=5;break pa}if(d>>>0<=19){g[e+210|0]=6;break pa}if(d>>>0<=29){g[e+210|0]=3;break pa}if(d>>>0>39){break pa}g[e+210|0]=4;break pa}g[e+212|0]=j[e+161|0];g[e+210|0]=j[d+15184|0];break pa}d=j[e+161|0]+33|0;if((d&255)>>>0>9){break pa}g[e+212|0]=d;g[e+210|0]=15;break pa}if(d>>>0>55){break pa}g[e+213|0]=j[e+161|0];g[e+211|0]=j[d+15184|0];break pa}g[e+210|0]=2;g[e+212|0]=d>>>2}p=p+1|0;if((p&255)>>>0<O>>>0){continue}break ma}break}d=B()|0;A()|0;break h}i[114610]=0;i[e+160>>2]=(K>>>4|0)+n;d=C(632,e+160|0,e+136|0)|0;p=i[114610];i[114610]=0;if((p|0)==1){break ja}d=i[d>>2];if(n>>>0<d>>>0){while(1){p=i[e+208>>2];g[f|0]=p;g[f+1|0]=p>>>8;g[f+2|0]=p>>>16;g[f+3|0]=p>>>24;p=k[e+212>>1];g[f+4|0]=p;g[f+5|0]=p>>>8;f=o(j[e+1112|0],6)+f|0;n=n+1|0;if((d|0)!=(n|0)){continue}break}n=d}if(n>>>0<l[e+136>>2]){continue}break}}w=w+1|0;if((w&65535)>>>0<j[e+1112|0]){continue}break}}u=u+1|0;if(u>>>0<(j[m|0]|j[m+1|0]<<8)>>>0){continue}break}}if(!((q^1)&1|k[a+480188>>1]!=4|i[a+480180>>2]!=1)){i[a+480208>>2]=i[a+480208>>2]|8454144}if(i[a+480180>>2]!=4){break ia}p=0;break ha}d=B()|0;A()|0;break h}p=!((j[v|0]|j[v+1|0]<<8|(j[v+2|0]<<16|j[v+3|0]<<24))&512);d=0;if(i[a+480180>>2]!=4){break ga}}d=k[a+480192>>1]}i[114610]=0;K=C(843,e+1048|0,d|0)|0;d=i[114610];i[114610]=0;if((d|0)!=1){Pa:{Qa:{Ra:{if(k[a+480192>>1]){n=1;d=1;while(1){Sa:{Ta:{Ua:{if(!p){i[114610]=0;f=I(454,a|0,d&65535,0)|0;m=i[114610];i[114610]=0;if((m|0)==1){break Ua}if(f){break Ta}}while(1){i[114610]=0;m=F(387,r|0)|0;n=i[114610];i[114610]=0;if((n|0)==1){break k}if(m){continue}break}if(j[e+1575|0]>=5){while(1){i[114610]=0;m=F(387,r|0)|0;n=i[114610];i[114610]=0;if((n|0)==1){d=B()|0;A()|0;break j}if(m){continue}break}}i[114610]=0;C(338,r|0,826)|0;m=i[114610];i[114610]=0;if((m|0)!=1){break Sa}}d=B()|0;A()|0;break j}m=Ab(e+136|0);i[114610]=0;I(600,r|0,m|0,-1)|0;q=i[114610];i[114610]=0;if((q|0)==1){break Ra}i[114610]=0;C(369,f+492|0,m|0)|0;q=i[114610];i[114610]=0;if((q|0)==1){break Ra}Va:{if(j[e+1575|0]<5){break Va}i[114610]=0;I(600,r|0,m|0,-1)|0;q=i[114610];i[114610]=0;if((q|0)==1){break Ra}i[114610]=0;C(369,f+524|0,m|0)|0;q=i[114610];i[114610]=0;if((q|0)!=1){break Va}break Ra}i[114610]=0;q=C(844,r|0,e+208|0)|0;u=i[114610];i[114610]=0;if((u|0)==1){break Ra}if(!q){break Qa}q=i[a+480180>>2];i[114610]=0;G(845,e+208|0,f|0,q|0);f=i[114610];i[114610]=0;if((f|0)==1){break Ra}if(i[a+480180>>2]==4){n=vb(K,n+ -1|0);f=k[e+1010>>1]|k[e+1012>>1]<<16;g[n|0]=f;g[n+1|0]=f>>>8;g[n+2|0]=f>>>16;g[n+3|0]=f>>>24}eb(m)}d=d+1|0;n=d&65535;if(n>>>0<=k[a+480192>>1]){continue}break}}if(!p){break Pa}h[a+480192>>1]=0;break Pa}d=B()|0;A()|0;eb(m);break j}eb(m)}d=k[a+480190>>1];i[114610]=0;M=C(846,e+192|0,d|0)|0;d=i[114610];i[114610]=0;w=1;Wa:{Xa:{if((d|0)!=1){w=j[e+1575|0]<=4?!(g[v|0]&1):w;if(k[a+480190>>1]){break Xa}u=c&2;m=0;break Wa}d=B()|0;A()|0;break j}u=c&2;p=1;d=0;n=1;while(1){m=d;z=Ab(e+176|0);i[114610]=0;I(600,r|0,z|0,-1)|0;c=i[114610];i[114610]=0;Ya:{Za:{_a:{$a:{ab:{if((c|0)==1){break ab}i[114610]=0;C(369,((p<<5)+a|0)+946300|0,z|0)|0;c=i[114610];i[114610]=0;if((c|0)==1){break ab}s=o(p,104);q=s+a|0;if(j[e+1575|0]<5){break $a}i[114610]=0;I(600,r|0,z|0,-1)|0;c=i[114610];i[114610]=0;if((c|0)==1){break ab}i[114610]=0;C(370,q+484423|0,z|0)|0;c=i[114610];i[114610]=0;if((c|0)!=1){break $a}}d=B()|0;A()|0;break _a}i[114610]=0;c=C(847,r|0,e+208|0)|0;d=i[114610];i[114610]=0;bb:{cb:{db:{eb:{fb:{gb:{hb:{if((d|0)==1){break hb}if(!c){break gb}c=i[a+480180>>2];i[114610]=0;f=q+484380|0;J(848,e+208|0,f|0,c|0,w|0);c=i[114610];i[114610]=0;if((c|0)==1){break hb}d=0;ib:{if(((j[e+228|0]|j[e+229|0]<<8)&61440)!=28672|j[e+1575|0]<5){break ib}i[114610]=0;d=F(849,r|0)|0;c=i[114610];i[114610]=0;if((c|0)!=1){break ib}d=B()|0;A()|0;break _a}if(!u){break Za}O=j[e+228|0]|j[e+229|0]<<8;t=O&61440;if(!(t|(j[e+243|0]|j[e+244|0]<<8|(j[e+245|0]<<16|j[e+246|0]<<24)))){c=Ic(e+136|0,(j[e+228|0]|j[e+229|0]<<8)&1?16:8,(j[e+228|0]|j[e+229|0]<<8)&1024?3:1,0,0);i[114610]=0;I(400,c|0,f|0,b|0)|0;c=i[114610];i[114610]=0;if((c|0)!=1){break Za}d=B()|0;A()|0;break _a}if(!(((j[e+243|0]|j[e+244|0]<<8|(j[e+245|0]<<16|j[e+246|0]<<24))+p|0)<1|(j[e+243|0]|j[e+244|0]<<8|(j[e+245|0]<<16|j[e+246|0]<<24))>-1)){d=a+484380|0;t=o((j[e+243|0]|j[e+244|0]<<8|(j[e+245|0]<<16|j[e+246|0]<<24))+p|0,104);c=d+t|0;kc(f,i[c>>2]);d=d+s|0;p=k[d+34>>1]&-2|h[c+34>>1]&1;h[d+34>>1]=p;h[d+34>>1]=k[c+34>>1]&64|p&65471;if(!ie(c)){break Za}i[114610]=0;c=F(465,f|0)|0;d=i[114610];i[114610]=0;if((d|0)!=1){if(!c){break Za}c=i[q+484400>>2];i[114610]=0;c=F(466,c|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break a}d=i[(a+t|0)+484400>>2];i[114610]=0;d=F(850,d|0)|0;p=i[114610];i[114610]=0;if((p|0)==1){break a}Tb(c,d,hk(f));break Za}d=B()|0;A()|0;break _a}if((j[e+243|0]|j[e+244|0]<<8|(j[e+245|0]<<16|j[e+246|0]<<24))<1){break Za}if(g[e+228|0]&1){c=q+484414|0;h[c>>1]=k[c>>1]|1}if(j[e+229|0]&4){c=q+484414|0;h[c>>1]=k[c>>1]|64}c=j[e+243|0]|j[e+244|0]<<8|(j[e+245|0]<<16|j[e+246|0]<<24);i[114610]=0;G(341,e+160|0,b|0,c|0);s=i[114610];i[114610]=0;jb:{kb:{W=e;lb:{mb:{if((s|0)!=1){s=$d(f);c=(t|0)==16384;if((t|0)!=8192?!c:0){break kb}i[114610]=0;y=F(255,e+160|0)|0;R=i[114610];i[114610]=0;if((R|0)==1){break jb}i[e+136>>2]=y;y=4/(s>>>0)|0;R=i[e+136>>2];if(4294967295/(y>>>0)>>>0<R>>>0){break mb}y=o(y,R);break lb}d=B()|0;A()|0;break _a}y=-1}i[W+136>>2]=y;kc(f,y);if(!c){if((t|0)!=8192){break kb}i[114610]=0;c=F(465,f|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break cb}if(!c){break eb}if(g[e+228|0]&1){c=i[q+484400>>2];d=i[f>>2];i[114610]=0;J(851,e+160|0,c|0,d|0,s|0);c=i[114610];i[114610]=0;d=m;if((c|0)!=1){break db}break cb}c=i[q+484400>>2];d=i[f>>2];i[114610]=0;J(852,e+160|0,c|0,d|0,s|0);c=i[114610];i[114610]=0;d=m;if((c|0)==1){break cb}break db}i[114610]=0;c=F(465,f|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break cb}if(!c){break eb}if(g[e+228|0]&1){c=i[q+484400>>2];d=i[f>>2];i[114610]=0;J(853,e+160|0,c|0,d|0,s|0);c=i[114610];i[114610]=0;d=m;if((c|0)==1){break cb}break db}c=i[q+484400>>2];d=i[f>>2];i[114610]=0;J(854,e+160|0,c|0,d|0,s|0);c=i[114610];i[114610]=0;d=m;if((c|0)==1){break cb}break db}if((O&45056)==12288){c=XO(e+136|0,e+160|0,j[e+247|0]|j[e+248|0]<<8,d);d=zy(M,p+ -1|0);Cd(d,c);i[d+16>>2]=i[c+16>>2];hb(c);break eb}if((t|0)!=32768){d=1;if((t|0)!=4096){break db}c=He(e+136|0,e+160|0);i[114610]=0;C(855,e+128|0,e+160|0)|0;d=i[114610];i[114610]=0;if((d|0)!=1){nb:{if(!j[e+133|0]){break nb}d=k[e+130>>1]<<1;if((j[e+247|0]|j[e+248|0]<<8)>>>0<(d&65535)>>>0){break nb}d=(j[e+247|0]|j[e+248|0]<<8)-d|0;g[e+247|0]=d;g[e+248|0]=d>>>8;i[114610]=0;C(256,e+160|0,k[e+128>>1])|0;d=i[114610];i[114610]=0;if((d|0)==1){break fb}i[114610]=0;d=F(548,e+160|0)|0;p=i[114610];i[114610]=0;if((p|0)==1){break fb}i[114610]=0;G(341,e+112|0,e+160|0,d|0);d=i[114610];i[114610]=0;if((d|0)==1){break fb}Cd(c,e+112|0);hb(e+112|0)}i[114610]=0;d=n&65535;p=S(856,a|0,d|0,c|0,1,1)|0;t=i[114610];i[114610]=0;if((t|0)==1){break fb}ob:{if(!p){i[114610]=0;p=N(857,a|0,d|0,c|0,1)|0;d=i[114610];i[114610]=0;if((d|0)==1){break fb}d=1;if(!p){break ob}}pb:{if(!(j[e+247|0]|j[e+248|0]<<8)){break pb}d=j[e+247|0]|j[e+248|0]<<8;if(hk(f)>>>0<=d>>>0){break pb}d=j[e+247|0]|j[e+248|0]<<8;p=xn(f);q=q+484400|0;t=i[q>>2];i[114610]=0;t=F(466,t|0)|0;s=i[114610];i[114610]=0;if((s|0)==1){break a}q=i[q>>2];i[114610]=0;q=F(466,q|0)|0;s=i[114610];i[114610]=0;if((s|0)==1){break a}yi(t,q+(j[e+247|0]|j[e+248|0]<<8)|0,hk(f)-(j[e+247|0]|j[e+248|0]<<8)|0);i[f>>2]=i[f>>2]-((d>>>0)/(p>>>0)|0)}d=i[e+216>>2];i[e+108>>2]=d;i[e+12>>2]=d;if(l[f>>2]>(j[e+12|0]|j[e+13|0]<<8|(j[e+14|0]<<16|j[e+15|0]<<24))>>>0){i[f>>2]=j[e+12|0]|j[e+13|0]<<8|(j[e+14|0]<<16|j[e+15|0]<<24)}d=m}hb(c);break db}break fb}i[114610]=0;c=C(644,e+160|0,e+136|0)|0;d=i[114610];i[114610]=0;if((d|0)!=1){if(!c){break eb}i[114610]=0;i[e+24>>2]=i[e+144>>2];c=i[e+140>>2];i[e+16>>2]=i[e+136>>2];i[e+20>>2]=c;G(645,f|0,1,e+16|0);c=i[114610];i[114610]=0;if((c|0)!=1){break eb}}d=B()|0;A()|0;break bb}d=B()|0;A()|0;break bb}d=B()|0;A()|0;break _a}eb(z);break Wa}d=B()|0;A()|0;hb(c);break bb}d=m}hb(e+160|0);break Ya}d=B()|0;A()|0}hb(e+160|0)}eb(z);break l}d=m}eb(z);n=n+1|0;p=n&65535;if(p>>>0<=k[a+480190>>1]){continue}break}m=d}if(!(!u|!k[a+480190>>1])){d=1;n=1;while(1){c=zy(M,d+ -1|0);i[114610]=0;b=F(337,c|0)|0;f=i[114610];i[114610]=0;qb:{rb:{sb:{if((f|0)!=1){if(!b){break qb}tb:{ub:{vb:{b=k[c+18>>1];wb:{if(!b){break wb}b=b+n&65535;if(!b){break wb}if(b>>>0<=k[a+480190>>1]){break vb}}i[114610]=0;F(255,c|0)|0;b=i[114610];i[114610]=0;if((b|0)!=1){break ub}break m}b=zy(M,b+ -1|0);f=k[c+16>>1];pc(b);p=k[c+16>>1];i[114610]=0;p=C(258,b|0,p|0)|0;q=i[114610];i[114610]=0;if((q|0)==1){break m}if(!p){break qb}i[114610]=0;i[e+136>>2]=0;i[e+160>>2]=0;G(858,e+208|0,b|0,f|0);f=i[114610];i[114610]=0;xb:{if((f|0)!=1){i[114610]=0;f=F(412,e+208|0)|0;p=i[114610];i[114610]=0;if((p|0)==1){break xb}i[114610]=0;f=F(859,f|0)|0;p=i[114610];i[114610]=0;if((p|0)==1){break xb}p=i[e+208>>2];i[114610]=0;p=F(860,p|0)|0;q=i[114610];i[114610]=0;if((q|0)==1){break xb}i[114610]=0;w=S(861,f|0,p|0,e+136|0,e+160|0,0)|0;f=i[114610];i[114610]=0;if((f|0)==1){break xb}i[114610]=0;C(338,b|0,i[e+136>>2])|0;b=i[114610];i[114610]=0;if((b|0)==1){break xb}jc(e+208|0);b=1;break tb}d=B()|0;A()|0;break l}d=B()|0;A()|0;jc(e+208|0);break l}pc(c);i[e+136>>2]=0;i[e+160>>2]=0;w=0;b=0}i[114610]=0;D(862,e+208|0,c|0);f=i[114610];i[114610]=0;yb:{zb:{if((f|0)!=1){i[114610]=0;u=F(412,e+208|0)|0;f=i[114610];i[114610]=0;if((f|0)==1){break yb}q=i[e+208>>2];if(!b){i[114610]=0;b=F(859,u|0)|0;f=i[114610];i[114610]=0;if((f|0)==1){break sb}i[114610]=0;f=F(860,q|0)|0;p=i[114610];i[114610]=0;if((p|0)==1){break sb}i[114610]=0;w=S(861,b|0,f|0,e+136|0,e+160|0,0)|0;b=i[114610];i[114610]=0;if((b|0)==1){break sb}i[114610]=0;C(338,c|0,i[e+136>>2])|0;b=i[114610];i[114610]=0;if((b|0)==1){break sb}b=i[e+136>>2];q=q-b|0;u=b+u|0}if(w){break zb}m=1;break rb}d=B()|0;A()|0;break l}i[114610]=0;d=o(d,104)+a|0;b=d+484380|0;F(465,b|0)|0;f=i[114610];i[114610]=0;if((f|0)==1){break sb}z=d+484400|0;t=d+484414|0;p=0;f=i[e+160>>2];while(1){Ab:{if(p>>>0>=l[b>>2]|(!q|(f|0)!=1?f:0)){break Ab}if(!ie(b)){break Ab}i[114610]=0;i[e+112>>2]=0;i[e+176>>2]=0;d=F(859,u|0)|0;f=i[114610];i[114610]=0;if((f|0)==1){break sb}i[114610]=0;f=F(860,q|0)|0;s=i[114610];i[114610]=0;if((s|0)==1){break sb}i[114610]=0;d=Y(863,w|0,d|0,f|0,e+112|0,e+128|0,e+176|0)|0;f=i[114610];i[114610]=0;if((f|0)==1){break sb}i[114610]=0;i[e+136>>2]=d;C(338,c|0,d|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break sb}f=i[b>>2];i[114610]=0;d=i[e+136>>2];f=F(864,f-p|0)|0;s=i[114610];i[114610]=0;if((s|0)==1){break sb}Xj(e+176|0,f);Bb:{if(i[e+176>>2]<1){break Bb}if(i[e+112>>2]!=($d(b)|0)){break Bb}f=0;if(i[e+112>>2]<=0){break Bb}while(1){Cb:{if(g[t|0]&1){s=i[z>>2];y=$d(b);O=i[i[e+128>>2]+(f<<2)>>2];i[114610]=0;T(865,s+(o(p,y)<<1)|0,O|0,i[e+112>>2],i[e+176>>2],f|0);s=i[114610];i[114610]=0;if((s|0)!=1){break Cb}break sb}s=i[z>>2];y=$d(b);O=i[i[e+128>>2]+(f<<2)>>2];i[114610]=0;T(866,s+o(p,y)|0,O|0,i[e+112>>2],i[e+176>>2],f|0);s=i[114610];i[114610]=0;if((s|0)==1){break sb}}f=f+1|0;if((f|0)<i[e+112>>2]){continue}break}}i[114610]=0;s=i[e+176>>2];f=F(867,w|0)|0;y=i[114610];i[114610]=0;if((y|0)==1){break sb}q=q-d|0;u=d+u|0;i[e+160>>2]=f;p=p+s|0;continue}break}i[114610]=0;L(868,w|0);b=i[114610];i[114610]=0;if((b|0)!=1){break rb}break sb}break sb}d=B()|0;A()|0;break l}d=B()|0;A()|0;jc(e+208|0);break l}jc(e+208|0)}n=n+1|0;d=n&65535;if(d>>>0<=k[a+480190>>1]){continue}break}}Db:{if(i[a+480180>>2]!=4){break Db}f=0;while(1){if(f>>>0>=k[a+480192>>1]){break Db}b=j[vb(K,f)|0];c=j[vb(K,f)+1|0];d=j[vb(K,f)+2|0];n=j[vb(K,f)+3|0];i[114610]=0;f=f+1|0;_(869,a|0,f&65535,b|0,c|0,d|0,n|0);b=i[114610];i[114610]=0;if((b|0)!=1){continue}break}d=B()|0;A()|0;break l}Eb:{Fb:{Gb:{Hb:{if(!(j[v+2|0]&16)){break Hb}i[114610]=0;b=C(258,r|0,1)|0;c=i[114610];i[114610]=0;if((c|0)==1){break n}if(!b){break Hb}i[114610]=0;b=F(387,r|0)|0;c=i[114610];i[114610]=0;if((c|0)==1){break o}if(!(!(b&1)|!k[V>>1])){f=0;while(1){i[114610]=0;b=F(390,r|0)|0;c=i[114610];i[114610]=0;if((c|0)==1){break Gb}g[((f<<5)+a|0)+480288|0]=b;f=f+1|0;if(f>>>0<k[a+480188>>1]){continue}break}}while(1){i[114610]=0;b=C(258,r|0,1)|0;c=i[114610];i[114610]=0;Ib:{if((c|0)!=1){if(!b){break Hb}i[114610]=0;b=F(387,r|0)|0;c=i[114610];i[114610]=0;if((c|0)==1){break Fb}if(!b){break Hb}i[114610]=0;c=F(390,r|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break Eb}i[114610]=0;G(341,e+208|0,r|0,c|0);c=i[114610];i[114610]=0;if((c|0)==1){break Eb}if(b>>>0>250){break Ib}i[114610]=0;D(670,e+208|0,(o(b,160)+a|0)+906140|0);b=i[114610];i[114610]=0;if((b|0)!=1){break Ib}d=B()|0;A()|0;hb(e+208|0);break l}d=B()|0;A()|0;break l}hb(e+208|0);continue}}n=a+901404|0;u=a+1074304|0;w=a+484344|0;b=Oc(e+112|0);p=0;q=0;Jb:{Kb:{while(1){i[114610]=0;c=C(258,r|0,8)|0;d=i[114610];i[114610]=0;if((d|0)==1){break Jb}if(!c){break Kb}i[114610]=0;c=F(390,r|0)|0;d=i[114610];i[114610]=0;Lb:{Mb:{Nb:{Ob:{Pb:{Qb:{Rb:{Sb:{Tb:{Ub:{Vb:{Wb:{Xb:{Yb:{Zb:{_b:{$b:{if((d|0)!=1){i[114610]=0;d=F(390,r|0)|0;f=i[114610];i[114610]=0;if((f|0)==1){break $b}i[114610]=0;G(341,e+136|0,r|0,d|0);d=i[114610];i[114610]=0;if((d|0)==1){break _b}if((c|0)<=1397900629){if((c|0)==1229211981){break Yb}if((c|0)!=1229476432){break Mb}i[114610]=0;c=F(387,e+136|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break r}i[a+480216>>2]=c;i[114610]=0;c=F(387,e+136|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break r}i[a+480220>>2]=c;break Mb}if((c|0)==1397900630){break Zb}if((c|0)!=1414548815){break Mb}i[114610]=0;c=C(621,e+136|0,15259)|0;d=i[114610];i[114610]=0;if((d|0)==1){break r}if(!c){break Wb}i[114610]=0;c=F(390,e+136|0)|0;d=i[114610];i[114610]=0;if((d|0)!=1){i[114610]=0;G(341,e+160|0,e+136|0,c|0);c=i[114610];i[114610]=0;if((c|0)!=1){break Xb}}d=B()|0;A()|0;break q}d=B()|0;A()|0;break p}d=B()|0;A()|0;break p}d=B()|0;A()|0;break p}ac:{bc:{cc:{c=i[a+480180>>2];switch(c+ -2|0){case 1:break Mb;case 0:break Nb;case 2:break bc;default:break cc}}if((c|0)==16){break ac}if((c|0)!=32){break Mb}i[114610]=0;p=F(357,e+136|0)|0;c=i[114610];i[114610]=0;if((c|0)==1){break r}i[114610]=0;q=F(357,e+136|0)|0;c=i[114610];i[114610]=0;if((c|0)!=1){break Mb}break r}i[114610]=0;i[e+208>>2]=32;c=F(255,e+136|0)|0;d=i[114610];i[114610]=0;dc:{if((d|0)==1){break dc}i[114610]=0;i[e+160>>2]=c;c=C(33,e+208|0,e+160|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break dc}c=i[c>>2];i[114610]=0;N(870,e+136|0,b|0,4,c|0)|0;c=i[114610];i[114610]=0;if((c|0)!=1){break Mb}}d=B()|0;A()|0;break q}i[114610]=0;d=F(387,e+136|0)|0;c=i[114610];i[114610]=0;if((c|0)==1){break Lb}i[114610]=0;c=C(2,e+96|0,15240)|0;f=i[114610];i[114610]=0;ec:{fc:{gc:{if((f|0)!=1){i[114610]=0;D(219,e+160|0,c|0);f=i[114610];i[114610]=0;if((f|0)==1){break gc}i[114610]=0;i[e+176>>2]=d>>>4;i[e+128>>2]=d&15;J(534,e+208|0,e+160|0,e+176|0,e+128|0);d=i[114610];i[114610]=0;if((d|0)==1){break fc}mb(b,e+208|0);eb(e+208|0);ob(e+160|0);eb(c);break Mb}d=B()|0;A()|0;break q}d=B()|0;A()|0;break ec}d=B()|0;A()|0;ob(e+160|0)}eb(c);break q}i[114610]=0;C(636,e+136|0,n|0)|0;c=i[114610];i[114610]=0;if((c|0)==1){break r}i[114610]=0;L(637,n|0);c=i[114610];i[114610]=0;if((c|0)==1){break r}break Mb}i[114610]=0;c=F(255,e+160|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break Vb}h[e+208>>1]=c>>>5;c=ke(w);i[114610]=0;h[e+176>>1]=c;c=C(477,e+208|0,e+176|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break Vb}c=k[c>>1];if(c){d=0;while(1){i[114610]=0;I(871,e+160|0,e+208|0,32)|0;f=i[114610];i[114610]=0;if((f|0)==1){break Vb}f=Fb(w,d);i[114610]=0;C(872,f|0,e+208|0)|0;f=i[114610];i[114610]=0;if((f|0)==1){break Vb}d=d+1|0;if((c|0)!=(d|0)){continue}break}}hb(e+160|0)}i[114610]=0;c=C(621,e+136|0,15264)|0;d=i[114610];i[114610]=0;if((d|0)==1){break r}if(!c){break Tb}i[114610]=0;c=F(390,e+136|0)|0;d=i[114610];i[114610]=0;if((d|0)!=1){i[114610]=0;G(341,e+208|0,e+136|0,c|0);c=i[114610];i[114610]=0;if((c|0)!=1){break Ub}}d=B()|0;A()|0;break q}d=B()|0;A()|0;hb(e+160|0);break q}i[114610]=0;c=F(255,e+208|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break Sb}h[e+160>>1]=(c>>>0)/20;c=k[a+480188>>1];i[114610]=0;h[e+176>>1]=c;c=C(477,e+160|0,e+176|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break Sb}c=k[c>>1];if(c){f=0;while(1){i[114610]=0;I(639,e+208|0,((f<<5)+a|0)+480289|0,20)|0;d=i[114610];i[114610]=0;if((d|0)==1){break Sb}f=f+1|0;if((c|0)!=(f|0)){continue}break}}hb(e+208|0)}i[114610]=0;C(656,a|0,e+136|0)|0;c=i[114610];i[114610]=0;if((c|0)==1){break r}i[114610]=0;J(657,a|0,e+136|0,1,0);c=i[114610];i[114610]=0;if((c|0)==1){break r}if((p+ -2186&65535)>>>0<=117){i[a+480180>>2]=16777216;i[114610]=0;G(668,a|0,e+136|0,p&65535);c=i[114610];i[114610]=0;if((c|0)==1){break r}}if(!i[u>>2]){break Mb}i[114610]=0;c=C(2,e+160|0,15269)|0;d=i[114610];i[114610]=0;if((d|0)==1){break Rb}i[114610]=0;D(242,e+176|0,u|0);d=i[114610];i[114610]=0;if((d|0)==1){break Qb}i[114610]=0;G(3,e+208|0,c|0,e+176|0);d=i[114610];i[114610]=0;if((d|0)==1){break Pb}mb(b,e+208|0);eb(e+208|0);eb(e+176|0);eb(c);break Mb}d=B()|0;A()|0;hb(e+208|0);break q}d=B()|0;A()|0;break q}d=B()|0;A()|0;break Ob}d=B()|0;A()|0;eb(e+176|0)}eb(c);break q}i[114610]=0;p=F(357,e+136|0)|0;c=i[114610];i[114610]=0;if((c|0)==1){break r}}hb(e+136|0);continue}break}d=B()|0;A()|0;break q}hc:{ic:{jc:{kc:{if(!((p&65504)!=4864|i[a+480180>>2]!=2?!((i[a+480180>>2]==32?(p+ -256&65535)>>>0<=275:0)|(i[a+480180>>2]==2?(p+ -12544&65535)>>>0<=275:0)):0)){i[114610]=0;L(638,n|0);c=i[114610];i[114610]=0;if((c|0)==1){break kc}}if(!(g[v+2|0]&1)){break hc}if(!(i[a+1074304>>2]|!k[a+480192>>1])){f=1;while(1){c=i[(((f&65535)<<2)+a|0)+900380>>2];if(c){i[114610]=0;d=C(374,c|0,2)|0;n=i[114610];i[114610]=0;if((n|0)==1){break jc}n=i[a+480180>>2];i[114610]=0;G(873,d|0,4,n|0);d=i[114610];i[114610]=0;if((d|0)==1){break ic}g[c+19|0]=j[c+19|0]+3>>>2}f=f+1|0;if((f&65535)>>>0<=k[a+480192>>1]){continue}break}}if(l[a+1074304>>2]<18350080){i[114610]=0;c=a+1074308|0;C(479,c|0,27)|0;d=i[114610];i[114610]=0;if((d|0)==1){break kc}i[114610]=0;C(479,c|0,57)|0;c=i[114610];i[114610]=0;if((c|0)==1){break kc}}if(l[a+1074304>>2]<19070976){i[114610]=0;C(479,a+1074308|0,73)|0;c=i[114610];i[114610]=0;if((c|0)==1){break kc}}if(l[a+1074304>>2]>=19267584){break hc}i[114610]=0;C(479,a+1074308|0,50)|0;c=i[114610];i[114610]=0;if((c|0)!=1){break hc}}d=B()|0;A()|0;break p}d=B()|0;A()|0;break p}d=B()|0;A()|0;break p}lc:{mc:{nc:{oc:{pc:{qc:{rc:{sc:{tc:{uc:{vc:{wc:{xc:{yc:{zc:{Ac:{Bc:{Cc:{if(Cc(b)){i[114610]=0;c=C(2,e+80|0,15278)|0;d=i[114610];i[114610]=0;Dc:{Ec:{Fc:{if((d|0)!=1){i[114610]=0;D(219,e+136|0,c|0);d=i[114610];i[114610]=0;if((d|0)==1){break Fc}i[114610]=0;G(537,e+208|0,e+136|0,e+1575|0);d=i[114610];i[114610]=0;if((d|0)==1){break Ec}break Cc}d=B()|0;A()|0;break p}d=B()|0;A()|0;break Dc}d=B()|0;A()|0;ob(e+136|0)}eb(c);break p}i[114610]=0;c=C(2,e- -64|0,15286)|0;d=i[114610];i[114610]=0;if((d|0)==1){break Bc}i[114610]=0;D(219,e+136|0,c|0);d=i[114610];i[114610]=0;if((d|0)==1){break Ac}i[114610]=0;J(451,e+208|0,e+136|0,e+1575|0,b|0);d=i[114610];i[114610]=0;if((d|0)==1){break zc}}mb(b,e+208|0);eb(e+208|0);ob(e+136|0);eb(c);i[114610]=0;c=C(2,e+48|0,15299)|0;d=i[114610];i[114610]=0;if((d|0)==1){break wc}i[114610]=0;D(219,e+136|0,c|0);d=i[114610];i[114610]=0;if((d|0)==1){break vc}i[114610]=0;G(537,e+208|0,e+136|0,e+1575|0);d=i[114610];i[114610]=0;if((d|0)==1){break uc}mb(a+1304436|0,e+208|0);eb(e+208|0);ob(e+136|0);eb(c);i[114610]=0;c=C(2,e+208|0,15315)|0;d=i[114610];i[114610]=0;if((d|0)==1){break sc}mb(a+1304448|0,c);eb(c);c=i[a+480180>>2];if((c|0)>15){break xc}switch(c+ -1|0){case 1:break oc;case 3:break pc;case 0:break qc;default:break w}}d=B()|0;A()|0;break p}d=B()|0;A()|0;break yc}d=B()|0;A()|0;ob(e+136|0)}eb(c);break p}if((c|0)==16){break rc}if((c|0)==32){break nc}if((c|0)!=16777216){break w}i[114610]=0;c=C(2,e+208|0,15430)|0;d=i[114610];i[114610]=0;if((d|0)==1){break mc}mb(a+1304484|0,c);eb(c);i[114610]=0;c=C(2,e+208|0,15435)|0;d=i[114610];i[114610]=0;if((d|0)==1){break lc}mb(a+1304472|0,c);eb(c);break w}d=B()|0;A()|0;break p}d=B()|0;A()|0;break tc}d=B()|0;A()|0;ob(e+136|0)}eb(c);break p}d=B()|0;A()|0;break p}i[114610]=0;c=C(2,e+208|0,15319)|0;d=i[114610];i[114610]=0;Gc:{if((d|0)!=1){mb(a+1304484|0,c);eb(c);i[114610]=0;c=C(2,e+208|0,15323)|0;d=i[114610];i[114610]=0;if((d|0)==1){break Gc}mb(a+1304472|0,c);eb(c);break w}d=B()|0;A()|0;break p}d=B()|0;A()|0;break p}i[114610]=0;c=C(2,e+208|0,15336)|0;d=i[114610];i[114610]=0;Hc:{if((d|0)!=1){mb(a+1304484|0,c);eb(c);i[114610]=0;c=C(2,e+208|0,15340)|0;d=i[114610];i[114610]=0;if((d|0)==1){break Hc}mb(a+1304472|0,c);eb(c);break w}d=B()|0;A()|0;break p}d=B()|0;A()|0;break p}i[114610]=0;c=C(2,e+208|0,15352)|0;d=i[114610];i[114610]=0;Ic:{if((d|0)!=1){mb(a+1304484|0,c);eb(c);i[114610]=0;c=C(2,e+208|0,15355)|0;d=i[114610];i[114610]=0;if((d|0)==1){break Ic}mb(a+1304472|0,c);eb(c);break w}d=B()|0;A()|0;break p}d=B()|0;A()|0;break p}i[114610]=0;c=C(2,e+208|0,15369)|0;d=i[114610];i[114610]=0;Jc:{if((d|0)!=1){mb(a+1304484|0,c);eb(c);i[114610]=0;c=C(2,e+208|0,15373)|0;d=i[114610];i[114610]=0;if((d|0)==1){break Jc}mb(a+1304472|0,c);eb(c);break w}d=B()|0;A()|0;break p}d=B()|0;A()|0;break p}i[114610]=0;c=C(2,e+208|0,15389)|0;d=i[114610];i[114610]=0;Kc:{Lc:{Mc:{Nc:{Oc:{Pc:{Qc:{if((d|0)!=1){mb(a+1304484|0,c);eb(c);if(!(q&65535)){break Kc}i[114610]=0;c=C(2,e+32|0,15392)|0;d=i[114610];i[114610]=0;if((d|0)==1){break Qc}i[114610]=0;D(219,e+136|0,c|0);d=i[114610];i[114610]=0;if((d|0)==1){break Pc}i[114610]=0;i[e+176>>2]=(q&65280)>>>8;i[e+128>>2]=q&255;D(664,e+160|0,e+128|0);d=i[114610];i[114610]=0;if((d|0)==1){break Oc}i[114610]=0;J(649,e+208|0,e+136|0,e+176|0,e+160|0);d=i[114610];i[114610]=0;if((d|0)==1){break Nc}mb(a+1304472|0,e+208|0);eb(e+208|0);eb(e+160|0);ob(e+136|0);eb(c);break w}d=B()|0;A()|0;break p}d=B()|0;A()|0;break p}d=B()|0;A()|0;break Lc}d=B()|0;A()|0;break Mc}d=B()|0;A()|0;eb(e+160|0)}ob(e+136|0)}eb(c);break p}i[114610]=0;c=C(2,e+208|0,15414)|0;d=i[114610];i[114610]=0;if((d|0)!=1){mb(a+1304472|0,c);eb(c);break w}d=B()|0;A()|0;break p}d=B()|0;A()|0;break p}d=B()|0;A()|0;break p}d=B()|0;A()|0;break p}d=B()|0;A()|0;break l}d=B()|0;A()|0;break l}d=B()|0;A()|0;break l}d=B()|0;A()|0;break h}d=B()|0;A()|0;break h}d=B()|0;A()|0;break h}d=B()|0;A()|0;break d}d=B()|0;A()|0;break d}d=B()|0;A()|0;break d}d=B()|0;A()|0;break c}d=B()|0;A()|0;break d}mb(a+1304460|0,b);Rc:{if(i[a+1074304>>2]){i[a+1304496>>2]=7;break Rc}if(i[a+480180>>2]==1){i[a+1304496>>2]=2;break Rc}i[a+1304496>>2]=4}f=1;if(m&1){i[114610]=0;c=C(2,e+208|0,15448)|0;d=i[114610];i[114610]=0;if((d|0)==1){break t}i[114610]=0;G(650,a|0,2,c|0);a=i[114610];i[114610]=0;if((a|0)==1){break s}eb(c)}eb(b);WO(M);VO(K);Qc(P);hb(e+1080|0);hb(e+1096|0)}hb(r)}Md(Q);break b}d=B()|0;A()|0;break p}d=B()|0;A()|0;eb(c);break p}d=B()|0;A()|0}hb(e+136|0)}eb(b);break l}d=B()|0;A()|0;break l}d=B()|0;A()|0;break l}d=B()|0;A()|0}WO(M);break j}d=B()|0;A()|0}VO(K);break h}d=B()|0;A()|0}Qc(P)}hb(e+1080|0)}hb(e+1096|0);break d}d=B()|0;A()|0}hb(r)}Md(Q);E(d|0);x()}Xa=e+1584|0;return f|0}a=H(0)|0;A()|0;gb(a);x()}function HDa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,m=0,n=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,H=0,K=0,L=0,M=0,O=0,P=0,Q=0,R=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0;e=Xa-912|0;Xa=e;pc(b);a:{if(!sP(b,e+856|0)){break a}if(!uP(e+856|0)){break a}if(!wb(b,Vc(tP(e+856|0),_a))){break a}if(!c){m=1;break a}md(a,8);Vh(a);g[e+855|0]=j[e+856|3]+ -48;d=j[e+864|0]|j[e+865|0]<<8|(j[e+866|0]<<16|j[e+867|0]<<24);vc(b,d<<24|d<<8&16711680|(d>>>8&65280|d>>>24));ad(e+832|0,b,504);i[114610]=0;C(775,b|0,e+544|0)|0;d=i[114610];i[114610]=0;b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{if((d|0)!=1){if(j[e+544|0]&128|j[e+827|0]>63){break b}yb(e+464|0,0,80);p:{if(!(j[e+888|0]|j[e+889|0]<<8|(j[e+890|0]<<16|j[e+891|0]<<24))){break p}d=j[e+888|0]|j[e+889|0]<<8|(j[e+890|0]<<16|j[e+891|0]<<24);i[114610]=0;f=C(256,b|0,d<<8&16711680|d<<24|(d>>>8&65280|d>>>24))|0;d=i[114610];i[114610]=0;if((d|0)!=1){if(!f){break p}i[114610]=0;C(776,b|0,e+464|0)|0;d=i[114610];i[114610]=0;if((d|0)!=1){break p}}m=B()|0;A()|0;break e}i[114610]=0;f=j[e+855|0];G(777,e+456|0,b|0,f|0);d=i[114610];i[114610]=0;if((d|0)!=1){ia=yf(e+456|0);d=k[e+456>>1];if((d+ -1&65535)>>>0>126){break b}h[a+480188>>1]=d;Z=e+440|0;pDa(Z);d=j[e+880|0]|j[e+881|0]<<8|(j[e+882|0]<<16|j[e+883|0]<<24);i[114610]=0;C(256,b|0,d<<8&16711680|d<<24|(d>>>8&65280|d>>>24))|0;d=i[114610];i[114610]=0;if((d|0)==1){break o}d=j[e+827|0];i[114610]=0;I(778,b|0,Z|0,d|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break o}m=j[e+827|0];h[a+480192>>1]=m;h[a+480190>>1]=m;if(f>>>0<=1){ja=k[a+480188>>1]==4}else{m=k[a+480192>>1];ja=g[e+808|0]>-1}if(m&65535){_=c&2;fa=ja^1;X=e+80|2;$=e+80|7;ba=e+80|6;Y=e+80|5;K=e+80|4;O=e+56|4;s=1;H=1;P=1;while(1){i[114610]=0;Q=P&65535;f=I(454,a|0,H&65535,Q|0)|0;d=i[114610];i[114610]=0;q:{if((d|0)!=1){if(f){break q}break d}m=B()|0;A()|0;break f}L=i[((s<<2)+a|0)+900380>>2];i[114610]=0;h[e+60>>1]=0;i[e+56>>2]=0;U=F(277,e+152|0)|0;d=i[114610];i[114610]=0;r:{s:{t:{u:{v:{if((d|0)!=1){d=s+ -1|0;f=vb(Z,d);w:{if(!(j[f|0]|j[f+1|0]<<8|(j[f+2|0]<<16|j[f+3|0]<<24))){break w}d=vb(Z,d);d=j[d|0]|j[d+1|0]<<8|(j[d+2|0]<<16|j[d+3|0]<<24);i[114610]=0;f=C(256,b|0,d<<8&16711680|d<<24|(d>>>8&65280|d>>>24))|0;d=i[114610];i[114610]=0;if((d|0)==1){break g}if(!f){break w}i[114610]=0;C(779,b|0,e+56|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break g}d=j[e+56|0]|j[e+57|0]<<8|(j[e+58|0]<<16|j[e+59|0]<<24);i[114610]=0;G(341,e+80|0,b|0,d<<8&16711680|d<<24|(d>>>8&65280|d>>>24));d=i[114610];i[114610]=0;if((d|0)==1){break g}Cd(U,e+80|0);hb(e+80|0)}n=j[O+1|0]&15;M=(j[O|0]|j[O+1|0]<<8)&128;if(!M){break v}i[114610]=0;D(780,L|0,0);d=i[114610];i[114610]=0;la=1;if((d|0)!=1){break u}break g}m=B()|0;A()|0;break f}if(7<=n>>>0){break u}f=j[n+14806|0];if(!n){d=f;break s}h[a+480190>>1]=(k[a+480190>>1]+f|0)+ -1;r=L+108|0;z=L+236|0;t=f+ -2|0;u=4;while(1){d=u+ -4|0;n=t<<3;q=d+(n+14864|0)|0;p=j[d+(n+14816|0)|0]+P|0;n=o(u,12);m=0;while(1){d=m+n|0;ma=Mc(z,d),na=p,h[ma>>1]=na;d=Nb(r,d);g[d|0]=j[d|0]+j[q|0];m=m+1|0;if((m|0)!=12){continue}break}v=1;u=u+1|0;if((u|0)!=10){continue}break}d=f;break t}f=1;if((n|0)!=7){d=1;break s}v=0;i[114610]=0;D(781,L|0,-24);f=i[114610];i[114610]=0;d=1;if((f|0)==1){break g}f=1}ca=1;break r}v=0;if(M|fa){break r}t=L+108|0;u=7;while(1){q=o(u,12);p=o(u,-12)+72|0;m=0;while(1){n=Nb(t,m+q|0);g[n|0]=p+j[n|0];m=m+1|0;if((m|0)!=12){continue}break}u=u+1|0;if((u|0)!=10){continue}break}}i[114610]=0;C(782,e+832|0,e+80|0)|0;n=i[114610];i[114610]=0;if((n|0)==1){break g}if(!(!j[K|0]|j[K|0]>16)){g[L+31|0]=j[K|0];ca=1}if(!(!j[Y|0]|j[Y|0]>128)){g[L+30|0]=j[Y|0]}if(d){s=0;r=0;while(1){i[114610]=0;q=o(s+Q|0,104)+a|0;D(386,q+484380|0,8);n=i[114610];i[114610]=0;if((n|0)==1){break g}n=j[ba|0];i[114610]=0;g[e+408|0]=n;g[e+136|0]=64;p=C(391,e+408|0,e+136|0)|0;n=i[114610];i[114610]=0;if((n|0)==1){break g}h[q+484410>>1]=j[p|0]<<2;g[q+484416|0]=j[$|0];r=r+1|0;s=r&65535;if(d>>>0>s>>>0){continue}break}}x:{if(M|!_){break x}z=Ic(e+408|0,8,1,1,0);t=j[X|0]|j[X+1|0]<<8;q=j[e+80|0]|j[e+81|0]<<8;p=j[X|0]|j[X+1|0]<<8;i[114610]=0;m=F(255,U|0)|0;n=i[114610];i[114610]=0;if((n|0)==1){break g}if(j[O+1|0]&16){mz(z);m=m>>>1|0}if(j[O+1|0]&32){jA(z);m=m>>>1|0}if(j[O+1|0]&64){cj(z,2)}m=v?(m>>>0)/((-1<<d^-1)>>>0)|0:m;if(!d){break x}r=(q<<8&16711680|q<<24)>>>16|0;v=r+((p<<8&16711680|p<<24)>>>16|0)|0;p=(t<<8&16711680|t<<24)>>>16|0;s=0;u=0;while(1){q=o(s+Q|0,104)+a|0;n=q+484380|0;i[n>>2]=m;i[114610]=0;I(400,z|0,n|0,U|0)|0;n=i[114610];i[114610]=0;if((n|0)==1){break g}r=r<<1;v=v<<1;if(p>>>0>=2){i[q+484388>>2]=v;i[q+484384>>2]=r;n=q+484414|0;h[n>>1]=k[n>>1]|2}m=m<<1;u=u+1|0;s=u&65535;if(d>>>0>s>>>0){continue}break}}hb(U);P=f+P|0;H=H+1|0;s=H&65535;if(s>>>0<=k[a+480192>>1]){continue}break}}d=e+464|4;y:{if(!(j[d|0]|j[d+1|0]<<8|(j[d+2|0]<<16|j[d+3|0]<<24))|!(j[e+472|0]|j[e+473|0]<<8)){break y}d=j[d|0]|j[d+1|0]<<8|(j[d+2|0]<<16|j[d+3|0]<<24);i[114610]=0;f=C(256,b|0,d<<8&16711680|d<<24|(d>>>8&65280|d>>>24))|0;d=i[114610];i[114610]=0;if((d|0)==1){break h}if(!f){break y}d=j[e+472|0]|j[e+473|0]<<8;h[e+152>>1]=(d<<24|d<<8&16711680)>>>16;d=j[e+827|0];i[114610]=0;h[e+80>>1]=d;f=C(477,e+152|0,e+80|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break i}$=k[f>>1];if(!$){break y}Q=e+152|5;ba=e+152|3;_=e+152|6;K=e+152|1;f=e+88|0;r=e+80|4;d=j[e+474|0]|j[e+475|0]<<8;M=(d<<24|d<<8&16711680)>>>16|0;z=M>>>0<7;t=M>>>0<15;s=0;while(1){i[114610]=0;I(783,b|0,e+152|0,M|0)|0;d=i[114610];i[114610]=0;z:{A:{B:{if((d|0)!=1){s=s+1|0;n=i[((s<<2)+a|0)+900380>>2];if(!j[e+152|0]){break z}q=ap(e+80|0,0,64);ap(r,j[e+152|0]+ -1&65535,64);p=j[e+152|0];ap(f,p+(j[K|0]?64/j[K|0]|0:0)|0,0);i[114610]=0;i[e+436>>2]=3;i[e+432>>2]=q;d=i[e+436>>2];i[e+8>>2]=i[e+432>>2];i[e+12>>2]=d;p=n+48|0;D(784,p|0,e+8|0);d=i[114610];i[114610]=0;if((d|0)==1){break B}if(j[e+152|0]!=1){break A}ma=e,na=Jb(p),i[ma+80>>2]=na;Ad(e+424|0,e+80|0);i[114610]=0;C(785,p|0,i[e+424>>2])|0;d=i[114610];i[114610]=0;if((d|0)!=1){break A}m=B()|0;A()|0;break f}m=B()|0;A()|0;break f}m=B()|0;A()|0;break f}d=n;if(j[K|0]){R=j[K|0]<<9}else{R=32767}i[d>>2]=R;ca=1;g[n+60|0]=j[n+60|0]|1}if(!z){d=j[_|0]|j[_+1|0]<<8;h[n+28>>1]=(d<<24|d<<8&16711680)>>>16}n=o(k[Mc(n+236|0,61)>>1],104)+a|0;g[n+484417|0]=j[ba|0]<<4;C:{D:{if(!t){d=j[e+162|0]|j[e+163|0]<<8|(j[e+164|0]<<16|j[e+165|0]<<24);i[n+484384>>2]=d<<24|d<<8&16711680|(d>>>8&65280|d>>>24);d=j[e+166|0]|j[e+167|0]<<8|(j[e+168|0]<<16|j[e+169|0]<<24);R=d<<24|d<<8&16711680|(d>>>8&65280|d>>>24);d=j[e+162|0]|j[e+163|0]<<8|(j[e+164|0]<<16|j[e+165|0]<<24);i[n+484388>>2]=R+(d<<8&16711680|d<<24|(d>>>8&65280|d>>>24));break D}if(M>>>0<6){break C}}if(g[Q|0]&1){d=n+484414|0;h[d>>1]=k[d>>1]|2}if(j[Q|0]&8){d=n+484414|0;h[d>>1]=k[d>>1]|6}if(!(j[Q|0]&4)){break C}h[n+484412>>1]=0}if((s|0)!=($|0)){continue}break}}if(!(j[e+484|0]|j[e+485|0]<<8|(j[e+486|0]<<16|j[e+487|0]<<24))|!(j[e+488|0]|j[e+489|0]<<8)){break j}d=j[e+484|0]|j[e+485|0]<<8|(j[e+486|0]<<16|j[e+487|0]<<24);i[114610]=0;f=C(256,b|0,d<<8&16711680|d<<24|(d>>>8&65280|d>>>24))|0;d=i[114610];i[114610]=0;if((d|0)==1){break h}if(!f){break j}d=j[e+488|0]|j[e+489|0]<<8;h[e+152>>1]=(d<<24|d<<8&16711680)>>>16;d=j[e+827|0];i[114610]=0;h[e+80>>1]=d;f=C(477,e+152|0,e+80|0)|0;d=i[114610];i[114610]=0;if((d|0)!=1){q=k[f>>1];if(!q){break j}d=j[e+490|0]|j[e+491|0]<<8;p=(d<<24|d<<8&16711680)>>>16|0;f=0;E:while(1){F:{i[114610]=0;I(786,b|0,e+152|0,p|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break k}i[114610]=0;G(787,e+56|0,2,e+152|0);d=i[114610];i[114610]=0;if((d|0)==1){break l}i[114610]=0;D(415,e+80|0,e+56|0);d=i[114610];i[114610]=0;if((d|0)==1){break l}f=f+1|0;t=((f<<2)+a|0)+900380|0;d=i[t>>2];i[114610]=0;C(369,d+492|0,e+80|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break m}eb(e+80|0);d=i[t>>2];i[114610]=0;D(788,e+80|0,d|0);d=i[114610];i[114610]=0;if((d|0)==1){break n}ma=e,na=Wm(e+80|0),i[ma+56>>2]=na;ma=e,na=fi(e+80|0),i[ma+408>>2]=na;while(1){i[114610]=0;n=C(789,e+56|0,e+408|0)|0;d=i[114610];i[114610]=0;G:{if((d|0)!=1){if(n){break G}_o(e+80|0);if((f|0)!=(q|0)){continue E}break j}break F}i[114610]=0;n=F(790,e+56|0)|0;d=i[114610];i[114610]=0;if((d|0)!=1){r=i[t>>2];d=i[r+520>>2];z=(k[n>>1]<<5)+a|0;n=z+946324|0;i[n>>2]=i[r+516>>2];i[n+4>>2]=d;d=i[r+512>>2];n=z+946316|0;i[n>>2]=i[r+508>>2];i[n+4>>2]=d;d=i[r+504>>2];n=z+946308|0;i[n>>2]=i[r+500>>2];i[n+4>>2]=d;d=i[r+496>>2];n=z+946300|0;i[n>>2]=i[r+492>>2];i[n+4>>2]=d;Js(e+56|0);continue}break}}break}m=B()|0;A()|0;_o(e+80|0);break f}m=B()|0;A()|0;break f}m=B()|0;A()|0;break e}m=B()|0;A()|0;break e}m=B()|0;A()|0;break f}m=B()|0;A()|0;break f}m=B()|0;A()|0;eb(e+80|0);break f}m=B()|0;A()|0;break f}m=B()|0;A()|0;break f}pc(b);H:{I:{J:{K:{L:{M:{N:{if(!j[ia|0]){break N}Q=c&1;aa=a+484344|0;da=a+1304424|0;L=a+1304400|0;O=a+484360|0;M=e+152|1;w=e+152|4;c=e+32|4;U=e+32|2;X=e+72|2;_=e+72|3;V=e+544|2;while(1){i[114610]=0;J(791,b|0,e+856|0,e+464|0,e+544|0);d=i[114610];i[114610]=0;O:{P:{Q:{R:{S:{T:{U:{V:{W:{if((d|0)==1){break W}n=ka&255;if(n){i[114610]=0;f=F(485,O|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break W}if((f|0)==255){break d}}y=bi(O,n);W=xDa(e+408|0);rp(y);if(j[e+855|0]>1){break U}d=j[V|0]|j[V+1|0]<<8;if((d<<24|d<<8&16711680)>>>16>>>0>256|k[a+480188>>1]>16){break S}pP(e+152|0,e+544|0);d=j[V|0]|j[V+1|0]<<8;i[114610]=0;S(792,y|0,e+152|0,(d<<8&16711680|d<<24)>>>16|0,65535,65535)|0;d=i[114610];i[114610]=0;if((d|0)==1){break T}ma=e,na=Jb(y),i[ma+152>>2]=na;ma=e,na=Kb(y),i[ma+80>>2]=na;if(pb(e+152|0,e+80|0)){break V}break Q}m=B()|0;A()|0;break f}while(1){d=i[e+152>>2];h[d>>1]=k[d>>1]+ea;he(e+152|0);if(pb(e+152|0,e+80|0)){continue}break}break Q}pP(e+152|0,e+544|0);if(!(j[e+164|0]|j[e+165|0]<<8)){break S}d=j[e+164|0]|j[e+165|0]<<8;if((d<<24|d<<8&16711680)>>>16>>>0>64|k[a+480188>>1]>64){break S}p=j[e+172|0]|j[e+173|0]<<8|(j[e+174|0]<<16|j[e+175|0]<<24);if(!(j[e+176|0]|j[e+177|0]<<8)){u=32;break R}d=j[e+176|0]|j[e+177|0]<<8;i[114610]=0;h[e+80>>1]=(d<<8&16711680|d<<24)>>>16;h[e+56>>1]=800;f=C(477,e+80|0,e+56|0)|0;d=i[114610];i[114610]=0;if((d|0)!=1){d=k[f>>1];i[114610]=0;u=eg(793,((d<<5)+50>>>0)/100|0,0);d=i[114610];i[114610]=0;if((d|0)!=1){break R}}m=B()|0;A()|0;break H}m=B()|0;A()|0;break H}Zo(W);break d}d=j[e+160|0]|j[e+161|0]<<8|(j[e+162|0]<<16|j[e+163|0]<<24);i[114610]=0;f=C(256,b|0,d<<8&16711680|d<<24|(d>>>8&65280|d>>>24))|0;d=i[114610];i[114610]=0;X:{if((d|0)==1){break X}Y:{if(!f){break Y}m=0;if(!k[a+480188>>1]){break Y}Z:{while(1){_:{i[114610]=0;f=F(387,b|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break _}i[114610]=0;g[e+80|0]=f;g[e+56|0]=64;f=C(391,e+80|0,e+56|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break Z}h[((m<<5)+a|0)+480286>>1]=j[f|0];m=m+1|0;if(m>>>0<k[a+480188>>1]){continue}break Y}break}m=B()|0;A()|0;break H}m=B()|0;A()|0;break H}$:{aa:{if(!(j[e+168|0]|j[e+169|0]<<8|(j[e+170|0]<<16|j[e+171|0]<<24))){break aa}d=j[e+168|0]|j[e+169|0]<<8|(j[e+170|0]<<16|j[e+171|0]<<24);i[114610]=0;f=C(256,b|0,d<<8&16711680|d<<24|(d>>>8&65280|d>>>24))|0;d=i[114610];i[114610]=0;if((d|0)==1){break X}if(!f){break aa}m=0;if(!k[a+480188>>1]){break $}while(1){ba:{i[114610]=0;f=F(794,b|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break ba}ma=((m<<5)+a|0)+480284|0,na=(Eb(f,-16,16)<<3)+128|0,h[ma>>1]=na;m=m+1|0;if(m>>>0<k[a+480188>>1]){continue}break $}break}m=B()|0;A()|0;break H}i[114610]=0;D(449,a|0,1);d=i[114610];i[114610]=0;if((d|0)==1){break X}}t=e+136|0;iDa(t);d=j[w|0]|j[w+1|0]<<8|(j[w+2|0]<<16|j[w+3|0]<<24);i[114610]=0;f=C(256,b|0,d<<8&16711680|d<<24|(d>>>8&65280|d>>>24))|0;d=i[114610];i[114610]=0;ca:{da:{ea:{fa:{ga:{if((d|0)==1){break ga}s=1;m=0;if(!f){break ca}d=j[V|0]|j[V+1|0]<<8;i[114610]=0;f=C(258,b|0,(d<<8&16711680|d<<24)>>>15|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break ga}if(!f){break ca}d=j[V|0]|j[V+1|0]<<8;i[114610]=0;f=I(795,b|0,t|0,(d<<8&16711680|d<<24)>>>16|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break ga}if(!f){break ca}ma=e,na=Jb(t),i[ma+32>>2]=na;ma=e,na=Kb(t),i[ma+128>>2]=na;if(!pb(e+32|0,e+128|0)){break da}while(1){d=i[e+32>>2];d=j[d|0]|j[d+1|0]<<8;f=(d<<24|d<<8&16711680)>>>16|0;d=j[e+166|0]|j[e+167|0]<<8;ha:{if(f>>>0>(d<<24|d<<8&16711680)>>>16>>>0){break ha}d=j[e+152|0]|j[e+153|0]<<8|(j[e+154|0]<<16|j[e+155|0]<<24);i[114610]=0;C(256,b|0,(d<<8&16711680|d<<24|(d>>>8&65280|d>>>24))+(f<<2)|0)|0;d=i[114610];i[114610]=0;ia:{ja:{ka:{la:{ma:{if((d|0)==1){break ma}i[114610]=0;f=F(494,b|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break ma}i[114610]=0;f=C(256,b|0,f|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break ma}if(!f){i[114610]=0;f=C(258,b|0,42)|0;d=i[114610];i[114610]=0;if((d|0)==1){break ma}if(f){break ha}}i[114610]=0;C(796,b|0,e+80|0)|0;d=i[114610];i[114610]=0;na:{if((d|0)!=1){if(Uc(y)){break na}i[114610]=0;D(797,y|0,65534);d=i[114610];i[114610]=0;if((d|0)!=1){break na}}m=B()|0;A()|0;break ea}d=j[e+120|0]|j[e+121|0]<<8;i[114610]=0;d=(d<<8&16711680|d<<24)>>>16|0;i[e+76>>2]=d;f=C(258,b|0,d|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break la}if(!f){i[114610]=0;f=F(548,b|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break la}kc(e+76|0,f)}kc(e+76|0,65534);q=Wb(y);i[114610]=0;D(798,y|0,q+i[e+76>>2]|0);d=i[114610];i[114610]=0;if((d|0)==1){break ja}s=0;if(!i[e+76>>2]){break ka}while(1){oa:{i[114610]=0;f=F(484,b|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break oa}d=f<<16>>16;if((d|0)>=0){i[114610]=0;D(797,y|0,d+ea&65535);d=i[114610];i[114610]=0;if((d|0)==1){break oa}}s=s+1|0;if(s>>>0<l[e+76>>2]){continue}break ka}break}m=B()|0;A()|0;break ea}m=B()|0;A()|0;break ea}m=B()|0;A()|0;break ea}pa:{if(!j[e+80|0]){break pa}i[114610]=0;D(799,e+56|0,e+80|0);d=i[114610];i[114610]=0;qa:{if((d|0)!=1){i[114610]=0;D(487,y|0,e+56|0);d=i[114610];i[114610]=0;if((d|0)==1){break qa}eb(e+56|0);break pa}m=B()|0;A()|0;break ea}m=B()|0;A()|0;eb(e+56|0);break ea}if(!(j[e+112|0]|j[e+113|0]<<8|(j[e+114|0]<<16|j[e+115|0]<<24))){break ha}d=j[e+112|0]|j[e+113|0]<<8|(j[e+114|0]<<16|j[e+115|0]<<24);i[114610]=0;f=C(256,b|0,d<<8&16711680|d<<24|(d>>>8&65280|d>>>24))|0;d=i[114610];i[114610]=0;if((d|0)!=1){break ia}}m=B()|0;A()|0;break ea}if(!f){break ha}while(1){ra:{i[114610]=0;f=C(800,b|0,e+72|0)|0;d=i[114610];i[114610]=0;sa:{ta:{if((d|0)!=1){if(!f){break ha}d=j[_|0];i[114610]=0;G(341,e+56|0,b|0,d|0);d=i[114610];i[114610]=0;if((d|0)==1){break ta}d=j[e+72|0]|j[e+73|0]<<8;i[114610]=0;f=F(801,q+((d<<8&16711680|d<<24)>>>16|0)|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break fa}h[e+54>>1]=f;if((j[e+72|0]|j[e+73|0]<<8)==65535){break ra}d=k[e+54>>1];if(Wb(y)>>>0>d>>>0){break sa}hb(e+56|0);break ha}m=B()|0;A()|0;break ea}m=B()|0;A()|0;break ea}ua:{if(j[X|0]==1){d=65535}else{if(j[X|0]!=2){break ua}i[114610]=0;n=F(484,e+56|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break fa}i[114610]=0;f=C(802,W|0,e+54|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break fa}h[f>>1]=n;d=65534}ma=$b(y,k[e+54>>1]),na=d,h[ma>>1]=na}hb(e+56|0);continue}break}hb(e+56|0)}he(e+32|0);if(pb(e+32|0,e+128|0)){continue}break}break da}m=B()|0;A()|0;break ea}m=B()|0;A()|0;hb(e+56|0)}nP(t);break H}s=0;m=1}nP(t);if(m){f=u>>>(p>>>25&1)|0;break P}Zo(W);if(!s){break d}break O}m=B()|0;A()|0;break H}i[114610]=0;D(449,a|0,1);d=i[114610];i[114610]=0;va:{if((d|0)!=1){m=0;f=32;if(!k[a+480188>>1]){break P}while(1){d=j[(e+m|0)+810|0];i[114610]=0;g[e+152|0]=d;g[e+80|0]=64;n=C(391,e+152|0,e+80|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break va}h[((m<<5)+a|0)+480286>>1]=j[n|0];m=m+1|0;if(m>>>0<k[a+480188>>1]){continue}break}break P}m=B()|0;A()|0;break H}m=B()|0;A()|0;break H}q=j[e+807|0];d=j[e+804|0]|j[e+805|0]<<8;fa=j[e+807|0]&64;Y=j[e+808|0]&32;ga=(j[e+808|0]&31)+1|0;ma=a,na=mP((d<<24|d<<8&16711680)>>>16|0,fa>>>6|0,Y>>>5|0,ga),i[ma+480204>>2]=na;ma=a,na=hd(j[e+809|0],1,32),i[ma+480196>>2]=na;if(Y){i[a+480216>>2]=ga;i[a+480220>>2]=ga<<2}wa:{xa:{if(j[e+826|0]){d=j[e+826|0];i[114610]=0;g[e+152|0]=d;g[e+80|0]=64;n=C(391,e+152|0,e+80|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break xa}i[a+480200>>2]=j[n|0]<<2}i[a+480228>>2]=f;i[a+480232>>2]=f;i[a+480208>>2]=i[a+480208>>2]&-3|(j[e+807|0]>>>4^-1)&2;ya:{za:{Aa:{Ba:{Ca:{Da:{Ea:{Fa:{Ga:{Ha:{Ia:{Ja:{if(!(j[e+508|0]|j[e+509|0]<<8|(j[e+510|0]<<16|j[e+511|0]<<24))){break Ja}d=j[e+508|0]|j[e+509|0]<<8|(j[e+510|0]<<16|j[e+511|0]<<24);i[114610]=0;f=C(256,b|0,d<<8&16711680|d<<24|(d>>>8&65280|d>>>24))|0;d=i[114610];i[114610]=0;if((d|0)==1){break Ia}if(!f){break Ja}d=j[e+512|0]|j[e+513|0]<<8|(j[e+514|0]<<16|j[e+515|0]<<24);i[114610]=0;I(481,b|0,L|0,d<<8&16711680|d<<24|(d>>>8&65280|d>>>24))|0;d=i[114610];i[114610]=0;if((d|0)==1){break Ia}if(j[ia|0]<2){break Ja}i[114610]=0;G(13,e+152|0,2,L|0);d=i[114610];i[114610]=0;if((d|0)==1){break Ha}i[114610]=0;D(487,y|0,e+152|0);d=i[114610];i[114610]=0;if((d|0)==1){break Ga}eb(e+152|0)}d=j[e+480|0]|j[e+481|0]<<8|(j[e+482|0]<<16|j[e+483|0]<<24);Ka:{if((d<<24|d<<8&16711680|(d>>>8&65280|d>>>24))>>>0<2){break Ka}d=j[e+476|0]|j[e+477|0]<<8|(j[e+478|0]<<16|j[e+479|0]<<24);i[114610]=0;f=C(256,b|0,d<<8&16711680|d<<24|(d>>>8&65280|d>>>24))|0;d=i[114610];i[114610]=0;if((d|0)==1){break Ia}if(!f){break Ka}d=j[e+480|0]|j[e+481|0]<<8|(j[e+482|0]<<16|j[e+483|0]<<24);i[114610]=0;N(587,da|0,b|0,(d<<8&16711680|d<<24|(d>>>8&65280|d>>>24))+ -1|0,4)|0;d=i[114610];i[114610]=0;if((d|0)==1){break Ia}}if(!(j[e+520|0]|j[e+521|0]<<8|(j[e+522|0]<<16|j[e+523|0]<<24))){break wa}d=j[e+520|0]|j[e+521|0]<<8|(j[e+522|0]<<16|j[e+523|0]<<24);i[114610]=0;f=C(256,b|0,d<<8&16711680|d<<24|(d>>>8&65280|d>>>24))|0;d=i[114610];i[114610]=0;if((d|0)==1){break Ia}if(!f){break wa}i[114610]=0;C(338,b|0,6)|0;d=i[114610];i[114610]=0;if((d|0)==1){break Ia}i[114610]=0;f=F(484,b|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break Ia}if((f|0)!=1){break wa}i[114610]=0;n=F(494,b|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break Ea}if(!n){break wa}i[114610]=0;f=C(258,b|0,n|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break Ea}if(f){break Fa}break wa}m=B()|0;A()|0;break H}m=B()|0;A()|0;break H}m=B()|0;A()|0;eb(e+152|0);break H}Lc(e+152|0,da);i[114610]=0;N(587,da|0,b|0,n|0,4)|0;d=i[114610];i[114610]=0;if((d|0)==1){break za}if(!Cc(e+152|0)){i[114610]=0;f=I(803,e+56|0,2,13)|0;d=i[114610];i[114610]=0;if((d|0)==1){break Da}i[114610]=0;G(804,e+80|0,e+152|0,f|0);d=i[114610];i[114610]=0;if((d|0)==1){break Ca}i[114610]=0;G(805,e+40|0,e+80|0,da|0);d=i[114610];i[114610]=0;if((d|0)==1){break Ba}mb(da,e+40|0);eb(e+40|0);eb(e+80|0);eb(f)}eb(e+152|0);break wa}m=B()|0;A()|0;break H}m=B()|0;A()|0;break ya}m=B()|0;A()|0;break Aa}m=B()|0;A()|0;eb(e+80|0)}eb(f);break ya}m=B()|0;A()|0}eb(e+152|0);break H}m=B()|0;A()|0;break H}La:{if(!(j[e+532|0]|j[e+533|0]<<8|(j[e+534|0]<<16|j[e+535|0]<<24))|j[e+855|0]<2){break La}v=0;if(!k[a+480188>>1]){break La}while(1){d=j[e+532|0]|j[e+533|0]<<8|(j[e+534|0]<<16|j[e+535|0]<<24);i[114610]=0;f=C(256,b|0,(d<<8&16711680|d<<24|(d>>>8&65280|d>>>24))+(v<<2)|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break I}Ma:{if(!f){break Ma}i[114610]=0;f=F(494,b|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break I}i[114610]=0;n=C(256,b|0,f|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break I}f=0;d=0;if(!n){break Ma}while(1){Na:{i[114610]=0;p=C(258,b|0,8)|0;n=i[114610];i[114610]=0;Oa:{Pa:{Qa:{if((n|0)!=1){if(!p){break Na}i[114610]=0;C(806,b|0,e+152|0)|0;n=i[114610];i[114610]=0;if((n|0)==1){break Qa}if(!(j[e+152|0]|j[e+153|0]<<8|(j[e+154|0]<<16|j[e+155|0]<<24))){break Na}n=(j[e+152|0]|j[e+153|0]<<8|(j[e+154|0]<<16|j[e+155|0]<<24))&-225;switch((n<<24|n<<8&16711680|(n>>>8&65280|n>>>24))+ -1|0){case 1:break Oa;case 0:break Pa;default:continue}}m=B()|0;A()|0;break H}m=B()|0;A()|0;break H}f=j[w|0]|j[w+1|0]<<8|(j[w+2|0]<<16|j[w+3|0]<<24);f=f<<24|f<<8&16711680|(f>>>8&65280|f>>>24);continue}d=j[w|0]|j[w+1|0]<<8|(j[w+2|0]<<16|j[w+3|0]<<24);d=d<<24|d<<8&16711680|(d>>>8&65280|d>>>24);continue}break}if(!f|!d){break Ma}i[114610]=0;n=C(256,b|0,f|0)|0;f=i[114610];i[114610]=0;if((f|0)==1){break J}if(!n){break Ma}i[114610]=0;I(639,b|0,((v<<5)+a|0)+480289|0,d|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break J}}v=v+1|0;if(v>>>0<k[a+480188>>1]){continue}break}}f=j[e+544|0]|j[e+545|0]<<8;i[114610]=0;H=(f<<8&16711680|f<<24)>>>16|0;D(401,aa|0,ea+H&65535);d=i[114610];i[114610]=0;Ra:{if((d|0)==1){break Ra}Sa:{if(f){$=q&16;ba=ea&65535;r=H>>>0>1?H:1;d=0;while(1){Ta:{if(!Q){break Ta}f=j[e+872|0]|j[e+873|0]<<8|(j[e+874|0]<<16|j[e+875|0]<<24);i[114610]=0;n=C(256,b|0,(f<<8&16711680|f<<24|(f>>>8&65280|f>>>24))+(d<<2)|0)|0;f=i[114610];i[114610]=0;if((f|0)==1){break Sa}if(!n){break Ta}i[114610]=0;n=F(494,b|0)|0;f=i[114610];i[114610]=0;if((f|0)==1){break Sa}i[114610]=0;n=C(256,b|0,n|0)|0;f=i[114610];i[114610]=0;if((f|0)==1){break Sa}if(!n){break Ta}ha=Ab(e+136|0);i[114610]=0;R=F(277,e+80|0)|0;f=i[114610];i[114610]=0;Ua:{Va:{if((f|0)!=1){t=j[e+855|0];if(t){break Va}i[114610]=0;C(807,b|0,e+152|0)|0;f=i[114610];i[114610]=0;if((f|0)==1){break L}h[e+128>>1]=j[e+152|0];u=j[M|0]+1|0;f=48;break Ua}m=B()|0;A()|0;break K}q=g[e+806|0];i[114610]=0;C(808,b|0,e+32|0)|0;f=i[114610];i[114610]=0;Wa:{Xa:{if((f|0)!=1){f=j[e+32|0]|j[e+33|0]<<8;h[e+128>>1]=(f<<24|f<<8&16711680)>>>16;f=j[U|0]|j[U+1|0]<<8;u=((f<<24|f<<8&16711680)>>>16|0)+1|0;f=c;if(!(j[f|0]|j[f+1|0]<<8|(j[f+2|0]<<16|j[f+3|0]<<24))){break Wa}p=i[b+8>>2];f=j[c|0]|j[f+1|0]<<8|(j[f+2|0]<<16|j[f+3|0]<<24);i[114610]=0;C(256,b|0,f<<8&16711680|f<<24|(f>>>8&65280|f>>>24))|0;f=i[114610];i[114610]=0;if((f|0)==1){break L}i[114610]=0;C(809,b|0,e+152|0)|0;f=i[114610];i[114610]=0;if((f|0)==1){break L}f=j[w|0]|j[w+1|0]<<8|(j[w+2|0]<<16|j[w+3|0]<<24);i[114610]=0;n=C(256,b|0,f<<8&16711680|f<<24|(f>>>8&65280|f>>>24))|0;f=i[114610];i[114610]=0;if((f|0)==1){break L}if(!n){break Xa}f=j[e+160|0]|j[e+161|0]<<8|(j[e+162|0]<<16|j[e+163|0]<<24);i[114610]=0;I(481,b|0,ha|0,f<<8&16711680|f<<24|(f>>>8&65280|f>>>24))|0;f=i[114610];i[114610]=0;if((f|0)!=1){break Xa}break L}break L}Ya:{if(!(j[e+168|0]|j[e+169|0]<<8|(j[e+170|0]<<16|j[e+171|0]<<24))){break Ya}f=j[e+168|0]|j[e+169|0]<<8|(j[e+170|0]<<16|j[e+171|0]<<24);i[114610]=0;n=C(256,b|0,f<<8&16711680|f<<24|(f>>>8&65280|f>>>24))|0;f=i[114610];i[114610]=0;if((f|0)==1){break L}if(!n){break Ya}i[114610]=0;n=F(494,b|0)|0;f=i[114610];i[114610]=0;if((f|0)==1){break L}i[114610]=0;n=C(256,b|0,n|0)|0;f=i[114610];i[114610]=0;if((f|0)==1){break L}if(!n){break Ya}i[114610]=0;G(341,e+56|0,b|0,o(k[e+128>>1],u)|0);f=i[114610];i[114610]=0;if((f|0)==1){break L}Cd(R,e+56|0);hb(e+56|0)}i[114610]=0;C(256,b|0,p|0)|0;f=i[114610];i[114610]=0;if((f|0)==1){break L}}f=q+(t>>>0<3?48:24)|0}i[114610]=0;q=d+ba|0;p=I(402,aa|0,q&65535,u|0)|0;n=i[114610];i[114610]=0;if((n|0)==1){break L}if(p){K=Fb(aa,q);i[114610]=0;C(496,K|0,ha|0)|0;n=i[114610];i[114610]=0;if((n|0)==1){break L}Ag(e+128|0,k[a+480188>>1]);P=0;while(1){i[114610]=0;m=I(471,K|0,P|0,0)|0;n=i[114610];i[114610]=0;Za:{_a:{if((n|0)!=1){v=0;if(k[e+128>>1]){break _a}break Za}break L}while(1){$a:{if(!j[e+855|0]){i[114610]=0;D(810,e+152|0,b|0);n=i[114610];i[114610]=0;if((n|0)!=1){q=Nc(e+152|0);n=yf(e+152|0);p=j[e+152|0];g[m+1|0]=p>>>3&16|j[q|0]>>>4|p>>>1&32;g[m+3|0]=j[q|0]&15;g[m+5|0]=j[n|0];n=p&63;s=n?n+f|0:0;break $a}break L}i[114610]=0;D(598,e+152|0,b|0);n=i[114610];i[114610]=0;ab:{bb:{if((n|0)!=1){z=Nc(e+152|0);t=yf(e+152|0);q=li(e+152|0);i[114610]=0;p=F(387,R|0)|0;n=i[114610];i[114610]=0;if((n|0)==1){break L}g[m+4|0]=p;p=j[e+152|0];n=p&127;if(!n){break bb}s=f+n|0;break ab}break L}s=0;if((p|0)!=128){break ab}g[m|0]=254}g[m+1|0]=j[z|0]&63;g[m+3|0]=j[t|0];g[m+5|0]=j[q|0]}if(s+ -1>>>0<=119){g[m|0]=s}i[114610]=0;T(811,m|0,(fa|0)!=0|0,(Y|0)!=0|0,ga|0,($|0)!=0|0);n=i[114610];i[114610]=0;if((n|0)!=1){ca=(s|0)>84&ja|ca;m=m+6|0;v=v+1|0;if((v&65535)>>>0>=k[e+128>>1]){break Za}continue}break}break L}P=P+1|0;if((P|0)!=(u|0)){continue}break}}hb(R);eb(ha)}d=d+1|0;if((r|0)!=(d|0)){continue}break}}ma=e,na=Wm(W),i[ma+80>>2]=na;ma=e,na=fi(W),i[ma+56>>2]=na;cb:{while(1){i[114610]=0;f=C(812,e+80|0,e+56|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break M}db:{eb:{fb:{gb:{hb:{ib:{if(!f){if(!(j[e+464|0]|j[e+465|0]<<8|(j[e+466|0]<<16|j[e+467|0]<<24))){break ib}d=j[e+464|0]|j[e+465|0]<<8|(j[e+466|0]<<16|j[e+467|0]<<24);i[114610]=0;f=C(256,b|0,d<<8&16711680|d<<24|(d>>>8&65280|d>>>24))|0;d=i[114610];i[114610]=0;if((d|0)==1){break Ra}if(!f){break ib}ea=H+ea|0;Zo(W);break O}i[114610]=0;p=F(813,e+80|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break hb}d=k[p>>1];if(!d){m=0;break gb}i[114610]=0;f=C(546,y|0,d+ -1&65535)|0;d=i[114610];i[114610]=0;if((d|0)==1){break db}m=k[p>>1];if(!f){break gb}i[114610]=0;m=C(814,y|0,m+ -1&65535)|0;d=i[114610];i[114610]=0;if((d|0)!=1){break fb}break db}Zo(W);break N}m=B()|0;A()|0;break H}if(k[p+2>>1]==((m&65535)+1|0)){break eb}i[114610]=0;m=I(815,aa|0,1,0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break db}if((m|0)==65535){break eb}ma=$b(y,k[p>>1]),na=m,h[ma>>1]=na}n=Fb(aa,m);d=k[p+2>>1];i[114610]=0;f=F(816,d|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break cb}i[114610]=0;f=I(498,e+152|0,12,f|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break cb}d=dn(Ee(f,i[Fb(aa,m)+12>>2]+ -1|0));i[114610]=0;C(499,n|0,d|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break cb}H=m>>>0<(H&65535)>>>0?H:m+1|0}i[114610]=0;F(817,e+80|0)|0;d=i[114610];i[114610]=0;if((d|0)!=1){continue}break M}break}m=B()|0;A()|0;break H}m=B()|0;A()|0;break H}m=B()|0;A()|0;break H}m=B()|0;A()|0;break H}ka=ka+1|0;if((ka&255)>>>0<j[ia|0]){continue}break}}i[114610]=0;D(489,a+484360|0,0);b=i[114610];i[114610]=0;if((b|0)!=1){if(!(ca&1)){r=k[a+480192>>1];if(r){m=1;while(1){c=(((m&65535)<<2)+a|0)+900380|0;b=i[c>>2];if(b){Cb(Is(b));r=k[a+480192>>1]}i[c>>2]=0;m=m+1|0;if((m&65535)>>>0<=(r&65535)>>>0){continue}break}}h[a+480192>>1]=0}jb:{kb:{lb:{mb:{nb:{ob:{pb:{if(la){i[114610]=0;c=C(2,e+152|0,14912)|0;b=i[114610];i[114610]=0;if((b|0)==1){break pb}i[114610]=0;G(650,a|0,2,c|0);b=i[114610];i[114610]=0;if((b|0)==1){break ob}eb(c)}r=14959;switch(j[e+855|0]){case 3:break kb;case 2:break lb;case 1:break mb;case 0:break nb;default:break jb}}m=B()|0;A()|0;break f}m=B()|0;A()|0;eb(c);break f}r=k[a+480188>>1]>4?14960:14981;break jb}r=14995;break jb}r=15013;break jb}r=15031}i[114610]=0;c=C(2,e+16|0,15058)|0;b=i[114610];i[114610]=0;qb:{rb:{sb:{tb:{ub:{if((b|0)!=1){i[114610]=0;D(219,e+80|0,c|0);b=i[114610];i[114610]=0;if((b|0)==1){break ub}i[114610]=0;G(537,e+152|0,e+80|0,e+855|0);b=i[114610];i[114610]=0;if((b|0)==1){break tb}mb(a+1304436|0,e+152|0);eb(e+152|0);ob(e+80|0);eb(c);i[114610]=0;c=C(2,e+152|0,15074)|0;b=i[114610];i[114610]=0;if((b|0)==1){break rb}mb(a+1304448|0,c);eb(c);i[114610]=0;C(238,a+1304460|0,r|0)|0;b=i[114610];i[114610]=0;m=1;if((b|0)==1){break qb}i[a+1304496>>2]=2;break c}m=B()|0;A()|0;break f}m=B()|0;A()|0;break sb}m=B()|0;A()|0;ob(e+80|0)}eb(c);break f}m=B()|0;A()|0;break f}m=B()|0;A()|0;break f}m=B()|0;A()|0;break f}m=B()|0;A()|0;break H}m=B()|0;A()|0;hb(R)}eb(ha);break H}m=B()|0;A()|0;break H}m=B()|0;A()|0}Zo(W);break f}m=B()|0;A()|0;break f}m=B()|0;A()|0;break f}m=B()|0;A()|0;hb(U)}jP(Z)}hb(e+832|0);E(m|0);x()}m=0}jP(Z)}hb(e+832|0)}Xa=e+912|0;return m|0}function Tr(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,m=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,H=0,K=0,M=0,O=0,P=0,Q=0,R=0,T=0,U=0,V=0,W=0,Y=0,Z=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0;m=Xa-176|0;Xa=m;jpa(a);M=xpa(m+144|0);e=k[d+4>>1];h[M+24>>1]=e;s=i[d>>2];i[M+16>>2]=s;ba=i[d+16>>2];ha=j[d+6|0];na=b+484360|0;if(ha>>>0>=ph(na)>>>0){ha=j[na+16|0]}oa=a;V=bi(na,ha);i[114610]=0;K=C(1333,m+104|0,b|0)|0;a=i[114610];i[114610]=0;a:{if((a|0)!=1){ta=K+4|0;f=i[ta>>2];i[114610]=0;ca=I(1334,m+72|0,b|0,ha|0)|0;a=i[114610];i[114610]=0;b:{if((a|0)!=1){h[f+64>>1]=e;h[f+62>>1]=e;i[f+52>>2]=s;i[f+48>>2]=s;$=m- -64|0;tf($);qa=Ss(m+56|0);c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{ra=c&7;ua=(ra|0)!=7;n:{if(ua){break n}i[114610]=0;I(1335,$|0,1,1)|0;a=i[114610];i[114610]=0;if((a|0)==1){break m}i[114610]=0;I(1335,$|0,2,1)|0;a=i[114610];i[114610]=0;if((a|0)==1){break m}i[114610]=0;I(1335,$|0,3,1)|0;a=i[114610];i[114610]=0;if((a|0)==1){break m}i[114610]=0;I(1335,$|0,28,1)|0;a=i[114610];i[114610]=0;if((a|0)==1){break m}i[114610]=0;I(1335,$|0,35,1)|0;a=i[114610];i[114610]=0;if((a|0)==1){break m}i[114610]=0;I(1335,$|0,37,1)|0;a=i[114610];i[114610]=0;if((a|0)==1){break m}i[114610]=0;I(1335,$|0,36,1)|0;a=i[114610];i[114610]=0;if((a|0)==1){break m}i[114610]=0;I(1335,$|0,38,1)|0;a=i[114610];i[114610]=0;if((a|0)==1){break m}i[114610]=0;I(1336,qa|0,12,1)|0;a=i[114610];i[114610]=0;if((a|0)==1){break m}i[114610]=0;I(1336,qa|0,13,1)|0;a=i[114610];i[114610]=0;if((a|0)==1){break m}if(k[b+480188>>1]){e=K+20|0;a=0;while(1){if(j[((a<<5)+b|0)+480281|0]&4){Ca=wc(e,a),Da=-1,i[Ca+16>>2]=Da}a=a+1|0;if(a>>>0<k[b+480188>>1]){continue}break}}if((ba|0)!=2){break n}a=k[d+12>>1];if(Wb(V)>>>0<=a>>>0){break n}a=k[$b(V,a)>>1];i[114610]=0;e=b+484344|0;s=C(442,e|0,a|0)|0;r=i[114610];i[114610]=0;if((r|0)==1){break d}if(!s){break n}r=Fb(e,a);s=i[d+8>>2];i[114610]=0;r=C(1337,r|0,s|0)|0;O=i[114610];i[114610]=0;if((O|0)==1){break d}if(!r){break n}a=Fb(e,a);i[114610]=0;a=I(471,a|0,s|0,0)|0;e=i[114610];i[114610]=0;if((e|0)==1){break e}if(!k[b+480188>>1]){break n}s=K+20|0;e=0;while(1){o:{p:{q:{switch(j[a|0]+ -253|0){case 0:if(k[b+480192>>1]){break p}break;case 1:case 2:break p;default:break q}}i[114610]=0;r=F(556,a|0)|0;O=i[114610];i[114610]=0;if((O|0)==1){break f}if(!r){break o}if(Ur(a)){break o}}Ca=wc(s,e),Da=-1,i[Ca+16>>2]=Da}a=a+6|0;e=e+1|0;if(e>>>0<k[b+480188>>1]){continue}break}}ea=f- -64|0;W=f+48|0;da=f+68|0;wa=f+44|0;sa=K+8|0;ia=c&1;z=K+20|0;P=b+1074308|0;Z=b+484344|0;xa=(ba|0)!=3;va=(ba|0)!=2;O=0;while(1){i[f+48>>2]=i[f+52>>2];a=k[f+64>>1];h[f+62>>1]=a;i[114610]=0;a=C(546,V|0,a|0)|0;e=i[114610];i[114610]=0;r:{if((e|0)!=1){s:{if(!a){break s}if(l[f+48>>2]<l[Fb(Z,k[$b(V,k[f+62>>1])>>1])+12>>2]){break s}i[W>>2]=0;kb(m,P,63);if(ib(m)){a=i[f+56>>2];i[f+56>>2]=0;i[f+48>>2]=a}a=k[f+64>>1]+1|0;h[f+62>>1]=a;h[f+64>>1]=a}if(n[K+32>>3]<n[d+8>>3]|xa){break r}g[M+26|0]=1;break g}a=B()|0;A()|0;break c}e=k[f+62>>1];a=f;t:{if(Wb(V)>>>0>e>>>0){e=k[$b(V,k[f+62>>1])>>1];break t}e=65535}h[a+60>>1]=e;i[114610]=0;a=C(442,Z|0,e&65535)|0;e=i[114610];i[114610]=0;if((e|0)==1){break i}if(!(k[f+60>>1]==65535|va|a|k[f+62>>1]!=k[d+12>>1])){g[M+26|0]=1;break g}u:{if(k[f+60>>1]<ke(Z)>>>0){break u}while(1){a=f;r=a;v:{w:{if(k[a+60>>1]!=65535){e=k[f+62>>1];if(Wb(V)>>>0>e>>>0){break w}}if(k[V+28>>1]==k[f+62>>1]){break u}e=k[V+28>>1];break v}e=k[f+62>>1]+1|0}h[r+62>>1]=e;a=f;x:{if(Wb(V)>>>0>(e&65535)>>>0){e=k[$b(V,k[f+62>>1])>>1];break x}e=65535}h[a+60>>1]=e;h[f+64>>1]=k[f+62>>1];i[114610]=0;a=C(442,Z|0,e&65535)|0;e=i[114610];i[114610]=0;if((e|0)==1){break h}y:{if(a){break y}a=k[f+62>>1];i[114610]=0;a=N(1338,ca|0,a|0,0,1)|0;e=i[114610];i[114610]=0;if((e|0)==1){break h}if(!a){break y}if(ba>>>0<=1){a=k[f+62>>1];i[M+8>>2]=0;h[M+20>>1]=a;if(!ba){break u}}i[114610]=0;a=N(1339,ca|0,ea|0,W|0,1)|0;e=i[114610];i[114610]=0;if((e|0)==1){break i}if(!a){break u}n[M>>3]=n[K+32>>3];i[114610]=0;D(1340,oa|0,M|0);a=i[114610];i[114610]=0;if((a|0)==1){break i}i[M+16>>2]=i[W>>2];h[M+24>>1]=k[ea>>1];i[114610]=0;L(1341,K|0);a=i[114610];i[114610]=0;if((a|0)==1){break i}a=k[f+64>>1];h[f+62>>1]=a;Ca=f,Da=k[$b(V,a)>>1],h[Ca+60>>1]=Da;i[f+52>>2]=i[f+48>>2];break u}if(k[f+60>>1]>=ke(Z)>>>0){continue}break}}if(k[ea>>1]==65535){break g}a=k[f+60>>1];i[114610]=0;a=C(442,Z|0,a|0)|0;e=i[114610];i[114610]=0;if((e|0)==1){break i}if(!a){if(k[V+28>>1]==k[f+62>>1]){if(!ba){break g}i[114610]=0;a=N(1339,ca|0,ea|0,W|0,1)|0;e=i[114610];i[114610]=0;if((e|0)==1){break i}if(!a){break g}n[M>>3]=n[K+32>>3];i[114610]=0;D(1340,oa|0,M|0);a=i[114610];i[114610]=0;if((a|0)==1){break i}i[M+16>>2]=i[W>>2];h[M+24>>1]=k[ea>>1];i[114610]=0;L(1341,K|0);a=i[114610];i[114610]=0;if((a|0)==1){break i}i[f+52>>2]=i[f+48>>2];continue}h[f+64>>1]=k[f+62>>1]+1;continue}if(l[f+48>>2]>=l[Fb(Z,k[f+60>>1])+12>>2]){i[W>>2]=0}a=k[f+62>>1];if(!((a|0)!=k[d+12>>1]|va|i[W>>2]!=i[d+8>>2])){g[M+26|0]=1;break g}e=i[W>>2];i[114610]=0;a=N(1338,ca|0,a|0,e|0,1)|0;e=i[114610];i[114610]=0;if((e|0)==1){break i}if(a){if(ba>>>0<=1){h[M+20>>1]=k[f+62>>1];i[M+8>>2]=i[f+48>>2];if(!ba){break g}}i[114610]=0;a=N(1339,ca|0,ea|0,W|0,1)|0;e=i[114610];i[114610]=0;if((e|0)==1){break i}if(!a){break g}n[M>>3]=n[K+32>>3];i[114610]=0;D(1340,oa|0,M|0);a=i[114610];i[114610]=0;if((a|0)==1){break i}i[M+16>>2]=i[W>>2];h[M+24>>1]=k[ea>>1];i[114610]=0;L(1341,K|0);a=i[114610];i[114610]=0;if((a|0)==1){break i}i[f+52>>2]=i[f+48>>2];continue}h[M+22>>1]=k[f+62>>1];a=i[f+48>>2];i[M+12>>2]=a;i[f+52>>2]=a+1;z:{A:{if(a>>>0>=l[Fb(Z,k[f+60>>1])+12>>2]){i[W>>2]=0;break A}if(i[W>>2]){break z}}a=0;if(!k[b+480188>>1]){break z}while(1){T=n[K+32>>3];Ca=wc(z,a),Ea=T,n[Ca>>3]=Ea;e=i[f>>2];Ca=wc(z,a),Da=e,i[Ca+8>>2]=Da;a=a+1|0;if(a>>>0<k[b+480188>>1]){continue}break}}a=Fb(Z,k[f+60>>1]);e=i[f+48>>2];i[114610]=0;a=I(471,a|0,e|0,0)|0;e=i[114610];i[114610]=0;B:{C:{D:{if((e|0)!=1){e=0;aa=0;ja=0;if(!k[b+480188>>1]){break C}while(1){E:{kb(m,P,77);F:{if(Ca=ib(m),Da=0,Fa=i[((e<<5)+b|0)+480280>>2]&1024,Fa?Ca:Da){break F}i[114610]=0;s=F(1342,a|0)|0;r=i[114610];i[114610]=0;G:{H:{I:{if((r|0)==1){break I}if(s){J:{if(!ia){break J}s=j[a+1|0];if(s+ -251>>>0<5|!s){break J}i[114610]=0;s=F(1343,a|0)|0;r=i[114610];i[114610]=0;if((r|0)==1){break I}i[114610]=0;r=F(1344,a|0)|0;t=i[114610];i[114610]=0;if((t|0)==1){break E}h[m+48>>1]=r;g[m|0]=j[a+1|0];h[m+2>>1]=k[m+48>>1];i[114610]=0;r=C(1345,sa|0,m|0)|0;t=i[114610];i[114610]=0;if((t|0)==1){break E}h[r>>1]=s}vs((o(e,896)+f|0)+1418|0);break F}s=o(e,896)+f|0;r=s+1422|0;t=j[a+4|0]|j[a+5|0]<<8;g[r|0]=t;g[r+1|0]=t>>>8;s=s+1418|0;r=j[a|0]|j[a+1|0]<<8|(j[a+2|0]<<16|j[a+3|0]<<24);g[s|0]=r;g[s+1|0]=r>>>8;g[s+2|0]=r>>>16;g[s+3|0]=r>>>24;K:{switch(j[a+3|0]+ -16|0){case 0:s=j[a+5|0];i[114610]=0;G(1346,b|0,f|0,s|0);s=i[114610];i[114610]=0;if((s|0)==1){break I}break F;case 3:break G;case 4:break H;case 1:break K;default:break F}}kb(m,P,5);if(!ib(m)){break F}s=j[a+5|0];if(!s){break F}i[114610]=0;G(1346,b|0,f|0,s|0);s=i[114610];i[114610]=0;if((s|0)!=1){break F}}a=B()|0;A()|0;break c}s=j[a+5|0];r=s&240;if((r|0)==96){ja=(s&15)+ja|0;break F}if((r|0)!=224|aa){break F}s=j[a+5|0]&15;if(i[b+480180>>2]&2){aa=0;if(!s){break F}}aa=s+1|0;break F}s=j[a+5|0];if((s&240)!=224){break F}aa=(s&15)+1|0}a=a+6|0;e=e+1|0;if(e>>>0<k[b+480188>>1]){continue}break D}break}a=B()|0;A()|0;break c}a=B()|0;A()|0;break c}e=ja;if(aa){break B}}aa=1;ja=e}Q=o(i[f+40>>2]+ja|0,aa);L:{if(!k[b+480188>>1]){s=0;la=0;pa=0;fa=0;ma=0;break L}v=Q+ -1|0;r=Q-aa|0;U=o(r,1e4);e=0;ma=0;fa=0;pa=0;la=0;s=0;while(1){M:{Y=o(e,896);t=Y+f|0;u=t+1418|0;N:{if(ppa(u)){break N}kb(m,P,77);if(Ca=ib(m),Da=0,Fa=i[((e<<5)+b|0)+480280>>2]&1024,Fa?Ca:Da){break N}q=j[t+1423|0];ga=t+1421|0;H=j[ga|0];y=j[u|0];a=t+1419|0;w=j[a|0];if(w){g[t+1429|0]=0;g[t+1433|0]=w;Ca=wc(z,e),Da=255,g[Ca+21|0]=Da}i[114610]=0;w=F(556,u|0)|0;R=i[114610];i[114610]=0;if((R|0)==1){break M}if(w){g[t+1429|0]=y}i[114610]=0;R=F(556,u|0)|0;w=i[114610];i[114610]=0;if((w|0)==1){break M}w=t+608|0;O:{P:{Q:{R:{S:{T:{if(j[a|0]?0:!R){break T}R=t+1433|0;a=j[R|0];if(k[b+480192>>1]){if(k[b+480192>>1]<a>>>0){break T}a=i[((j[R|0]<<2)+b|0)+900380>>2];if(!a){break T}U:{if(!(g[a+15|0]&1)){break U}R=i[a+8>>2];i[114610]=0;G(1347,w|0,R|0,b|0);R=i[114610];i[114610]=0;if((R|0)!=1){break U}a=B()|0;A()|0;break c}if(!Jd(y)){break T}a=k[Mc(a+236|0,y+ -1|0)>>1]}a=a&65535;if(!a|a>>>0>k[b+480190>>1]){break T}y=o(a,104)+b|0;R=y+484414|0;a=k[R>>1];if(a&32){a=k[y+484408>>1];i[114610]=0;G(1347,w|0,a|0,b|0);a=i[114610];i[114610]=0;if((a|0)==1){break S}a=k[R>>1]}if(!(a&512)){break T}a=i[ta>>2];i[114610]=0;L(1348,(a+Y|0)+608|0);a=i[114610];i[114610]=0;if((a|0)==1){break S}Ca=wc(z,e),Da=0,i[Ca+16>>2]=Da}V:{W:{X:{Y=t+1420|0;a=j[Y|0];switch(a+ -1|0){case 1:break Q;case 2:case 3:break W;case 0:break X;default:break V}}a=j[t+1422|0];Ca=wc(z,e),Da=a,g[Ca+21|0]=Da;break Q}a=j[t+1422|0];if(!a){break Q}g[t+1462|0]=a;break Q}if((a|0)==11){break R}break Q}a=B()|0;A()|0;break c}if(!j[t+1422|0]){break Q}rx(m,b,u,0);a=Pb(m);i[t+1384>>2]=i[m>>2]<<2;if(!j[a|0]){break Q}H=0;break P}Y:{Z:{_:{switch(H+ -12|0){case 0:a=i[f+48>>2];q=k[f+60>>1];i[114610]=0;a=S(1349,b|0,q|0,a|0,e&65535,0)|0;q=i[114610];i[114610]=0;if((q|0)==1){break M}i[f+56>>2]=0;h[f+64>>1]=a;if(!(i[b+480180>>2]&5?0:pa)){i[f+52>>2]=0}fa=1;if(!ia){ma=1;break N}i[t+1412>>2]=0;g[t+1469|0]=0;ma=1;break O;case 2:i[114610]=0;a=N(1350,b|0,f|0,e&65535,q|0)|0;u=i[114610];i[114610]=0;if((u|0)==1){break Z}if((a|0)==-1){H=14;break P}i[f+52>>2]=a;if(!ma){h[f+64>>1]=k[f+62>>1]+1}pa=1;if(!ia){break N}i[t+1412>>2]=0;g[t+1469|0]=0;break O;case 5:kb(m,P,5);H=17;if(ib(m)){break P}a=i[f+48>>2];u=k[f+60>>1];i[114610]=0;a=S(1349,b|0,u|0,a|0,e&65535,0)|0;u=i[114610];i[114610]=0;$:{aa:{if((u|0)!=1){a=o(a,1e4);if(!ia|!(i[b+480180>>2]&16777250)){break $}if(a>>>0<1e4){break aa}g[t+1463|0]=(a>>>0)/1e4;break $}a=B()|0;A()|0;break c}a=o(j[t+1463|0],1e4)}u=(a>>>0)/1e4|0;ba:{if(a>>>0>319999){break ba}y=o(U,u&15);a=i[f+44>>2];if((u&240)==16){a=a+y|0;break ba}u=a-y|0;a=u>>>0>a>>>0?0:u}i[f+44>>2]=a;a=i[i[b+8>>2]+20>>2];u=i[i[b+8>>2]+24>>2];kb(m,P,8);wn(wa,o(a,1e4),ib(m)?255e4:o(u,1e4));break P;case 8:H=20;ca:{switch((q&240)+ -144>>>4|0){case 0:if(q>>>0>145){break P}i[t+696>>2]=i[t+696>>2]&-257|((q|0)==145)<<8;break P;case 1:g[t+1464|0]=q&15;break P;case 2:u=e;a=e;if(i[b+480180>>2]==2){u=k[b+480188>>1]+ -1|0;a=0}if(!(q&15)){fa=0;s=1;u=u&65535;if((a&65535)>>>0>u>>>0){break P}while(1){T=n[K+32>>3];s=a&65535;Ca=wc(z,s),Ea=T,n[Ca>>3]=Ea;y=i[f>>2];Ca=wc(z,s),Da=y,i[Ca+8>>2]=Da;y=i[f+48>>2];Ca=wc(z,s),Da=y,i[Ca+12>>2]=Da;i[(o(s,896)+f|0)+1412>>2]=i[f+48>>2];s=1;a=a+1|0;if((a&65535)>>>0<=u>>>0){continue}break}break P}kb(m,P,16);if(!ib(m)){fa=0;la=1;if(i[b+480180>>2]!=2|(a&65535)>>>0>(u&65535)>>>0){break P}break Y}if((a&65535)>>>0<=(u&65535)>>>0){break Y}fa=0;la=1;break P;case 6:break ca;default:break P}}g[t+1472|0]=q&15;break P;case 7:H=19;a=q&240;if((a|0)!=240){if((a|0)!=96){break P}if(q&15){Ca=f,Da=i[wc(z,e)+12>>2],i[Ca+56>>2]=Da;la=1;break P}T=n[K+32>>3];Ca=wc(z,e),Ea=T,n[Ca>>3]=Ea;a=i[f>>2];Ca=wc(z,e),Da=a,i[Ca+8>>2]=Da;a=i[f+48>>2];Ca=wc(z,e),Da=a,i[Ca+12>>2]=Da;i[t+1412>>2]=i[f+48>>2];s=1;break P}g[t+1472|0]=q&15;break P;case 1:case 3:case 4:case 6:break P;default:break _}}if((H|0)!=28){break P}if((q&240)==160){kb(m,P,58);H=28;if(ib(m)){break P}g[t+1464|0]=q&15;break P}H=28;break P}a=B()|0;A()|0;break c}y=i[W>>2]+1|0;while(1){i[(o(a&65535,896)+f|0)+1412>>2]=y;la=1;fa=0;a=a+1|0;if((a&65535)>>>0<=(u&65535)>>>0){continue}break}}if(!ia){break N}da:{ea:{fa:{ga:{ha:{ia:{ja:{switch(H+ -2|0){case 0:if(!q){break O}kb(m,P,90);if(!ib(m)){g[t+1440|0]=q}g[t+1439|0]=q;break O;case 1:if(!q){break O}kb(m,P,90);if(!ib(m)){g[t+1439|0]=q}g[t+1440|0]=q;break O;case 2:if(!q){break O}i[t+1384>>2]=q<<2;break O;case 8:if(!q){break O}i[t+1272>>2]=q<<8;break O;case 4:case 9:if(!q){break O}g[t+1437|0]=q;break O;case 11:Ca=wc(z,e),Da=q,g[Ca+21|0]=Da;break O;case 21:a=q<<(!(i[b+480180>>2]&59593760)&q<<24>>24>-1)&255;if(a>>>0<=128){i[da>>2]=a<<1;break O}if(i[b+480180>>2]&16777250){break O}i[da>>2]=256;break O;case 22:kb(m,P,9);ka:{if(ib(m)){a=t+1445|0;if(q){g[a|0]=q;break ka}q=j[a|0];break ka}if(q){g[f+1445|0]=q;break ka}q=j[f+1445|0]}a=da;u=q&240;q=q&15;la:{if(!(!u|(q|0)!=15)){y=i[da>>2]+(u>>>4<<!(i[b+480180>>2]&59593760)<<1&254)|0;break la}y=i[da>>2]-(q<<(i[b+480180>>2]&59593760?1:2))|0;if(!(!q|(u|0)!=240)){break la}y=i[da>>2]+o(r,u>>>4<<(i[b+480180>>2]&59593760?1:2)&255)|0;if(u){break la}y=i[da>>2]-o(r,q<<(i[b+480180>>2]&59593760?1:2))|0}i[a>>2]=y;Kd(da,0,256);break O;case 19:if(q>>>0>64){break O}i[t+1368>>2]=q;break O;case 20:a=t+1444|0;ma:{if(q){g[a|0]=q;break ma}q=j[a|0]}y=t+1368|0;u=i[y>>2];i[m>>2]=u;a=q;H=a&240;q=a&15;na:{if(!(!H|(q|0)!=15)){i[m>>2]=u+(a>>>4|0);break na}if(!(!q|(H|0)!=240)){i[m>>2]=u-q;break na}if(q){i[m>>2]=u-o(q,r);break na}i[m>>2]=u+o(r,a>>>4|0)}Kd(m,0,64);i[y>>2]=i[m>>2];break O;case 7:$k(b,w,q,8);break O;case 25:break da;case 6:break ea;case 24:break fa;case 3:break ga;case 5:break ha;case 18:break ia;case 17:break ja;default:break O}}if(!k[b+480188>>1]|q>>>0>15){break ia}u=(q&1)<<14;a=0;while(1){y=o(a,896)+f|0;i[y+696>>2]=(u|i[y+696>>2]&-16385)^16384;a=a+1|0;if(a>>>0<k[b+480188>>1]){continue}break}}if((q&240)!=128){break O}$k(b,w,q&15,4);break O}if(q){g[t+1437|0]=q}q=0}Lj(w,q);break O}QK(b,w,q);break O}PK(w,q);break O}OK(w,q)}oa:{pa:{switch(j[Y|0]+ -2|0){case 0:$k(b,w,j[t+1422|0],6);break oa;case 5:kb(m,P,53);q=ib(m);a=j[t+1422|0];if(q){g[t+1451|0]=a&15;break oa}Lj(w,a<<4);break oa;case 6:break pa;default:break oa}}Lj(w,j[t+1422|0])}qa:{ra:{sa:{ta:{a=j[ga|0];switch(a+ -5|0){case 3:break ra;case 0:case 2:break sa;case 1:break N;default:break ta}}switch(a+ -26|0){case 1:break qa;case 0:break sa;default:break N}}ua:{if(i[b+480180>>2]&16777248){a=Q;if(!(j[b+480208|0]&4)){break ua}}a=r}q=j[t+1451|0];kb(m,P,21);w=ib(m);t=t+1447|0;a=o(a,q);g[t|0]=j[t|0]+(w?a<<2:a);break N}va:{if(i[b+480180>>2]&16777248){a=Q;if(!(j[b+480208|0]&4)){break va}}a=r}q=j[t+1454|0];kb(m,P,21);w=ib(m);t=t+1448|0;a=o(a,q);g[t|0]=j[t|0]+(w?a<<2:a);break N}a=t+1449|0;g[a|0]=j[a|0]+o(v,j[t+1457|0]);i[114610]=0;D(1351,b|0,w|0);a=i[114610];i[114610]=0;if((a|0)==1){break M}}e=e+1|0;if(e>>>0<k[b+480188>>1]){continue}break L}break}a=B()|0;A()|0;break c}if(i[f+40>>2]==65535?i[b+480180>>2]==4:0){break g}i[f+32>>2]=i[b+480216>>2];if(NK(Fb(Z,k[f+60>>1]))){Ca=f,Da=i[Fb(Z,k[f+60>>1])+16>>2],i[Ca+32>>2]=Da}i[114610]=0;t=C(1352,b|0,f|0)|0;a=i[114610];i[114610]=0;wa:{xa:{if((a|0)!=1){a=o(t,Q);n[K+32>>3]=+(a>>>0)/+l[b+24620>>2]+n[K+32>>3];i[f>>2]=a+i[f>>2];if(!(!k[b+480188>>1]|ua)){H=0;R=(O|0)!=0&(t|0)!=(O|0);ya=Q>>>0>1?Q:1;za=aa+ -1|0;while(1){ya:{if(i[wc(z,H)+16>>2]==-1){break ya}v=o(H,896)+f|0;U=v+1423|0;a=j[U|0];u=1;za:{Aa:{Y=v+1421|0;switch(j[Y|0]+ -4|0){case 0:case 2:break za;default:break Aa}}u=j[v+1420|0]==11}if(j[v+1419|0]){i[v+1268>>2]=0}i[114610]=0;ga=v+1418|0;e=F(556,ga|0)|0;r=i[114610];i[114610]=0;if((r|0)==1){break k}w=v+608|0;r=a&15;q=0;Ba:{if(!e){break Ba}Ca:{Da:{Ea:{if(!u){break Ea}if(!j[wc(z,H)+20|0]){break Ea}e=i[v+1308>>2];i[114610]=0;e=Hn(1353,b,w,e,0);q=_a;y=i[114610];i[114610]=0;if((y|0)==1){break Da}i[v+616>>2]=e;i[v+620>>2]=q}g[v+1432|0]=j[v+1429|0];y=v+1300|0;Aa=i[y>>2];e=j[v+1433|0];if(!e){break Ca}i[114610]=0;_(1354,b|0,w|0,e|0,u|0,1,1);e=i[114610];i[114610]=0;if((e|0)!=1){break Ca}break j}a=B()|0;A()|0;break c}e=j[ga|0];i[114610]=0;X(1355,b|0,w|0,e|0,u|0,1,0,65535);e=i[114610];i[114610]=0;if((e|0)==1){break j}a=a>>>4|0;Ca=wc(z,H),Da=1,g[Ca+20|0]=Da;Ba=!(i[b+480180>>2]&16777250);e=j[Y|0];Fa:{if(!((e+ -19&255)>>>0>1|r>>>0>=Q>>>0)){q=r;if((j[U|0]&-16)==208){break Fa}}q=a>>>0<Q>>>0?(e|0)==33?a:0:0}if(!(Ba|(!q|aa>>>0<2))){q=o(i[f+40>>2]+ja|0,za)+q|0}if(!u){Ca=wc(z,H),Da=0,i[Ca+16>>2]=Da}e=j[Y|0];Ga:{Ha:{Ia:{if(e+ -19>>>0>=2){if((e|0)!=9){break Ia}break Ha}if((a|0)==8){break Ha}}if(j[v+1420|0]!=2){break Ga}}i[y>>2]=Aa}Ja:{Ka:{switch(e+ -39|0){default:if((e|0)!=10){break Ja}g[m|0]=0;a=i[f+48>>2];e=k[f+60>>1];i[114610]=0;a=S(1349,b|0,e|0,a|0,H&65535,m|0)|0;e=i[114610];i[114610]=0;if((e|0)!=1){if(!j[m|0]){a=a<<8;if(!a){a=i[v+1272>>2]}a=(j[v+1464|0]<<16)+a|0}i[114610]=0;G(1356,b|0,w|0,a|0);a=i[114610];i[114610]=0;if((a|0)!=1){break Ba}}a=B()|0;A()|0;break c;case 2:a=i[v+684>>2];e=j[U|0];i[114610]=0;e=XMa(a,0,e,0);a=_a;y=a>>>8|0;a=eg(793,(a&255)<<24|e>>>8,y);e=i[114610];i[114610]=0;if((e|0)==1){break j}i[114610]=0;G(1356,b|0,w|0,a|0);a=i[114610];i[114610]=0;if((a|0)==1){break j}break Ba;case 1:break Ja;case 0:break Ka}}if(!i[v+712>>2]){break Ja}i[114610]=0;J(1357,K|0,H&65535,O|0,-1);a=i[114610];i[114610]=0;if((a|0)==1){break j}a=j[U|0];i[114610]=0;G(1358,f|0,w|0,a|0);a=i[114610];i[114610]=0;if((a|0)==1){break j}q=i[f+40>>2]+ -1|0;break Ba}if(j[v+1420|0]!=15){break Ba}a=j[v+1422|0];if(a>>>0>9){break Ba}e=i[v+712>>2];if(!e){break Ba}La:{if(!a){a=i[v+1272>>2];break La}a=i[(e+(a<<2)|0)- -64>>2];i[v+1272>>2]=a}i[114610]=0;G(1356,b|0,w|0,a|0);a=i[114610];i[114610]=0;if((a|0)!=1){break Ba}a=B()|0;A()|0;break c}Ma:{Na:{Oa:{Pa:{Qa:{Ra:{Sa:{Ta:{Ua:{Va:{switch(j[ga|0]+ -253|0){case 0:if(k[b+480192>>1]){break Ua}break;case 1:case 2:break Ua;default:break Va}}e=j[Y|0];if((e+ -19&255)>>>0<=1){if(r>>>0>=Q>>>0){a=s;break Sa}a=s;if((j[U|0]&-16)==192){break Ua}break Sa}y=e;if((e|0)==25){break Ua}a=s;if(!((y|0)==33&(r|0)!=0&q+r>>>0<Q>>>0)){break Ta}}e=j[Y|0];a=1}if((e|0)==13){break Ra}}if(j[v+1420|0]==1){i[v+1296>>2]=j[v+1422|0]<<2}if((!i[v+712>>2]|a)&1){break Qa}r=0;if(e>>>0>42){break Oa}break Pa}i[v+1296>>2]=j[U|0]<<2;e=13;if(!((!i[v+712>>2]|a)&1)){break Pa}}if(!(a&1)){break Na}break Ma}kb(m,$,e);r=1;if(ib(m)){break Oa}r=a;if(j[Y|0]!=19){break Oa}e=j[U|0]&240;if((e|0)!=32){r=a;if((e|0)!=16){break Oa}}r=1}a=v+1420|0;if(16>j[a|0]){lj(m,qa,j[a|0]);if((ib(m)|r)&1){break Ma}break Na}if(r&1){break Ma}}if(R){i[114610]=0;J(1357,K|0,H&65535,O|0,-1);a=i[114610];i[114610]=0;if((a|0)==1){break k}}Wa:{Xa:{Ya:{a=j[Y|0];if(a+ -6>>>0>=2){Za:{switch(a+ -19|0){case 1:break Xa;case 0:break Ya;default:break Za}}if((a|0)!=11){break Wa}}if(!Q|(i[b+480180>>2]==1?!j[U|0]:0)){break Wa}a=v+1480|0;e=0;while(1){g[a|0]=!e|j[a|0]&254;Cm(b,w,j[U|0]);e=e+1|0;if((ya|0)!=(e|0)){continue}break}break Wa}e=j[U|0];if(!(e&15)){if(!(i[b+480180>>2]&1048580)){break Wa}e=j[U|0]}a=v+1480|0;g[a|0]=j[a|0]|1;a=e&240;if((a|0)!=176){if((a|0)!=160){break Wa}Ao(b,w,e&15,0);break Wa}zo(b,w,e&15,0);break Wa}_a:{switch(j[U|0]+ -158|0){case 0:i[114610]=0;J(1357,K|0,H&65535,O|0,-1);a=i[114610];i[114610]=0;if((a|0)==1){break k}i[v+696>>2]=i[v+696>>2]&-129;break Wa;case 1:break _a;default:break Wa}}i[114610]=0;J(1357,K|0,H&65535,O|0,-1);a=i[114610];i[114610]=0;if((a|0)==1){break k}i[v+696>>2]=i[v+696>>2]|128;if(!i[v+684>>2]|l[w+4>>2]>0){break Wa}i[114610]=0;a=F(556,ga|0)|0;e=i[114610];i[114610]=0;if((e|0)==1){break k}if(j[v+696|0]&2?!a:0){break Wa}e=i[v+684>>2]+ -1|0;a=w;i[a>>2]=-1;i[a+4>>2]=e}e=v+1480|0;g[e|0]=j[e|0]|1;$a:{ab:{bb:{cb:{r=v+1420|0;switch(j[r|0]+ -3|0){case 0:case 1:break ab;case 3:break bb;case 2:break cb;default:break $a}}a=j[v+1422|0];kb(m,P,41);Ao(b,w,a,ib(m));break $a}a=j[v+1422|0];kb(m,P,41);zo(b,w,a,ib(m));break $a}a=j[v+1422|0];db:{if(a){break db}kb(m,P,41);a=0;if(!ib(m)){break db}a=j[v+1462|0];if(!a){break $a}}if(!Q){break $a}r=j[r|0]==3?a<<4:a;a=0;while(1){g[e|0]=!a|j[e|0]&254;Cm(b,w,r&255);a=a+1|0;if((Q|0)!=(a|0)){continue}break}}if(u){a=i[wc(z,H)+16>>2];e=wc(z,H);i[e+16>>2]=i[e+16>>2]+Q;i[114610]=0;J(1357,K|0,H&65535,t|0,(a+q|0)+1|0);a=i[114610];i[114610]=0;if((a|0)!=1){break ya}a=B()|0;A()|0;break c}a=wc(z,H);i[a+16>>2]=i[a+16>>2]+(Q-q|0);break ya}i[114610]=0;L(1348,w|0);a=i[114610];i[114610]=0;if((a|0)==1){break k}Ca=wc(z,H),Da=0,i[Ca+16>>2]=Da}H=H+1|0;if(H>>>0<k[b+480188>>1]){continue}break}}if(!la){break wa}kb(m,P,68);if(Ca=ib(m),Da=0,Fa=ma|pa,Fa?Ca:Da){break wa}kb(m+48|0,P,49);if(ib(m+48|0)&ma){break wa}kb(m+40|0,P,103);O=t;if(ib(m+40|0)&fa){continue}a=0;s=npa(m);if(!k[b+480188>>1]){break xa}while(1){eb:{r=o(a,896)+f|0;e=j[r+1423|0];r=j[r+1421|0];if(!((r|0)!=19|(e+ -97&255)>>>0>14?!((e+79&255)>>>0<15?(r|0)==20:0):0)){T=n[wc(z,a)>>3];i[114610]=0;n[m+48>>3]=T;r=C(1359,s|0,m+48|0)|0;O=i[114610];i[114610]=0;if((O|0)==1){break eb}if(!i[r>>2]){i[114610]=0;r=C(1359,s|0,m+48|0)|0;O=i[114610];i[114610]=0;if((O|0)==1){break eb}i[r>>2]=1}i[114610]=0;r=C(1359,s|0,m+48|0)|0;O=i[114610];i[114610]=0;if((O|0)==1){break eb}r=i[r>>2];i[114610]=0;e=C(1360,r|0,(e&15)+1|0)|0;r=i[114610];i[114610]=0;if((r|0)==1){break eb}i[114610]=0;r=C(1359,s|0,m+48|0)|0;O=i[114610];i[114610]=0;if((O|0)==1){break eb}i[r>>2]=e}a=a+1|0;if(a>>>0<k[b+480188>>1]){continue}break xa}break}break l}a=B()|0;A()|0;break c}Ca=m,Da=Wm(s),i[Ca+40>>2]=Da;Ca=m,Da=fi(s),i[Ca+32>>2]=Da;while(1){i[114610]=0;a=C(1361,m+40|0,m+32|0)|0;e=i[114610];i[114610]=0;if((e|0)==1){break l}if(!a){fb:{if(i[b+480180>>2]!=32){break fb}a=0;if(!k[b+480188>>1]){break fb}while(1){e=o(a,896)+f|0;if(!(j[e+1421|0]!=20|(j[e+1423|0]+79&255)>>>0>14)){T=n[K+32>>3];Ca=wc(z,a),Ea=T,n[Ca>>3]=Ea;e=i[f>>2];Ca=wc(z,a),Da=e,i[Ca+8>>2]=Da}a=a+1|0;if(a>>>0<k[b+480188>>1]){continue}break}}FK(s);break wa}i[114610]=0;a=F(1362,m+40|0)|0;e=i[114610];i[114610]=0;gb:{hb:{if((e|0)!=1){r=fb(a);e=a;T=n[K+32>>3];n[K+32>>3]=(T-n[a>>3])*+(i[r>>2]+ -1|0)+T;a=0;if(k[b+480188>>1]){break hb}break gb}break l}while(1){if(n[wc(z,a)>>3]!=n[e>>3]){a=a+1|0;if(a>>>0<k[b+480188>>1]){continue}break gb}break}e=i[f>>2];O=wc(z,a);i[f>>2]=i[f>>2]+o(i[r>>2]+ -1|0,e-i[O+8>>2]|0);kb(m+48|0,P,16);if(Ca=!ib(m+48|0),Da=0,Fa=i[b+480180>>2]!=2,Fa?Ca:Da){break gb}T=n[K+32>>3];Ca=wc(z,a),Ea=T,n[Ca>>3]=Ea;e=i[f>>2];Ca=wc(z,a),Da=e,i[Ca+8>>2]=Da;e=i[f+48>>2];Ca=wc(z,a),Da=e+1|0,i[Ca+12>>2]=Da}i[114610]=0;F(1363,m+40|0)|0;a=i[114610];i[114610]=0;if((a|0)!=1){continue}break}break l}O=t;continue}}a=B()|0;A()|0;break c}a=B()|0;A()|0;FK(s);break c}a=B()|0;A()|0;break c}a=B()|0;A()|0;break c}a=B()|0;A()|0;break c}a=B()|0;A()|0;break c}ib:{jb:{if(!(!k[b+480188>>1]|(ra|0)!=7)){a=0;while(1){if(i[wc(z,a)+16>>2]!=-1){i[114610]=0;J(1357,K|0,a&65535,O|0,-1);d=i[114610];i[114610]=0;if((d|0)==1){break jb}}a=a+1|0;if(a>>>0<k[b+480188>>1]){continue}break}}if(j[M+26|0]){h[M+20>>1]=k[f+62>>1];i[M+8>>2]=i[f+48>>2]}n[M>>3]=n[K+32>>3];i[114610]=0;D(1340,oa|0,M|0);a=i[114610];i[114610]=0;if((a|0)==1){break ib}kb:{lb:{if(!ia){break lb}mb:{if(!(ba?!j[M+26|0]:0)){a=b+1074376|0;LK(a,f);qx(a);a=b+1074396|0;i[a>>2]=0;i[a+4>>2]=0;i[b+1074428>>2]=i[b+1074424>>2];g[b+1074464|0]=1;i[b+1074392>>2]=-2;nb:{if(k[b+480188>>1]){a=0;e=(ra|0)==7;while(1){d=o(a,896)+b|0;f=j[d+1075805|0];if(f){g[d+1075808|0]=f}if(!(j[wc(z,a)+21|0]==255|e)){f=wc(z,a);i[114610]=0;g[m|0]=64;f=C(391,f+21|0,m|0)|0;s=i[114610];i[114610]=0;if((s|0)==1){break nb}i[d+1075672>>2]=j[f|0]<<2}a=a+1|0;if(a>>>0<k[b+480188>>1]){continue}break}}a=b+1304392|0;if($c(a)){a=i[a>>2];i[114610]=0;L(1364,a|0);a=i[114610];i[114610]=0;if((a|0)==1){break ib}}d=my(m);Ca=m,Da=Wm(sa),i[Ca+40>>2]=Da;Ca=m,Da=fi(sa),i[Ca+32>>2]=Da;ob:{while(1){pb:{i[114610]=0;a=C(1365,m+40|0,m+32|0)|0;e=i[114610];i[114610]=0;if((e|0)==1){break pb}if(!a){if(!_oa(d)){break mb}a=0;while(1){kb(m+48|0,d,a);qb:{if(!ib(m+48|0)){break qb}e=i[(o(a,160)+b|0)+906300>>2];f=i[i[e>>2]+172>>2];i[114610]=0;L(f|0,e|0);e=i[114610];i[114610]=0;if((e|0)!=1){break qb}a=B()|0;A()|0;break c}a=a+1|0;if((a|0)!=250){continue}break}break mb}i[114610]=0;e=F(1366,m+40|0)|0;a=i[114610];i[114610]=0;if((a|0)==1){break ob}f=j[e|0]+ -1&255;a=i[(o(f,160)+b|0)+906300>>2];if(a){kb(m+48|0,d,f);if(!ib(m+48|0)){i[114610]=0;I(1367,d|0,f|0,1)|0;f=i[114610];i[114610]=0;if((f|0)==1){break kb}f=i[i[a>>2]+168>>2];i[114610]=0;D(f|0,a|0,-1);f=i[114610];i[114610]=0;if((f|0)==1){break kb}}f=k[e+2>>1];s=i[i[a>>2]+44>>2];e=k[e+4>>1];i[114610]=0;ka(s|0,a|0,f|0,p(p(p(e>>>0)*p(.0010010009864345193))));a=i[114610];i[114610]=0;if((a|0)==1){break kb}}i[114610]=0;F(1368,m+40|0)|0;a=i[114610];i[114610]=0;if((a|0)!=1){continue}}break}a=B()|0;A()|0;break c}a=B()|0;A()|0;break c}a=B()|0;A()|0;break c}if((c|0)==3){break mb}i[b+1074416>>2]=i[b+480196>>2];i[b+1074420>>2]=i[b+480204>>2];i[b+1074444>>2]=i[b+480200>>2]}if(j[na+16|0]==(ha|0)){break lb}i[114610]=0;D(489,na|0,ha|0);a=i[114610];i[114610]=0;if((a|0)==1){break ib}}if(c&9){i[114610]=0;D(1369,b+1304360|0,ca|0);a=i[114610];i[114610]=0;if((a|0)==1){break ib}}yo(ca);KK(K);Xa=m+176|0;return}a=B()|0;A()|0;break c}a=B()|0;A()|0;break c}a=B()|0;A()|0;break c}a=B()|0;A()|0;break c}a=B()|0;A()|0;break c}a=B()|0;A()|0}yo(ca);break b}a=B()|0;A()|0}KK(K);break a}a=B()|0;A()|0}hl(oa);E(a|0);x()}function $Aa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,m=0,n=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,H=0,K=0,L=0,M=0,O=0,P=0,Q=0,R=0,S=0,T=0;e=Xa-1728|0;Xa=e;pc(b);f=e+1600|0;p=HAa(b,f);if(!p){jO(f)}a:{if(!p){break a}if(!pO(e+1600|0)){break a}if(!wb(b,Vc(256,0))){break a}b:{if(!c){break b}md(a,1048576);Vh(a);d=Bb(e+1584|0,16368);i[114610]=0;D(219,e+1328|0,d|0);f=i[114610];i[114610]=0;c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{if((f|0)!=1){y=e+1608|0;i[e+160>>2]=j[y+1|0];f=j[y|0];i[114610]=0;i[e+24>>2]=f;D(664,e+88|0,e+24|0);f=i[114610];i[114610]=0;if((f|0)==1){break r}i[114610]=0;J(649,e+240|0,e+1328|0,e+160|0,e+88|0);f=i[114610];i[114610]=0;if((f|0)==1){break q}mb(a+1304436|0,e+240|0);eb(e+240|0);eb(e+88|0);ob(e+1328|0);eb(d);d=Bb(e+240|0,16385);mb(a+1304448|0,d);eb(d);rg(e+88|0,2,e+1610|0);oc(e+1328|0,e+88|0);i[114610]=0;G(13,e+240|0,7,e+1328|0);d=i[114610];i[114610]=0;if((d|0)==1){break k}mb(a+1304460|0,e+240|0);eb(e+240|0);eb(e+1328|0);i[a+1304496>>2]=7;it(e+1328|0,2,e+1642|0);oc(e+240|0,e+1328|0);mb(a+1304400|0,e+240|0);eb(e+240|0);d=e+1712|0;h[a+480188>>1]=j[d|0]|j[d+1|0]<<8;d=hd(j[e+1716|0],1,31);i[a+480204>>2]=125e4;i[a+480208>>2]=32792;i[a+480196>>2]=d;L=e+1722|0;h[a+480192>>1]=j[L|0]|j[L+1|0]<<8;M=e+1724|0;h[a+480190>>1]=j[M|0]|j[M+1|0]<<8;d=hd(j[e+1717|0],1,32);i[a+480216>>2]=d;i[a+480228>>2]=96;i[a+480232>>2]=48;i[a+480220>>2]=d<<2;Wz(b,e+1328|0);O=a+484360|0;z=e+1706|0;st(Db(O),e+1328|0,j[z|0]|j[z+1|0]<<8,65535,65535);d=e+1708|0;Fe(Db(O),j[d|0]|j[d+1|0]<<8);ad(e+1312|0,b,_f(b));i[114610]=0;d=F(390,b|0)|0;f=i[114610];i[114610]=0;if((f|0)==1){break n}i[114610]=0;G(341,e+1296|0,b|0,d|0);d=i[114610];i[114610]=0;if((d|0)==1){break n}v=k[a+480188>>1];i[114610]=0;w=C(258,e+1312|0,274)|0;d=i[114610];i[114610]=0;if((d|0)==1){break m}if(w){h[a+480188>>1]=k[a+480188>>1]+8}H=c&1;if(!H){break l}d=e+1710|0;d=j[d|0]|j[d+1|0]<<8;i[114610]=0;D(401,a+484344|0,d|0);d=i[114610];i[114610]=0;if((d|0)!=1){break l}break f}f=B()|0;A()|0;break o}f=B()|0;A()|0;break p}f=B()|0;A()|0;eb(e+88|0)}ob(e+1328|0)}eb(d);break c}f=B()|0;A()|0;break d}f=B()|0;A()|0;break e}u=e+1710|0;if(!(j[u|0]|j[u+1|0]<<8)){break g}P=a+484344|0;Q=e+1718|0;while(1){i[114610]=0;d=F(357,b|0)|0;f=i[114610];i[114610]=0;if((f|0)==1){break h}i[114610]=0;i[e+160>>2]=d;d=F(390,b|0)|0;f=i[114610];i[114610]=0;if((f|0)==1){break i}i[114610]=0;G(341,e+240|0,b|0,d+1&-2);d=i[114610];i[114610]=0;if((d|0)==1){break i}kc(e+160|0,1024);s:{if(!H){break s}d=i[e+160>>2];if(!d){break s}i[114610]=0;d=I(402,P|0,n&65535,d|0)|0;f=i[114610];i[114610]=0;t:{if((f|0)!=1){if(!d){break s}q=0;if(g[Q|0]&1){m=0;while(1){i[114610]=0;d=C(258,e+240|0,1)|0;f=i[114610];i[114610]=0;u:{if((f|0)!=1){if(!d){break s}i[114610]=0;d=F(387,e+240|0)|0;f=i[114610];i[114610]=0;if((f|0)==1){break j}f=0;if((d|0)!=255){break u}i[114610]=0;f=F(387,e+240|0)|0;d=i[114610];i[114610]=0;if((d|0)!=1){i[114610]=0;d=F(387,e+240|0)|0;p=i[114610];i[114610]=0;if((p|0)!=1){break u}}break j}break j}v:{if(!(d&127)){break v}p=Fb(P,n);i[114610]=0;p=I(471,p|0,m|0,q&65535)|0;r=i[114610];i[114610]=0;if((r|0)==1){break j}g[e+88|0]=0;g[e+89|0]=0;g[e+90|0]=0;g[e+91|0]=0;g[e+91|0]=0;g[e+92|0]=0;g[e+93|0]=0;g[e+94|0]=0;if(d&1){i[114610]=0;r=F(387,e+240|0)|0;s=i[114610];i[114610]=0;if((s|0)==1){break j}g[e+88|0]=r}if(d&2){i[114610]=0;r=F(387,e+240|0)|0;s=i[114610];i[114610]=0;if((s|0)==1){break j}g[e+89|0]=r}if(d&4){i[114610]=0;r=F(387,e+240|0)|0;s=i[114610];i[114610]=0;if((s|0)==1){break j}g[e+90|0]=r}if(d&8){i[114610]=0;r=F(387,e+240|0)|0;s=i[114610];i[114610]=0;if((s|0)==1){break j}g[e+91|0]=r}if(d&16){i[114610]=0;r=F(387,e+240|0)|0;s=i[114610];i[114610]=0;if((s|0)==1){break j}g[e+92|0]=r}if(d&32){i[114610]=0;r=F(387,e+240|0)|0;s=i[114610];i[114610]=0;if((s|0)==1){break j}g[e+93|0]=r}if(d&64){i[114610]=0;d=F(387,e+240|0)|0;r=i[114610];i[114610]=0;if((r|0)==1){break j}g[e+94|0]=d}i[114610]=0;d=C(897,p|0,e+88|0)|0;r=i[114610];i[114610]=0;if((r|0)==1){break j}i[114610]=0;i[e+24>>2]=f;i[e+224>>2]=i[e+160>>2]+(m^-1);r=C(632,e+24|0,e+224|0)|0;s=i[114610];i[114610]=0;if((s|0)==1){break j}t=d|t;R=i[r>>2];if(!R){break v}r=0;d=p;while(1){d=o(k[a+480188>>1],6)+d|0;s=j[p|0]|j[p+1|0]<<8|(j[p+2|0]<<16|j[p+3|0]<<24);g[d|0]=s;g[d+1|0]=s>>>8;g[d+2|0]=s>>>16;g[d+3|0]=s>>>24;s=j[p+4|0]|j[p+5|0]<<8;g[d+4|0]=s;g[d+5|0]=s>>>8;r=r+1|0;if((R|0)!=(r|0)){continue}break}}m=(f+m|0)+1|0;d=i[e+160>>2];if(m>>>0>=d>>>0){while(1){q=q+1|0;m=m-d|0;if(m>>>0>=d>>>0){continue}break}}if((q&65535)>>>0<v>>>0){continue}break}break s}f=0;if(i[e+160>>2]){break t}break s}break j}while(1){d=Fb(P,n);i[114610]=0;p=C(497,d|0,f|0)|0;d=i[114610];i[114610]=0;w:{x:{if((d|0)!=1){d=0;if(v){break x}break w}break j}while(1){y:{i[114610]=0;C(898,e+240|0,e+88|0)|0;m=i[114610];i[114610]=0;if((m|0)==1){break y}i[114610]=0;m=C(897,p+o(d,6)|0,e+88|0)|0;q=i[114610];i[114610]=0;if((q|0)==1){break y}t=m|t;d=d+1|0;if((v|0)!=(d|0)){continue}break w}break}break j}f=f+1|0;if(f>>>0<l[e+160>>2]){continue}break}}hb(e+240|0);n=n+1|0;if(n>>>0<(j[u|0]|j[u+1|0]<<8)>>>0){continue}break}break g}f=B()|0;A()|0;eb(e+1328|0);break c}f=B()|0;A()|0;hb(e+240|0);break e}f=B()|0;A()|0;break e}f=B()|0;A()|0;break e}d=e+1714|0;z:{if((j[d|0]|j[d+1|0]<<8)>>>0<=1|(j[d|0]|j[d+1|0]<<8)>>>0>4999){break z}if(t&1){d=j[d|0]|j[d+1|0]<<8;i[114610]=0;d=eg(458,((d>>>1|0)+11025e5>>>0)/(d>>>0)|0,0);f=i[114610];i[114610]=0;if((f|0)==1){break f}i[a+480224>>2]=0;i[a+480204>>2]=d;break z}f=i[a+480216>>2];p=i[a+480196>>2];n=j[d|0]|j[d+1|0]<<8;i[a+480224>>2]=2;d=a;K=2646e7/+(o(n,o(f,p))>>>0);A:{if(K<4294967296&K>=0){f=~~K>>>0;break A}f=0}i[d+480204>>2]=f}d=k[a+480188>>1];i[114610]=0;g[e+240|0]=0;P=I(899,e+1280|0,d|0,e+240|0)|0;d=i[114610];i[114610]=0;if((d|0)!=1){m=a+1304412|0;p=a+484344|0;s=a+1304424|0;H=e+240|3;r=0;B:{C:{D:{E:{F:{while(1){i[114610]=0;d=C(258,e+1296|0,8)|0;f=i[114610];i[114610]=0;G:{if((f|0)!=1){if(d){break G}if(k[a+480188>>1]){d=0;while(1){f=g[dc(P,d)|0];H:{if((d|0)>=(f|0)|(f|0)>=k[a+480188>>1]){break H}n=((f<<5)+a|0)+480288|0;f=j[n|0];if(!f){break H}m=((d<<5)+a|0)+480288|0;q=j[m|0];if(!q){g[m|0]=f;break H}m=(o(q+ -1&255,160)+a|0)+906300|0;if((dj(m)|0)!=255){while(1){m=(o(dj(m),160)+a|0)+906300|0;if((dj(m)|0)!=255){continue}break}}f=m+28|0;n=j[n|0]+ -1&255;n=n>>>0<250?n+128|0:0;g[f|0]=n;g[f+1|0]=n>>>8;g[f+2|0]=n>>>16;g[f+3|0]=n>>>24}d=d+1|0;if(d>>>0<k[a+480188>>1]){continue}break}}i[e+232>>2]=0;i[e+236>>2]=0;i[e+224>>2]=0;i[e+228>>2]=0;i[e+216>>2]=0;i[e+220>>2]=0;i[e+208>>2]=0;i[e+212>>2]=0;I:{J:{K:{L:{M:{N:{if(w){i[114610]=0;C(900,e+1312|0,e+240|0)|0;d=i[114610];i[114610]=0;O:{if((d|0)!=1){m=0;while(1){d=k[a+480192>>1];i[114610]=0;d=C(901,a|0,d+1&65535)|0;f=i[114610];i[114610]=0;P:{Q:{R:{S:{T:{U:{V:{if((f|0)!=1){f=m<<1;n=f+(e+224|0)|0;h[n>>1]=d;s=f+(e+208|0)|0;f=e+f|0;q=f+242|0;h[s>>1]=j[q|0]|j[q+1|0]<<8;if((d|0)==65535){break Q}f=j[f+242|0]|j[f+243|0]<<8;i[114610]=0;d=I(454,a|0,d|0,f+1&65535)|0;f=i[114610];i[114610]=0;if((f|0)==1){break V}if(!d){break P}i[114610]=0;D(509,e+160|0,16402);f=i[114610];i[114610]=0;if((f|0)==1){break U}i[114610]=0;i[e+24>>2]=m+1;G(902,e+88|0,e+160|0,e+24|0);f=i[114610];i[114610]=0;if((f|0)==1){break T}i[114610]=0;C(369,d+492|0,e+88|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break S}eb(e+88|0);ob(e+160|0);break P}f=B()|0;A()|0;break B}f=B()|0;A()|0;break B}f=B()|0;A()|0;break B}f=B()|0;A()|0;break R}f=B()|0;A()|0;eb(e+88|0)}ob(e+160|0);break B}h[n>>1]=0}m=m+1|0;if((m|0)!=8){continue}break}break O}f=B()|0;A()|0;break B}d=j[e+240|0]|j[e+241|0]<<8;i[114610]=0;s=C(395,e+160|0,d|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break I}if(j[e+240|0]|j[e+241|0]<<8){d=0;while(1){i[114610]=0;f=F(357,b|0)|0;n=i[114610];i[114610]=0;if((n|0)==1){break K}i[114610]=0;G(341,e+88|0,b|0,f<<5);f=i[114610];i[114610]=0;if((f|0)==1){break L}Cd(_b(s,d),e+88|0);hb(e+88|0);d=d+1|0;if(d>>>0<(j[e+240|0]|j[e+241|0]<<8)>>>0){continue}break}}d=j[u|0]|j[u+1|0]<<8;i[114610]=0;t=I(903,e+88|0,d|0,16412)|0;d=i[114610];i[114610]=0;if((d|0)==1){break M}if(j[z|0]|j[z+1|0]<<8){n=0;while(1){m=e+n|0;W:{if((j[e+240|0]|j[e+241|0]<<8)>>>0<=j[m+258|0]){break W}if(k[$b(Db(O),n)>>1]>=(j[u|0]|j[u+1|0]<<8)>>>0){break W}f=k[$b(Db(O),n)>>1];X:{if(k[$b(t,f)>>1]==65535){d=j[m+258|0];S=$b(t,f),T=d,h[S>>1]=T;break X}if(k[$b(t,f)>>1]==j[m+258|0]){break X}i[114610]=0;d=I(904,p|0,f|0,0)|0;q=i[114610];i[114610]=0;if((q|0)==1){break N}if((d|0)==65535){break X}S=$b(Db(O),n),T=d,h[S>>1]=T;f=d}i[114610]=0;d=C(442,p|0,f|0)|0;q=i[114610];i[114610]=0;if((q|0)==1){break N}if(!d){break W}H=_b(s,j[m+258|0]);pc(H);i[114610]=0;d=F(255,H|0)|0;m=i[114610];i[114610]=0;if((m|0)==1){break N}if(!i[Fb(p,f)+12>>2]){break W}Q=d>>>5|0;q=0;while(1){d=Fb(p,f);m=k[a+480188>>1];i[114610]=0;d=I(471,d|0,q|0,m+ -8&65535)|0;m=i[114610];i[114610]=0;if((m|0)==1){break N}m=0;while(1){Tg(e+24|0);w=k[e+28>>1];g[d+4|0]=w;g[d+5|0]=w>>>8;w=i[e+24>>2];g[d|0]=w;g[d+1|0]=w>>>8;g[d+2|0]=w>>>16;g[d+3|0]=w>>>24;Y:{if(q>>>0>=Q>>>0){break Y}i[114610]=0;C(905,H|0,e+24|0)|0;w=i[114610];i[114610]=0;if((w|0)==1){break N}if(g[e+24|0]>-1){break Y}g[d|0]=61;g[d+1|0]=j[(e+224|0)+(m<<1)|0];w=j[e+24|0]&31;g[e+72|0]=w;if(w){ze(e+72|0,15);g[d+3|0]=20;g[d+5|0]=j[e+72|0]|208}g[d+2|0]=1;g[d+4|0]=j[e+25|0]+3>>>2}d=d+6|0;m=m+1|0;if((m|0)!=8){continue}break}q=q+1|0;if(q>>>0<l[Fb(p,f)+12>>2]){continue}break}}n=n+1|0;if(n>>>0<(j[z|0]|j[z+1|0]<<8)>>>0){continue}break}}df(t);Qc(s)}d=e+1718|0;Z:{if(!(j[d|0]&2)){break Z}v=j[d|0]&8?k[a+480188>>1]:v;if(!(j[u|0]|j[u+1|0]<<8)){break Z}d=((v&65535)+((j[y|0]|j[y+1|0]<<8)>>>0>591?r:0)|0)+((j[d|0]|j[d+1|0]<<8|(j[d+2|0]<<16|j[d+3|0]<<24))>>>4&1)|0;v=0;while(1){m=0;_:{if(!d){break _}while(1){$:{i[114610]=0;f=C(258,b|0,4)|0;p=i[114610];i[114610]=0;if((p|0)==1){break $}if(!f){break _}f=j[y|0]|j[y+1|0]<<8;i[114610]=0;D(906,f|0,b|0);f=i[114610];i[114610]=0;if((f|0)==1){break $}m=m+1|0;if((d|0)!=(m|0)){continue}break _}break}f=B()|0;A()|0;break B}v=v+1|0;if(v>>>0<(j[u|0]|j[u+1|0]<<8)>>>0){continue}break}}i[114610]=0;u=C(395,e+192|0,255)|0;d=i[114610];i[114610]=0;aa:{ba:{ca:{da:{ea:{fa:{if((d|0)!=1){w=e+88|7;O=e+88|1;s=e+88|4;z=e+88|2;H=e+88|3;n=0;while(1){d=n;i[114610]=0;C(907,b|0,e+160|0)|0;f=i[114610];i[114610]=0;ga:{ha:{ia:{ja:{if((f|0)!=1){i[114610]=0;f=F(390,b|0)|0;p=i[114610];i[114610]=0;if((p|0)==1){break ja}p=j[y|0]|j[y+1|0]<<8;i[114610]=0;f=(f|0)==32?428:f;f=f?p>>>0>513?f+4|0:f:f;G(341,e+240|0,b|0,f|0);p=i[114610];i[114610]=0;if((p|0)==1){break ia}n=d+1|0;q=He(e+24|0,Cd(_b(u,d),e+240|0));hb(e+240|0);if(d>>>0>=(j[L|0]|j[L+1|0]<<8)>>>0){break ga}i[114610]=0;d=n&65535;m=I(454,a|0,d|0,d|0)|0;d=i[114610];i[114610]=0;if((d|0)!=1){break ha}f=B()|0;A()|0;break ba}f=B()|0;A()|0;break aa}f=B()|0;A()|0;break aa}f=B()|0;A()|0;break aa}if(!m){break ga}i[114610]=0;G(748,e+88|0,2,e+160|0);d=i[114610];i[114610]=0;ka:{la:{ma:{if((d|0)==1){break ma}i[114610]=0;D(415,e+240|0,e+88|0);d=i[114610];i[114610]=0;if((d|0)==1){break ma}i[114610]=0;C(369,m+492|0,e+240|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break la}eb(e+240|0);if(!f){break ga}i[114610]=0;C(908,q|0,e+240|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break da}t=0;if((j[y|0]|j[y+1|0]<<8)>>>0<513){break ka}i[114610]=0;t=F(357,q|0)|0;d=i[114610];i[114610]=0;if((d|0)!=1){break ka}f=B()|0;A()|0;break ba}f=B()|0;A()|0;break ba}f=B()|0;A()|0;eb(e+240|0);break ba}f=3;na:{if((j[y|0]|j[y+1|0]<<8)>>>0<514){break na}i[114610]=0;f=F(390,q|0)|0;d=i[114610];i[114610]=0;if((d|0)!=1){break na}f=B()|0;A()|0;break ba}i[m>>2]=j[e+342|0]|j[e+343|0]<<8;g[m+16|0]=j[((j[e+344|0]|j[e+345|0]<<8)&3)+16414|0];g[m+17|0]=j[(j[e+345|0]&3)+16414|0];g[m+18|0]=j[((j[e+344|0]|j[e+345|0]<<8)>>>12&3)+16418|0];v=0;oa:{pa:{qa:{ra:{while(1){sa:{if(!(f&1)){break sa}i[114610]=0;C(909,q|0,e+88|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break ra}i[114610]=0;p=C(374,m|0,j[v+16422|0])|0;d=i[114610];i[114610]=0;if((d|0)==1){break qa}d=p;if(!(g[e+88|0]&1)|(v|0)!=3){r=j[p+12|0]&-17}else{r=j[p+12|0]|16}g[d+12|0]=r;g[p+12|0]=j[p+12|0]&254|g[e+88|0]&1;g[p+12|0]=j[p+12|0]&251|j[e+88|0]<<1&4;g[p+12|0]=j[p+12|0]&253|j[e+88|0]>>>1&2;d=j[O|0];i[114610]=0;g[e+72|0]=d;g[e+56|0]=16;d=C(391,e+72|0,e+56|0)|0;r=i[114610];i[114610]=0;if((r|0)==1){break pa}d=j[d|0];i[114610]=0;D(594,p|0,d|0);d=i[114610];i[114610]=0;if((d|0)==1){break pa}d=j[z|0];g[p+15|0]=d;g[p+16|0]=d;g[p+13|0]=j[H|0];g[p+14|0]=j[s|0];d=0;if(!qb(p)){break sa}while(1){r=(e+88|0)+(d<<2)|0;Q=j[r+8|0]|j[r+9|0]<<8;S=vb(p,d),T=Q,h[S>>1]=T;r=hd(j[r+10|0]|j[r+11|0]<<8,0,64);S=vb(p,d),T=r,g[S+2|0]=T;d=d+1|0;if(d>>>0<qb(p)>>>0){continue}break}}f=f>>>1|0;v=v+1|0;if((v|0)!=4){continue}break}if(!(g[m+60|0]&1|j[m+16|0]==3)){i[m>>2]=32767}i[114610]=0;G(910,m|0,127,1);d=i[114610];i[114610]=0;if((d|0)==1){break fa}i[114610]=0;G(911,m|0,0,1);d=i[114610];i[114610]=0;if((d|0)==1){break fa}if(!t){break ga}i[114610]=0;C(912,q|0,e+88|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break ca}if(!(t&2)){break oa}d=j[z|0]|j[z+1|0]<<8;i[114610]=0;d=Wa(913,a|0,+(d>>>0))|0;f=i[114610];i[114610]=0;if((f|0)==1){break ca}i[114610]=0;G(910,m|0,d|0,1);d=i[114610];i[114610]=0;if((d|0)==1){break ca}d=j[s|0];i[114610]=0;G(911,m|0,d|0,1);d=i[114610];i[114610]=0;if((d|0)!=1){break oa}break ca}f=B()|0;A()|0;break ba}f=B()|0;A()|0;break ba}f=B()|0;A()|0;break ba}g[m+25|0]=j[O|0]==1;if(!(t&4)){break ga}g[m+31|0]=j[w|0]+1;g[m+34|0]=j[e+96|0]+1;if(g[e+96|0]<=-1){g[m+30|0]=j[e+103|0]+1}if(j[e+100|0]){d=0;p=m+108|0;while(1){f=d+1|0;i[e+72>>2]=f+g[e+100|0];mO(e+72|0);v=i[e+72>>2];S=Nb(p,d),T=v,g[S|0]=T;d=f;if(d>>>0<128){continue}break}}i[114610]=0;D(780,m|0,0);d=i[114610];i[114610]=0;if((d|0)==1){break ca}}hb(q);if((n|0)!=255){continue}break}v=my(e+88|0);p=e+24|4;y=my(e+160|0);m=0;ta:{ua:{while(1){i[114610]=0;C(907,b|0,e+240|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break ta}i[114610]=0;d=F(390,b|0)|0;f=i[114610];i[114610]=0;va:{wa:{xa:{ya:{za:{Aa:{Ba:{Ca:{if((f|0)!=1){i[114610]=0;G(341,e+72|0,b|0,d|0);f=i[114610];i[114610]=0;if((f|0)==1){break Ca}if(m>>>0<(j[M|0]|j[M+1|0]<<8)>>>0){i[114610]=0;G(748,e+56|0,2,e+240|0);f=i[114610];i[114610]=0;if((f|0)==1){break va}i[114610]=0;D(415,e+24|0,e+56|0);f=i[114610];i[114610]=0;if((f|0)==1){break va}i[114610]=0;C(369,((m<<5)+a|0)+946332|0,e+24|0)|0;f=i[114610];i[114610]=0;if((f|0)==1){break Ba}eb(e+24|0)}if(!d|m>>>0>=(j[M|0]|j[M+1|0]<<8)>>>0){break wa}i[114610]=0;d=o(m+1|0,104)+a|0;f=d+484380|0;D(386,f|0,32);n=i[114610];i[114610]=0;if((n|0)==1){break Aa}i[114610]=0;C(914,e+72|0,e+24|0)|0;n=i[114610];i[114610]=0;if((n|0)==1){break za}i[f>>2]=j[e+24|0]|j[e+25|0]<<8|(j[e+26|0]<<16|j[e+27|0]<<24);i[d+484404>>2]=j[p|0]|j[p+1|0]<<8|(j[p+2|0]<<16|j[p+3|0]<<24);if(j[e+32|0]>=2){n=d+484414|0;h[n>>1]=k[n>>1]|1;i[f>>2]=i[f>>2]>>>1}if(j[e+33|0]>=2){n=d+484414|0;h[n>>1]=k[n>>1]|64;i[f>>2]=i[f>>2]>>>1}t=2;Da:{if(j[e+35|0]!=1){t=6;if(j[e+35|0]!=2){break Da}}f=d+484414|0;h[f>>1]=k[f>>1]|t}i[d+484384>>2]=j[e+36|0]|j[e+37|0]<<8|(j[e+38|0]<<16|j[e+39|0]<<24);i[d+484388>>2]=j[e+40|0]|j[e+41|0]<<8|(j[e+42|0]<<16|j[e+43|0]<<24);h[d+484410>>1]=(j[e+44|0]|j[e+45|0]<<8)>>>7;if(j[e+46|0]!=128){break ya}f=d+484414|0;q=k[f>>1]|256;h[f>>1]=q;break xa}f=B()|0;A()|0;break aa}f=B()|0;A()|0;break aa}f=B()|0;A()|0;eb(e+24|0);break ua}f=B()|0;A()|0;break ua}f=B()|0;A()|0;break ua}h[d+484408>>1]=g[e+46|0]+128;q=k[d+484414>>1]}f=d+484414|0;h[f>>1]=q|32;g[d+484416|0]=j[e+47|0];if(j[e+34|0]&2){kb(e+56|0,y,m);Od(e+56|0,1)}if(j[e+34|0]&5){h[f>>1]=k[f>>1]|16384}if(!(j[e+34|0]&8)){break wa}kb(e+56|0,v,m);Od(e+56|0,1);d=0;while(1){f=d<<1;Ea:{if(k[f+(e+208|0)>>1]!=(m|0)){break Ea}f=i[((k[f+(e+224|0)>>1]<<2)+a|0)+900380>>2];if(!f){break Ea}g[f+14|0]=0}d=d+1|0;if((d|0)!=8){continue}break}}hb(e+72|0);m=m+1|0;if((m|0)==256){break ea}continue}break}f=B()|0;A()|0}hb(e+72|0);break aa}f=B()|0;A()|0;break aa}f=B()|0;A()|0;break B}f=B()|0;A()|0;break ba}Fa:{if(!(j[L|0]|j[L+1|0]<<8)){break Fa}f=0;Ga:{Ha:{while(1){Ia:{d=_b(u,f);i[114610]=0;d=F(255,d|0)|0;p=i[114610];i[114610]=0;if((p|0)==1){break Ia}Ja:{if(!d){f=f+1|0;break Ja}d=_b(u,f);pc(d);i[114610]=0;C(908,d|0,e+240|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break Ha}m=e+24|0;KAa(m);d=j[e+240|0]|j[e+241|0]<<8;i[114610]=0;I(915,b|0,m|0,d|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break Ga}f=f+1|0;p=i[((f<<2)+a|0)+900380>>2];if(!(!p|j[p+34|0])){i[p+4>>2]=32;i[114610]=0;D(780,p|0,0);d=i[114610];i[114610]=0;if((d|0)==1){break Ga}M=p+108|0;z=p+236|0;d=0;while(1){n=d+e|0;Ka:{if((j[e+240|0]|j[e+241|0]<<8)>>>0<=j[n+242|0]){break Ka}t=uk(m,j[n+242|0]);n=j[t|0];q=n+1|0;r=d+12|0;S=Mc(z,r),T=q,h[S>>1]=T;if(k[a+480190>>1]<=n>>>0){break Ka}n=o(q,104)+a|0;g[n+484418|0]=j[e+338|0]&3;g[n+484419|0]=j[e+339|0];g[n+484420|0]=j[e+340|0];g[n+484421|0]=j[e+341|0];h[n+484412>>1]=j[t+1|0]<<1;g[n+484417|0]=j[t+2|0];n=q+ -1|0;kb(e+72|0,v,n);if(ib(e+72|0)){g[p+14|0]=0}kb(e+72|0,y,n);if(!ib(e+72|0)){break Ka}S=Nb(M,r),T=61,g[S|0]=T}d=d+1|0;if((d|0)!=96){continue}break}}lO(m)}if(f>>>0<(j[L|0]|j[L+1|0]<<8)>>>0){continue}break Fa}break}f=B()|0;A()|0;break aa}f=B()|0;A()|0;break aa}f=B()|0;A()|0;lO(m);break aa}La:{Ma:{Na:{Oa:{Pa:{Qa:{Ra:{Sa:{Ta:{Ua:{Va:{Wa:{if(!(!(c&2)|!k[a+480190>>1])){m=0;while(1){m=m+1|0;d=o(m,104)+a|0;c=d+484416|0;f=g[c|0];p=d+484417|0;n=g[p|0];i[114610]=0;q=d+484380|0;da(916,q|0,+((+(n|0)*.0078125- +(f+ -49|0))*.08333333333333333));f=i[114610];i[114610]=0;if((f|0)==1){break La}g[p|0]=0;g[c|0]=0;c=k[d+484414>>1];Xa:{if(!(c&16384)){c=Ic(e+240|0,c&1?16:8,c&64?3:1,0,12);i[114610]=0;I(400,c|0,q|0,b|0)|0;c=i[114610];i[114610]=0;if((c|0)!=1){break Xa}f=B()|0;A()|0;break aa}i[114610]=0;f=F(390,b|0)|0;c=i[114610];i[114610]=0;if((c|0)==1){break Wa}i[114610]=0;C(338,b|0,12)|0;c=i[114610];i[114610]=0;if((c|0)==1){break Wa}c=Ab(e+240|0);i[114610]=0;I(481,b|0,c|0,f|0)|0;f=i[114610];i[114610]=0;if((f|0)==1){break Va}i[114610]=0;C(370,d+484423|0,c|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break Va}i[114610]=0;d=C(2,e+8|0,16426)|0;f=i[114610];i[114610]=0;if((f|0)==1){break Ua}i[114610]=0;D(219,e+72|0,d|0);f=i[114610];i[114610]=0;if((f|0)==1){break Ta}i[e+4>>2]=m;f=Vy(a);i[114610]=0;G(13,e+56|0,f|0,c|0);f=i[114610];i[114610]=0;if((f|0)==1){break Sa}i[114610]=0;J(649,e+24|0,e+72|0,e+4|0,e+56|0);f=i[114610];i[114610]=0;if((f|0)==1){break Ra}i[114610]=0;G(650,a|0,2,e+24|0);f=i[114610];i[114610]=0;if((f|0)==1){break Qa}eb(e+24|0);eb(e+56|0);ob(e+72|0);eb(d);eb(c)}if(m>>>0<k[a+480190>>1]){continue}break}}Qc(u);Jp(P);hb(e+1296|0);hb(e+1312|0);break b}f=B()|0;A()|0;break aa}f=B()|0;A()|0;break Ma}f=B()|0;A()|0;break Ma}f=B()|0;A()|0;break Na}f=B()|0;A()|0;break Oa}f=B()|0;A()|0;break Pa}f=B()|0;A()|0;eb(e+24|0)}eb(e+56|0)}ob(e+72|0)}eb(d)}eb(c);break aa}f=B()|0;A()|0;break aa}f=B()|0;A()|0;break ba}f=B()|0;A()|0}hb(q)}Qc(u);break B}f=B()|0;A()|0;df(t);break J}f=B()|0;A()|0;break J}f=B()|0;A()|0;break J}f=B()|0;A()|0}Qc(s);break B}f=B()|0;A()|0;break B}f=B()|0;A()|0;break B}i[114610]=0;f=F(390,e+1296|0)|0;n=i[114610];i[114610]=0;d=a;Ya:{Za:{_a:{$a:{ab:{bb:{cb:{db:{eb:{fb:{gb:{hb:{ib:{jb:{kb:{if((n|0)!=1){i[114610]=0;n=F(390,e+1296|0)|0;q=i[114610];i[114610]=0;if((q|0)==1){break kb}i[114610]=0;G(341,e+88|0,e+1296|0,n|0);n=i[114610];i[114610]=0;if((n|0)==1){break kb}if((f|0)<=844387157){if((f|0)==4674381){break ab}if((f|0)==5068115){break $a}if(t&1|(f|0)!=726487106){break Za}i[a+480224>>2]=2;i[114610]=0;K=+Z(917,e+88|0);f=i[114610];i[114610]=0;if((f|0)==1){break Ya}if(K==0){break Za}K=2646e7/(K*+(o(i[a+480216>>2],i[a+480196>>2])>>>0));if(!(K<4294967296&K>=0)){break jb}f=~~K>>>0;break ib}if((f|0)<=1314144591){if((f|0)==844387158){break _a}if((f|0)!=1280004692){break Za}q=0;if(!k[a+480188>>1]){break Za}while(1){i[114610]=0;d=C(258,e+88|0,1)|0;f=i[114610];i[114610]=0;if((f|0)==1){break E}if(!d){break Za}d=Ab(e+240|0);i[114610]=0;I(600,e+88|0,d|0,-1)|0;f=i[114610];i[114610]=0;if((f|0)==1){break gb}f=xb(d);n=lb(d);i[114610]=0;J(414,e+24|0,3,f|0,n|0);f=i[114610];i[114610]=0;if((f|0)==1){break fb}i[114610]=0;D(415,e+160|0,e+24|0);f=i[114610];i[114610]=0;if((f|0)==1){break fb}i[114610]=0;C(378,((q<<5)+a|0)+480289|0,e+160|0)|0;f=i[114610];i[114610]=0;if((f|0)==1){break eb}eb(e+160|0);eb(d);q=q+1|0;if(q>>>0<k[a+480188>>1]){continue}break}break Za}if((f|0)==1397445204){break hb}if((f|0)!=1314144592){break Za}d=0;if(!(j[u|0]|j[u+1|0]<<8)){break Za}while(1){i[114610]=0;f=C(258,e+88|0,1)|0;n=i[114610];i[114610]=0;if((n|0)==1){break cb}if(!f){break Za}i[114610]=0;f=C(918,p|0,d&65535)|0;n=i[114610];i[114610]=0;if((n|0)==1){break cb}if(!f){break Za}n=Ab(e+240|0);i[114610]=0;I(600,e+88|0,n|0,-1)|0;f=i[114610];i[114610]=0;if((f|0)==1){break bb}f=Fb(p,d);i[114610]=0;C(496,f|0,n|0)|0;f=i[114610];i[114610]=0;if((f|0)==1){break bb}eb(n);d=d+1|0;if(d>>>0<(j[u|0]|j[u+1|0]<<8)>>>0){continue}break}break Za}f=B()|0;A()|0;break B}f=B()|0;A()|0;break B}f=0}i[d+480204>>2]=f;break Za}i[114610]=0;d=F(357,e+88|0)|0;f=i[114610];i[114610]=0;if((f|0)==1){break D}i[a+480232>>2]=d>>>9;i[a+480228>>2]=d>>>8;d=0;if(!k[a+480188>>1]){break Za}while(1){i[114610]=0;f=C(919,e+88|0,e+240|0)|0;n=i[114610];i[114610]=0;if((n|0)==1){break F}if(f){h[((d<<5)+a|0)+480286>>1]=(j[e+240|0]|j[e+241|0]<<8)>>>10;f=j[H|0];S=dc(P,d),T=f,g[S|0]=T}d=d+1|0;if(d>>>0<k[a+480188>>1]){continue}break}break Za}f=B()|0;A()|0;break db}f=B()|0;A()|0;break db}f=B()|0;A()|0;eb(e+160|0)}eb(d);break C}f=B()|0;A()|0;break C}f=B()|0;A()|0;eb(n);break C}i[114610]=0;C(338,e+88|0,1)|0;d=i[114610];i[114610]=0;if((d|0)==1){break D}i[114610]=0;d=F(548,e+88|0)|0;f=i[114610];i[114610]=0;if((f|0)==1){break D}i[114610]=0;N(587,s|0,e+88|0,d|0,2)|0;d=i[114610];i[114610]=0;if((d|0)!=1){break Za}break D}i[114610]=0;C(920,e+88|0,e+24|0)|0;d=i[114610];i[114610]=0;lb:{if((d|0)!=1){d=Ab(e+240|0);i[114610]=0;I(600,e+88|0,d|0,-1)|0;f=i[114610];i[114610]=0;if((f|0)==1){break lb}if(Us(d,16389)){i[114610]=0;G(13,e+160|0,7,d|0);f=i[114610];i[114610]=0;if((f|0)==1){break lb}mb(m,e+160|0);eb(e+160|0)}eb(d);break Za}f=B()|0;A()|0;break C}f=B()|0;A()|0;eb(d);break C}i[114610]=0;r=F(390,e+88|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break D}}hb(e+88|0);continue}break}f=B()|0;A()|0;break C}f=B()|0;A()|0;break C}f=B()|0;A()|0;break C}f=B()|0;A()|0}hb(e+88|0)}Jp(P);break e}f=B()|0;A()|0;break e}f=B()|0;A()|0}hb(e+1296|0)}hb(e+1312|0)}E(f|0);x()}d=1}Xa=e+1728|0;return d|0}function Xf(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,q=0,r=0,s=0,t=0,u=0,v=p(0),w=0,y=0,z=0,D=0,J=0,L=0,O=0,P=0;d=Xa-2912|0;Xa=d;a:{b:{c:{d:{e:{if(Op(c)){kc(b,268435456);z=i[c+8>>2];t=d+2888|0;f=t;i[f>>2]=0;i[f+4>>2]=0;ni(f+8|0);i[d+2884>>2]=0;f:{g:{f=d;h:{i:{j:{k:{l:{if(j[a+3|0]+ -4>>>0<=4){i[114610]=0;e=F(548,c|0)|0;r=i[114610];i[114610]=0;if((r|0)==1){break k}i[d+2884>>2]=e;break l}e=j[a+3|0];if(e>>>0>18){break l}e=1<<e;m:{if(!(e&126991)){if(e&396800){break m}break l}if(!j[a|0]){break l}}e=i[b>>2];i[114610]=0;e=C(647,a|0,e|0)|0;q=i[114610];i[114610]=0;if((q|0)==1){break j}i[114610]=0;G(858,d+736|0,c|0,e|0);e=i[114610];i[114610]=0;if((e|0)==1){break j}e=d+736|0;q=i[e+4>>2];i[t>>2]=i[e>>2];i[t+4>>2]=q;Cpa(t+8|0,e+8|0);jc(d+736|0);i[114610]=0;q=F(412,t|0)|0;e=i[114610];i[114610]=0;if((e|0)==1){break k}i[d+2884>>2]=i[t>>2]}e=j[a+3|0];if(e>>>0>18){break g}r=1<<e;n:{if(!(r&126991)){e=0;if(r&396800){break n}break g}e=!j[a|0]}if(e|l[b>>2]<262145){break g}e=i[d+2884>>2];r=j[a+3|0];i[114610]=0;i[d+720>>2]=((r|0)==11)<<4;r=C(33,d+720|0,d+2884|0)|0;s=i[114610];i[114610]=0;if((s|0)!=1){i[d+736>>2]=e-i[r>>2];e=j[a+3|0];if(e>>>0>16){break i}o:{if(!(1<<e&126991)){if((e|0)==11){break o}break i}if(!(j[a|0]&7)){break i}}e=i[d+736>>2];if(2147483647>=e>>>0){e=e<<1;break h}e=-1;break h}a=B()|0;A()|0;break a}a=B()|0;A()|0;break a}a=B()|0;A()|0;break a}e=0;i[114610]=0;r=F(1261,a|0)|0;s=i[114610];i[114610]=0;p:{q:{if((s|0)!=1){r:{s:{switch(j[a+3|0]){case 0:case 1:case 2:case 3:case 12:case 13:case 14:case 15:case 16:e=j[a|0];break r;case 9:e=16;break r;case 11:e=4;break r;case 10:case 17:case 18:break s;default:break r}}e=8}s=i[d+736>>2];r=o(e,r)>>>3|0;e=r+ -1|0;if(-1-s>>>0<e>>>0){break q}e=e+s|0;break p}a=B()|0;A()|0;break a}e=-1}e=(e>>>0)/(r>>>0)|0}i[f+736>>2]=e;kc(b,e);break f}if(!(j[a+3|0]==4|j[a+3|0]==5|j[a+3|0]==8)){if(j[a+3|0]!=7){break f}}i[114610]=0;i[d+736>>2]=i[d+2884>>2];e=F(1261,a|0)|0;r=i[114610];i[114610]=0;f=d;t:{u:{if((r|0)!=1){e=8/(e>>>0)|0;r=i[d+736>>2];if(4294967295/(e>>>0)>>>0<r>>>0){break u}e=o(e,r);break t}a=B()|0;A()|0;break a}e=-1}i[f+736>>2]=e;kc(b,e)}v:{if(!i[b>>2]){e=0;break v}h[b+34>>1]=k[b+34>>1]&65534|j[a|0]>15;h[b+34>>1]=k[b+34>>1]&65471|(j[a+1|0]!=1)<<6;i[114610]=0;f=F(465,b|0)|0;e=i[114610];i[114610]=0;if((e|0)==1){break e}if(!f){e=0;i[b>>2]=0;break v}f=Ic(d+736|0,8,1,0,11);i[114610]=0;f=C(1262,a|0,f|0)|0;e=i[114610];i[114610]=0;w:{x:{y:{z:{A:{B:{if((e|0)!=1){if(!f){break x}e=0;i[114610]=0;a=C(1263,c|0,d+736|0)|0;f=i[114610];i[114610]=0;if((f|0)==1){break y}if(!a){break w}a=i[b>>2];i[114610]=0;i[d+720>>2]=a+1>>>1;a=F(548,c|0)|0;f=i[114610];i[114610]=0;if((f|0)==1){break B}kc(d+720|0,a);i[114610]=0;a=F(859,q|0)|0;f=i[114610];i[114610]=0;if((f|0)==1){break A}e=i[d+720>>2];if(e){break z}e=16;break w}a=B()|0;A()|0;break a}a=B()|0;A()|0;break a}a=B()|0;A()|0;break a}a=a+16|0;b=i[b+20>>2];q=0;while(1){f=j[d+736|j[a|0]&15]+q|0;g[b|0]=f;q=j[d+736|j[a|0]>>>4]+(f&255)|0;g[b+1|0]=q;a=a+1|0;b=b+2|0;e=e+ -1|0;if(e){continue}break}e=i[d+720>>2]+16|0;break w}a=B()|0;A()|0;break a}if(!(j[a+3|0]!=5?j[a+3|0]!=4:0)){a=j[a+3|0];i[114610]=0;a=N(1264,d+1800|0,c|0,b|0,(a|0)==5|0)|0;b=i[114610];i[114610]=0;if((b|0)==1){break e}hb(a);e=i[c+8>>2]-z|0;break w}if(!(j[a+3|0]!=6|j[a+1|0]!=1)){e=0;if(l[d+2884>>2]<10){break w}i[114610]=0;C(338,c|0,4)|0;a=i[114610];i[114610]=0;if((a|0)==1){break e}i[114610]=0;a=F(390,c|0)|0;f=i[114610];i[114610]=0;C:{D:{E:{if((f|0)!=1){i[114610]=0;i[d+720>>2]=a;f=F(387,c|0)|0;e=i[114610];i[114610]=0;if((e|0)==1){break E}i[114610]=0;G(1265,d+736|0,c|0,a|0);a=i[114610];i[114610]=0;if((a|0)==1){break D}kc(d+720|0,i[d+736>>2]);i[114610]=0;a=i[d+720>>2];e=F(412,d+736|0)|0;q=i[114610];i[114610]=0;if((q|0)==1){break C}q=i[d+736>>2];r=i[b+20>>2];b=hk(b);i[114610]=0;T(1266,e|0,q|0,r|0,b|0,f<<24>>24);b=i[114610];i[114610]=0;if((b|0)==1){break C}e=a+9|0;jc(d+736|0);break w}a=B()|0;A()|0;break a}a=B()|0;A()|0;break a}a=B()|0;A()|0;break a}a=B()|0;A()|0;jc(d+736|0);break a}if(!(j[a+3|0]!=9|j[a+1|0]!=1|j[a|0]!=16)){a=i[d+2884>>2];f=k[bl(d+1792|0)>>1];i[114610]=0;e=N(1267,b|0,q|0,a|0,f|0)|0;a=i[114610];i[114610]=0;if((a|0)==1){break e}break w}F:{G:{H:{I:{if(!(j[a+3|0]!=8|j[a+1|0]!=1|j[a|0]>16)){e=0;i[114610]=0;f=C(258,c|0,8)|0;q=i[114610];i[114610]=0;if((q|0)==1){break e}if(!f){break w}i[114610]=0;f=F(390,c|0)|0;q=i[114610];i[114610]=0;if((q|0)==1){break e}i[d+2884>>2]=f;if(f>>>0<4){break w}i[114610]=0;G(341,d+720|0,c|0,f|0);f=i[114610];i[114610]=0;if((f|0)==1){break b}f=Gl(d+736|0,d+720|0);hb(d+720|0);i[114610]=0;r=F(1268,f|0)|0;e=i[114610];i[114610]=0;if((e|0)==1){break d}if(!i[b>>2]){break G}s=j[a|0];D=(s|0)!=16;a=0;q=0;while(1){J:{if(D){break J}i[114610]=0;J=C(260,f|0,8)|0;e=i[114610];i[114610]=0;if((e|0)!=1){break J}a=H(77024)|0;break H}i[114610]=0;L=C(260,f|0,1)|0;e=i[114610];i[114610]=0;if((e|0)==1){break I}i[114610]=0;e=C(260,f|0,1)|0;u=i[114610];i[114610]=0;if((u|0)==1){break I}K:{L:{M:{if(!e){e=8;while(1){i[114610]=0;u=C(260,f|0,1)|0;y=i[114610];i[114610]=0;if((y|0)==1){break K}if(u){break M}e=e+16|0;continue}}i[114610]=0;e=C(260,f|0,3)|0;u=i[114610];i[114610]=0;if((u|0)!=1){break L}break I}i[114610]=0;u=C(260,f|0,4)|0;y=i[114610];i[114610]=0;if((y|0)==1){break I}e=e+u|0}q=(q&255)+(((L?-1:0)^e)&255)|0;N:{if((s|0)!=16){g[i[b+20>>2]+a|0]=q;break N}h[i[b+20>>2]+(a<<1)>>1]=J&255|q<<8}a=a+1|0;if(a>>>0<l[b>>2]){continue}break G}break}a=H(77024)|0;break H}O:{P:{Q:{R:{S:{if(!(j[a+3|0]!=7|j[a+1|0]!=1|j[a|0]>16)){e=0;if(l[d+2884>>2]<5){break w}a=i[b+20>>2];i[114610]=0;a=F(466,a|0)|0;f=i[114610];i[114610]=0;if((f|0)==1){break S}i[114610]=0;a=F(1269,a|0)|0;f=i[114610];i[114610]=0;if((f|0)==1){break e}b=hk(b);i[114610]=0;e=I(1270,c|0,a|0,b|0)|0;a=i[114610];i[114610]=0;if((a|0)==1){break e}break w}if(!(j[a|0]!=8|j[a+1|0]!=1)){T:{U:{V:{W:{X:{a=j[a+3|0];switch(a|0){case 2:break U;case 1:break V;case 0:break W;default:break X}}e=0;switch(a+ -10|0){case 0:break T;case 2:break U;default:break w}}i[114610]=0;e=I(1271,b|0,q|0,i[d+2884>>2])|0;a=i[114610];i[114610]=0;if((a|0)==1){break e}break w}i[114610]=0;e=I(1272,b|0,q|0,i[d+2884>>2])|0;a=i[114610];i[114610]=0;if((a|0)==1){break e}break w}a=i[d+2884>>2];f=j[ux(d+712|0)|0];i[114610]=0;e=N(1273,b|0,q|0,a|0,f|0)|0;a=i[114610];i[114610]=0;if((a|0)==1){break e}break w}i[114610]=0;e=I(1274,b|0,q|0,i[d+2884>>2])|0;a=i[114610];i[114610]=0;if((a|0)==1){break e}break w}if(!(j[a|0]!=8|j[a+1|0]!=3)){Y:{Z:{_:{$:{f=j[a+3|0];switch(f|0){case 2:break Y;case 1:break _;case 0:break $;default:break Z}}i[114610]=0;e=I(1275,b|0,q|0,i[d+2884>>2])|0;a=i[114610];i[114610]=0;if((a|0)==1){break e}break w}i[114610]=0;e=I(1276,b|0,q|0,i[d+2884>>2])|0;a=i[114610];i[114610]=0;if((a|0)==1){break e}break w}e=0;if((f|0)!=12){break w}}f=i[d+2884>>2];e=j[ux(d+704|0)|0];i[114610]=0;e=N(1277,b|0,q|0,f|0,e|0)|0;f=i[114610];i[114610]=0;if((f|0)==1){break e}if(j[a+3|0]!=12){break w}f=i[b>>2]<<1;if((f|0)<1){break w}a=i[b+20>>2];b=f+a|0;while(1){g[a+1|0]=j[a+1|0]+j[a|0];a=a+2|0;if(a>>>0<b>>>0){continue}break}break w}if(!(j[a|0]!=8|j[a+1|0]!=2)){e=0;aa:{switch(j[a+3|0]){case 0:i[114610]=0;e=I(1278,b|0,q|0,i[d+2884>>2])|0;a=i[114610];i[114610]=0;if((a|0)==1){break e}break w;case 1:i[114610]=0;e=I(1279,b|0,q|0,i[d+2884>>2])|0;a=i[114610];i[114610]=0;if((a|0)==1){break e}break w;case 2:break aa;default:break w}}a=i[d+2884>>2];f=j[ux(d+696|0)|0];i[114610]=0;e=N(1280,b|0,q|0,a|0,f|0)|0;a=i[114610];i[114610]=0;if((a|0)==1){break e}break w}if(!(j[a+2|0]|(j[a|0]!=16|j[a+1|0]!=1))){ba:{ca:{da:{ea:{a=j[a+3|0];switch(a|0){case 2:break ba;case 1:break da;case 0:break ea;default:break ca}}i[114610]=0;e=I(1281,b|0,q|0,i[d+2884>>2])|0;a=i[114610];i[114610]=0;if((a|0)==1){break e}break w}i[114610]=0;e=I(1282,b|0,q|0,i[d+2884>>2])|0;a=i[114610];i[114610]=0;if((a|0)==1){break e}break w}e=0;if((a|0)!=12){break w}}a=i[d+2884>>2];f=k[bl(d+688|0)>>1];i[114610]=0;e=N(1283,b|0,q|0,a|0,f|0)|0;a=i[114610];i[114610]=0;if((a|0)==1){break e}break w}if(!(j[a|0]!=16|j[a+1|0]!=1|j[a+2|0]!=1)){e=0;fa:{switch(j[a+3|0]){case 0:i[114610]=0;e=I(1284,b|0,q|0,i[d+2884>>2])|0;a=i[114610];i[114610]=0;if((a|0)==1){break e}break w;case 1:i[114610]=0;e=I(1285,b|0,q|0,i[d+2884>>2])|0;a=i[114610];i[114610]=0;if((a|0)==1){break e}break w;case 2:break fa;default:break w}}a=i[d+2884>>2];f=k[bl(d+680|0)>>1];i[114610]=0;e=N(1286,b|0,q|0,a|0,f|0)|0;a=i[114610];i[114610]=0;if((a|0)==1){break e}break w}if(!(j[a+2|0]|(j[a|0]!=16|j[a+1|0]!=3))){ga:{ha:{ia:{ja:{f=j[a+3|0];switch(f|0){case 2:break ga;case 1:break ia;case 0:break ja;default:break ha}}i[114610]=0;e=I(1287,b|0,q|0,i[d+2884>>2])|0;a=i[114610];i[114610]=0;if((a|0)==1){break e}break w}i[114610]=0;e=I(1288,b|0,q|0,i[d+2884>>2])|0;a=i[114610];i[114610]=0;if((a|0)==1){break e}break w}e=0;if((f|0)!=12){break w}}f=i[d+2884>>2];e=k[bl(d+672|0)>>1];i[114610]=0;e=N(1289,b|0,q|0,f|0,e|0)|0;f=i[114610];i[114610]=0;if((f|0)==1){break e}if(j[a+3|0]!=12){break w}f=i[b>>2];if(f<<1<1){break w}a=i[b+20>>2];b=a+(f<<2)|0;while(1){h[a+2>>1]=k[a+2>>1]+k[a>>1];a=a+4|0;if(a>>>0<b>>>0){continue}break}break w}if(!(j[a|0]!=16|j[a+1|0]!=3|j[a+2|0]!=1)){e=0;ka:{switch(j[a+3|0]){case 0:i[114610]=0;e=I(1290,b|0,q|0,i[d+2884>>2])|0;a=i[114610];i[114610]=0;if((a|0)==1){break e}break w;case 1:i[114610]=0;e=I(1291,b|0,q|0,i[d+2884>>2])|0;a=i[114610];i[114610]=0;if((a|0)==1){break e}break w;case 2:break ka;default:break w}}a=i[d+2884>>2];f=k[bl(d+664|0)>>1];i[114610]=0;e=N(1292,b|0,q|0,a|0,f|0)|0;a=i[114610];i[114610]=0;if((a|0)==1){break e}break w}if(!(j[a+2|0]|(j[a|0]!=16|j[a+1|0]!=2))){e=0;la:{switch(j[a+3|0]){case 0:i[114610]=0;e=I(1293,b|0,q|0,i[d+2884>>2])|0;a=i[114610];i[114610]=0;if((a|0)==1){break e}break w;case 1:i[114610]=0;e=I(1294,b|0,q|0,i[d+2884>>2])|0;a=i[114610];i[114610]=0;if((a|0)==1){break e}break w;case 2:break la;default:break w}}a=i[d+2884>>2];f=k[bl(d+656|0)>>1];i[114610]=0;e=N(1295,b|0,q|0,a|0,f|0)|0;a=i[114610];i[114610]=0;if((a|0)==1){break e}break w}if(!(j[a|0]!=16|j[a+1|0]!=2|j[a+2|0]!=1)){e=0;ma:{switch(j[a+3|0]){case 0:i[114610]=0;e=I(1296,b|0,q|0,i[d+2884>>2])|0;a=i[114610];i[114610]=0;if((a|0)==1){break e}break w;case 1:i[114610]=0;e=I(1297,b|0,q|0,i[d+2884>>2])|0;a=i[114610];i[114610]=0;if((a|0)==1){break e}break w;case 2:break ma;default:break w}}a=i[d+2884>>2];f=k[bl(d+648|0)>>1];i[114610]=0;e=N(1298,b|0,q|0,a|0,f|0)|0;a=i[114610];i[114610]=0;if((a|0)==1){break e}break w}if(!(j[a+3|0]|(j[a|0]!=24|j[a+1|0]!=1))){f=i[d+2884>>2];if(!j[a+2|0]){i[114610]=0;h[d>>1]=k[d+640>>1];e=N(1299,b|0,q|0,f|0,d|0)|0;a=i[114610];i[114610]=0;if((a|0)==1){break e}break w}i[114610]=0;h[d+2>>1]=k[d+632>>1];e=N(1300,b|0,q|0,f|0,d+2|0)|0;a=i[114610];i[114610]=0;if((a|0)==1){break e}break w}if(!(j[a+3|0]|(j[a|0]!=24|j[a+1|0]!=2))){f=i[d+2884>>2];if(!j[a+2|0]){i[114610]=0;h[d+4>>1]=k[d+624>>1];e=N(1301,b|0,q|0,f|0,d+4|0)|0;a=i[114610];i[114610]=0;if((a|0)==1){break e}break w}i[114610]=0;h[d+6>>1]=k[d+616>>1];e=N(1302,b|0,q|0,f|0,d+6|0)|0;a=i[114610];i[114610]=0;if((a|0)==1){break e}break w}if(!(j[a+3|0]|(j[a|0]!=32|j[a+1|0]!=1))){f=i[d+2884>>2];if(!j[a+2|0]){i[114610]=0;h[d+8>>1]=k[d+608>>1];e=N(1303,b|0,q|0,f|0,d+8|0)|0;a=i[114610];i[114610]=0;if((a|0)==1){break e}break w}i[114610]=0;h[d+10>>1]=k[d+600>>1];e=N(1304,b|0,q|0,f|0,d+10|0)|0;a=i[114610];i[114610]=0;if((a|0)==1){break e}break w}if(!(j[a+3|0]|(j[a|0]!=32|j[a+1|0]!=2))){f=i[d+2884>>2];if(!j[a+2|0]){i[114610]=0;h[d+12>>1]=k[d+592>>1];e=N(1305,b|0,q|0,f|0,d+12|0)|0;a=i[114610];i[114610]=0;if((a|0)==1){break e}break w}i[114610]=0;h[d+14>>1]=k[d+584>>1];e=N(1306,b|0,q|0,f|0,d+14|0)|0;a=i[114610];i[114610]=0;if((a|0)==1){break e}break w}if(!(j[a+3|0]|(j[a|0]!=64|j[a+1|0]!=1))){f=i[d+2884>>2];if(!j[a+2|0]){i[114610]=0;h[d+16>>1]=k[d+576>>1];e=N(1307,b|0,q|0,f|0,d+16|0)|0;a=i[114610];i[114610]=0;if((a|0)==1){break e}break w}i[114610]=0;h[d+18>>1]=k[d+568>>1];e=N(1308,b|0,q|0,f|0,d+18|0)|0;a=i[114610];i[114610]=0;if((a|0)==1){break e}break w}if(!(j[a+3|0]|(j[a|0]!=64|j[a+1|0]!=2))){f=i[d+2884>>2];if(!j[a+2|0]){i[114610]=0;h[d+20>>1]=k[d+560>>1];e=N(1309,b|0,q|0,f|0,d+20|0)|0;a=i[114610];i[114610]=0;if((a|0)==1){break e}break w}i[114610]=0;h[d+22>>1]=k[d+552>>1];e=N(1310,b|0,q|0,f|0,d+22|0)|0;a=i[114610];i[114610]=0;if((a|0)==1){break e}break w}if(!(j[a|0]!=32|j[a+1|0]!=1|j[a+3|0]!=3)){f=i[d+2884>>2];if(!j[a+2|0]){i[114610]=0;h[d+24>>1]=k[d+544>>1];e=N(1311,b|0,q|0,f|0,d+24|0)|0;a=i[114610];i[114610]=0;if((a|0)==1){break e}break w}i[114610]=0;h[d+26>>1]=k[d+536>>1];e=N(1312,b|0,q|0,f|0,d+26|0)|0;a=i[114610];i[114610]=0;if((a|0)==1){break e}break w}if(!(j[a|0]!=32|j[a+1|0]!=2|j[a+3|0]!=3)){f=i[d+2884>>2];if(!j[a+2|0]){i[114610]=0;h[d+28>>1]=k[d+528>>1];e=N(1313,b|0,q|0,f|0,d+28|0)|0;a=i[114610];i[114610]=0;if((a|0)==1){break e}break w}i[114610]=0;h[d+30>>1]=k[d+520>>1];e=N(1314,b|0,q|0,f|0,d+30|0)|0;a=i[114610];i[114610]=0;if((a|0)==1){break e}break w}if(!(j[a|0]!=64|j[a+1|0]!=1|j[a+3|0]!=3)){f=i[d+2884>>2];if(!j[a+2|0]){i[114610]=0;h[d+32>>1]=k[d+512>>1];e=N(1315,b|0,q|0,f|0,d+32|0)|0;a=i[114610];i[114610]=0;if((a|0)==1){break e}break w}i[114610]=0;h[d+34>>1]=k[d+504>>1];e=N(1316,b|0,q|0,f|0,d+34|0)|0;a=i[114610];i[114610]=0;if((a|0)==1){break e}break w}if(!(j[a|0]!=64|j[a+1|0]!=2|j[a+3|0]!=3)){f=i[d+2884>>2];if(!j[a+2|0]){i[114610]=0;h[d+36>>1]=k[d+496>>1];e=N(1317,b|0,q|0,f|0,d+36|0)|0;a=i[114610];i[114610]=0;if((a|0)==1){break e}break w}i[114610]=0;h[d+38>>1]=k[d+488>>1];e=N(1318,b|0,q|0,f|0,d+38|0)|0;a=i[114610];i[114610]=0;if((a|0)==1){break e}break w}if(!(j[a|0]!=24|(j[a+1|0]!=2?j[a+1|0]!=1:0)|j[a+3|0]!=16)){i[d+736>>2]=-2147483648;f=i[d+2884>>2];na:{if(!j[a+2|0]){i[114610]=0;i[d+48>>2]=i[d+480>>2];i[d+476>>2]=0;a=i[d+476>>2];i[d+40>>2]=i[d+472>>2];i[d+44>>2]=a;e=S(1319,b|0,q|0,f|0,d+736|0,d+40|0)|0;a=i[114610];i[114610]=0;if((a|0)!=1){break na}break O}i[114610]=0;i[d- -64>>2]=i[d+464>>2];i[d+460>>2]=0;a=i[d+460>>2];i[d+56>>2]=i[d+456>>2];i[d+60>>2]=a;e=S(1320,b|0,q|0,f|0,d+736|0,d+56|0)|0;a=i[114610];i[114610]=0;if((a|0)==1){break O}}if(!e){break w}a=i[d+736>>2];if((a|0)==-2147483648){break w}f=k[b+32>>1];i[114610]=0;f=XMa(f,0,a,0)+1073741824|0;a=_a;a=f>>>0<1073741824?a+1|0:a;a=eg(793,(a&2147483647)<<1|f>>>31,a>>>31|0);f=i[114610];i[114610]=0;if((f|0)==1){break O}O=b,P=hd(a,1,64),h[O+32>>1]=P;h[b+34>>1]=k[b+34>>1]|8192;break w}if(!(j[a|0]!=32|(j[a+1|0]!=2?j[a+1|0]!=1:0)|j[a+3|0]!=16)){i[d+736>>2]=-2147483648;f=i[d+2884>>2];oa:{if(!j[a+2|0]){i[114610]=0;i[d+80>>2]=i[d+448>>2];i[d+444>>2]=0;a=i[d+444>>2];i[d+72>>2]=i[d+440>>2];i[d+76>>2]=a;e=S(1321,b|0,q|0,f|0,d+736|0,d+72|0)|0;a=i[114610];i[114610]=0;if((a|0)!=1){break oa}break P}i[114610]=0;i[d+96>>2]=i[d+432>>2];i[d+428>>2]=0;a=i[d+428>>2];i[d+88>>2]=i[d+424>>2];i[d+92>>2]=a;e=S(1322,b|0,q|0,f|0,d+736|0,d+88|0)|0;a=i[114610];i[114610]=0;if((a|0)==1){break P}}if(!e){break w}a=i[d+736>>2];if((a|0)==-2147483648){break w}f=k[b+32>>1];i[114610]=0;a=XMa(f,0,a,0)+1073741824|0;f=_a;f=a>>>0<1073741824?f+1|0:f;a=eg(793,(f&2147483647)<<1|a>>>31,f>>>31|0);f=i[114610];i[114610]=0;if((f|0)==1){break P}O=b,P=hd(a,1,64),h[O+32>>1]=P;h[b+34>>1]=k[b+34>>1]|8192;break w}if(!(j[a|0]!=32|(j[a+1|0]!=2?j[a+1|0]!=1:0)|j[a+3|0]!=15)){i[d+736>>2]=1065353216;f=i[d+2884>>2];pa:{if(!j[a+2|0]){i[114610]=0;i[d+412>>2]=0;i[d+416>>2]=1065353216;a=i[d+420>>2];i[d+112>>2]=i[d+416>>2];i[d+116>>2]=a;a=i[d+412>>2];i[d+104>>2]=i[d+408>>2];i[d+108>>2]=a;e=S(1323,b|0,q|0,f|0,d+736|0,d+104|0)|0;a=i[114610];i[114610]=0;if((a|0)!=1){break pa}break Q}i[114610]=0;i[d+396>>2]=0;i[d+400>>2]=1065353216;a=i[d+404>>2];i[d+128>>2]=i[d+400>>2];i[d+132>>2]=a;a=i[d+396>>2];i[d+120>>2]=i[d+392>>2];i[d+124>>2]=a;e=S(1324,b|0,q|0,f|0,d+736|0,d+120|0)|0;a=i[114610];i[114610]=0;if((a|0)==1){break Q}}if(!e){break w}v=m[d+736>>2];if(v==p(1)){break w}v=Fm(p(v*p(k[b+32>>1])),p(1),p(64));i[114610]=0;a=Ua(1325,p(v))|0;f=i[114610];i[114610]=0;if((f|0)==1){break Q}h[b+32>>1]=a;h[b+34>>1]=k[b+34>>1]|8192;break w}if(!(j[a|0]!=64|(j[a+1|0]!=2?j[a+1|0]!=1:0)|j[a+3|0]!=15)){i[d+736>>2]=0;i[d+740>>2]=1072693248;f=i[d+2884>>2];qa:{if(!j[a+2|0]){i[114610]=0;i[d+376>>2]=0;i[d+380>>2]=1072693248;i[d+368>>2]=0;i[d+372>>2]=0;i[d+144>>2]=0;i[d+148>>2]=0;i[d+152>>2]=0;i[d+156>>2]=1072693248;a=i[d+388>>2];i[d+160>>2]=i[d+384>>2];i[d+164>>2]=a;a=i[d+364>>2];i[d+136>>2]=i[d+360>>2];i[d+140>>2]=a;e=S(1326,b|0,q|0,f|0,d+736|0,d+136|0)|0;a=i[114610];i[114610]=0;if((a|0)!=1){break qa}break R}i[114610]=0;i[d+344>>2]=0;i[d+348>>2]=1072693248;i[d+336>>2]=0;i[d+340>>2]=0;i[d+176>>2]=0;i[d+180>>2]=0;i[d+184>>2]=0;i[d+188>>2]=1072693248;a=i[d+356>>2];i[d+192>>2]=i[d+352>>2];i[d+196>>2]=a;a=i[d+332>>2];i[d+168>>2]=i[d+328>>2];i[d+172>>2]=a;e=S(1327,b|0,q|0,f|0,d+736|0,d+168|0)|0;a=i[114610];i[114610]=0;if((a|0)==1){break R}}if(!e){break w}w=n[d+736>>3];if(w==1){break w}w=tx(w*+k[b+32>>1],1,64);i[114610]=0;a=la(1328,+w)|0;f=i[114610];i[114610]=0;if((f|0)==1){break R}h[b+32>>1]=a;h[b+34>>1]=k[b+34>>1]|8192;break w}if(!(j[a|0]!=32|j[a+1|0]!=1|j[a+3|0]!=13)){f=i[d+2884>>2];if(!j[a+2|0]){i[114610]=0;i[d+320>>2]=939524096;a=i[d+324>>2];i[d+200>>2]=i[d+320>>2];i[d+204>>2]=a;e=N(1329,b|0,q|0,f|0,d+200|0)|0;a=i[114610];i[114610]=0;if((a|0)==1){break e}break w}i[114610]=0;i[d+312>>2]=939524096;a=i[d+316>>2];i[d+208>>2]=i[d+312>>2];i[d+212>>2]=a;e=N(1330,b|0,q|0,f|0,d+208|0)|0;a=i[114610];i[114610]=0;if((a|0)==1){break e}break w}if(!(j[a|0]!=32|j[a+1|0]!=2|j[a+3|0]!=13)){f=i[d+2884>>2];if(!j[a+2|0]){i[114610]=0;i[d+304>>2]=939524096;a=i[d+308>>2];i[d+216>>2]=i[d+304>>2];i[d+220>>2]=a;e=N(1331,b|0,q|0,f|0,d+216|0)|0;a=i[114610];i[114610]=0;if((a|0)==1){break e}break w}i[114610]=0;i[d+296>>2]=939524096;a=i[d+300>>2];i[d+224>>2]=i[d+296>>2];i[d+228>>2]=a;e=N(1332,b|0,q|0,f|0,d+224|0)|0;a=i[114610];i[114610]=0;if((a|0)==1){break e}break w}if(!(j[a|0]!=32|j[a+1|0]!=1|j[a+3|0]!=14)){f=i[d+2884>>2];if(!j[a+2|0]){i[114610]=0;i[d+288>>2]=872415232;a=i[d+292>>2];i[d+232>>2]=i[d+288>>2];i[d+236>>2]=a;e=N(1329,b|0,q|0,f|0,d+232|0)|0;a=i[114610];i[114610]=0;if((a|0)==1){break e}break w}i[114610]=0;i[d+280>>2]=872415232;a=i[d+284>>2];i[d+240>>2]=i[d+280>>2];i[d+244>>2]=a;e=N(1330,b|0,q|0,f|0,d+240|0)|0;a=i[114610];i[114610]=0;if((a|0)==1){break e}break w}e=0;if(j[a|0]!=32|j[a+1|0]!=2|j[a+3|0]!=14){break w}f=i[d+2884>>2];if(!j[a+2|0]){i[114610]=0;i[d+272>>2]=872415232;a=i[d+276>>2];i[d+248>>2]=i[d+272>>2];i[d+252>>2]=a;e=N(1331,b|0,q|0,f|0,d+248|0)|0;a=i[114610];i[114610]=0;if((a|0)!=1){break w}break e}i[114610]=0;i[d+264>>2]=872415232;a=i[d+268>>2];i[d+256>>2]=i[d+264>>2];i[d+260>>2]=a;e=N(1332,b|0,q|0,f|0,d+256|0)|0;a=i[114610];i[114610]=0;if((a|0)==1){break e}break w}a=H(0)|0;A()|0;gb(a);x()}a=B()|0;A()|0;break a}a=B()|0;A()|0;break a}a=B()|0;A()|0;break a}a=B()|0;A()|0;break a}a=H(77024)|0}if((A()|0)!=(U(77024)|0)){break c}M(a|0)|0;i[114610]=0;K(20);a=i[114610];i[114610]=0;if((a|0)==1){break F}}e=r+4|0;hb(f);break w}a=B()|0;A()|0;break c}i[114610]=0;C(256,c|0,e+z|0)|0;a=i[114610];i[114610]=0;if((a|0)==1){break e}}jc(t)}Xa=d+2912|0;return e|0}a=B()|0;A()|0;break a}a=B()|0;A()|0}hb(f);break a}a=B()|0;A()|0}jc(t);E(a|0);x()}function Yoa(a){var b=0,c=0,d=0,e=0,f=0,n=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=p(0),Q=0,R=0,S=p(0),T=0,U=0;d=Xa-32|0;Xa=d;a:{if(!k[a+480188>>1]){E=-1;B=65535;C=-1;break a}Q=a+1075821|0;H=a+1304392|0;r=a+1074308|0;O=a+1074376|0;L=a+480209|0;C=-1;E=-1;B=65535;while(1){f=o(u,896)+a|0;s=f+1075799|0;n=j[s|0];A=f+1075797|0;w=j[A|0];D=f+1075798|0;v=j[D|0];K=f+1075796|0;F=j[K|0];I=f+1075795|0;b=j[I|0];c=i[a+1074392>>2];q=i[a+1074400>>2];t=i[a+1074416>>2];G=f+1075794|0;x=Ur(G);y=f+1075856|0;g[y|0]=i[a+480208>>2]>>>12&1|j[y|0]&254;e=(c>>>0)%(q+t>>>0)|0;c=j[G|0];if((c|0)==252){c=j[I|0];q=sx(G);t=Sr(G);b:{if(!c|c+ -251>>>0<5){break b}c=i[(o(c,160)+a|0)+906140>>2];if(!c){break b}$a[i[i[c>>2]+44>>2]](c,q,p(p(t>>>0)*p(.0010010009864345193)))}c=j[G|0]}c:{if(w&255|m[f+1075868>>2]==p(0)?(c&255)!=251:0){break c}z=i[a+480208>>2]&4096;d:{if(!z){t=j[f+1075878|0];break d}t=j[I|0];g[f+1075878|0]=t}c=t&255;if(c+ -251>>>0<5|!c){break c}q=(o(c,160)+a|0)+906140|0;if(!i[q>>2]){break c}e:{if(!z){c=k[f+1075876>>1];break e}c=Pr(j[K|0],j[D|0]);h[f+1075876>>1]=c;P=p(p(Pr(j[A|0],j[s|0])>>>0)*p(.0010010009864345193));m[f+1075872>>2]=P;s=i[q>>2];R=f+1075868|0,S=p(p(P-p($a[i[i[s>>2]+48>>2]](s,c)))/p(Zk(a)>>>0)),m[R>>2]=S}s=i[a+1074392>>2];t=Zk(a);q=i[q>>2];if((t|0)==(s+1|0)){$a[i[i[q>>2]+44>>2]](q,c,m[f+1075872>>2]);break c}$a[i[i[q>>2]+100>>2]](q,c,m[f+1075868>>2])}s=f+1074984|0;f:{g:{h:{i:{j:{if(!IK(j[G|0])){if(j[L|0]&16){break j}break i}Woa(s);b=0;F=0;v=0;w=0;n=0;x=0;if(!(j[L|0]&16)){break i}t=0;break g}if(!b){b=0;break h}i[f+1075768>>2]=0;break h}zK(a,s)}A=w&255;if((A|0)==33){kb(d+24|0,r,30);t=n>>>4|0;ox(a,u&65535,t+(n&15)|0,ib(d+24|0));w=33;break g}t=0;if((w+ -19&255)>>>0>1){break g}k:{if(!(!(i[a+480180>>2]&16777250)|n)){n=j[f+1075837|0];break k}g[f+1075837|0]=n}c=n&240;if((c|0)==208){c=n&15;if(!c){if(i[a+480180>>2]&16777248){t=1;break g}if(i[a+480180>>2]!=2){break g}break f}l:{if(c>>>0<i[a+1074400>>2]+i[a+1074416>>2]>>>0){break l}kb(d+24|0,r,14);if(!ib(d+24|0)){break l}if(!b){break f}g[f+1075809|0]=b;break f}t=c;break g}if(!(j[L|0]&16)){break g}q=19;m:{n:{o:{if(!((c|0)==96?(A|0)==19:0)){if((c|0)!=176){break n}q=20;if((A|0)!=20){break o}}kb(d+24|0,r,77);if(!(!ib(d+24|0)|!(i[((u<<5)+a|0)+480280>>2]&1024))){w=q;break g}c=Voa(a,s,n&15);p:{if((c|0)==-1){c=E;break p}q:{if((C|0)!=-1){kb(d+24|0,r,68);C=ib(d+24|0)?c:C;break q}C=-1}kb(d+24|0,r,103);B=ib(d+24|0)?-1:B}if(!k[a+480188>>1]|i[a+480180>>2]!=2){break m}E=f+1075845|0;A=f+1075788|0;w=0;while(1){D=o(w,896)+a|0;i[D+1075788>>2]=i[A>>2];g[D+1075845|0]=j[E|0];w=w+1|0;if(w>>>0<k[a+480188>>1]){continue}break}break m}w=19;break g}if((c|0)!=224|(i[a+1074396>>2]?i[a+480180>>2]&16777250:0)){break g}c=n&15;if(i[a+480180>>2]&2?!c:0){break g}i[a+1074396>>2]=c+1;break g}w=q;E=c}M=w&255;q=(M|0)==19&i[a+480180>>2]==16&(n&240)==208;z=q?0:t;r:{if(!z|j[G|0]!=255|j[K|0]!=2){break r}kb(d+24|0,r,74);if(!ib(d+24|0)){break r}g[K|0]=0}c=i[a+1074392>>2];kb(d+24|0,r,72);s:{if(ib(d+24|0)){t=0;if(z>>>0>=l[a+1074416>>2]){break s}}kb(d+24|0,r,88);t=(e|0)==(z|0)|(c|0)==(z|0);if(!(!z|!ib(d+24|0))){break s}t=(c|0)==(z|0)}D=t;kb(d+24|0,r,44);if(ib(d+24|0)){g[y|0]=j[y|0]&254|(e|0)==(z|0)}N=n&15;e=q?N|144:n;kb(d+24|0,r,66);x=(!z|ib(d+24|0)^1)&x;t:{u:{if(!(i[a+1074392>>2]|(!b|!(i[a+480208>>2]&2097152)))){i[f+1075644>>2]=0;if(D){break u}if(!nh(s)){break t}g[f+1075809|0]=b;if(b>>>0>k[a+480190>>1]){break t}b=o(b,104)+a|0;i[f+1075672>>2]=k[b+484410>>1];i[f+1075752>>2]=g[b+484417|0];break t}if(!D){break t}}n=j[G|0];if(b){g[f+1075809|0]=b}v:{w:{if(!Jd(n)){break w}kb(d+24|0,r,67);if(!ib(d+24|0)){break w}q=i[f+1075756>>2];x:{if(!b|x){break x}y:{if(k[a+480192>>1]){c=65535;if(b>>>0>k[a+480192>>1]){break y}t=i[((b<<2)+a|0)+900380>>2];if(!t){break y}c=k[Mc(t+236|0,n+ -1|0)>>1];break y}c=b}c=c&65535;if(c>>>0>k[a+480190>>1]){break x}q=g[Uo(a,c)+36|0]}n=(n+q|0)+ -12>>>0>119?0:n;break v}if(!(i[a+480180>>2]&25165856)|!k[a+480192>>1]){break v}c=n;q=1;z:{if(!c){break z}q=Jd(c)}if(!q){break v}q=b?b:j[f+1075810|0];if(!q|(i[((q<<2)+a|0)+900380>>2]?q>>>0<=k[a+480192>>1]:0)){break v}n=0;b=0}if(!((M|0)!=25|e)){kb(d+24|0,r,55);c=ib(d+24|0);b=c?0:b;n=c?0:n}kb(d+24|0,r,65);c=(b|0)!=0;q=!n;t=ib(d+24|0);J=1;A:{if(i[a+480180>>2]&16777248){break A}kb(d+24|0,r,107);if(ib(d+24|0)){break A}kb(d+16|0,r,85);J=0;if(!ib(d+16|0)){break A}if(nh(s)){break A}J=1;y=i[f+1075088>>2];if(!y){break A}J=ie(y)^1}q=c&q;A=c&t;B:{C:{D:{E:{F:{G:{H:{I:{if(!(i[a+480180>>2]&1048580)){break I}J:{if((n|0)!=255){break J}if(!(b?0:!((M|0)==13|(F&255)==1))){kb(d+24|0,r,55);if(ib(d+24|0)){break J}}c=i[f+1075640>>2];if(g[c+60|0]&1?c:0){break J}i[f+1075672>>2]=0;b=f+1075072|0;i[b>>2]=i[b>>2]|2097152;K:{if(!(i[a+480208>>2]&4096)){break K}kb(d+24|0,r,86);if(!ib(d+24|0)){break K}i[b>>2]=i[b>>2]|4096}b=0;n=0;c=0;q=0;t=0;y=1;if(A){break C}break B}kb(d+24|0,r,59);if(!ib(d+24|0)|i[a+480208>>2]&4096){break I}c=j[f+1075803|0]-j[f+1075756|0]|0;if(!n){break G}if(n>>>0>250){J=0;A=1;c=0;break G}if(!b){kb(d+24|0,r,98);A=0;if(ib(d+24|0)){break H}}J=1;A=1;break H}c=0;t=0;if(!q){break E}break F}c=n}x=0}kb(d+24|0,r,65);if(!ib(d+24|0)){break D}n=c;t=1}q=n;c=t;y=1;if(A){break C}break B}n=c;c=1;y=A}L:{M:{if(!k[a+480192>>1]){if(b>>>0>k[a+480190>>1]){break L}q=(o(b,104)+a|0)+484380|0;break M}q=i[f+1075088>>2];if(!q){break L}}N:{if(h[q+34>>1]<0){break N}if(i[a+480180>>2]==2){if(!ie(q)){break N}}i[f+1075672>>2]=k[q+30>>1]}if(!y){break L}is(s,k[q+28>>1],a)}q=n;t=c}kb(d+24|0,r,71);if(!(!b|!ib(d+24|0))){g[f+1075843|0]=32}O:{if(!k[a+480192>>1]){break O}kb(d+24|0,r,100);if(!b|!ib(d+24|0)){break O}if(Jd(q&255)){break O}c=i[a+480208>>2];P:{if(x){if(c&8){break P}break O}if(!(c&4)){break O}}_k(s);i[f+1075680>>2]=65536;c=f+1075072|0;i[c>>2]=i[c>>2]|2097152}if(t){kb(d+24|0,r,11);Q:{if(R=!ib(d+24|0),T=0,U=i[a+480180>>2]!=268435456,U?R:T){break Q}kb(d+24|0,r,87);n=0;if(ib(d+24|0)){n=nh(s)^1}if(k[a+480192>>1]){if((n^-1)&i[f+1075640>>2]==i[((b<<2)+a|0)+900380>>2]|b>>>0>k[a+480192>>1]){break Q}q=j[f+1075803|0];break Q}if((n^-1)&i[f+1075088>>2]==((o(b,104)+a|0)+484380|0)|b>>>0>3999){break Q}q=j[f+1075803|0]}R:{if(!k[a+480192>>1]|!(i[a+480180>>2]&1048588)){break R}_k(s);g[f+1075822|0]=0;i[f+1075764>>2]=0;i[f+1075680>>2]=65536;c=f+1075072|0;i[c>>2]=i[c>>2]&-2101249|2097152;kb(d+24|0,r,86);if(!ib(d+24|0)){break R}i[c>>2]=i[c>>2]&-2049}b=J?b:0}t=q&255;S:{if(t>>>0<251){break S}kb(d+24|0,r,50);T:{if(!b|!ib(d+24|0)){break T}if(k[a+480192>>1]){if(b>>>0>k[a+480192>>1]){break T}c=((b<<2)+a|0)+900380|0;if(!i[c>>2]){break T}n=f+1075805|0;if(!Jd(j[n|0])){break T}c=k[Mc(i[c>>2]+236|0,j[n|0]+ -1|0)>>1]}else{c=b}c=c&65535;if(!c|c>>>0>k[a+480190>>1]){break T}c=o(c,104)+a|0;if(h[c+484414>>1]<0){break T}i[f+1075672>>2]=k[c+484410>>1]}kb(d+24|0,r,100);if(R=ib(d+24|0),T=0,U=i[a+480208>>2]&4,U?R:T){break S}b=0}U:{if(!Jd(t)){break U}g[f+1075808|0]=q;g[f+1075805|0]=q;if(x){break U}CK(a,u&65535,b,t,0)}V:{W:{X:{Y:{if(t){n=f+1075780|0;c=h[n>>1];if(c){i[f+1075676>>2]=(c&32767)+ -1;if((c|0)<=-1){c=f+1075072|0;i[c>>2]=i[c>>2]|256}h[n>>1]=0}c=f+1075801|0;n=j[c|0];if(n){g[f+1075842|0]=n+ -1;g[c|0]=0}c=f+1075802|0;n=j[c|0];if(n){g[f+1075841|0]=n+ -1;g[c|0]=0}if(!b){break Y}break X}if(b){break X}b=x;break V}c=0;q=1;y=f+1075809|0;Z:{if(!j[y|0]){break Z}if(!Jd(t)){break Z}Co(a,s,j[y|0],x,i[f+1075088>>2]?0:!i[f+1075640>>2],!(i[a+480180>>2]&1048580));g[y|0]=0;c=1}b=x;break W}c=f+1075088|0;n=i[c>>2];Co(a,s,b,x,1,1);b=i[c>>2];_:{if(!b|!(j[b+35|0]&2)){break _}if(!$c(H)){break _}Fx(i[H>>2],u&65535,i[c>>2]+68|0)}$:{if(i[a+480180>>2]==1){if(x){kb(d+24|0,r,85);if(ib(d+24|0)){break $}}g[f+1075809|0]=0;break $}kb(d+24|0,r,50);if(ib(d+24|0)){if(!Jd(t)){break $}}g[f+1075809|0]=0}kb(d+24|0,r,42);aa:{ba:{ca:{if(ib(d+24|0)){if(!Jd(t)|(n|0)==i[c>>2]){break ba}break ca}if(!(!(i[a+480180>>2]&16777248)|(n|0)==i[c>>2])){b=0;if(Jd(t)){break aa}}kb(d+24|0,r,107);da:{if(!ib(d+24|0)|(n|0)==i[c>>2]){break da}if(!x){if(Jd(t)){break da}}b=f+1075060|0;if(l[b>>2]>=l[s+4>>2]){break da}i[b>>2]=0;break ba}kb(d+24|0,r,85);if(!ib(d+24|0)){break ba}if(nh(s)){break ba}}i[s>>2]=0;i[s+4>>2]=0}b=x}q=0;c=0;if(!t){break V}}n=f+1075088|0;x=i[n>>2];ea:{if(!x|!(j[x+35|0]&2)){break ea}if(!$c(H)){break ea}if(!c){if(DK(i[H>>2],u&65535)){break ea}}Fx(i[H>>2],u&65535,i[n>>2]+68|0)}c=u&65535;Rr(a,s,t,b,!(i[a+480180>>2]&1048580),0,c);if(!(!b|(!(i[a+480180>>2]&1048580)|q))){n=f+1075072|0;i[n>>2]=i[n>>2]|2097152;_k(s);g[f+1075822|0]=0;i[f+1075764>>2]=0}if(!(i[f+1075072>>2]&512)){break V}if(!$c(H)){break V}fa:{switch(t+ -253|0){case 0:kb(d+24|0,r,99);if(ib(d+24|0)){break V}break;case 1:case 2:break fa;default:break V}}Rj(i[H>>2],c)}ga:{ha:{switch((F&255)+ -1|0){case 0:v=v>>>0<64?v:64;i[f+1075672>>2]=v<<2;c=f+1075072|0;i[c>>2]=i[c>>2]|2097152;break ga;case 1:break ha;default:break ga}}$k(a,s,v,6)}if(k[a+480192>>1]){gJ(a,u&65535)}x=b}kb(d+24|0,r,77);if(R=ib(d+24|0),T=0,U=i[((u<<5)+a|0)+480280>>2]&1024,U?R:T){break f}b=i[a+1074392>>2];kb(d+24|0,r,75);ia:{ja:{ka:{b=b>>>0>=z>>>0;la:{if(!z|!ib(d+24|0)){break la}c=i[a+1074392>>2];if(!c){break ka}b=1;if((c|0)!=(z|0)){break la}b=!j[I|0]&(F&255)!=11}c=F&255;if(!b|c>>>0<3){break ka}if((c|0)==11){rx(d+24|0,a,G,z);b=j[Pb(d+24|0)|0];zm(a,s,i[d+24>>2]);if(b){break ia}b=11;break ja}kb(d+24|0,r,62);ma:{if(!(!ib(d+24|0)|v)){v=0;b=0;na:{switch(c+ -8|0){case 0:break ma;case 1:break na;default:break ja}}if(j[L|0]&16){break ja}i[f+1075676>>2]=0;break ja}kb(d+24|0,r,41);if(ib(d+24|0)){break ma}if(v){g[f+1075838|0]=v;break ma}v=j[f+1075838|0]}b=F;oa:{switch(c+ -3|0){case 0:case 1:pa:{qa:{if(v){break qa}kb(d+24|0,r,41);if(!ib(d+24|0)){break qa}v=j[f+1075838|0];if(v){break pa}v=0;break ka}g[f+1075838|0]=v}Cm(a,s,((c|0)==3?v<<4:v)&255);break ka;case 2:if((z|0)!=i[a+1074392>>2]){kb(d+24|0,r,41);b=5;if(ib(d+24|0)){break ja}}kb(d+24|0,r,41);Ao(a,s,v,ib(d+24|0));b=5;break ja;case 3:if((z|0)!=i[a+1074392>>2]){kb(d+24|0,r,41);b=6;if(ib(d+24|0)){break ja}}kb(d+24|0,r,41);zo(a,s,v,ib(d+24|0));b=6;break ja;case 4:kb(d+24|0,r,53);if(ib(d+24|0)){g[f+1075827|0]=v&15;b=7;break ja}Lj(s,v<<4);b=7;break ja;case 5:Lj(s,v);b=8;break ja;case 6:kb(d+24|0,r,62);nx(a,s,v,ib(d+24|0)^1);b=9;break ja;case 7:kb(d+24|0,r,62);nx(a,s,v<<4&240,ib(d+24|0)^1);b=10;break ja;case 9:b=12;kb(d+24|0,r,12);yK(a,u&65535,v<<2&252,ib(d+24|0));break ja;case 10:kb(d+24|0,r,12);xK(a,u&65535,v<<2&252,ib(d+24|0));b=13;break ja;case 12:break oa;default:break ja}}b=15;if(!D|v>>>0>9){break ja}c=i[f+1075088>>2];if(!c){break ja}ra:{if(!v){t=i[f+1075648>>2];break ra}t=i[(c+(v<<2)|0)- -64>>2];i[f+1075648>>2]=t}Bo(a,s,t);break ja}b=F}sa:{ta:{ua:{va:{wa:{xa:{ya:{za:{Aa:{Ba:{Ca:{Da:{Ea:{Fa:{Ga:{Ha:{Ia:{Ja:{Ka:{La:{Ma:{Na:{Oa:{Pa:{Qa:{Ra:{switch(M+ -1|0){case 12:if(!(j[a+480209|0]&16)){break ia}b=o(u,896)+a|0;i[b+1075672>>2]=e>>>0<64?e<<2:256;b=b+1075072|0;i[b>>2]=i[b>>2]|2097152;break ia;case 1:if(i[a+480180>>2]&1?!e:0){break Qa}yK(a,u&65535,e,0);break ia;case 2:if(i[a+480180>>2]&1?!e:0){break Qa}xK(a,u&65535,e,0);break ia;case 10:if(i[a+480180>>2]==1?!e:0){break Qa}Cm(a,s,e);break ia;case 3:zm(a,s,e);break ia;case 5:if(!(i[a+480180>>2]==1?!e:0)){Cm(a,s,e)}zm(a,s,0);break ia;case 4:Lj(s,e);break ia;case 6:if(!(i[a+480180>>2]==1?!e:0)){Cm(a,s,e)}Lj(s,0);break ia;case 15:if(!(j[a+480209|0]&16)){break ia}break sa;case 16:kb(d+24|0,r,5);if(ib(d+24|0)){if(!e){break ia}if(i[a+480208>>2]&4096){break sa}break ia}e=Do(a,k[a+1074436>>1],i[a+1074424>>2],u&65535,0);Sa:{if(!(i[a+480180>>2]&16777250)){break Sa}if(e){g[(o(u,896)+a|0)+1075839|0]=e;break Sa}e=j[(o(u,896)+a|0)+1075839|0]}i[d+24>>2]=o(e,1e4);kc(d+24|0,o(i[i[a+8>>2]+24>>2],1e4));Uoa(a,i[d+24>>2]);break ia;case 9:if(!D|(i[a+480180>>2]==4?x:0)){break ia}g[d+24|0]=0;b=Do(a,k[a+1074436>>1],i[a+1074424>>2],u&65535,d+24|0);c=a;n=s;if(!j[d+24|0]){q=(o(u,896)+a|0)+1075648|0;b=b<<8;Ta:{if(b){i[q>>2]=b;break Ta}b=i[q>>2]}b=(j[(o(u,896)+a|0)+1075840|0]<<16)+b|0}Bo(c,n,b);break ia;case 40:if(!D){break ia}c=XMa(i[(o(u,896)+a|0)+1075060>>2],0,e,0);b=_a;n=b>>>8|0;Bo(a,s,Vc((b&255)<<24|c>>>8,n));break ia;case 0:if(i[a+1074392>>2]){break ia}b=o(u,896)+a|0;Ua:{if(j[b+1075803|0]?i[b+1075684>>2]:0){break Ua}b=i[b+1075640>>2];if(b){if(Xh(b)){break Ua}}kb(d+24|0,r,13);if(ib(d+24|0)){break Ua}if(i[a+480180>>2]&16777248){break ia}}if(!e){e=0;if(i[a+480180>>2]&5){break ia}g[(o(u,896)+a|0)+1075811|0]=1;break ia}b=o(u,896)+a|0;g[b+1075812|0]=e;g[b+1075811|0]=1;break ia;case 14:if(i[a+480180>>2]&1048580){e=e&240?e:k[(o(u,896)+a|0)+1075784>>1]&240|e;if(!(e&15)){e=k[(o(u,896)+a|0)+1075784>>1]&15|e}e=e|256}kb(d+24|0,r,23);if(ib(d+24|0)){Va:{if(!e){t=k[(o(u,896)+a|0)+1075784>>1];break Va}t=e&255;h[(o(u,896)+a|0)+1075784>>1]=t}mx(a,u&65535,t<<16>>16,(b&255)==15?v+1|0:0);break ia}Wa:{if(e){h[(o(u,896)+a|0)+1075784>>1]=e&255;break Wa}e=h[(o(u,896)+a|0)+1075784>>1]}mx(a,u&65535,e,(b&255)==15?v+1|0:0);break ia;case 39:break wa;case 38:break xa;case 34:case 35:case 36:case 37:break ya;case 13:break za;case 11:break Aa;case 29:break Ba;case 26:break Ca;case 21:break Da;case 20:break Ea;case 27:break Fa;case 24:break Ga;case 19:break Ha;case 18:break Ia;case 25:break Ja;case 7:break Ka;case 28:break La;case 8:break Ma;case 23:break Na;case 22:break Oa;case 17:break Ra;default:break ia}}if(!(j[a+480209|0]&16)){break ia}kb(d+24|0,r,22);Xa:{Ya:{if(ib(d+24|0)){if(!e){e=0;break Ya}if(j[a+480208|0]&4){break Ya}b=e&240?e+ -16|0:e;e=b-((b&15)!=0)|0;break Ya}kb(d+24|0,r,71);if(!ib(d+24|0)){break Xa}}b=(o(u,896)+a|0)+1075843|0;g[b|0]=j[b|0]|128}b=o(u,896)+a|0;g[b+1075811|0]=18;if(e){break Pa}}e=0;break ia}g[b+1075844|0]=e;break ia}if(!(j[a+480209|0]&16)){break ia}e=e<<!(i[a+480180>>2]&59593760);if(e>>>0<=128){i[a+1074444>>2]=e<<1;break ia}if(i[a+480180>>2]&16777250){break ia}i[a+1074444>>2]=256;break ia}kb(d+24|0,r,9);if(ib(d+24|0)){wK(a,e,(o(u,896)+a|0)+1075821|0);break ia}wK(a,e,Q);break ia}if(!(j[a+480209|0]&16)){break ia}$k(a,s,e,8);break ia}nx(a,s,e,1);break ia}PK(s,e);break ia}QK(a,s,e);break ia}Soa(a,u&65535,e);break ia}kb(d+24|0,r,78);c=a;b=u&65535;if(!(!ib(d+24|0)|e)){e=j[(o(u,896)+a|0)+1075812|0]}vK(c,b,e);break ia}kb(d+24|0,r,55);if(ib(d+24|0)){if(i[a+1074392>>2]!=(e|0)){break ia}b=i[(o(u,896)+a|0)+1075640>>2];if(g[b+60|0]&1?b:0){break ta}if(!((j[K|0]?0:!j[I|0])|e)){b=(o(u,896)+a|0)+1075072|0;i[b>>2]=i[b>>2]|4096;break ta}b=o(u,896)+a|0;i[b+1075672>>2]=0;b=b+1075072|0;i[b>>2]=i[b>>2]|2097152;break ta}if(j[a+480209|0]&16){break ta}break ia}b=(e&240)+ -16>>>4|0;if(b>>>0>9){break ia}if(!(1<<b&880)){if(!b){break va}if((b|0)!=1){break ia}uK(a,s,e&15);break ia}kb(d+24|0,r,58);if(ib(d+24|0)){break ia}vK(a,u&65535,e);break ia}if(!(i[a+480208>>2]&4096)|e>>>0>64){break ia}b=o(u,896)+a|0;i[b+1075744>>2]=e;b=b+1075072|0;i[b>>2]=i[b>>2]|2097152;break ia}Roa(a,s,e);break ia}OK(s,e);break ia}if(!(j[a+480209|0]&16)){break ia}b=o(u,896)+a|0;i[b+1075712>>2]=e;kb(d+24|0,r,60);if(R=0,T=ib(d+24|0),U=j[b+1075708|0]&4,U?R:T){break ia}b=o(u,896)+a|0;i[b+1075736>>2]=e;i[b+1075724>>2]=e;break ia}i[a+1074432>>2]=0;B=Do(a,k[a+1074436>>1],i[a+1074424>>2],u&65535,0);C=(C|0)!=-1?i[a+480180>>2]&5?0:C:C;break ia}b=SK(a,O,u&65535,e);if((b|0)==-1){break ia}if(!(j[a+480208|0]&32)){break ua}B=k[a+1074438>>1];break ua}b=w&255;Qoa(a,s,e,(b|0)==35|(b|0)==37,(w+ -37&255)>>>0<2);break ia}MK(d,s,e);break ia}if(i[a+1074392>>2]|N>>>0>2|e>>>0>31){break ia}b=u;F=b;if((e&240)==16){F=k[a+480188>>1]+ -1|0;b=0}while(1){n=b&65535;c=((n<<5)+a|0)+480280|0;q=i[c>>2];Za:{if((N|0)==1){w=i[(o(n,896)+a|0)+1075072>>2]|67108864;q=q|67108864;break Za}w=i[(o(n,896)+a|0)+1075072>>2]&-67108865;q=q&-67108865}i[c>>2]=q;i[(o(n,896)+a|0)+1075072>>2]=w;b=b+1|0;if((b&65535)>>>0<=(F&65535)>>>0){continue}break}break ia}tK(a,s,e&15);break ia}C=b;break ia}Bm(a,s);break ia}TK(a,O,e)}kb(d+24|0,r,78);if(!(!e|!ib(d+24|0))){Poa(s,e&255)}b=j[I|0];if(!b){break f}g[f+1075810|0]=b}u=u+1|0;if(u>>>0<k[a+480188>>1]){continue}break}}_a:{if(!(j[a+480209|0]&16)){break _a}$a:{if(!((B&65535)!=65535|(C|0)!=-1)){if((E|0)==-1){break _a}break $a}ab:{if((E|0)==-1){break ab}b=a+1074308|0;kb(d+24|0,b,68);if(ib(d+24|0)){break ab}kb(d+16|0,b,103);c=(B&65535)==65535;if(ib(d+16|0)?!c:0){break ab}kb(d+8|0,b,49);if(c|!ib(d+8|0)){break $a}}B=(B&65535)==65535?k[a+1074438>>1]+1|0:B;i[a+480208>>2]=i[a+480208>>2]|524288;b=a+484360|0;if(Wb(Db(b))>>>0<=(B&65535)>>>0){B=k[Db(b)+28>>1]}c=(C|0)==-1?0:C;bb:{if(k[a+1074438>>1]==(B&65535)){break bb}b=a+1074308|0;kb(d+24|0,b,26);if(ib(d+24|0)){break bb}kb(d+16|0,b,68);if(ib(d+16|0)|i[a+480180>>2]==1|!k[a+480188>>1]){break bb}b=0;while(1){g[(o(b,896)+a|0)+1075845|0]=0;b=b+1|0;if(b>>>0<k[a+480188>>1]){continue}break}}i[a+1074428>>2]=c;if(j[a+480208|0]&32){break _a}h[a+1074440>>1]=B;break _a}i[a+1074428>>2]=E;h[a+1074440>>1]=k[a+1074438>>1];cb:{if(!i[a+1074396>>2]){break cb}if(i[a+480180>>2]==32){kb(d+24|0,a+1074308|0,103);if(ib(d+24|0)){break cb}}if(i[a+480180>>2]==2){break cb}i[a+1074428>>2]=i[a+1074428>>2]+1}if(E>>>0>=l[Fb(a+484344|0,k[a+1074436>>1])+12>>2]){i[a+1074428>>2]=0;h[a+1074440>>1]=k[a+1074440>>1]+1}tra(a+1304360|0,k[a+1074438>>1],E)}Xa=d+32|0;return 1}function yKa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,l=0,m=0,n=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,H=0,K=0,M=0,N=0,O=0,P=0,Q=0,R=0,U=0;d=Xa-304|0;Xa=d;pc(b);a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{I:{J:{K:{L:{M:{N:{O:{P:{Q:{R:{S:{if(!Se(b,d+296|0)){break S}if(!YR(d+296|0)){break S}if(!c){y=1;break S}z=gk(d+280|0,b);i[114610]=0;G(473,d+264|0,z|0,1);b=i[114610];i[114610]=0;T:{U:{V:{W:{X:{Y:{Z:{_:{if((b|0)!=1){i[114610]=0;G(474,d+128|0,d+264|0,1229866575);b=i[114610];i[114610]=0;if((b|0)==1){break Y}i[114610]=0;y=C(475,d+128|0,d+248|0)|0;b=i[114610];i[114610]=0;if((b|0)==1){break _}hb(d+128|0);if(!y){break T}i[114610]=0;D(447,a|0,524288);b=i[114610];i[114610]=0;if((b|0)==1){break c}i[114610]=0;L(476,a|0);b=i[114610];i[114610]=0;if((b|0)!=1){break Z}break c}b=B()|0;A()|0;break a}b=B()|0;A()|0;hb(d+128|0);break b}i[a+480208>>2]=12;b=j[d+256|0]|j[d+257|0]<<8;R=a,U=hd((b<<24|b<<8&16711680)>>>16|0,1,127),h[R+480188>>1]=U;b=j[d+248|0]|j[d+249|0]<<8;i[114610]=0;h[d+128>>1]=(b<<8&16711680|b<<24)>>>16;h[d+216>>1]=255;b=C(477,d+128|0,d+216|0)|0;e=i[114610];i[114610]=0;if((e|0)==1){break d}h[a+480192>>1]=k[b>>1];b=d+248|2;b=j[b|0]|j[b+1|0]<<8;i[114610]=0;h[d+128>>1]=(b<<8&16711680|b<<24)>>>16;h[d+216>>1]=3999;b=C(477,d+128|0,d+216|0)|0;e=i[114610];i[114610]=0;if((e|0)==1){break e}h[a+480190>>1]=k[b>>1];i[114610]=0;b=a+1074308|0;I(478,b|0,6,1)|0;e=i[114610];i[114610]=0;if((e|0)==1){break c}i[114610]=0;C(479,b|0,21)|0;e=i[114610];i[114610]=0;if((e|0)==1){break c}i[114610]=0;C(479,b|0,13)|0;b=i[114610];i[114610]=0;if((b|0)==1){break c}i[114610]=0;b=C(2,d+128|0,12385)|0;e=i[114610];i[114610]=0;if((e|0)==1){break f}mb(a+1304436|0,b);eb(b);i[114610]=0;b=C(2,d+128|0,12401)|0;e=i[114610];i[114610]=0;if((e|0)==1){break g}mb(a+1304448|0,b);eb(b);i[114610]=0;e=C(2,d+232|0,12405)|0;b=i[114610];i[114610]=0;if((b|0)==1){break h}i[114610]=0;D(219,d+216|0,e|0);b=i[114610];i[114610]=0;if((b|0)==1){break j}i[114610]=0;D(480,d+200|0,d+296|4);b=i[114610];i[114610]=0;if((b|0)==1){break l}i[114610]=0;D(480,d+184|0,d+296|5);b=i[114610];i[114610]=0;if((b|0)==1){break n}i[114610]=0;J(222,d+128|0,d+216|0,d+200|0,d+184|0);b=i[114610];i[114610]=0;if((b|0)==1){break o}mb(a+1304460|0,d+128|0);eb(d+128|0);eb(d+184|0);eb(d+200|0);ob(d+216|0);eb(e);i[a+1304496>>2]=2;i[114610]=0;G(474,d+216|0,d+264|0,1312902469);b=i[114610];i[114610]=0;if((b|0)==1){break p}i[114610]=0;b=F(255,d+216|0)|0;e=i[114610];i[114610]=0;if((e|0)==1){break r}i[114610]=0;f=a+1304400|0;I(481,d+216|0,f|0,b|0)|0;b=i[114610];i[114610]=0;if((b|0)==1){break r}i[114610]=0;G(474,d+200|0,d+264|0,1397706311);b=i[114610];i[114610]=0;if((b|0)==1){break s}b=a+484360|0;rp(Db(b));$:{e=d+248|4;e=j[e|0]|j[e+1|0]<<8;aa:{if(!e){break aa}m=(e<<24|e<<8)>>>16|0;e=0;while(1){i[114610]=0;l=C(258,d+200|0,46)|0;n=i[114610];i[114610]=0;ba:{if((n|0)!=1){if(!l){break aa}i[114610]=0;I(482,d+200|0,d+128|0,44)|0;l=i[114610];i[114610]=0;if((l|0)!=1){if(!Cc(f)){break ba}i[114610]=0;C(483,f|0,d+128|0)|0;l=i[114610];i[114610]=0;if((l|0)!=1){break ba}}b=B()|0;A()|0;break t}b=B()|0;A()|0;break t}i[114610]=0;l=F(484,d+200|0)|0;n=i[114610];i[114610]=0;if((n|0)==1){break $}if(!Uc(Db(b))){i[114610]=0;n=F(485,b|0)|0;p=i[114610];i[114610]=0;if((p|0)==1){break $}if((n|0)==255){break aa}}n=Db(b);i[114610]=0;D(486,d+184|0,d+128|0);p=i[114610];i[114610]=0;if((p|0)==1){break u}i[114610]=0;D(487,n|0,d+184|0);n=i[114610];i[114610]=0;if((n|0)==1){break v}eb(d+184|0);n=Db(b);i[114610]=0;S(488,n|0,d+200|0,l|0,65535,65535)|0;l=i[114610];i[114610]=0;if((l|0)==1){break $}e=e+1|0;if((e&65535)>>>0<m>>>0){continue}break}}i[114610]=0;D(489,b|0,0);b=i[114610];i[114610]=0;if((b|0)==1){break w}i[114610]=0;G(474,d+184|0,d+264|0,1229869908);b=i[114610];i[114610]=0;if((b|0)==1){break x}i[114610]=0;b=F(490,d+184|0)|0;e=i[114610];i[114610]=0;if((e|0)==1){break G}ca:{if(!b){break ca}if(k[a+480192>>1]){m=1;while(1){i[114610]=0;C(491,d+184|0,d+128|0)|0;b=i[114610];i[114610]=0;da:{ea:{fa:{if((b|0)!=1){b=j[d+158|0]|j[d+159|0]<<8;i[114610]=0;b=I(454,a|0,m&65535,(b<<8&16711680|b<<24)>>>16|0)|0;e=i[114610];i[114610]=0;if((e|0)==1){break fa}if(!b){break da}e=j[d+158|0]|j[d+159|0]<<8;if((e<<24|e<<8&16711680)>>>16>>>0>3999){break da}i[114610]=0;G(492,d+16|0,2,d+128|0);e=i[114610];i[114610]=0;if((e|0)!=1){i[114610]=0;D(415,d- -64|0,d+16|0);e=i[114610];i[114610]=0;if((e|0)!=1){break ea}}b=B()|0;A()|0;break y}b=B()|0;A()|0;break y}b=B()|0;A()|0;break y}i[114610]=0;C(369,b+492|0,d- -64|0)|0;e=i[114610];i[114610]=0;if((e|0)==1){break z}eb(d- -64|0);i[114610]=0;G(492,d+16|0,2,d+128|0);e=i[114610];i[114610]=0;if((e|0)==1){break A}i[114610]=0;D(415,d- -64|0,d+16|0);e=i[114610];i[114610]=0;if((e|0)==1){break A}e=j[d+158|0]|j[d+159|0]<<8;i[114610]=0;C(369,(((e<<8&16711680|e<<24)>>>11|0)+a|0)+946300|0,d- -64|0)|0;e=i[114610];i[114610]=0;if((e|0)==1){break B}eb(d- -64|0);i[b>>2]=0;e=j[d+174|0]|j[d+175|0]<<8;i[b+8>>2]=((e<<24|e<<8&16711680)>>>16|0)+128&65535;kc(b+8|0,256);g[b+15|0]=j[b+15|0]|1;b=j[d+158|0]|j[d+159|0]<<8;i[114610]=0;b=o((b<<8&16711680|b<<24)>>>16|0,104)+a|0;D(386,b+484380|0,0);e=i[114610];i[114610]=0;if((e|0)==1){break C}e=j[d+160|0]|j[d+161|0]<<8;i[114610]=0;h[d+64>>1]=(e<<8&16711680|e<<24)>>>16;h[d+16>>1]=64;e=C(477,d- -64|0,d+16|0)|0;f=i[114610];i[114610]=0;if((f|0)==1){break D}h[b+484410>>1]=k[e>>1]<<2;e=j[d+162|0]|j[d+163|0]<<8|(j[d+164|0]<<16|j[d+165|0]<<24);i[b+484404>>2]=e<<24|e<<8&16711680|(e>>>8&65280|e>>>24);if(!(j[d+170|0]|j[d+171|0]<<8|(j[d+172|0]<<16|j[d+173|0]<<24))|!(j[d+177|0]&3)){break da}e=j[d+166|0]|j[d+167|0]<<8|(j[d+168|0]<<16|j[d+169|0]<<24);l=e<<24|e<<8&16711680|(e>>>8&65280|e>>>24);i[b+484384>>2]=l;e=j[d+170|0]|j[d+171|0]<<8|(j[d+172|0]<<16|j[d+173|0]<<24);f=b+484414|0;h[f>>1]=k[f>>1]|2;i[b+484388>>2]=l+(e<<8&16711680|e<<24|(e>>>8&65280|e>>>24));if(!(j[d+177|0]&2)){break da}h[f>>1]=k[f>>1]|4}m=m+1|0;if((m&65535)>>>0<=k[a+480192>>1]){continue}break}}i[114610]=0;G(474,d+112|0,d+264|0,1447382614);b=i[114610];i[114610]=0;if((b|0)==1){break G}i[114610]=0;J(493,d+112|0,0,a|0,0);b=i[114610];i[114610]=0;if((b|0)==1){break E}hb(d+112|0);i[114610]=0;G(474,d+96|0,d+264|0,1346719318);b=i[114610];i[114610]=0;if((b|0)==1){break G}i[114610]=0;J(493,d+96|0,1,a|0,j[d+300|0]>2|0);b=i[114610];i[114610]=0;if((b|0)==1){break F}hb(d+96|0);if(!k[a+480192>>1]){break ca}b=1;while(1){e=i[(((b&65535)<<2)+a|0)+900380>>2];if(!(!e|g[e+60|0]&1)){i[e>>2]=32767}b=b+1|0;if((b&65535)>>>0<=k[a+480192>>1]){continue}break}}hb(d+184|0);i[114610]=0;G(474,d+128|0,d+264|0,1346458708);b=i[114610];i[114610]=0;if((b|0)==1){break H}i[114610]=0;b=F(337,d+128|0)|0;e=i[114610];i[114610]=0;if((e|0)==1){break J}if(!(c&1)|b^1){break X}i[114610]=0;G(474,d+184|0,d+264|0,1347305805);b=i[114610];i[114610]=0;if((b|0)==1){break K}i[114610]=0;C(338,d+184|0,1)|0;b=i[114610];i[114610]=0;if((b|0)==1){break M}s=d+248|6;e=j[s|0]|j[s+1|0]<<8;b=0;i[114610]=0;t=a+484344|0;D(401,t|0,(e<<8&16711680|e<<24)>>>16|0);e=i[114610];i[114610]=0;if((e|0)==1){break M}e=d+80|0;cKa(e);if(j[s|0]|j[s+1|0]<<8){K=d+16|5;M=d+16|3;N=d+16|4;O=d+16|2;P=d+16|1;f=0;while(1){i[114610]=0;H=F(484,d+128|0)|0;m=i[114610];i[114610]=0;ga:{ha:{ia:{ja:{ka:{if((m|0)!=1){i[114610]=0;m=F(494,d+128|0)|0;l=i[114610];i[114610]=0;if((l|0)==1){break ka}i[114610]=0;G(341,d- -64|0,d+128|0,m|0);m=i[114610];i[114610]=0;if((m|0)==1){break ja}i[114610]=0;m=I(402,t|0,f&65535,H|0)|0;l=i[114610];i[114610]=0;if((l|0)==1){break ia}if(!m){break ga}v=Ab(d+48|0);i[114610]=0;I(495,d+184|0,v|0,-1)|0;m=i[114610];i[114610]=0;if((m|0)!=1){m=Fb(t,f);i[114610]=0;C(496,m|0,v|0)|0;m=i[114610];i[114610]=0;if((m|0)!=1){break ha}}break P}b=B()|0;A()|0;break N}b=B()|0;A()|0;break N}b=B()|0;A()|0;break N}b=B()|0;A()|0;break O}m=Fb(t,f);i[114610]=0;m=C(497,m|0,0)|0;l=i[114610];i[114610]=0;if((l|0)==1){break P}RR(e);u=0;la:{while(1){i[114610]=0;l=C(258,d- -64|0,1)|0;n=i[114610];i[114610]=0;ma:{na:{oa:{if((n|0)!=1){if(!l){break la}i[114610]=0;p=F(387,d- -64|0)|0;l=i[114610];i[114610]=0;if((l|0)==1){break P}if(p){break na}R=d,U=Jb(e),i[R+40>>2]=U;R=d,U=Kb(e),i[R+32>>2]=U;if(pb(d+40|0,d+32|0)){break oa}break ma}break P}while(1){pa:{m=i[d+40>>2];l=Fb(t,f);n=j[m+1|0];m=j[m|0];i[114610]=0;m=I(498,d+16|0,m|0,n|0)|0;n=i[114610];i[114610]=0;if((n|0)==1){break pa}m=Ee(m,u);i[114610]=0;C(499,l|0,m|0)|0;m=i[114610];i[114610]=0;if((m|0)==1){break pa}he(d+40|0);if(pb(d+40|0,d+32|0)){continue}break ma}break}break P}Tg(d+16|0);w=k[a+480188>>1];i[114610]=0;l=F(387,d- -64|0)|0;n=i[114610];i[114610]=0;qa:{if((n|0)==1){break qa}n=o(p+ -1|0,6)+m|0;ra:{if(!(l&1)){break ra}i[114610]=0;q=F(387,d- -64|0)|0;r=i[114610];i[114610]=0;sa:{if((r|0)!=1){if(!q){break ra}if((q|0)!=31){break sa}g[(w>>>0<p>>>0?d+16|0:n)|0]=255;break ra}break P}if(q>>>0>253){break ra}g[(w>>>0<p>>>0?d+16|0:n)|0]=(o(q>>>4|0,12)+(q&15)|0)+13}if(l&2){i[114610]=0;q=F(387,d- -64|0)|0;r=i[114610];i[114610]=0;if((r|0)==1){break qa}g[(w>>>0<p>>>0?P:n+1|0)|0]=q}if(!(l&60)){continue}g[d+15|0]=0;g[d+14|0]=0;g[d+13|0]=0;g[d+12|0]=0;if(l&4){i[114610]=0;q=F(387,d- -64|0)|0;r=i[114610];i[114610]=0;if((r|0)==1){break P}g[d+14|0]=q}if(l&8){i[114610]=0;q=F(387,d- -64|0)|0;r=i[114610];i[114610]=0;if((r|0)==1){break P}g[d+12|0]=q}if(l&16){i[114610]=0;q=F(387,d- -64|0)|0;r=i[114610];i[114610]=0;if((r|0)==1){break P}g[d+15|0]=q}if(l&32){i[114610]=0;l=F(387,d- -64|0)|0;q=i[114610];i[114610]=0;if((q|0)==1){break P}g[d+13|0]=l}QR(d+15|0,d+13|0);QR(d+14|0,d+12|0);l=j[d+14|0];if(!(j[d+15|0]==13|l?(l|0)!=13:0)){Sg(d+15|0,d+14|0);Sg(d+13|0,d+12|0)}i[114610]=0;T(500,d+32|0,d+15|0,d+13|0,d+14|0,d+12|0);l=i[114610];i[114610]=0;ta:{if((l|0)==1){break ta}i[114610]=0;l=C(501,j[d+32|0],j[d+33|0])|0;q=i[114610];i[114610]=0;if((q|0)==1){break ta}ua:{if(!l){break ua}R=d,U=Jb(e),i[R+40>>2]=U;Ad(d+8|0,d+40|0);i[114610]=0;I(502,e|0,i[d+8>>2],d+32|0)|0;l=i[114610];i[114610]=0;if((l|0)!=1){break ua}break P}l=w>>>0<p>>>0;g[(l?O:n+2|0)|0]=j[d+15|0];g[(l?N:n+4|0)|0]=j[d+13|0];p=j[d+14|0];g[(l?M:n+3|0)|0]=p;g[(l?K:n+5|0)|0]=j[d+12|0];if((p|0)==40){Q=1;continue}if((p|0)!=31){continue}b=1;continue}break P}break P}RR(e);u=u+1|0;if(u>>>0>=H>>>0){break la}m=Fb(t,f);i[114610]=0;m=C(497,m|0,u|0)|0;l=i[114610];i[114610]=0;if((l|0)!=1){continue}break}break P}eb(v)}hb(d- -64|0);f=f+1|0;m=j[s|0]|j[s+1|0]<<8;if(f>>>0<(m<<24|m<<8&16711680)>>>16>>>0){continue}break}}PR(e);m=b;hb(d+184|0);if(!(c&4)){break V}e=0;if(!Q){break W}f=k[a+480188>>1];if(!f){e=1;break W}b=0;while(1){e=1;l=(b<<5)+a|0;g[l+480288|0]=1;l=l+480280|0;i[l>>2]=i[l>>2]|67108864;b=b+1|0;if((f|0)!=(b|0)){continue}break}break W}b=B()|0;A()|0;break t}b=B()|0;A()|0;break b}m=0;e=0;if(!(c&4)){break U}}i[114610]=0;i[d+64>>2]=-1778364416;i[d+68>>2]=-16756736;G(474,d+184|0,d+264|0,1146310725);b=i[114610];i[114610]=0;va:{wa:{xa:{ya:{za:{Aa:{if((b|0)!=1){i[114610]=0;b=F(490,d+184|0)|0;f=i[114610];i[114610]=0;if((f|0)==1){break xa}if(!b){break za}i[114610]=0;l=F(484,d+184|0)|0;b=i[114610];i[114610]=0;if((b|0)==1){break xa}if(l){break Aa}f=e;break ya}b=B()|0;A()|0;break I}b=0;f=e;while(1){i[114610]=0;n=F(387,d+184|0)|0;p=i[114610];i[114610]=0;Ba:{Ca:{if((p|0)!=1){if(b>>>0>=k[a+480188>>1]){break Ba}if(!e){break Ca}p=((b<<5)+a|0)+480280|0;i[p>>2]=i[p>>2]&-67108865|((n|0)!=0)<<26;break Ba}break xa}if(n){break Ba}f=1;g[((b<<5)+a|0)+480288|0]=1}b=b+1|0;if((l|0)!=(b|0)){continue}break}break ya}hb(d+184|0);if(!e){break V}break va}i[114610]=0;C(503,d+184|0,d- -64|0)|0;b=i[114610];i[114610]=0;if((b|0)!=1){break wa}}b=B()|0;A()|0;hb(d+184|0);break I}hb(d+184|0);if(!(f&1)){break V}}i[114610]=0;L(504,a+906300|0);b=i[114610];i[114610]=0;Da:{Ea:{Fa:{Ga:{Ha:{Ia:{if((b|0)==1){break Ia}b=a+906316|0;i[b>>2]=810369604;i[b+4>>2]=1869112133;g[a+906324|0]=16;g[a+906325|0]=0;g[a+906326|0]=10;g[a+906327|0]=0;b=a+906328|0;g[b|0]=0;g[b+1|0]=0;g[b+2|0]=0;g[b+3|0]=0;i[114610]=0;i[d+184>>2]=0;b=a+906332|0;G(505,b|0,b+16|0,d+184|0);b=i[114610];i[114610]=0;if((b|0)==1){break Ha}i[114610]=0;e=C(85,d+184|0,12427)|0;b=i[114610];i[114610]=0;if((b|0)==1){break Ga}i[114610]=0;C(506,a+906348|0,e|0)|0;b=i[114610];i[114610]=0;if((b|0)==1){break Fa}eb(e);i[114610]=0;e=C(85,d+184|0,12432)|0;b=i[114610];i[114610]=0;if((b|0)==1){break Ea}i[114610]=0;C(507,a+906380|0,e|0)|0;b=i[114610];i[114610]=0;if((b|0)==1){break Da}eb(e);i[114610]=0;b=a+906304|0;D(508,b|0,8);e=i[114610];i[114610]=0;if((e|0)==1){break Ia}NR(d+184|0,j[d+65|0],j[d+67|0],j[d+69|0],j[d+71|0]);e=i[d+188>>2];b=i[b>>2];f=i[d+184>>2];g[b|0]=f;g[b+1|0]=f>>>8;g[b+2|0]=f>>>16;g[b+3|0]=f>>>24;g[b+4|0]=e;g[b+5|0]=e>>>8;g[b+6|0]=e>>>16;g[b+7|0]=e>>>24;break V}b=B()|0;A()|0;break I}b=B()|0;A()|0;break I}b=B()|0;A()|0;break I}b=B()|0;A()|0;eb(e);break I}b=B()|0;A()|0;break I}b=B()|0;A()|0;eb(e);break I}if(!m){break U}b=0;Ja:{Ka:{La:{Ma:{Na:{Oa:{Pa:{Qa:{Ra:{Sa:{Ta:{Ua:{Va:{Wa:{Xa:{Ya:{Za:{_a:{$a:{ab:{bb:{cb:{db:{while(1){eb:{i[114610]=0;i[d+48>>2]=o(b,127)>>>5;D(509,d- -64|0,12453);e=i[114610];i[114610]=0;if((e|0)==1){break eb}i[114610]=0;D(510,d+16|0,d+48|0);e=i[114610];i[114610]=0;if((e|0)==1){break db}i[114610]=0;G(511,d+184|0,d- -64|0,d+16|0);e=i[114610];i[114610]=0;if((e|0)==1){break cb}i[114610]=0;e=(b<<5)+a|0;D(512,d+80|0,e+902204|0);f=i[114610];i[114610]=0;if((f|0)==1){break bb}i[114610]=0;C(470,d+80|0,d+184|0)|0;f=i[114610];i[114610]=0;if((f|0)==1){break bb}eb(d+184|0);eb(d+16|0);ob(d- -64|0);i[114610]=0;D(509,d- -64|0,12462);f=i[114610];i[114610]=0;if((f|0)==1){break _a}i[114610]=0;D(510,d+16|0,d+48|0);f=i[114610];i[114610]=0;if((f|0)==1){break Za}i[114610]=0;G(511,d+184|0,d- -64|0,d+16|0);f=i[114610];i[114610]=0;if((f|0)==1){break Ya}i[114610]=0;D(512,d+80|0,e+903228|0);f=i[114610];i[114610]=0;if((f|0)==1){break Xa}i[114610]=0;C(470,d+80|0,d+184|0)|0;f=i[114610];i[114610]=0;if((f|0)==1){break Xa}eb(d+184|0);eb(d+16|0);ob(d- -64|0);i[114610]=0;D(509,d- -64|0,12471);f=i[114610];i[114610]=0;if((f|0)==1){break Ua}i[114610]=0;D(510,d+16|0,d+48|0);f=i[114610];i[114610]=0;if((f|0)==1){break Ta}i[114610]=0;G(511,d+184|0,d- -64|0,d+16|0);f=i[114610];i[114610]=0;if((f|0)==1){break Sa}i[114610]=0;D(512,d+80|0,e+904252|0);f=i[114610];i[114610]=0;if((f|0)==1){break Ra}i[114610]=0;C(470,d+80|0,d+184|0)|0;f=i[114610];i[114610]=0;if((f|0)==1){break Ra}eb(d+184|0);eb(d+16|0);ob(d- -64|0);i[114610]=0;D(509,d- -64|0,12480);f=i[114610];i[114610]=0;if((f|0)==1){break Oa}i[114610]=0;D(510,d+16|0,d+48|0);f=i[114610];i[114610]=0;if((f|0)==1){break Na}i[114610]=0;G(511,d+184|0,d- -64|0,d+16|0);f=i[114610];i[114610]=0;if((f|0)==1){break Ma}i[114610]=0;D(512,d+80|0,e+905276|0);e=i[114610];i[114610]=0;if((e|0)==1){break La}i[114610]=0;C(470,d+80|0,d+184|0)|0;e=i[114610];i[114610]=0;if((e|0)==1){break La}eb(d+184|0);eb(d+16|0);ob(d- -64|0);b=b+1|0;if((b|0)!=32){continue}break U}break}b=B()|0;A()|0;break I}b=B()|0;A()|0;break $a}b=B()|0;A()|0;break ab}b=B()|0;A()|0;eb(d+184|0)}eb(d+16|0)}ob(d- -64|0);break I}b=B()|0;A()|0;break I}b=B()|0;A()|0;break Va}b=B()|0;A()|0;break Wa}b=B()|0;A()|0;eb(d+184|0)}eb(d+16|0)}ob(d- -64|0);break I}b=B()|0;A()|0;break I}b=B()|0;A()|0;break Pa}b=B()|0;A()|0;break Qa}b=B()|0;A()|0;eb(d+184|0)}eb(d+16|0)}ob(d- -64|0);break I}b=B()|0;A()|0;break I}b=B()|0;A()|0;break Ja}b=B()|0;A()|0;break Ka}b=B()|0;A()|0;eb(d+184|0)}eb(d+16|0)}ob(d- -64|0);break I}i[114610]=0;G(474,d+184|0,d+264|0,1397575756);b=i[114610];i[114610]=0;if((b|0)==1){break Q}i[114610]=0;b=F(337,d+184|0)|0;e=i[114610];i[114610]=0;if((e|0)==1){break R}if(!(!k[a+480190>>1]|(!(c&2)|b^1))){e=1;c=1;while(1){i[114610]=0;b=F(494,d+184|0)|0;f=i[114610];i[114610]=0;fb:{if((f|0)!=1){i[114610]=0;f=F(494,d+184|0)|0;m=i[114610];i[114610]=0;if((m|0)==1){break R}if(!(b&7)){break fb}e=(o(e,104)+a|0)+484380|0;i[e>>2]=f;b=Ic(d- -64|0,b&4?32:b&2?16:8,1,1,0);i[114610]=0;I(400,b|0,e|0,d+184|0)|0;b=i[114610];i[114610]=0;if((b|0)!=1){break fb}break R}break R}c=c+1|0;e=c&65535;if(e>>>0<=k[a+480190>>1]){continue}break}}hb(d+184|0);hb(d+128|0);hb(d+200|0);hb(d+216|0)}Cz(d+264|0);hb(z)}Xa=d+304|0;return y|0}b=B()|0;A()|0;hb(d+184|0);break I}b=B()|0;A()|0;break I}b=B()|0;A()|0;eb(v)}hb(d- -64|0)}PR(e);break L}b=B()|0;A()|0}hb(d+184|0);break I}b=B()|0;A()|0;break I}b=B()|0;A()|0}hb(d+128|0);break t}b=B()|0;A()|0;break t}b=B()|0;A()|0;break y}b=B()|0;A()|0;hb(d+96|0);break y}b=B()|0;A()|0;hb(d+112|0);break y}b=B()|0;A()|0;break y}b=B()|0;A()|0;break y}b=B()|0;A()|0;eb(d- -64|0);break y}b=B()|0;A()|0;break y}b=B()|0;A()|0;eb(d- -64|0)}hb(d+184|0);break t}b=B()|0;A()|0;break t}b=B()|0;A()|0;break t}b=B()|0;A()|0;eb(d+184|0);break t}b=B()|0;A()|0}hb(d+200|0);break q}b=B()|0;A()|0;break q}b=B()|0;A()|0}hb(d+216|0);break b}b=B()|0;A()|0;break b}b=B()|0;A()|0;eb(d+184|0);break m}b=B()|0;A()|0}eb(d+200|0);break k}b=B()|0;A()|0}ob(d+216|0);break i}b=B()|0;A()|0}eb(e);break b}b=B()|0;A()|0;break b}b=B()|0;A()|0;break b}b=B()|0;A()|0;break b}b=B()|0;A()|0;break b}b=B()|0;A()|0;break b}b=B()|0;A()|0}Cz(d+264|0)}hb(z);E(b|0);x()}function Dza(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,l=0,m=0,n=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,H=0,K=0,M=0;d=Xa-320|0;Xa=d;pc(b);a:{if(!Xs(b,d+304|0)){break a}if(!JN(d+304|0)){break a}w=gk(d+288|0,b);v=hy(d+272|0);b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{if(!c){i[114610]=0;J(953,d|0,w|0,1,1413891155);b=i[114610];i[114610]=0;if((b|0)==1){break s}break u}i[114610]=0;G(954,d|0,w|0,1);b=i[114610];i[114610]=0;if((b|0)==1){break t}}dza(v,d);gl(d);i[114610]=0;G(955,d|0,v|0,1413891155);b=i[114610];i[114610]=0;v:{w:{if((b|0)!=1){i[114610]=0;e=C(956,d|0,16763)|0;b=i[114610];i[114610]=0;if((b|0)==1){break w}hb(d);if(!c){break b}if(!(e^1)){break v}break b}e=B()|0;A()|0;break c}e=B()|0;A()|0;hb(d);break c}i[114610]=0;D(447,a|0,4194304);b=i[114610];i[114610]=0;if((b|0)==1){break d}i[a+480208>>2]=12;i[114610]=0;G(955,d+256|0,v|0,1280592212);b=i[114610];i[114610]=0;if((b|0)==1){break e}i[114610]=0;b=F(255,d+256|0)|0;e=i[114610];i[114610]=0;if((e|0)==1){break g}i[114610]=0;I(463,d+256|0,a+1304400|0,b|0)|0;b=i[114610];i[114610]=0;if((b|0)==1){break g}s=a+484360|0;rp(Db(s));q=d+240|0;nza(q);i[114610]=0;g[d+239|0]=0;G(957,d+224|0,v|0,1196314451);b=i[114610];i[114610]=0;if((b|0)==1){break i}K=d,M=Jb(d+224|0),i[K+216>>2]=M;K=d,M=Kb(d+224|0),i[K+208>>2]=M;x:{y:{z:{A:{B:{C:{if(!pb(d+216|0,d+208|0)){break C}p=d+12|0;f=d+24|0;u=d+44|0;while(1){e=gk(d+192|0,i[d+216>>2]);i[114610]=0;l=C(958,d+192|0,d+176|0)|0;b=i[114610];i[114610]=0;D:{E:{F:{G:{H:{I:{if((b|0)!=1){b=1;if(!(l&j[d+185|0]==1)){break D}K=a,M=hd(j[d+186|0],k[a+480188>>1],127),h[K+480188>>1]=M;i[114610]=0;r=F(959,d|0)|0;b=i[114610];i[114610]=0;J:{K:{L:{M:{if((b|0)!=1){i[114610]=0;G(960,d+160|0,1,d+176|0);b=i[114610];i[114610]=0;if((b|0)==1){break M}i[114610]=0;D(415,d+120|0,d+160|0);b=i[114610];i[114610]=0;if((b|0)==1){break M}i[114610]=0;D(961,d+152|0,u|0);b=i[114610];i[114610]=0;if((b|0)==1){break L}i[114610]=0;C(470,d+152|0,d+120|0)|0;b=i[114610];i[114610]=0;if((b|0)==1){break L}eb(d+120|0);if(Uc(Db(s))){break J}i[114610]=0;b=F(485,s|0)|0;l=i[114610];i[114610]=0;if((l|0)==1){break K}if((b|0)!=255){break J}b=2;break E}e=B()|0;A()|0;break k}e=B()|0;A()|0;break l}e=B()|0;A()|0;eb(d+120|0);break l}e=B()|0;A()|0;break l}b=Db(s);i[114610]=0;D(962,d+120|0,u|0);l=i[114610];i[114610]=0;N:{O:{P:{if((l|0)!=1){i[114610]=0;D(487,b|0,d+120|0);b=i[114610];i[114610]=0;if((b|0)==1){break P}eb(d+120|0);i[114610]=0;G(954,d+160|0,e|0,1);b=i[114610];i[114610]=0;if((b|0)==1){break O}K=d,M=Jb(d+160|0),i[K+144>>2]=M;K=d,M=Kb(d+160|0),i[K+136>>2]=M;if(pb(d+144|0,d+136|0)){break N}break H}e=B()|0;A()|0;break l}e=B()|0;A()|0;eb(d+120|0);break l}e=B()|0;A()|0;break l}Q:{R:{while(1){S:{e=i[d+144>>2];b=He(d+120|0,fb(e));l=j[e+4|0]|j[e+5|0]<<8|(j[e+6|0]<<16|j[e+7|0]<<24);i[d+152>>2]=j[e|0]|j[e+1|0]<<8|(j[e+2|0]<<16|j[e+3|0]<<24);i[d+156>>2]=l;t=1;T:{e=j[d+152|0]|j[d+153|0]<<8|(j[d+154|0]<<16|j[d+155|0]<<24);if((e|0)!=1212960847){if((e|0)!=1312903248){break T}e=0;if(!k[a+480188>>1]){break T}U:{while(1){i[114610]=0;l=C(258,b|0,2)|0;m=i[114610];i[114610]=0;if((m|0)==1){break U}if(!l){break T}i[114610]=0;D(472,d+96|0,b|0);l=i[114610];i[114610]=0;V:{W:{X:{Y:{if((l|0)!=1){l=Nc(d+96|0);switch(j[d+96|0]){case 4:break W;case 2:break X;case 0:break Y;default:break V}}break I}l=j[l|0];K=dc(d,e),M=l^128,g[K|0]=M;Ld(d+104|0,f,e);Od(d+104|0,0);break V}K=dc(d,e),M=128,g[K|0]=M;Ld(d+104|0,f,e);Od(d+104|0,1);break V}K=dc(d,e),M=128,g[K|0]=M;Ld(d+104|0,f,e);Od(d+104|0,0)}e=e+1|0;if(e>>>0<k[a+480188>>1]){continue}break}break T}break I}if(pz(d+152|0)>>>0<9){break T}m=0;i[114610]=0;C(338,b|0,2)|0;e=i[114610];i[114610]=0;l=65535;if((e|0)==1){break S}while(1){i[114610]=0;e=C(258,b|0,1)|0;n=i[114610];i[114610]=0;Z:{_:{$:{aa:{ba:{ca:{da:{ea:{fa:{if((n|0)!=1){if(!e){break T}i[114610]=0;e=F(387,b|0)|0;n=i[114610];i[114610]=0;if((n|0)==1){break I}switch(e|0){case 0:break T;case 14:break _;case 13:break $;case 12:break ba;case 8:break ca;case 7:break da;case 4:break ea;case 1:break fa;default:break aa}}break I}if(k[d+36>>1]==65535){e=Db(s);i[114610]=0;e=F(544,e|0)|0;n=i[114610];i[114610]=0;if((n|0)==1){break I}h[d+36>>1]=e}e=Db(s);i[114610]=0;e=F(544,e|0)|0;n=i[114610];i[114610]=0;if((n|0)==1){break I}i[114610]=0;h[d+38>>1]=e;e=C(963,b|0,d+239|0)|0;n=i[114610];i[114610]=0;if((n|0)==1){break I}ga:{ha:{switch(e+ -254|0){case 1:i[114610]=0;e=R(964)|0;n=i[114610];i[114610]=0;if((n|0)!=1){break ga}break I;case 0:break ha;default:break ga}}i[114610]=0;e=R(965)|0;n=i[114610];i[114610]=0;if((n|0)==1){break I}}n=Db(s);i[114610]=0;D(797,n|0,e|0);e=i[114610];i[114610]=0;if((e|0)==1){break I}l=(l&65535)==65535?m:l;break Z}i[114610]=0;e=F(357,b|0)|0;n=i[114610];i[114610]=0;if((n|0)==1){break I}if(e>>>0>=(l&65535)>>>0){h[d+40>>1]=e-l}Fe(Db(s),k[d+40>>1]);break Z}i[114610]=0;e=F(387,b|0)|0;n=i[114610];i[114610]=0;if((n|0)==1){break I}g[d+43|0]=e;break Z}i[114610]=0;e=F(387,b|0)|0;n=i[114610];i[114610]=0;if((n|0)==1){break I}g[d+42|0]=e;break Z}i[114610]=0;e=C(920,b|0,d+104|0)|0;n=i[114610];i[114610]=0;if((n|0)==1){break I}if(!(e&!j[d+104|0])|(j[d+106|0]|j[d+107|0])|(j[d+105|0]!=255|j[d+108|0]!=1)){break aa}if(!j[d+109|0]){break Z}}t=0;break T}i[114610]=0;D(810,d+112|0,b|0);e=i[114610];i[114610]=0;ia:{ja:{ka:{la:{if((e|0)!=1){n=Nc(d+112|0);y=yf(d+112|0);e=d+112|0;H=j[e|0];if(rc(d)>>>0<=H>>>0){break Z}switch(j[y|0]){case 4:break ja;case 2:break ka;case 0:break la;default:break ia}}break I}n=j[n|0];K=dc(d,j[e|0]),M=n^128,g[K|0]=M;Ld(d+104|0,f,j[e|0]);Od(d+104|0,0);break ia}K=dc(d,j[e|0]),M=128,g[K|0]=M;Ld(d+104|0,f,j[e|0]);Od(d+104|0,1);break ia}K=dc(d,j[e|0]),M=128,g[K|0]=M;Ld(d+104|0,f,j[e|0]);Od(d+104|0,0)}ma:{if(z){break ma}z=0;if(!Tj(q)){break Z}if(j[dc(HN(q),j[e|0])|0]!=j[dc(d,j[e|0])|0]){break ma}Ld(d+104|0,HN(q)+24|0,j[e|0]);n=ib(d+104|0);Ld(d+96|0,f,j[e|0]);if((ib(d+96|0)|0)==(n|0)){break Z}}z=1;break Z}i[114610]=0;D(472,d+104|0,b|0);e=i[114610];i[114610]=0;if((e|0)==1){break Q}e=Nc(d+104|0);n=d+104|0;y=j[n|0];if(rc(p)>>>0<=y>>>0){break Z}e=j[e|0];K=dc(p,j[n|0]),M=(e>>>2|0)+1|0,g[K|0]=M}m=m+1|0;continue}}hb(b);if(!t){break R}dk(d+144|0);if(pb(d+144|0,d+136|0)){continue}break H}break}break I}b=1;break F}break I}e=B()|0;A()|0;break k}e=B()|0;A()|0;hb(b);break G}b=0;if(k[d+36>>1]==65535|k[d+38>>1]==65535){break F}b=Db(s);i[114610]=0;L(966,b|0);b=i[114610];i[114610]=0;if((b|0)!=1){b=0;i[114610]=0;D(967,q|0,r|0);e=i[114610];i[114610]=0;if((e|0)!=1){break F}}e=B()|0;A()|0}gl(d+160|0);break l}gl(d+160|0)}gy(r)}hb(d+192|0);if(!b){vf(d+216|0);if(pb(d+216|0,d+208|0)){continue}break C}break}e=0;if((b|0)!=2){break B}}e=0;i[114610]=0;D(489,s|0,0);b=i[114610];i[114610]=0;if((b|0)==1){break r}if(Uc(q)){break B}if(c&2){i[114610]=0;G(957,d+192|0,v|0,1347244868);b=i[114610];i[114610]=0;if((b|0)==1){break x}K=d,M=Jb(d+192|0),i[K+176>>2]=M;K=d,M=Kb(d+192|0),i[K+152>>2]=M;if(pb(d+176|0,d+152|0)){e=a+480190|0;f=d+13|0;l=d+17|0;r=j[d+239|0];while(1){b=i[d+176>>2];na:{oa:{pa:{qa:{ra:{if(!r){i[114610]=0;m=C(968,b|0,d|0)|0;p=i[114610];i[114610]=0;if((p|0)==1){break ra}if(!m){break na}m=j[d+52|0]|j[d+53|0]<<8;h[d+104>>1]=m+1;if(m>>>0>3998){break pa}i[114610]=0;m=C(452,e|0,d+104|0)|0;p=i[114610];i[114610]=0;if((p|0)==1){break ra}h[a+480190>>1]=k[m>>1];i[114610]=0;D(969,d|0,(o(k[d+104>>1],104)+a|0)+484380|0);m=i[114610];i[114610]=0;if((m|0)==1){break ra}i[114610]=0;G(970,d+160|0,1,f|0);m=i[114610];i[114610]=0;sa:{ta:{if((m|0)==1){break ta}i[114610]=0;D(415,d+120|0,d+160|0);m=i[114610];i[114610]=0;if((m|0)==1){break ta}i[114610]=0;C(369,((k[d+104>>1]<<5)+a|0)+946300|0,d+120|0)|0;m=i[114610];i[114610]=0;if((m|0)==1){break sa}eb(d+120|0);break pa}e=B()|0;A()|0;break oa}e=B()|0;A()|0;eb(d+120|0);break oa}i[114610]=0;m=C(971,b|0,d|0)|0;p=i[114610];i[114610]=0;if((p|0)==1){break qa}if(!m){break na}m=j[d+56|0]|j[d+57|0]<<8;h[d+104>>1]=m+1;if(m>>>0>3998){break pa}i[114610]=0;m=C(452,e|0,d+104|0)|0;p=i[114610];i[114610]=0;if((p|0)==1){break qa}h[a+480190>>1]=k[m>>1];i[114610]=0;D(972,d|0,(o(k[d+104>>1],104)+a|0)+484380|0);m=i[114610];i[114610]=0;if((m|0)==1){break qa}i[114610]=0;G(970,d+160|0,1,l|0);m=i[114610];i[114610]=0;ua:{va:{if((m|0)==1){break va}i[114610]=0;D(415,d+120|0,d+160|0);m=i[114610];i[114610]=0;if((m|0)==1){break va}i[114610]=0;C(369,((k[d+104>>1]<<5)+a|0)+946300|0,d+120|0)|0;m=i[114610];i[114610]=0;if((m|0)==1){break ua}eb(d+120|0);break pa}e=B()|0;A()|0;break oa}e=B()|0;A()|0;eb(d+120|0);break oa}e=B()|0;A()|0;break oa}e=B()|0;A()|0;break oa}if((k[d+104>>1]+ -1&65535)>>>0>3998){break na}m=Ic(d,8,1,0,2);i[114610]=0;I(400,m|0,(o(k[d+104>>1],104)+a|0)+484380|0,b|0)|0;b=i[114610];i[114610]=0;if((b|0)!=1){break na}e=B()|0;A()|0}Qc(d+192|0);break j}vf(d+176|0);if(pb(d+176|0,d+152|0)){continue}break}}Qc(d+192|0)}K=a,M=j[fl(q,0)+43|0],i[K+480196>>2]=M;K=a,M=o(j[fl(q,0)+42|0],1e4),i[K+480204>>2]=M;Fe(Db(s),k[fl(q,0)+40>>1]);if(k[a+480188>>1]){b=0;while(1){i[114610]=0;e=(b<<5)+a|0;f=e+480280|0;L(432,f|0);l=i[114610];i[114610]=0;if((l|0)==1){break y}K=e+480286|0,M=j[dc(fl(q,0)+12|0,b)|0],h[K>>1]=M;K=e+480284|0,M=j[dc(fl(q,0),b)|0],h[K>>1]=M;Ld(d,fl(q,0)+24|0,b);e=ib(d);i[f>>2]=i[f>>2]&-257|(e?256:0);b=b+1|0;if(b>>>0<k[a+480188>>1]){continue}break}}wa:{if(j[d+239|0]){i[114610]=0;C(2,d|0,16772)|0;b=i[114610];i[114610]=0;if((b|0)!=1){break wa}break m}i[114610]=0;C(2,d|0,16816)|0;b=i[114610];i[114610]=0;if((b|0)==1){break m}}mb(a+1304436|0,d);eb(d);i[114610]=0;b=C(2,d|0,16850)|0;f=i[114610];i[114610]=0;e=1;if((f|0)==1){break z}mb(a+1304448|0,b);eb(b);i[a+1304496>>2]=4;if(!(c&1)|!k[a+480188>>1]){break B}i[114610]=0;G(957,d+192|0,v|0,1146045008);b=i[114610];i[114610]=0;if((b|0)==1){break n}b=Wc(d+192|0);i[114610]=0;m=a+484344|0;D(401,m|0,b&65535);b=i[114610];i[114610]=0;if((b|0)==1){break q}K=d,M=Jb(d+192|0),i[K+120>>2]=M;K=d,M=Kb(d+192|0),i[K+160>>2]=M;if(pb(d+120|0,d+160|0)){while(1){r=i[d+120>>2];i[114610]=0;b=F(255,r|0)|0;c=i[114610];i[114610]=0;xa:{ya:{za:{if((c|0)==1){break za}i[114610]=0;c=F(390,r|0)|0;e=i[114610];i[114610]=0;if((e|0)==1){break za}if((b|0)!=(c|0)){break xa}i[114610]=0;b=C(973,r|0,8)|0;c=i[114610];i[114610]=0;if((c|0)==1){break za}if(b){break ya}break xa}e=B()|0;A()|0;break o}i[114610]=0;u=C(963,r|0,d+239|0)|0;b=i[114610];i[114610]=0;if((b|0)!=1){i[114610]=0;p=F(357,r|0)|0;b=i[114610];i[114610]=0;Aa:{if((b|0)==1){break Aa}i[114610]=0;b=I(402,m|0,u|0,p|0)|0;c=i[114610];i[114610]=0;if((c|0)==1){break Aa}if(!p|b^1){break xa}l=0;while(1){Ba:{b=Fb(m,u);i[114610]=0;c=C(497,b|0,l|0)|0;b=i[114610];i[114610]=0;Ca:{Da:{Ea:{if((b|0)!=1){i[114610]=0;b=F(357,r|0)|0;e=i[114610];i[114610]=0;if((e|0)==1){break Ea}if(b>>>0<3){break Ca}i[114610]=0;G(341,d|0,r|0,b+ -2|0);b=i[114610];i[114610]=0;if((b|0)!=1){break Da}e=B()|0;A()|0;break o}e=B()|0;A()|0;break o}e=B()|0;A()|0;break o}while(1){i[114610]=0;b=C(258,d|0,3)|0;e=i[114610];i[114610]=0;if((e|0)==1){break Ba}if(b){i[114610]=0;D(472,d+176|0,d|0);b=i[114610];i[114610]=0;Fa:{Ga:{Ha:{Ia:{if((b|0)!=1){f=d+176|0;b=Nc(d+176|0);h[d+152>>1]=k[a+480188>>1]+ -1;b=j[b|0];i[114610]=0;h[d+104>>1]=b;b=C(477,d+152|0,d+104|0)|0;e=i[114610];i[114610]=0;if((e|0)==1){break Ba}e=k[b>>1];b=g[f|0];if((b|0)>-1){break Fa}i[114610]=0;b=F(387,d|0)|0;t=i[114610];i[114610]=0;if((t|0)==1){break Ba}if(j[d+239|0]){break Ha}if((b|0)!=255){break Ia}b=254;break Ga}break Ba}if(b>>>0>128){break Ga}b=(o(b>>>4|0,12)+(b&15)|0)+13|0;break Ga}b=b>>>0<85?b+36|0:b}g[c+o(e,6)|0]=b;b=j[f|0]}if(b&64){i[114610]=0;b=F(387,d|0)|0;t=i[114610];i[114610]=0;if((t|0)==1){break Ba}g[(c+o(e,6)|0)+1|0]=b+1;b=j[f|0]}if(b&32){i[114610]=0;b=F(387,d|0)|0;t=i[114610];i[114610]=0;if((t|0)==1){break Ba}g[d+152|0]=b;b=c+o(e,6)|0;g[b+2|0]=1;i[114610]=0;g[d+104|0]=127;t=C(391,d+152|0,d+104|0)|0;n=i[114610];i[114610]=0;if((n|0)==1){break Ba}g[b+4|0]=j[t|0]+1>>>1;b=j[f|0]}if(!(b&16)){continue}i[114610]=0;D(472,d+152|0,d|0);b=i[114610];i[114610]=0;if((b|0)==1){break Ba}b=c+o(e,6)|0;f=j[Nc(d+152|0)|0];g[b+5|0]=f;Ja:{switch(j[d+152|0]+ -1|0){case 0:g[(c+o(e,6)|0)+3|0]=11;if(!j[d+239|0]){g[b+5|0]=f<<3|15;continue}g[b+5|0]=f<<4|15;continue;case 1:g[(c+o(e,6)|0)+3|0]=11;if(j[d+239|0]){g[b+5|0]=f<<4;continue}g[b+5|0]=f<<3&240;continue;case 2:g[(c+o(e,6)|0)+3|0]=11;if(j[d+239|0]){g[b+5|0]=f|240;continue}g[b+5|0]=f>>>1|240;continue;case 3:g[(c+o(e,6)|0)+3|0]=11;if(j[d+239|0]){g[b+5|0]=f&15;continue}if(f>>>0<=1){g[b+5|0]=f|240;continue}g[b+5|0]=f>>>1&15;continue;case 10:g[(c+o(e,6)|0)+3|0]=2;K=b,M=rs(f,j[d+239|0])|240,g[K+5|0]=M;continue;case 11:g[(c+o(e,6)|0)+3|0]=2;K=b,M=rs(f,j[d+239|0]),g[K+5|0]=M;continue;case 12:g[(c+o(e,6)|0)+3|0]=3;K=b,M=rs(f,j[d+239|0])|240,g[K+5|0]=M;continue;case 13:g[(c+o(e,6)|0)+3|0]=3;K=b,M=rs(f,j[d+239|0]),g[K+5|0]=M;continue;case 14:g[(c+o(e,6)|0)+3|0]=4;if(j[d+239|0]){continue}g[b+5|0]=(f&252)>>>2;continue;case 16:g[(c+o(e,6)|0)+3|0]=20;g[b+5|0]=f&1|16;continue;case 15:g[(c+o(e,6)|0)+3|0]=6;g[b+5|0]=f&240;continue;case 17:g[(c+o(e,6)|0)+3|0]=6;g[b+5|0]=(f&240)>>>4;continue;case 18:g[(c+o(e,6)|0)+3|0]=20;continue;case 20:g[(c+o(e,6)|0)+3|0]=5;continue;case 21:g[(c+o(e,6)|0)+3|0]=20;g[b+5|0]=f&15|48;continue;case 22:g[(c+o(e,6)|0)+3|0]=7;g[b+5|0]=f|240;continue;case 23:g[(c+o(e,6)|0)+3|0]=7;continue;case 30:g[(c+o(e,6)|0)+3|0]=8;continue;case 31:g[(c+o(e,6)|0)+3|0]=20;g[b+5|0]=f&15|64;continue;case 40:g[(c+o(e,6)|0)+3|0]=10;i[114610]=0;e=F(387,d|0)|0;f=i[114610];i[114610]=0;if((f|0)==1){break Ba}g[b+5|0]=e;i[114610]=0;C(338,d|0,1)|0;b=i[114610];i[114610]=0;if((b|0)!=1){continue}break Ba;case 41:g[(c+o(e,6)|0)+3|0]=15;continue;case 42:g[(c+o(e,6)|0)+3|0]=20;g[b+5|0]=f&15|192;continue;case 43:g[(c+o(e,6)|0)+3|0]=20;g[b+5|0]=f&15|208;continue;case 50:g[(c+o(e,6)|0)+3|0]=12;g[b+5|0]=(f&254)>>>1;i[114610]=0;C(338,d|0,1)|0;b=i[114610];i[114610]=0;if((b|0)!=1){continue}break Ba;case 51:g[(c+o(e,6)|0)+3|0]=14;g[b+5|0]=0;continue;case 52:g[(c+o(e,6)|0)+3|0]=20;g[b+5|0]=f&15|176;continue;case 53:g[(c+o(e,6)|0)+3|0]=20;g[b+5|0]=f&15|224;continue;case 60:g[(c+o(e,6)|0)+3|0]=16;continue;case 61:g[(c+o(e,6)|0)+3|0]=17;continue;case 70:g[(c+o(e,6)|0)+3|0]=1;continue;case 71:g[(c+o(e,6)|0)+3|0]=20;g[b+5|0]=f&15|32;continue;case 72:g[(c+o(e,6)|0)+3|0]=20;g[b+5|0]=f&15|128;continue;default:break Ja}}g[(c+o(e,6)|0)+3|0]=0;continue}break}hb(d)}l=l+1|0;if((p|0)!=(l|0)){continue}break xa}break}e=B()|0;A()|0;hb(d);break o}e=B()|0;A()|0;break o}e=B()|0;A()|0;break o}vf(d+120|0);if(pb(d+120|0,d+160|0)){continue}break}}Ka:{if(Tj(q)>>>0<2){break Ka}if(!Tj(q)){break Ka}e=0;while(1){b=bi(s,e&255);c=fl(q,e);f=k[$b(b,k[c+36>>1])>>1];i[114610]=0;f=C(442,m|0,f|0)|0;l=i[114610];i[114610]=0;if((l|0)==1){break p}La:{if(!f){break La}f=k[c+36>>1];i[114610]=0;f=C(814,b|0,f|0)|0;b=i[114610];i[114610]=0;if((b|0)==1){break p}if(!(!z|!k[a+480188>>1])){r=c+24|0;b=0;while(1){Ld(d,r,b);p=ib(d);l=Fb(m,f);Ma:{if(p){i[114610]=0;p=I(498,d|0,20,145)|0;u=i[114610];i[114610]=0;if((u|0)!=1){p=mi(cn(Ee(p,0),b&65535));i[114610]=0;C(499,l|0,p|0)|0;l=i[114610];i[114610]=0;if((l|0)!=1){break Ma}}e=B()|0;A()|0;break o}p=j[dc(c,b)|0];i[114610]=0;p=I(498,d|0,9,p|0)|0;u=i[114610];i[114610]=0;if((u|0)!=1){p=mi(cn(Ee(p,0),b&65535));i[114610]=0;C(499,l|0,p|0)|0;l=i[114610];i[114610]=0;if((l|0)!=1){break Ma}}e=B()|0;A()|0;break o}b=b+1|0;if(b>>>0<k[a+480188>>1]){continue}break}}b=Fb(m,f);l=j[c+43|0];i[114610]=0;l=I(498,d|0,16,l|0)|0;r=i[114610];i[114610]=0;if((r|0)==1){break A}l=mi(Ee(l,0));i[114610]=0;C(499,b|0,l|0)|0;b=i[114610];i[114610]=0;if((b|0)==1){break A}b=Fb(m,f);c=j[c+42|0];i[114610]=0;c=I(498,d|0,17,c|0)|0;f=i[114610];i[114610]=0;if((f|0)!=1){c=mi(Ee(c,0));i[114610]=0;C(499,b|0,c|0)|0;b=i[114610];i[114610]=0;if((b|0)!=1){break La}}e=B()|0;A()|0;break o}e=e+1|0;if(e>>>0<Tj(q)>>>0){continue}break}}Qc(d+192|0);e=1}Qc(d+224|0);GN(q);hb(d+256|0);break b}e=B()|0;A()|0;break o}e=B()|0;A()|0;break j}e=B()|0;A()|0;break j}e=B()|0;A()|0;break j}e=B()|0;A()|0;break c}e=B()|0;A()|0;break c}e=B()|0;A()|0;break j}e=B()|0;A()|0;break o}e=B()|0;A()|0}Qc(d+192|0);break j}e=B()|0;A()|0;break j}e=B()|0;A()|0;break j}gy(r)}hb(d+192|0)}Qc(d+224|0);break h}e=B()|0;A()|0}GN(q);break f}e=B()|0;A()|0}hb(d+256|0);break c}e=B()|0;A()|0;break c}e=B()|0;A()|0}gl(v);hb(w);E(e|0);x()}gl(v);hb(w)}Xa=d+320|0;return e|0}function nIa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,m=0,n=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,H=0,K=0,M=0,O=0,P=0,Q=0,R=0;d=Xa-288|0;Xa=d;pc(b);f=d+264|0;m=XHa(b,f);if(!m){WQ(f)}a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{if(!m){break u}if(!ZQ(d+264|0)){break u}if(!c){e=1;break u}md(a,1024);Vh(a);i[a+480208>>2]=i[a+480208>>2]|12;ng(a+1074308|0,21);if(j[d+280|0]|j[d+281|0]<<8){e=j[d+280|0]|j[d+281|0]<<8;i[a+480204>>2]=o((e<<24|e<<8&16711680)>>>16|0,1e4)}if(j[d+278|0]|j[d+279|0]<<8){e=j[d+278|0]|j[d+279|0]<<8;i[a+480196>>2]=(e<<24|e<<8&16711680)>>>16}if(!j[d+274|0]){Ni(a,1)}e=d+264|4;e=j[e|0]|j[e+1|0]<<8|(j[e+2|0]<<16|j[e+3|0]<<24);Ez(b,a+1304400|0,(e<<24|e<<8&16711680|(e>>>8&65280|e>>>24))+ -14|0);b=gk(d+160|0,b);i[114610]=0;G(582,d+248|0,b|0,1);e=i[114610];i[114610]=0;v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{I:{J:{K:{L:{M:{if((e|0)!=1){hb(b);i[114610]=0;G(583,d+160|0,d+248|0,1395544366);b=i[114610];i[114610]=0;if((b|0)==1){break E}i[114610]=0;b=F(490,d+160|0)|0;e=i[114610];i[114610]=0;if((e|0)==1){break L}if(!b){break F}i[114610]=0;b=F(484,d+160|0)|0;e=i[114610];i[114610]=0;if((e|0)==1){break L}i[114610]=0;e=F(484,d+160|0)|0;f=i[114610];i[114610]=0;N:{if((f|0)==1){break N}i[114610]=0;C(338,d+160|0,4)|0;f=i[114610];i[114610]=0;if((f|0)==1){break N}f=a+484360|0;m=Db(f);i[114610]=0;S(584,m|0,d+160|0,b|0,65535,65535)|0;b=i[114610];i[114610]=0;if((b|0)!=1){break M}}break L}e=B()|0;A()|0;hb(b);break a}Fe(Db(f),e);hb(d+160|0);i[114610]=0;G(583,d+160|0,d+248|0,1346458708);b=i[114610];i[114610]=0;if((b|0)==1){break K}i[114610]=0;b=F(490,d+160|0)|0;e=i[114610];i[114610]=0;if((e|0)==1){break J}if(!b){break H}i[114610]=0;b=F(484,d+160|0)|0;e=i[114610];i[114610]=0;if((e|0)==1){break J}h[a+480188>>1]=b;if((b+ -1&65535)>>>0>31){break H}i[114610]=0;b=F(484,d+160|0)|0;e=i[114610];i[114610]=0;if((e|0)==1){break J}i[114610]=0;v=a+484344|0;D(401,v|0,b|0);b=i[114610];i[114610]=0;if((b|0)==1){break J}i[114610]=0;w=F(494,d+160|0)|0;b=i[114610];i[114610]=0;if((b|0)==1){break J}switch(w+ -841887796|0){case 0:case 2:break G;case 1:break H;default:break I}}e=B()|0;A()|0;hb(d+160|0);break b}e=B()|0;A()|0;break b}e=B()|0;A()|0;hb(d+160|0);break b}if(!w){break G}}hb(d+160|0);break A}hb(d+160|0);i[114610]=0;G(583,d+232|0,d+248|0,1398157625);b=i[114610];i[114610]=0;if((b|0)==1){break D}i[114610]=0;b=F(490,d+232|0)|0;e=i[114610];i[114610]=0;O:{if((e|0)==1){break O}if(!b){break B}i[114610]=0;C(338,d+232|0,2)|0;b=i[114610];i[114610]=0;if((b|0)==1){break O}i[114610]=0;e=F(494,d+232|0)|0;b=i[114610];i[114610]=0;if((b|0)==1){break c}b=a;m=b;z=(+(e>>>0)*2.3283064365386963e-10+ +(l[b+480204>>2]/1e4>>>0))*1e4;P:{if(z<4294967296&z>=0){b=~~z>>>0;break P}b=0}i[m+480204>>2]=b;i[114610]=0;C(585,d+232|0,d+160|0)|0;b=i[114610];i[114610]=0;if((b|0)==1){break c}b=0;while(1){if(b>>>0>=k[a+480188>>1]){break C}e=(d+160|0)+(b<<1)|0;e=j[e|0]|j[e+1|0]<<8;i[114610]=0;i[d+96>>2]=(e<<8&16711680|e<<24)>>>16;i[d+80>>2]=180;e=C(462,d+96|0,d+80|0)|0;f=i[114610];i[114610]=0;Q:{if((f|0)==1){break Q}e=i[e>>2];i[114610]=0;e=e+ -90|0;f=e>>31;e=eg(458,YMa(e<<7|45,f<<7|e>>>25,90,0),_a);f=i[114610];i[114610]=0;if((f|0)==1){break Q}h[((b<<5)+a|0)+480284>>1]=e+128;b=b+1|0;if((b|0)!=32){continue}break C}break}break c}break c}hb(d+160|0);break A}e=B()|0;A()|0;break b}e=B()|0;A()|0;break b}i[114610]=0;C(338,d+232|0,16)|0;b=i[114610];i[114610]=0;if((b|0)==1){break c}i[114610]=0;b=C(258,d+232|0,2)|0;e=i[114610];i[114610]=0;if((e|0)==1){break c}if(b){i[114610]=0;b=F(484,d+232|0)|0;e=i[114610];i[114610]=0;if((e|0)==1){break c}i[114610]=0;h[d+96>>1]=b;h[d+80>>1]=256;b=C(477,d+96|0,d+80|0)|0;e=i[114610];i[114610]=0;if((e|0)==1){break c}i[a+480200>>2]=k[b>>1]}i[114610]=0;C(338,d+232|0,128)|0;b=i[114610];i[114610]=0;if((b|0)==1){break c}i[114610]=0;b=C(585,d+232|0,d+96|0)|0;e=i[114610];i[114610]=0;R:{if((e|0)!=1){if(!b){break B}b=0;while(1){if(b>>>0>=k[a+480188>>1]){break R}e=(d+96|0)+(b<<1)|0;e=j[e|0]|j[e+1|0]<<8;i[114610]=0;i[d+80>>2]=(e<<8&16711680|e<<24)>>>16;i[d+56>>2]=128;e=C(462,d+80|0,d+56|0)|0;f=i[114610];i[114610]=0;if((f|0)!=1){h[((b<<5)+a|0)+480286>>1]=i[e>>2]/2&255;b=b+1|0;if((b|0)!=32){continue}break R}break}break c}break c}i[a+480228>>2]=i[a+480228>>2]<<1}hb(d+232|0);i[114610]=0;G(583,d+160|0,d+248|0,1413830740);b=i[114610];i[114610]=0;S:{T:{if((b|0)!=1){i[114610]=0;b=F(490,d+160|0)|0;e=i[114610];i[114610]=0;if((e|0)==1){break d}if(!b){break S}i[114610]=0;C(586,d+160|0,d+96|0)|0;b=i[114610];i[114610]=0;if((b|0)==1){break d}if((j[d+106|0]|j[d+107|0]<<8)!=65535){break T}i[114610]=0;C(338,d+160|0,1)|0;b=i[114610];i[114610]=0;if((b|0)!=1){break T}break d}e=B()|0;A()|0;break b}i[114610]=0;b=F(548,d+160|0)|0;e=i[114610];i[114610]=0;if((e|0)==1){break d}i[114610]=0;N(587,a+1304424|0,d+160|0,b|0,2)|0;b=i[114610];i[114610]=0;if((b|0)==1){break d}}hb(d+160|0);i[114610]=0;G(583,d+96|0,d+248|0,1229869908);b=i[114610];i[114610]=0;if((b|0)==1){break e}i[114610]=0;b=F(490,d+96|0)|0;e=i[114610];i[114610]=0;if((e|0)!=1){if(b){i[114610]=0;b=F(484,d+96|0)|0;e=i[114610];i[114610]=0;if((e|0)==1){break g}U:{b=b<<16>>16;f=b&32767;if(f>>>0>3999){break U}i[114610]=0;e=C(258,d+96|0,o(f,(b>>>14&2)+50|0)|0)|0;m=i[114610];i[114610]=0;if((m|0)==1){break y}if(!e){break U}h[a+480190>>1]=f;m=a+480190|0;if(!f){break z}p=d+178|0;q=(b|0)>-1;b=1;V:{W:{while(1){X:{e=b;Y:{Z:{_:{if(!q){i[114610]=0;e=F(484,d+96|0)|0;n=i[114610];i[114610]=0;if((n|0)==1){break _}e=e+1|0}i[114610]=0;h[d+56>>1]=e;C(588,d+96|0,d+160|0)|0;e=i[114610];i[114610]=0;if((e|0)!=1){if((k[d+56>>1]+ -1&65535)>>>0>3998){break Y}i[114610]=0;e=C(452,m|0,d+56|0)|0;n=i[114610];i[114610]=0;if((n|0)!=1){break Z}}e=B()|0;A()|0;break f}e=B()|0;A()|0;break f}h[a+480190>>1]=k[e>>1];n=k[d+56>>1];e=j[d+282|0]|j[d+283|0]<<8|(j[d+284|0]<<16|j[d+285|0]<<24);i[114610]=0;J(589,d+160|0,(o(n,104)+a|0)+484380|0,e<<8&16711680|e<<24|(e>>>8&65280|e>>>24),w|0);e=i[114610];i[114610]=0;if((e|0)==1){break X}i[114610]=0;G(590,d+80|0,2,p|0);e=i[114610];i[114610]=0;if((e|0)==1){break W}i[114610]=0;D(415,d+232|0,d+80|0);e=i[114610];i[114610]=0;if((e|0)==1){break W}i[114610]=0;C(369,((k[d+56>>1]<<5)+a|0)+946300|0,d+232|0)|0;e=i[114610];i[114610]=0;if((e|0)==1){break V}eb(d+232|0)}e=b&65535;b=b+1|0;if(e>>>0<f>>>0){continue}break z}break}e=B()|0;A()|0;break f}e=B()|0;A()|0;break f}e=B()|0;A()|0;eb(d+232|0);break f}hb(d+96|0);break A}break w}e=B()|0;A()|0;break f}e=0;break v}i[114610]=0;b=F(484,d+96|0)|0;e=i[114610];i[114610]=0;if((e|0)!=1){break x}}e=B()|0;A()|0;break f}if((b|0)==4){b=k[m>>1];i[114610]=0;h[d+160>>1]=b;h[d+232>>1]=255;b=C(477,d+160|0,d+232|0)|0;e=i[114610];i[114610]=0;if((e|0)==1){break h}h[a+480192>>1]=k[b>>1];i[114610]=0;G(583,d+232|0,d+248|0,1229278806);b=i[114610];i[114610]=0;if((b|0)==1){break i}m=d+80|4;p=d+80|3;q=d+80|5;n=d+80|7;while(1){i[114610]=0;b=C(258,d+96|0,15)|0;e=i[114610];i[114610]=0;$:{if((e|0)!=1){aa:{if(b){i[114610]=0;C(591,d+96|0,d+80|0)|0;b=i[114610];i[114610]=0;ba:{if((b|0)!=1){b=j[d+80|0]|j[d+81|0]<<8;if((b<<24|b<<8&16711680)>>>16>>>0>=k[a+480192>>1]){continue}b=j[d+80|0]|j[d+81|0]<<8;b=o((b<<24|b<<8&16711680)>>>16|0,104)+a|0;g[b+484524|0]=j[d+88|0];e=j[n|0];g[b+484523|0]=255;g[b+484525|0]=e;b=j[d+80|0]|j[d+81|0]<<8;e=j[d+80|0]|j[d+81|0]<<8;i[114610]=0;e=I(454,a|0,((b<<8&16711680|b<<24)>>>16|0)+1&65535,((e<<8&16711680|e<<24)>>>16|0)+1&65535)|0;b=i[114610];i[114610]=0;if((b|0)==1){break aa}if(!e){continue}b=j[q|0]|j[q+1|0]<<8;i[114610]=0;h[d+160>>1]=(b<<8&16711680|b<<24)>>>16;h[d+56>>1]=4095;b=C(477,d+160|0,d+56|0)|0;f=i[114610];i[114610]=0;if((f|0)==1){break aa}i[e>>2]=k[b>>1];if(j[p|0]==255){continue}b=j[p|0];i[114610]=0;b=C(256,d+232|0,o(b,34)+2|0)|0;f=i[114610];i[114610]=0;if((f|0)==1){break aa}if(!b){continue}i[114610]=0;C(592,d+232|0,d+160|0)|0;b=i[114610];i[114610]=0;if((b|0)==1){break aa}g[e+60|0]=j[e+60|0]|1;b=j[d+160|0]|j[d+161|0]<<8;i[d+56>>2]=(b<<24|b<<8&16711680)>>>16;i[114610]=0;i[d+76>>2]=3;i[d+64>>2]=240;i[d+60>>2]=16;i[d+72>>2]=d+56;b=i[d+76>>2];i[d+8>>2]=i[d+72>>2];i[d+12>>2]=b;b=F(593,d+8|0)|0;f=i[114610];i[114610]=0;if((f|0)==1){break aa}i[114610]=0;f=e+48|0;D(594,f|0,b|0);b=i[114610];i[114610]=0;if((b|0)==1){break aa}b=0;if(qb(f)){break ba}break $}break aa}while(1){ca:{g[d+56|0]=64;u=(d+160|0)+(b<<1)|0;t=j[u+2|0];i[114610]=0;g[d+48|0]=t;t=C(391,d+56|0,d+48|0)|0;s=i[114610];i[114610]=0;if((s|0)==1){break ca}t=j[t|0];Q=vb(f,b),R=t,g[Q+2|0]=R;u=j[u+3|0];Q=vb(f,b),R=u,h[Q>>1]=R;b=b+1|0;if(b>>>0<qb(f)>>>0){continue}break $}break}break aa}hb(d+232|0);break w}}e=B()|0;A()|0;hb(d+232|0);break f}if(j[m|0]!=255){g[e+60|0]=j[e+60|0]|4;b=j[m|0];g[e+63|0]=b;g[e- -64|0]=b}if(Uc(f)){continue}g[e+60|0]=j[e+60|0]|2;b=qb(f)+ -1|0;g[e+61|0]=b;g[e+62|0]=b;continue}}}hb(d+96|0);i[114610]=0;G(595,d+96|0,d+248|0,1145131092);b=i[114610];i[114610]=0;if((b|0)==1){break j}Q=d,R=Jb(d+96|0),i[Q+48>>2]=R;Q=d,R=Kb(d+96|0),i[Q+40>>2]=R;if(pb(d+48|0,d+40|0)){M=c&1;u=d+232|4;t=(w|0)!=841887798;O=(w|0)!=841887796;while(1){p=i[d+48>>2];i[114610]=0;C(338,p|0,4)|0;b=i[114610];i[114610]=0;da:{ea:{fa:{if((b|0)!=1){i[114610]=0;e=F(484,p|0)|0;b=i[114610];i[114610]=0;if((b|0)==1){break l}i[114610]=0;q=F(484,p|0)|0;b=i[114610];i[114610]=0;if((b|0)==1){break m}q=t?q:(q>>>0)/l[a+480196>>2]|0;if(!M|e>>>0>255){break da}i[114610]=0;b=I(402,v|0,e|0,q|0)|0;f=i[114610];i[114610]=0;if((f|0)==1){break m}if(!b){break da}if(t){break ea}i[114610]=0;C(338,p|0,4)|0;b=i[114610];i[114610]=0;if((b|0)==1){break m}n=0;if(!k[a+480188>>1]){break da}while(1){i[114610]=0;b=F(484,p|0)|0;f=i[114610];i[114610]=0;if((f|0)==1){break fa}i[114610]=0;G(341,d+160|0,p|0,b+(b&1)&65535);b=i[114610];i[114610]=0;if((b|0)==1){break n}i[d+232>>2]=0;i[d+236>>2]=0;f=0;ga:{while(1){i[114610]=0;b=C(258,d+160|0,6)|0;m=i[114610];i[114610]=0;if((m|0)==1){break o}if(b^1|l[d+232>>2]>=q>>>0){break ga}b=Fb(v,e);i[114610]=0;b=I(471,b|0,i[d+232>>2],n&65535)|0;m=i[114610];i[114610]=0;ha:{ia:{if((m|0)!=1){i[114610]=0;D(596,d+56|0,d+160|0);m=i[114610];i[114610]=0;if((m|0)==1){break o}m=Nc(d+56|0);H=yf(d+56|0);y=li(d+56|0);s=Pb(d+56|0);P=d+61|0;r=g[d+56|0];if((r+ -1&255)>>>0>95){break ia}g[b|0]=r+13;if(!i[d+236>>2]){break ha}g[b+3|0]=19;i[114610]=0;i[d+80>>2]=15;r=C(462,u|0,d+80|0)|0;K=i[114610];i[114610]=0;if((K|0)==1){break o}g[b+5|0]=j[r|0]|208;break ha}break o}if((r|0)>-1){break ha}if(i[d+236>>2]){g[b+3|0]=19;i[114610]=0;i[d+80>>2]=15;r=C(462,u|0,d+80|0)|0;K=i[114610];i[114610]=0;if((K|0)!=1){g[b+5|0]=j[r|0]|192;break ha}break o}g[b|0]=254}if(j[m|0]){g[b+2|0]=1;i[114610]=0;g[d+80|0]=64;m=C(391,m|0,d+80|0)|0;r=i[114610];i[114610]=0;if((r|0)==1){break o}g[b+4|0]=j[m|0]}m=j[H|0];if(m){g[b+1|0]=m}m=j[y|0];if(m|j[s|0]){g[b+3|0]=m;g[b+5|0]=j[s|0];i[114610]=0;L(577,b|0);b=i[114610];i[114610]=0;if((b|0)==1){break o}}b=j[P|0];if(b&128){i[114610]=0;m=F(387,d+160|0)|0;s=i[114610];i[114610]=0;if((s|0)==1){break o}b=m|b<<8&32512}m=i[a+480196>>2];i[114610]=0;f=b+f|0;G(597,d+80|0,f|0,m|0);b=i[114610];i[114610]=0;if((b|0)!=1){b=i[d+84>>2];i[d+232>>2]=i[d+80>>2];i[d+236>>2]=b;continue}break}break o}hb(d+160|0);n=n+1|0;if((n&65535)>>>0<k[a+480188>>1]){continue}break}break da}e=B()|0;A()|0;break k}e=B()|0;A()|0;break k}b=Fb(v,e);i[114610]=0;b=I(471,b|0,0,0)|0;e=i[114610];i[114610]=0;if((e|0)==1){break s}n=0;if(!q){break da}while(1){e=0;ja:{if(!k[a+480188>>1]){break ja}while(1){ka:{i[114610]=0;D(598,d+160|0,p|0);f=i[114610];i[114610]=0;if((f|0)==1){break ka}la:{if(!O){i[d+232>>2]=i[d+160>>2];s=Nc(d+232|0);r=yf(d+232|0);H=li(d+232|0);f=g[d+232|0];if((f|0)>=1){g[b|0]=(o((f&240)>>>4|0,12)+(f&15)|0)+12}m=b;f=j[s|0];y=f>>>2|0;if(y){g[b+2|0]=1;g[b+4|0]=y+ -1;f=j[s|0]}g[m+1|0]=f<<4&48|j[r|0]>>>4;g[b+3|0]=j[r|0]&15;g[b+5|0]=j[H|0];break la}i[114610]=0;f=i[d+160>>2];i[d+36>>2]=f;i[d+20>>2]=f;D(599,d+20|0,b|0);f=i[114610];i[114610]=0;if((f|0)==1){break ka}f=Nb(d+160|0,0);g[b+1|0]=j[b+1|0]|j[f|0]&48}i[114610]=0;L(577,b|0);f=i[114610];i[114610]=0;if((f|0)==1){break ka}f=j[b+3|0];ma:{if(f>>>0>11){break ma}f=1<<f;na:{if(!(f&2240)){if(!(f&12)){break ma}if(!j[b+5|0]){break na}break ma}f=j[b+5|0];m=f&240;if(m){g[b+5|0]=m;break ma}if(f){break ma}}g[b+3|0]=0}b=b+6|0;e=e+1|0;if((e&65535)>>>0<k[a+480188>>1]){continue}break ja}break}e=B()|0;A()|0;break k}n=n+1|0;if((n|0)!=(q|0)){continue}break}}vf(d+48|0);if(pb(d+48|0,d+40|0)){continue}break}}Qc(d+96|0);i[114610]=0;G(583,d+160|0,d+248|0,1346458702);b=i[114610];i[114610]=0;if((b|0)==1){e=B()|0;A()|0;break b}i[114610]=0;b=F(490,d+160|0)|0;e=i[114610];i[114610]=0;oa:{pa:{qa:{ra:{sa:{ta:{ua:{va:{wa:{xa:{ya:{za:{Aa:{Ba:{if((e|0)!=1){if(b){f=Ab(d+96|0);b=0;Ca:{while(1){Da:{i[114610]=0;e=C(258,d+160|0,1)|0;m=i[114610];i[114610]=0;if((m|0)==1){break Da}if(!e){break Ca}if(b>>>0>=ke(v)>>>0){break Ca}i[114610]=0;I(600,d+160|0,f|0,32)|0;e=i[114610];i[114610]=0;if((e|0)==1){break Da}e=Fb(v,b);i[114610]=0;C(496,e|0,f|0)|0;e=i[114610];i[114610]=0;if((e|0)==1){break Da}b=b+1|0;continue}break}e=B()|0;A()|0;eb(f);break Ba}eb(f)}hb(d+160|0);i[114610]=0;G(583,d+160|0,d+248|0,1414679374);b=i[114610];i[114610]=0;if((b|0)==1){break Aa}i[114610]=0;b=F(490,d+160|0)|0;e=i[114610];i[114610]=0;if((e|0)==1){break wa}if(!b){break xa}f=Ab(d+96|0);b=0;while(1){i[114610]=0;e=C(258,d+160|0,1)|0;m=i[114610];i[114610]=0;if((m|0)==1){break za}if(!e|b>>>0>=k[a+480188>>1]){break ya}i[114610]=0;I(600,d+160|0,f|0,32)|0;e=i[114610];i[114610]=0;if((e|0)==1){break za}i[114610]=0;C(378,((b<<5)+a|0)+480289|0,f|0)|0;e=i[114610];i[114610]=0;if((e|0)==1){break za}b=b+1|0;continue}}e=B()|0;A()|0}hb(d+160|0);break b}e=B()|0;A()|0;break b}e=B()|0;A()|0;eb(f);break va}eb(f)}hb(d+160|0);i[114610]=0;G(595,d+160|0,d+248|0,1145129300);b=i[114610];i[114610]=0;if((b|0)==1){break ua}Q=d,R=Jb(d+160|0),i[Q+96>>2]=R;Q=d,R=Kb(d+160|0),i[Q+232>>2]=R;if(pb(d+96|0,d+232|0)){e=c&2;while(1){b=i[d+96>>2];i[114610]=0;c=F(484,b|0)|0;f=i[114610];i[114610]=0;if((f|0)==1){break p}if(!(!e|c>>>0>=k[a+480190>>1])){c=o(c,104)+a|0;f=k[c+484518>>1];f=Ic(d+80|0,f&1?16:8,f&64?2:1,1,0);i[114610]=0;I(400,f|0,c+484484|0,b|0)|0;b=i[114610];i[114610]=0;if((b|0)==1){break p}}vf(d+96|0);if(pb(d+96|0,d+232|0)){continue}break}}Qc(d+160|0);b=Oc(d+96|0);if((w|0)!=841887798){break sa}i[114610]=0;c=C(2,d+160|0,12790)|0;e=i[114610];i[114610]=0;if((e|0)==1){break ta}mb(b,c);eb(c);break ra}e=B()|0;A()|0}hb(d+160|0);break b}e=B()|0;A()|0;break b}e=B()|0;A()|0;break q}i[114610]=0;G(583,d+160|0,d+248|0,1447383635);c=i[114610];i[114610]=0;Ea:{Fa:{Ga:{Ha:{Ia:{Ja:{Ka:{if((c|0)!=1){i[114610]=0;c=F(490,d+160|0)|0;e=i[114610];i[114610]=0;if((e|0)==1){break qa}if(!c){break Fa}i[114610]=0;e=F(494,d+160|0)|0;c=i[114610];i[114610]=0;if((c|0)==1){break Ka}i[114610]=0;c=C(2,d+24|0,12810)|0;f=i[114610];i[114610]=0;if((f|0)==1){break Ja}i[114610]=0;D(219,d+80|0,c|0);f=i[114610];i[114610]=0;if((f|0)==1){break Ia}i[114610]=0;i[d+56>>2]=e>>>4;i[d+48>>2]=e&15;J(601,d+232|0,d+80|0,d+56|0,d+48|0);e=i[114610];i[114610]=0;if((e|0)==1){break Ha}mb(b,d+232|0);eb(d+232|0);ob(d+80|0);break Ea}e=B()|0;A()|0;break q}e=B()|0;A()|0;break r}e=B()|0;A()|0;break r}e=B()|0;A()|0;break Ga}e=B()|0;A()|0;ob(d+80|0)}eb(c);break r}i[114610]=0;c=C(2,d+232|0,12832)|0;e=i[114610];i[114610]=0;if((e|0)==1){break t}mb(b,c)}eb(c);hb(d+160|0)}i[114610]=0;c=C(2,d+160|0,12832)|0;e=i[114610];i[114610]=0;if((e|0)==1){break pa}mb(a+1304436|0,c);eb(c);i[114610]=0;c=C(2,d+160|0,12848)|0;e=i[114610];i[114610]=0;if((e|0)==1){break oa}mb(a+1304448|0,c);eb(c);mb(a+1304460|0,b);i[a+1304496>>2]=2;eb(b);e=1;break v}e=B()|0;A()|0;break r}e=B()|0;A()|0;break q}e=B()|0;A()|0;break q}kz(d+248|0)}Xa=d+288|0;return e|0}e=B()|0;A()|0;break r}e=B()|0;A()|0;break k}hb(d+160|0)}eb(b);break b}e=B()|0;A()|0;Qc(d+160|0);break b}e=B()|0;A()|0;hb(d+160|0);break k}e=B()|0;A()|0;break k}e=B()|0;A()|0;break k}e=B()|0;A()|0}Qc(d+96|0);break b}e=B()|0;A()|0;break b}e=B()|0;A()|0;break f}e=B()|0;A()|0;break f}e=B()|0;A()|0}hb(d+96|0);break b}e=B()|0;A()|0;break b}e=B()|0;A()|0;hb(d+160|0);break b}e=B()|0;A()|0;hb(d+232|0)}kz(d+248|0)}E(e|0);x()}function cxa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,m=0,n=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,H=0,K=0,M=0,O=0,P=0,Q=0,T=0,U=0;d=Xa-528|0;Xa=d;pc(b);a:{if(!an(b,d+448|0)){break a}if(!QM(d+448|0)){break a}if(!wb(b,Vc(PM(d+448|0),_a))){break a}b:{if(!c){break b}md(a,4);Vh(a);i[a+1074368>>2]=4;s=Oc(d+432|0);c:{d:{r=d+486|0;e:{if(!(Xc(r,17520,20)|(j[d+508|0]|j[d+509|0]<<8|(j[d+510|0]<<16|j[d+511|0]<<24))!=276)){e=48;if((j[d+506|0]|j[d+507|0]<<8)>>>0<260){break e}i[114610]=0;m=I(628,d+465|0,0,20)|0;f=i[114610];i[114610]=0;if((f|0)==1){break d}e=m?1154:34;break e}if(!Xc(r,17541,20)){e=1;break e}i[114610]=0;G(749,d+416|0,3,r|0);m=i[114610];i[114610]=0;f:{g:{h:{if((m|0)==1){break h}i[114610]=0;D(415,d+72|0,d+416|0);m=i[114610];i[114610]=0;if((m|0)==1){break h}i[114610]=0;G(13,d+144|0,4,d+72|0);m=i[114610];i[114610]=0;if((m|0)==1){break g}mb(s,d+144|0);eb(d+144|0);eb(d+72|0);if((j[r|0]|j[r+1|0]<<8|(j[r+2|0]<<16|j[r+3|0]<<24))!=1852141647|(j[r+4|0]|j[r+5|0]<<8|(j[r+6|0]<<16|j[r+7|0]<<24))!=542396493){break f}e=1048;break e}e=B()|0;A()|0;break c}e=B()|0;A()|0;eb(d+72|0);break c}if(!Xc(r,17571,12)){e=16;if((k[d+498>>1]|k[d+500>>1]<<16)==538976288&(k[d+502>>1]|k[d+504>>1]<<16)==538976288){break e}i[a+1074368>>2]=5;break e}if(!Xc(r,17585,20)){e=48;break e}if(!Xc(r,17606,15)){i[114610]=0;m=a+1074308|0;C(479,m|0,54)|0;f=i[114610];i[114610]=0;if((f|0)==1){break d}i[114610]=0;C(479,m|0,51)|0;m=i[114610];i[114610]=0;e=16;if((m|0)==1){break d}break e}if(!Xc(r,17622,14)){i[114610]=0;C(479,a+1074308|0,57)|0;m=i[114610];i[114610]=0;e=16;if((m|0)!=1){break e}break d}e=Xc(r,17637,11)?16:256}i[114610]=0;K=d+465|0;G(749,d+72|0,3,K|0);m=i[114610];i[114610]=0;i:{j:{k:{l:{m:{if((m|0)==1){break m}i[114610]=0;D(415,d+144|0,d+72|0);m=i[114610];i[114610]=0;if((m|0)==1){break m}mb(a+1304400|0,d+144|0);eb(d+144|0);i[a+480260>>2]=1;i[a+480264>>2]=31999;y=a+484360|0;Fe(Db(y),j[d+514|0]|j[d+515|0]<<8);h[a+480188>>1]=j[d+516|0]|j[d+517|0]<<8;m=j[d+520|0]|j[d+521|0]<<8;i[114610]=0;h[d+144>>1]=m;h[d+72>>1]=255;m=C(477,d+144|0,d+72|0)|0;f=i[114610];i[114610]=0;if((f|0)==1){break l}h[a+480192>>1]=k[m>>1];if(j[d+524|0]|j[d+525|0]<<8){i[a+480196>>2]=j[d+524|0]|j[d+525|0]<<8}if(j[d+526|0]|j[d+527|0]<<8){m=i[19850];T=a,U=hd(o(j[d+526|0]|j[d+527|0]<<8,1e4),o(i[m+20>>2],1e4),o(i[m+24>>2],1e4)),i[T+480204>>2]=U}i[a+480208>>2]=0;i[a+480208>>2]=i[a+480208>>2]&-17|(j[d+522|0]|j[d+523|0]<<8)<<4&16;m=(j[d+522|0]|j[d+523|0]<<8)<<3&32768;i[a+480208>>2]=m|i[a+480208>>2]&-32769;f=Db(y);p=j[d+512|0]|j[d+513|0]<<8;i[114610]=0;S(584,f|0,b|0,p|0,65535,65535)|0;f=i[114610];i[114610]=0;if((f|0)==1){break d}n=(e|0)==34?m>>>15|0?146:e:e;if(!(n&1024|(j[d+512|0]|j[d+513|0]<<8))){m=Db(y);i[114610]=0;G(1033,m|0,1,0);m=i[114610];i[114610]=0;if((m|0)==1){break d}}m=j[d+508|0]|j[d+509|0]<<8|(j[d+510|0]<<16|j[d+511|0]<<24);i[114610]=0;C(256,b|0,m+60|0)|0;m=i[114610];i[114610]=0;if((m|0)==1){break d}if((j[d+506|0]|j[d+507|0]<<8)>>>0>=260){i[114610]=0;G(1034,b|0,d+448|0,a|0);m=i[114610];i[114610]=0;if((m|0)==1){break d}}g[d+415|0]=0;t=d+416|0;Uwa(t);if(k[a+480192>>1]){break k}m=-1;break j}e=B()|0;A()|0;break c}e=B()|0;A()|0;break c}O=c&2;P=d+90|0;Q=d+177|0;p=d+173|0;e=1;m=-1;u=1;while(1){n:{i[114610]=0;f=F(390,b|0)|0;q=i[114610];i[114610]=0;o:{p:{q:{r:{s:{t:{if((q|0)!=1){tg(b,4);i[114610]=0;I(1035,b|0,d+144|0,(f?f:263)|0)|0;f=i[114610];i[114610]=0;if((f|0)==1){break n}u:{if((n|0)==1){if((j[d+144|0]|j[d+145|0]<<8|(j[d+146|0]<<16|j[d+147|0]<<24))==245){i[a+1074304>>2]=16777381;i[114610]=0;f=C(2,d+72|0,17649)|0;n=i[114610];i[114610]=0;if((n|0)!=1){mb(s,f);eb(f);n=17;break u}e=B()|0;A()|0;break i}n=16;if((j[d+144|0]|j[d+145|0]<<8|(j[d+146|0]<<16|j[d+147|0]<<24))!=263){break u}i[a+1074304>>2]=16777395;i[114610]=0;f=C(2,d+72|0,17675)|0;n=i[114610];i[114610]=0;if((n|0)!=1){mb(s,f);eb(f);n=17;break u}e=B()|0;A()|0;break i}if(j[d+171|0]|j[d+172|0]<<8){break u}v:{if(!(n&2)|(j[d+144|0]|j[d+145|0]<<8|(j[d+146|0]<<16|j[d+147|0]<<24))!=263){break v}f=p;if(j[f|0]|j[f+1|0]<<8|(j[f+2|0]<<16|j[f+3|0]<<24)){break v}n=n|16;break u}if(!(!(n&256)|(j[d+144|0]|j[d+145|0]<<8|(j[d+146|0]<<16|j[d+147|0]<<24))==29)){n=n&-257;break u}if(!(n&160)){break u}n=(j[d+144|0]|j[d+145|0]<<8|(j[d+146|0]<<16|j[d+147|0]<<24))==33?n:0}i[114610]=0;f=I(454,a|0,u&65535,0)|0;q=i[114610];i[114610]=0;if((q|0)==1){break n}if(!f){break o}q=((e<<2)+a|0)+900380|0;f=i[q>>2];i[114610]=0;D(1036,d+144|0,f|0);f=i[114610];i[114610]=0;if((f|0)==1){break n}f=j[d+170|0];w:{if((m|0)==-1){m=f;break w}if(!(n&32)|(f|0)==(m|0)){break w}n=n&-161|128}if(!(j[d+171|0]|j[d+172|0]<<8)){break o}f=j[d+385|0];e=j[d+386|0];w=j[d+387|0]|j[d+388|0]<<8;v=j[d+391|0];z=j[d+171|0]|j[d+172|0]<<8;i[114610]=0;G(1037,d+128|0,a|0,z|0);z=i[114610];i[114610]=0;if((z|0)==1){break t}n=v|(w|(e|f))?n&-4:n;e=12;while(1){f=k[Mc(i[q>>2]+236|0,e)>>1];if(Wb(d+128|0)>>>0>f>>>0){f=k[$b(d+128|0,k[Mc(i[q>>2]+236|0,e)>>1])>>1];T=Mc(i[q>>2]+236|0,e),U=f,h[T>>1]=U}e=e+1|0;if((e|0)!=108){continue}break}if((j[d+506|0]|j[d+507|0]<<8)>>>0>259){qb(t);NM(t);vg(t)}f=j[d+171|0]|j[d+172|0]<<8;i[114610]=0;f=C(1038,d+112|0,f|0)|0;e=i[114610];i[114610]=0;x:{if((e|0)!=1){e=0;if(j[d+171|0]|j[d+172|0]<<8){break x}break s}e=B()|0;A()|0;break q}y:{z:{A:{B:{while(1){i[114610]=0;C(1039,b|0,d+72|0)|0;q=i[114610];i[114610]=0;if((q|0)==1){break y}i[114610]=0;D(1040,d+56|0,d+72|0);q=i[114610];i[114610]=0;C:{if((q|0)==1){break C}i[114610]=0;D(1041,t|0,d+56|0);q=i[114610];i[114610]=0;if((q|0)==1){break C}q=j[d+72|0]|j[d+73|0]<<8|(j[d+74|0]<<16|j[d+75|0]<<24);T=vb(f,e),U=q,i[T>>2]=U;w=j[d+89|0];if(Wb(d+128|0)>>>0>e>>>0){q=k[$b(d+128|0,e)>>1];i[114610]=0;v=(o(q,104)+a|0)+484380|0;D(1042,d+72|0,v|0);z=i[114610];i[114610]=0;if((z|0)==1){break B}i[114610]=0;D(1043,Q|0,v|0);v=i[114610];i[114610]=0;if((v|0)==1){break B}i[114610]=0;G(590,d+40|0,3,P|0);v=i[114610];i[114610]=0;if((v|0)==1){break A}i[114610]=0;D(415,d+56|0,d+40|0);v=i[114610];i[114610]=0;if((v|0)==1){break A}i[114610]=0;C(369,((q<<5)+a|0)+946300|0,d+56|0)|0;q=i[114610];i[114610]=0;if((q|0)==1){break z}eb(d+56|0);n=(n&2)>>>1|0?(j[d+86|0]&3)==3?n|4:n:n}H=w|H;e=e+1|0;if(e>>>0>=(j[d+171|0]|j[d+172|0]<<8)>>>0){break s}continue}break}e=B()|0;A()|0;break r}e=B()|0;A()|0;break r}e=B()|0;A()|0;break r}e=B()|0;A()|0;eb(d+56|0);break r}e=B()|0;A()|0;break r}e=B()|0;A()|0;break i}e=B()|0;A()|0;break i}if((j[d+506|0]|j[d+507|0]<<8)>>>0<260){break p}e=0;if(!(j[d+171|0]|j[d+172|0]<<8)){break p}D:{while(1){E:{w=j[vb(t,e)+3|0];q=i[vb(f,e)>>2];i[114610]=0;G(341,d+72|0,b|0,((w|0)==11?(q+1>>>1|0)+16|0:q)|0);q=i[114610];i[114610]=0;if((q|0)==1){break E}if(!(!O|Wb(d+128|0)>>>0<=e>>>0)){w=k[$b(d+128|0,e)>>1];q=vb(t,e);q=j[q|0]|j[q+1|0]<<8|(j[q+2|0]<<16|j[q+3|0]<<24);i[114610]=0;i[d+36>>2]=q;i[d+4>>2]=q;q=N(1044,(o(w,104)+a|0)+484380|0,d+4|0,d+72|0,d+415|0)|0;w=i[114610];i[114610]=0;if((w|0)==1){break D}M=q^1|M}hb(d+72|0);e=e+1|0;if(e>>>0<(j[d+171|0]|j[d+172|0]<<8)>>>0){continue}break p}break}e=B()|0;A()|0;break r}e=B()|0;A()|0;hb(d+72|0)}Sd(f)}df(d+128|0);break i}Sd(f);df(d+128|0)}u=u+1|0;e=u&65535;if(e>>>0<=k[a+480192>>1]){continue}break j}break}e=B()|0;A()|0;break i}F:{G:{H:{I:{J:{K:{L:{M:{N:{O:{P:{Q:{R:{S:{T:{U:{V:{W:{if(!(!(n&2)|H&255)){i[114610]=0;f=I(628,K|0,0,20)|0;p=i[114610];i[114610]=0;if((p|0)==1){break W}n=f?n|16:n}X:{if((j[d+506|0]|j[d+507|0]<<8)>>>0>259){break X}if(c&3){i[114610]=0;G(1034,b|0,d+448|0,a|0);f=i[114610];i[114610]=0;if((f|0)==1){break W}}if(!(c&2)|!k[a+480190>>1]){break X}c=1;e=1;while(1){f=vb(t,c+ -1|0);i[114610]=0;I(400,f|0,(o(c,104)+a|0)+484380|0,b|0)|0;c=i[114610];i[114610]=0;if((c|0)==1){break V}e=e+1|0;c=e&65535;if(c>>>0<=k[a+480190>>1]){continue}break}}if(M&1){i[114610]=0;c=C(2,d+144|0,17700)|0;f=i[114610];i[114610]=0;if((f|0)==1){break U}i[114610]=0;G(650,a|0,2,c|0);f=i[114610];i[114610]=0;if((f|0)==1){break T}eb(c)}i[114610]=0;c=C(621,b|0,17783)|0;f=i[114610];i[114610]=0;if((f|0)==1){break W}if(c){i[114610]=0;c=F(390,b|0)|0;f=i[114610];i[114610]=0;if((f|0)==1){break W}i[114610]=0;N(587,a+1304424|0,b|0,c|0,0)|0;c=i[114610];i[114610]=0;if((c|0)==1){break W}n=n|16}i[114610]=0;f=C(621,b|0,17788)|0;c=i[114610];i[114610]=0;if((c|0)==1){break F}if(f){i[114610]=0;c=F(390,b|0)|0;p=i[114610];i[114610]=0;if((p|0)==1){break F}i[114610]=0;p=a+901404|0;I(1045,b|0,p|0,c|0)|0;c=i[114610];i[114610]=0;if((c|0)==1){break F}i[114610]=0;L(637,p|0);c=i[114610];i[114610]=0;if((c|0)==1){break F}n=n|16}i[114610]=0;c=C(621,b|0,17793)|0;p=i[114610];i[114610]=0;if((p|0)==1){break F}if(c){i[114610]=0;c=F(390,b|0)|0;p=i[114610];i[114610]=0;if((p|0)==1){break S}h[d+144>>1]=c>>>5;p=a+484344|0;c=ke(p);i[114610]=0;h[d+72>>1]=c;c=C(477,d+144|0,d+72|0)|0;e=i[114610];i[114610]=0;if((e|0)==1){break R}e=k[c>>1];if(e){c=0;while(1){i[114610]=0;I(871,b|0,d+144|0,32)|0;u=i[114610];i[114610]=0;if((u|0)==1){break Q}u=Fb(p,c);i[114610]=0;C(872,u|0,d+144|0)|0;u=i[114610];i[114610]=0;if((u|0)==1){break Q}c=c+1|0;if((e|0)!=(c|0)){continue}break}}n=n|16}i[114610]=0;c=C(621,b|0,17798)|0;p=i[114610];i[114610]=0;if((p|0)==1){break F}if(c){i[114610]=0;c=F(390,b|0)|0;p=i[114610];i[114610]=0;if((p|0)==1){break P}h[d+144>>1]=(c>>>0)/20;c=k[a+480188>>1];i[114610]=0;h[d+72>>1]=c;c=C(477,d+144|0,d+72|0)|0;p=i[114610];i[114610]=0;if((p|0)==1){break O}c=k[c>>1];if(c){e=0;while(1){i[114610]=0;I(639,b|0,((e<<5)+a|0)+480289|0,20)|0;p=i[114610];i[114610]=0;if((p|0)==1){break K}e=e+1|0;if((c|0)!=(e|0)){continue}break}}n=n|16}i[114610]=0;c=C(258,b|0,8)|0;p=i[114610];i[114610]=0;if((p|0)==1){break F}if(c){c=i[b+8>>2];i[114610]=0;C(640,a|0,b|0)|0;p=i[114610];i[114610]=0;if((p|0)==1){break J}n=(c|0)==i[b+8>>2]?n:n|16}if(!(n&16)){break L}if(!(n&4)){break M}i[a+1074304>>2]=17367040;i[114610]=0;c=C(2,d+144|0,17803)|0;p=i[114610];i[114610]=0;if((p|0)==1){break N}mb(s,c);eb(c);break L}e=B()|0;A()|0;break i}e=B()|0;A()|0;break i}e=B()|0;A()|0;break i}e=B()|0;A()|0;eb(c);break i}e=B()|0;A()|0;break i}e=B()|0;A()|0;break i}e=B()|0;A()|0;break i}e=B()|0;A()|0;break i}e=B()|0;A()|0;break i}e=B()|0;A()|0;break i}if(!(n&2)){break L}i[a+1074304>>2]=18219008;i[114610]=0;c=C(2,d+144|0,17824)|0;p=i[114610];i[114610]=0;if((p|0)==1){break I}mb(s,c);eb(c)}Y:{Z:{_:{$:{aa:{ba:{ca:{if((j[r|0]|j[r+1|0]<<8|(j[r+2|0]<<16|j[r+3|0]<<24))==1852141647&(j[r+4|0]|j[r+5|0]<<8|(j[r+6|0]<<16|j[r+7|0]<<24))==542396493){i[114610]=0;c=I(1046,d+144|0,d+494|0,12)|0;p=i[114610];i[114610]=0;if((p|0)==1){break ca}i[114610]=0;G(13,d+72|0,1,c|0);p=i[114610];i[114610]=0;if((p|0)==1){break ba}i[114610]=0;p=F(1047,d+72|0)|0;e=i[114610];i[114610]=0;if((e|0)==1){break aa}i[a+1074304>>2]=p;eb(d+72|0);i[a+1074368>>2]=l[a+1074304>>2]<19007257?4:5;eb(c);n=24}if(!(!i[a+1074304>>2]|n&8)){i[a+1074368>>2]=0;Rs(a+1074308|0)}c=n&32;da:{if(!c){break da}i[a+1074368>>2]=5;if(!f){i[114610]=0;L(638,a+901404|0);f=i[114610];i[114610]=0;if((f|0)==1){break F}}if((j[d+506|0]|j[d+507|0]<<8)>>>0<260){break da}i[114610]=0;I(478,a+1074308|0,4,1)|0;f=i[114610];i[114610]=0;if((f|0)==1){break F}}if(!Cc(s)){break Y}if(!(n&256)|(H&255|m+1>>>0>1)){break Z}i[114610]=0;c=C(2,d+144|0,17852)|0;m=i[114610];i[114610]=0;if((m|0)==1){break _}mb(s,c);eb(c);break Y}e=B()|0;A()|0;break i}e=B()|0;A()|0;break $}e=B()|0;A()|0;eb(d+72|0)}eb(c);break i}e=B()|0;A()|0;break i}if(c){i[114610]=0;c=C(2,d+144|0,17864)|0;m=i[114610];i[114610]=0;if((m|0)!=1){mb(s,c);eb(c);break Y}e=B()|0;A()|0;break i}i[114610]=0;c=C(2,d+144|0,17892)|0;m=i[114610];i[114610]=0;if((m|0)==1){break H}mb(s,c);eb(c)}g[d+40|0]=0;ea:{if(k[a+480192>>1]){i[114610]=0;c=C(656,a|0,b|0)|0;m=i[114610];i[114610]=0;if((m|0)==1){break ea}g[d+40|0]=c}i[114610]=0;J(657,a|0,b|0,1,d+40|0);b=i[114610];i[114610]=0;if((b|0)==1){break ea}c=a+1074304|0;if(!(!j[d+40|0]|l[c>>2]>=18284544)){i[c>>2]=18284544}fa:{ga:{ha:{ia:{ja:{ka:{la:{ma:{na:{oa:{pa:{qa:{ra:{sa:{b=i[c>>2];if(b>>>0>=18284544){i[114610]=0;b=C(2,d+72|0,17562)|0;m=i[114610];i[114610]=0;if((m|0)==1){break sa}i[114610]=0;D(1048,d+128|0,c|0);m=i[114610];i[114610]=0;if((m|0)==1){break ra}i[114610]=0;G(3,d+144|0,b|0,d+128|0);m=i[114610];i[114610]=0;if((m|0)==1){break qa}mb(s,d+144|0);eb(d+144|0);eb(d+128|0);eb(b);b=i[c>>2]}ta:{if(!b|l[c>>2]>=19005954){break ta}i[114610]=0;b=a+484344|0;c=C(442,b|0,254)|0;m=i[114610];i[114610]=0;if((m|0)==1){break ea}if(!c){c=Db(y);i[114610]=0;D(1049,c|0,254);c=i[114610];i[114610]=0;if((c|0)==1){break ea}}i[114610]=0;b=C(442,b|0,255)|0;c=i[114610];i[114610]=0;if((c|0)==1){break ea}if(b){break ta}b=Db(y);i[114610]=0;c=R(964)|0;m=i[114610];i[114610]=0;if((m|0)==1){break ea}i[114610]=0;G(1050,b|0,255,c|0);b=i[114610];i[114610]=0;if((b|0)==1){break ea}}if(!j[d+415|0]){break fa}i[114610]=0;b=C(2,d+144|0,17900)|0;c=i[114610];i[114610]=0;if((c|0)==1){break oa}mb(a+1304436|0,b);eb(b);i[114610]=0;b=C(2,d+144|0,17921)|0;c=i[114610];i[114610]=0;if((c|0)==1){break na}mb(a+1304448|0,b);eb(b);i[114610]=0;b=C(2,d+24|0,17925)|0;c=i[114610];i[114610]=0;if((c|0)==1){break ma}i[114610]=0;D(219,d+72|0,b|0);c=i[114610];i[114610]=0;if((c|0)==1){break la}i[d+112>>2]=j[d+507|0];c=j[d+506|0];i[114610]=0;i[d+56>>2]=c;D(664,d+128|0,d+56|0);c=i[114610];i[114610]=0;if((c|0)==1){break ka}i[114610]=0;J(649,d+144|0,d+72|0,d+112|0,d+128|0);c=i[114610];i[114610]=0;if((c|0)==1){break ja}mb(a+1304472|0,d+144|0);eb(d+144|0);eb(d+128|0);ob(d+72|0);eb(b);i[114610]=0;c=C(2,d+144|0,17946)|0;b=i[114610];i[114610]=0;if((b|0)==1){break ga}mb(a+1304484|0,c);break G}e=B()|0;A()|0;break i}e=B()|0;A()|0;break pa}e=B()|0;A()|0;eb(d+128|0)}eb(b);break i}e=B()|0;A()|0;break i}e=B()|0;A()|0;break i}e=B()|0;A()|0;break i}e=B()|0;A()|0;break ha}e=B()|0;A()|0;break ia}e=B()|0;A()|0;eb(d+128|0)}ob(d+72|0)}eb(b);break i}e=B()|0;A()|0;break i}i[114610]=0;b=C(2,d+8|0,17925)|0;c=i[114610];i[114610]=0;ua:{va:{wa:{xa:{ya:{za:{if((c|0)!=1){i[114610]=0;D(219,d+72|0,b|0);c=i[114610];i[114610]=0;if((c|0)==1){break za}i[d+112>>2]=j[d+507|0];c=j[d+506|0];i[114610]=0;i[d+56>>2]=c;D(664,d+128|0,d+56|0);c=i[114610];i[114610]=0;if((c|0)==1){break ya}i[114610]=0;J(649,d+144|0,d+72|0,d+112|0,d+128|0);c=i[114610];i[114610]=0;if((c|0)==1){break xa}mb(a+1304436|0,d+144|0);eb(d+144|0);eb(d+128|0);ob(d+72|0);eb(b);i[114610]=0;c=C(2,d+144|0,17946)|0;b=i[114610];i[114610]=0;if((b|0)==1){break ua}mb(a+1304448|0,c);break G}e=B()|0;A()|0;break i}e=B()|0;A()|0;break va}e=B()|0;A()|0;break wa}e=B()|0;A()|0;eb(d+128|0)}ob(d+72|0)}eb(b);break i}e=B()|0;A()|0;break i}e=B()|0;A()|0;break i}e=B()|0;A()|0;break i}e=B()|0;A()|0;break i}e=B()|0;A()|0;break i}e=B()|0;A()|0;break i}eb(c);mb(a+1304460|0,s);i[a+1304496>>2]=i[a+1074304>>2]?7:4;OM(t);eb(s);break b}e=B()|0;A()|0}OM(t);break c}e=B()|0;A()|0}eb(s);E(e|0);x()}e=1}Xa=d+528|0;return e|0}function PEa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,l=0,m=0,n=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,H=0,J=0,K=0,M=0,O=0,P=0,Q=0,R=0,T=0;d=Xa-288|0;Xa=d;pc(b);a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{if(!Oz(b,d+280|0)){break x}if(!KP(d+280|0)){break x}if(!c){H=1;break x}M=gk(d+264|0,b);i[114610]=0;G(745,d+248|0,M|0,0);b=i[114610];i[114610]=0;y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{I:{J:{K:{L:{M:{N:{if((b|0)!=1){i[114610]=0;G(746,d+232|0,d+248|0,20041);b=i[114610];i[114610]=0;if((b|0)==1){break N}i[114610]=0;b=F(337,d+232|0)|0;e=i[114610];i[114610]=0;if((e|0)==1){break E}if(!b){break y}i[114610]=0;b=C(747,d+232|0,d+136|0)|0;e=i[114610];i[114610]=0;if((e|0)==1){break E}if(!b){break y}i[114610]=0;D(447,a|0,16384);b=i[114610];i[114610]=0;if((b|0)==1){break E}i[a+480208>>2]=8;i[114610]=0;b=a+1074308|0;I(478,b|0,9,1)|0;e=i[114610];i[114610]=0;if((e|0)==1){break E}i[114610]=0;C(479,b|0,21)|0;e=i[114610];i[114610]=0;if((e|0)==1){break E}i[114610]=0;C(479,b|0,30)|0;b=i[114610];i[114610]=0;if((b|0)==1){break E}i[114610]=0;b=C(2,d+16|0,14652)|0;e=i[114610];i[114610]=0;if((e|0)==1){break K}mb(a+1304436|0,b);eb(b);i[114610]=0;b=C(2,d+16|0,14664)|0;e=i[114610];i[114610]=0;if((e|0)==1){break J}mb(a+1304448|0,b);eb(b);i[114610]=0;e=C(2,d+120|0,14668)|0;b=i[114610];i[114610]=0;if((b|0)==1){break I}b=j[d+284|0];switch(b+ -16|0){case 1:break H;case 0:break M;default:break L}}b=B()|0;A()|0;break a}b=B()|0;A()|0;break b}i[114610]=0;C(2,d+104|0,14683)|0;b=i[114610];i[114610]=0;if((b|0)!=1){break F}break e}if(!b){break G}i[114610]=0;C(2,d+104|0,14698)|0;b=i[114610];i[114610]=0;if((b|0)==1){break e}break F}b=B()|0;A()|0;break c}b=B()|0;A()|0;break c}b=B()|0;A()|0;break c}i[114610]=0;C(2,d+104|0,14681)|0;b=i[114610];i[114610]=0;if((b|0)!=1){break F}break e}i[114610]=0;C(2,d+104|0,14687)|0;b=i[114610];i[114610]=0;if((b|0)==1){break e}}i[114610]=0;G(3,d+16|0,e|0,d+104|0);b=i[114610];i[114610]=0;if((b|0)==1){break f}mb(a+1304460|0,d+16|0);eb(d+16|0);eb(d+104|0);eb(e);i[a+1304496>>2]=4;i[114610]=0;G(748,d+120|0,3,d+136|0);b=i[114610];i[114610]=0;if((b|0)==1){break g}i[114610]=0;D(415,d+16|0,d+120|0);b=i[114610];i[114610]=0;if((b|0)==1){break g}mb(a+1304400|0,d+16|0);eb(d+16|0);i[114610]=0;G(749,d+104|0,3,d+168|0);b=i[114610];i[114610]=0;if((b|0)==1){break h}i[114610]=0;D(415,d+120|0,d+104|0);b=i[114610];i[114610]=0;if((b|0)==1){break h}i[114610]=0;G(13,d+16|0,4,d+120|0);b=i[114610];i[114610]=0;if((b|0)==1){break i}mb(a+1304412|0,d+16|0);eb(d+16|0);eb(d+120|0);i[a+480200>>2]=j[d+192|0]+1;R=a,T=hd(j[d+193|0],1,255),i[R+480196>>2]=T;R=a,T=o(hd(j[d+194|0],4,255),1e4),i[R+480204>>2]=T;b=a+484360|0;e=Db(b);f=j[d+188|0]|j[d+189|0]<<8;i[114610]=0;S(584,e|0,d+232|0,f|0,65535,65535)|0;e=i[114610];i[114610]=0;if((e|0)==1){break E}Fe(Db(b),j[d+190|0]|j[d+191|0]<<8);h[a+480188>>1]=0;b=0;while(1){i[114610]=0;e=(b<<5)+a|0;f=e+480280|0;L(432,f|0);l=i[114610];i[114610]=0;if((l|0)==1){break j}l=b+d|0;n=j[l+195|0]<<1&254;h[e+480284>>1]=(n|0)==254?256:n;O:{if(g[l+195|0]<=-1){i[f>>2]=i[f>>2]|1024;break O}h[a+480188>>1]=b+1}i[114610]=0;I(750,d+232|0,e+480289|0,8)|0;e=i[114610];i[114610]=0;if((e|0)==1){break j}b=b+1|0;if((b|0)!=32){continue}break}i[114610]=0;G(746,d+16|0,d+248|0,17741);b=i[114610];i[114610]=0;if((b|0)==1){break k}Cd(d+232|0,d+16|0);hb(d+16|0);i[114610]=0;b=F(255,d+232|0)|0;e=i[114610];i[114610]=0;if((e|0)==1){break E}i[114610]=0;N(587,a+1304424|0,d+232|0,b|0,0)|0;b=i[114610];i[114610]=0;if((b|0)==1){break E}i[114610]=0;G(746,d+16|0,d+248|0,21321);b=i[114610];i[114610]=0;if((b|0)==1){break l}Cd(d+232|0,d+16|0);hb(d+16|0);i[114610]=0;b=F(337,d+232|0)|0;e=i[114610];i[114610]=0;if((e|0)==1){break E}P:{if(b){i[114610]=0;G(746,d+16|0,d+248|0,16723);b=i[114610];i[114610]=0;if((b|0)==1){break m}i[114610]=0;q=F(387,d+232|0)|0;b=i[114610];i[114610]=0;if((b|0)==1){break n}Q:{if(!q){break Q}r=c&2;while(1){i[114610]=0;e=F(387,d+232|0)|0;b=i[114610];i[114610]=0;if((b|0)==1){break n}if(!e){break Q}i[114610]=0;b=C(258,d+232|0,56)|0;f=i[114610];i[114610]=0;if((f|0)==1){break n}if(!b){break Q}if(k[a+480190>>1]<e>>>0){h[a+480190>>1]=e}i[114610]=0;b=o(e,104)+a|0;f=b+484380|0;D(386,f|0,0);l=i[114610];i[114610]=0;if((l|0)==1){break n}i[114610]=0;I(751,d+232|0,((e<<5)+a|0)+946300|0,32)|0;e=i[114610];i[114610]=0;if((e|0)==1){break n}i[114610]=0;I(552,d+232|0,b+484423|0,8)|0;e=i[114610];i[114610]=0;if((e|0)==1){break n}R:{if(j[d+284|0]<=15){i[114610]=0;e=F(357,d+232|0)|0;l=i[114610];i[114610]=0;if((l|0)!=1){break R}break n}i[114610]=0;e=F(390,d+232|0)|0;l=i[114610];i[114610]=0;if((l|0)==1){break n}}i[b+484404>>2]=e<<1;i[114610]=0;e=F(390,d+232|0)|0;l=i[114610];i[114610]=0;if((l|0)==1){break n}i[f>>2]=e;i[114610]=0;l=F(390,d+232|0)|0;e=i[114610];i[114610]=0;if((e|0)==1){break n}e=b+484384|0;i[e>>2]=l;i[114610]=0;l=F(390,d+232|0)|0;n=i[114610];i[114610]=0;if((n|0)==1){break n}n=b+484388|0;i[n>>2]=l;if(l){p=b+484414|0;h[p>>1]=k[p>>1]|2;i[n>>2]=l+i[e>>2]}i[114610]=0;l=F(387,d+232|0)|0;p=i[114610];i[114610]=0;if((p|0)==1){break P}if(j[d+284|0]<=15){h[b+484410>>1]=l}i[114610]=0;l=F(387,d+232|0)|0;p=i[114610];i[114610]=0;if((p|0)==1){break n}p=8;if(l&1){p=b+484414|0;h[p>>1]=k[p>>1]|1;i[f>>2]=i[f>>2]>>>1;i[e>>2]=i[e>>2]>>>1;i[n>>2]=i[n>>2]>>>1;p=16}b=b+484414|0;h[b>>1]=k[b>>1]&65531|l<<1&4;b=Ic(d+120|0,p,1,0,((l&12)!=0)<<3);S:{if(!r){break S}i[114610]=0;I(400,b|0,f|0,d+16|0)|0;b=i[114610];i[114610]=0;if((b|0)!=1){break S}break n}m=m+1|0;if((m&255)>>>0<q>>>0){continue}break}}hb(d+16|0)}i[114610]=0;G(746,d+16|0,d+248|0,18761);b=i[114610];i[114610]=0;if((b|0)==1){break q}Cd(d+232|0,d+16|0);hb(d+16|0);i[114610]=0;b=F(337,d+232|0)|0;e=i[114610];i[114610]=0;if((e|0)==1){break E}T:{U:{V:{W:{if(b){q=My(d+120|0);r=My(d+104|0);p=My(d+88|0);i[114610]=0;G(746,d+72|0,d+248|0,17750);b=i[114610];i[114610]=0;if((b|0)==1){break r}i[114610]=0;D(752,d+72|0,q|0);b=i[114610];i[114610]=0;if((b|0)==1){break s}hb(d+72|0);i[114610]=0;G(746,d+56|0,d+248|0,17744);b=i[114610];i[114610]=0;if((b|0)==1){break r}i[114610]=0;D(752,d+56|0,r|0);b=i[114610];i[114610]=0;if((b|0)==1){break t}hb(d+56|0);i[114610]=0;G(746,d+40|0,d+248|0,17734);b=i[114610];i[114610]=0;if((b|0)==1){break r}i[114610]=0;D(752,d+40|0,p|0);b=i[114610];i[114610]=0;if((b|0)==1){break u}hb(d+40|0);i[114610]=0;t=F(387,d+232|0)|0;b=i[114610];i[114610]=0;if((b|0)==1){break v}if(t){z=d+16|4;H=d+16|2;v=d+16|6;w=d+16|5;y=d+16|3;e=d+16|1;m=0;while(1){i[114610]=0;D(472,d|0,d+232|0);b=i[114610];i[114610]=0;if((b|0)==1){break A}s=Nc(d);X:{Y:{Z:{if(!j[d|0]){break Z}b=j[s|0];i[114610]=0;b=C(258,d+232|0,o(b,14)+32|0)|0;f=i[114610];i[114610]=0;if((f|0)==1){break p}if(!b){break Z}b=j[d|0];i[114610]=0;n=I(454,a|0,b|0,0)|0;b=i[114610];i[114610]=0;if((b|0)==1){break p}if(n){break Y}}b=j[s|0];i[114610]=0;C(338,d+232|0,o(b,14)+32|0)|0;b=i[114610];i[114610]=0;if((b|0)!=1){break X}break p}i[114610]=0;I(751,d+232|0,n+492|0,32)|0;b=i[114610];i[114610]=0;if((b|0)==1){break p}if(!j[s|0]){break X}J=n+88|0;K=n+68|0;O=n+48|0;P=n+236|0;l=0;b=0;while(1){i[114610]=0;C(753,d+232|0,d+16|0)|0;f=i[114610];i[114610]=0;if((f|0)==1){break w}_:{if(!j[d+16|0]|k[a+480190>>1]<j[d+16|0]){break _}f=e;if(j[e|0]>128){g[f|0]=128}if((b&255)>>>0<=j[e|0]){while(1){f=j[d+16|0];R=Mc(P,b&255),T=f,h[R>>1]=T;b=b+1|0;if((b&255)>>>0<=j[e|0]){continue}break}}b=j[e|0];f=j[y|0];i[114610]=0;G(754,O|0,f|0,q|0);f=i[114610];i[114610]=0;if((f|0)==1){break w}f=j[w|0];i[114610]=0;G(754,K|0,f|0,r|0);f=i[114610];i[114610]=0;if((f|0)==1){break w}f=j[d+29|0];i[114610]=0;G(754,J|0,f|0,p|0);f=i[114610];i[114610]=0;if((f|0)==1){break w}i[n>>2]=(j[v|0]|j[v+1|0]<<8)+1>>>1;f=j[d+16|0];$:{if(j[y|0]&64){h[(o(f,104)+a|0)+484410>>1]=j[H|0];break $}u=(o(f,104)+a|0)+484414|0;h[u>>1]=k[u>>1]|32768}u=j[z|0];i[114610]=0;h[d+38>>1]=u<<1;h[d+36>>1]=254;u=C(477,d+38|0,d+36|0)|0;Q=i[114610];i[114610]=0;if((Q|0)==1){break W}b=b+1|0;f=o(f,104)+a|0;h[f+484408>>1]=k[u>>1];g[f+484418|0]=j[(j[d+27|0]&3)+14699|0];g[f+484419|0]=j[d+26|0];g[f+484420|0]=j[d+25|0];g[f+484421|0]=j[d+24|0];if(!(j[w|0]&64)){break _}f=f+484414|0;h[f>>1]=k[f>>1]|32}l=l+1|0;if((l&255)>>>0<j[s|0]){continue}break}}m=m+1|0;if((m&255)>>>0<t>>>0){continue}break}}Xm(p);Xm(r);Xm(q)}H=1;r=gp(d+120|0);if(!(c&1)){break z}i[114610]=0;G(746,d+16|0,d+248|0,21076);b=i[114610];i[114610]=0;if((b|0)!=1){b=Cd(d+232|0,d+16|0);i[114610]=0;b=F(337,b|0)|0;c=i[114610];i[114610]=0;aa:{ba:{ca:{da:{ea:{fa:{if((c|0)!=1){hb(d+16|0);ga:{if(!b){break ga}i[114610]=0;c=F(357,d+232|0)|0;b=i[114610];i[114610]=0;if((b|0)==1){break fa}i[114610]=0;D(755,r|0,c+1|0);b=i[114610];i[114610]=0;if((b|0)==1){break fa}if(!c){break ga}b=1;while(1){i[114610]=0;e=F(357,d+232|0)|0;f=i[114610];i[114610]=0;if((f|0)==1){break ea}i[114610]=0;G(341,d+16|0,d+232|0,e|0);e=i[114610];i[114610]=0;if((e|0)==1){break ea}Cd(_b(r,b),d+16|0);e=(b|0)==(c|0);hb(d+16|0);b=b+1|0;if(!e){continue}break}}i[114610]=0;G(746,d+16|0,d+248|0,16720);b=i[114610];i[114610]=0;if((b|0)==1){break da}b=Cd(d+232|0,d+16|0);i[114610]=0;b=F(337,b|0)|0;c=i[114610];i[114610]=0;if((c|0)==1){break ca}hb(d+16|0);if(!b){break aa}i[114610]=0;s=F(387,d+232|0)|0;b=i[114610];i[114610]=0;if((b|0)==1){break C}if(s){q=0;while(1){l=32;ha:{if(j[d+284|0]>=16){i[114610]=0;C(756,d+232|0,d+16|0)|0;b=i[114610];i[114610]=0;if((b|0)==1){break V}if(!(j[d+16|0]>32|k[a+480188>>1]>=j[d+16|0])){h[a+480188>>1]=j[d+16|0]}l=j[d+16|0];if(!l){break ha}}e=0;while(1){i[114610]=0;b=F(357,d+232|0)|0;c=i[114610];i[114610]=0;if((c|0)==1){break U}if(!(!b|(e&65535)>>>0<k[a+480188>>1])){h[a+480188>>1]=e+1}e=e+1|0;if(l>>>0>(e&65535)>>>0){continue}break}}q=q+1|0;if((q&65535)>>>0<s>>>0){continue}break}}i[114610]=0;C(256,d+232|0,1)|0;b=i[114610];i[114610]=0;if((b|0)!=1){break ba}break C}b=B()|0;A()|0;hb(d+16|0);break B}b=B()|0;A()|0;break B}b=B()|0;A()|0;break B}b=B()|0;A()|0;break B}b=B()|0;A()|0;hb(d+16|0);break B}i[114610]=0;t=a+484344|0;D(401,t|0,s|0);b=i[114610];i[114610]=0;if((b|0)==1){break C}if(!s){break aa}O=d+16|2;P=d+16|1;c=0;while(1){v=Ab(d+104|0);q=64;w=32;if(j[d+284|0]>=16){i[114610]=0;C(756,d+232|0,d+16|0)|0;b=i[114610];i[114610]=0;if((b|0)==1){break D}w=j[d+16|0];b=j[P|0];i[114610]=0;G(757,d|0,3,O|0);e=i[114610];i[114610]=0;if((e|0)==1){break D}i[114610]=0;D(415,d+88|0,d|0);e=i[114610];i[114610]=0;if((e|0)==1){break D}mb(v,d+88|0);eb(d+88|0);q=b+1|0}i[114610]=0;b=I(402,t|0,c&65535,q|0)|0;e=i[114610];i[114610]=0;if((e|0)==1){break D}ia:{if(!b){i[114610]=0;C(338,d+232|0,w<<1)|0;b=i[114610];i[114610]=0;if((b|0)!=1){break ia}break D}b=Fb(t,c);i[114610]=0;C(496,b|0,v|0)|0;b=i[114610];i[114610]=0;if((b|0)==1){break D}y=0;if(!w){break ia}while(1){i[114610]=0;b=F(357,d+232|0)|0;e=i[114610];i[114610]=0;if((e|0)==1){break D}ja:{if(!b){break ja}if(Wc(r)>>>0<=b>>>0){break ja}z=y&65535;if(z>>>0>=k[a+480188>>1]){break ja}n=_b(r,b);pc(n);f=0;while(1){i[114610]=0;b=C(258,n|0,1)|0;e=i[114610];i[114610]=0;ka:{la:{ma:{na:{oa:{pa:{if((e|0)!=1){if(!b){break ja}b=Fb(t,c);i[114610]=0;b=I(471,b|0,f|0,z|0)|0;e=i[114610];i[114610]=0;if((e|0)==1){break D}i[114610]=0;l=F(387,n|0)|0;e=i[114610];i[114610]=0;if((e|0)==1){break D}e=l>>>2|0;switch((l&3)-1|0){case 2:break ma;case 1:break na;case 0:break oa;default:break pa}}break D}f=(e+f|0)+1|0;break ka}if(!f){f=0;break ka}l=Fb(t,c);i[114610]=0;l=I(471,l|0,f+ -1|0,z|0)|0;m=i[114610];i[114610]=0;if((m|0)!=1){while(1){m=j[l|0]|j[l+1|0]<<8|(j[l+2|0]<<16|j[l+3|0]<<24);g[b|0]=m;g[b+1|0]=m>>>8;g[b+2|0]=m>>>16;g[b+3|0]=m>>>24;m=j[l+4|0]|j[l+5|0]<<8;g[b+4|0]=m;g[b+5|0]=m>>>8;f=f+1|0;if(f>>>0>=q>>>0){break ka}b=o(k[a+480188>>1],6)+b|0;m=e&255;e=e+ -1|0;if(m){continue}break ka}}break D}if(f>>>0<=e>>>0){break la}l=Fb(t,c);i[114610]=0;e=I(471,l|0,e|0,z|0)|0;l=i[114610];i[114610]=0;if((l|0)==1){break T}l=j[e|0]|j[e+1|0]<<8|(j[e+2|0]<<16|j[e+3|0]<<24);g[b|0]=l;g[b+1|0]=l>>>8;g[b+2|0]=l>>>16;g[b+3|0]=l>>>24;e=j[e+4|0]|j[e+5|0]<<8;g[b+4|0]=e;g[b+5|0]=e>>>8;break la}if(e&1){i[114610]=0;l=F(387,n|0)|0;m=i[114610];i[114610]=0;if((m|0)==1){break T}g[b|0]=l>>>0>120?-1:l}if(e&2){i[114610]=0;l=F(387,n|0)|0;m=i[114610];i[114610]=0;if((m|0)==1){break T}g[b+1|0]=l}p=0;l=0;if(e&4){i[114610]=0;l=F(387,n|0)|0;m=i[114610];i[114610]=0;if((m|0)==1){break D}}J=0;if(e&8){i[114610]=0;m=F(387,n|0)|0;p=i[114610];i[114610]=0;if((p|0)==1){break D}J=m>>>4|0;p=m&15}K=0;m=0;if(e&16){i[114610]=0;m=F(387,n|0)|0;u=i[114610];i[114610]=0;if((u|0)==1){break D}}if(e&32){i[114610]=0;K=F(387,n|0)|0;e=i[114610];i[114610]=0;if((e|0)==1){break D}}i[114610]=0;_(758,b|0,l|0,p|0,J|0,m|0,K|0);b=i[114610];i[114610]=0;if((b|0)==1){break D}}f=f+1|0}if(f>>>0<q>>>0){continue}break}}y=y+1|0;if((y&65535)>>>0<w>>>0){continue}break}}eb(v);c=c+1|0;if((s|0)!=(c|0)){continue}break}}i[114610]=0;G(746,d+16|0,d+248|0,20048);b=i[114610];i[114610]=0;qa:{ra:{sa:{if((b|0)!=1){b=Cd(d+232|0,d+16|0);i[114610]=0;b=F(337,b|0)|0;c=i[114610];i[114610]=0;if((c|0)==1){break sa}hb(d+16|0);if(!b){break z}a=a+484344|0;if(!ke(a)){break z}while(1){i[114610]=0;b=C(258,d+232|0,16)|0;c=i[114610];i[114610]=0;if((c|0)==1){break ra}if(!b){break z}i[114610]=0;I(759,d+232|0,d+16|0,16)|0;b=i[114610];i[114610]=0;if((b|0)==1){break qa}b=Fb(a,0);i[114610]=0;C(760,b|0,d+16|0)|0;b=i[114610];i[114610]=0;if((b|0)==1){break qa}if(ke(a)){continue}break}break z}b=B()|0;A()|0;break B}b=B()|0;A()|0;hb(d+16|0);break B}b=B()|0;A()|0;break B}b=B()|0;A()|0;break B}b=B()|0;A()|0;break B}b=B()|0;A()|0;break o}b=B()|0;A()|0;break B}b=B()|0;A()|0;break B}break D}break n}b=B()|0;A()|0;break c}b=B()|0;A()|0;eb(v);break B}b=B()|0;A()|0}Qc(r);break c}b=B()|0;A()|0;break o}Qc(r)}hb(d+232|0);Ly(d+248|0);hb(M)}Xa=d+288|0;return H|0}b=B()|0;A()|0;break o}b=B()|0;A()|0;break o}b=B()|0;A()|0;hb(d+40|0);break o}b=B()|0;A()|0;hb(d+56|0);break o}b=B()|0;A()|0;hb(d+72|0);break o}b=B()|0;A()|0;break o}b=B()|0;A()|0;break c}b=B()|0;A()|0}Xm(p);Xm(r);Xm(q);break c}b=B()|0;A()|0;hb(d+16|0);break c}b=B()|0;A()|0;break c}b=B()|0;A()|0;break c}b=B()|0;A()|0;break c}b=B()|0;A()|0;break c}b=B()|0;A()|0;eb(d+120|0);break c}b=B()|0;A()|0;break c}b=B()|0;A()|0;break c}b=B()|0;A()|0;eb(d+104|0);break d}b=B()|0;A()|0}eb(e)}hb(d+232|0)}Ly(d+248|0)}hb(M);E(b|0);x()}function jF(a,b,c,d,e,f,m){var n=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0;L=Xa-144|0;Xa=L;a:{b:{c:{if(e>>>0>=d>>>0){q=i[f>>2];N=m&4;M=N?-1:q+((d^-1)+e|0)|0;F=M+1|0;if(!(F&M)){break c}}i[f>>2]=0;i[c>>2]=0;r=-3;break b}G=e+q|0;E=i[c>>2];B=E+b|0;H=i[a+60>>2];z=i[a+40>>2];q=i[a+36>>2];C=i[a+32>>2];t=i[a+56>>2];p=i[a+4>>2];s=b;w=e;A=-1;r=-1;d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{I:{J:{K:{L:{M:{N:{O:{y=i[a>>2];switch(y|0){case 35:break i;case 17:break j;case 21:break k;case 37:break l;case 34:break m;case 42:break q;case 41:break r;case 53:break s;case 52:break t;case 51:break u;case 38:break v;case 27:break w;case 26:break x;case 25:break y;case 24:break z;case 23:break A;case 18:break B;case 16:break C;case 14:break D;case 11:break E;case 9:break F;case 7:break G;case 6:break H;case 3:break I;case 32:break J;case 5:break K;case 2:break M;case 1:break N;case 0:break O;case 36:break f;case 39:break g;case 10:break h;default:break d}}i[a+28>>2]=1;t=0;i[a+8>>2]=0;i[a+12>>2]=0;i[a+16>>2]=1;z=0;q=0;C=0;p=0;if(m&1){break N}break L}if((E|0)<=0){i[a>>2]=1;break e}i[a+8>>2]=j[b|0];s=b+1|0}if(s>>>0>=B>>>0){i[a>>2]=2;r=m&2?1:-4;break d}q=j[s|0];i[a+12>>2]=q;n=i[a+8>>2];r=(((q|n<<8)>>>0)%31|q&32)!=0|(n&15)!=8;q=1;s=s+1|0;if(!N){y=36;n=256<<(n>>>4);if(!(r|(n>>>0>32768|F>>>0<n>>>0))){break L}break f}y=36;if(r){break f}}n=0;break p}if((E|0)<=0){i[a>>2]=5;break e}s=b+1|0;t=j[b|0]<<p|t;p=p+8|0;n=2;break p}if((E|0)<=0){i[a>>2]=32;break e}s=b+1|0;t=j[b|0]<<p|t;D=q;p=p+8|0;break o}n=1;break p}n=3;break p}n=4;break p}n=5;break p}n=9;break p}n=10;break p}n=11;break p}n=12;break p}n=13;break p}n=14;break p}n=15;break p}n=16;break p}n=17;break p}n=8;break p}n=6;break p}n=7;break p}n=18;break p}u=2;break n}u=1;break n}P:while(1){Q:{R:{S:{T:{U:{V:{W:{X:{Y:{Z:{_:{$:{aa:{ba:{ca:{da:{ea:{fa:{ga:{ha:{ia:{ja:{ka:{la:{ma:{na:{oa:{pa:{qa:{ra:{sa:{ta:{ua:{va:{wa:{xa:{ya:{za:{Aa:{Ba:{Ca:{Da:{switch(n|0){case 0:q=D;if(p>>>0>2){break Ca}n=1;continue;case 17:break la;case 16:break ma;case 15:break na;case 14:break oa;case 13:break pa;case 12:break qa;case 11:break ra;case 10:break sa;case 9:break ta;case 8:break va;case 7:break wa;case 6:break xa;case 5:break ya;case 4:break za;case 3:break Aa;case 2:break Ba;case 1:break Da;default:break ka}}while(1){if(s>>>0>=B>>>0){i[a>>2]=3;r=m&2?1:-4;break d}t=j[s|0]<<p|t;n=s+1|0;s=n;p=p+8|0;if(p>>>0<3){continue}break}s=n;D=q}q=t&7;i[a+20>>2]=q;n=q>>>1|0;i[a+24>>2]=n;p=p+ -3|0;t=t>>>3|0;r=0;q=D;switch(n|0){case 0:break ja;case 1:break ua;case 3:break h;default:break ga}}n=p&-8;t=t>>>(p&7)|0;q=0;p=0;break ha}while(1){if(s>>>0>=B>>>0){i[a>>2]=6;r=m&2?1:-4;break d}t=j[s|0]<<p|t;v=p>>>0>4294967287;r=s+1|0;s=r;n=p+8|0;p=n;if(v){continue}break}s=r;p=1;break ha}if(s>>>0>=B>>>0){i[a>>2]=7;r=m&2?1:-4;break d}g[(a+q|0)+10528|0]=j[s|0];s=s+1|0;n=p;p=2;break ha}if(w>>>0<G>>>0){break ia}A=2;y=9;break f}while(1){if(s>>>0>=B>>>0){i[a>>2]=51;r=m&2?1:-4;break d}t=j[s|0]<<p|t;v=p>>>0>4294967287;r=s+1|0;s=r;n=p+8|0;p=n;if(v){continue}break}s=r;break R}if(w>>>0<G>>>0){g[w|0]=C;q=q+ -1|0;w=w+1|0;n=p;break U}A=2;y=52;break f}if(s>>>0>=B>>>0){i[a>>2]=38;r=m&2?1:-4;break d}n=G-w|0;r=B-s|0;n=n>>>0<r>>>0?n:r;n=n>>>0<q>>>0?n:q;q=q-n|0;w=Tb(w,s,n)+n|0;s=n+s|0;break T}i[a+44>>2]=288;i[a+48>>2]=32;n=a+3552|0;i[n>>2]=84215045;i[n+4>>2]=84215045;n=a+3560|0;i[n>>2]=84215045;i[n+4>>2]=84215045;n=a+3568|0;i[n>>2]=84215045;i[n+4>>2]=84215045;n=a+3576|0;i[n>>2]=84215045;i[n+4>>2]=84215045;n=a- -64|0;yb(n,8,144);while(1){n=n+1|0;r=r+1|0;if((r|0)!=144){continue}break}yb(n,9,112);r=144;while(1){n=n+1|0;r=r+1|0;if((r|0)!=256){continue}break}g[n|0]=117901063;g[n+1|0]=460551;g[n+2|0]=1799;g[n+3|0]=7;g[n+4|0]=117901063;g[n+5|0]=460551;g[n+6|0]=1799;g[n+7|0]=7;g[n+16|0]=117901063;g[n+17|0]=460551;g[n+18|0]=1799;g[n+19|0]=7;g[n+20|0]=117901063;g[n+21|0]=460551;g[n+22|0]=1799;g[n+23|0]=7;g[n+8|0]=117901063;g[n+9|0]=460551;g[n+10|0]=1799;g[n+11|0]=7;g[n+12|0]=117901063;g[n+13|0]=460551;g[n+14|0]=1799;g[n+15|0]=7;r=256;while(1){n=n+1|0;r=r+1|0;if((r|0)!=280){continue}break}g[n|0]=134744072;g[n+1|0]=526344;g[n+2|0]=2056;g[n+3|0]=8;g[n+4|0]=134744072;g[n+5|0]=526344;g[n+6|0]=2056;g[n+7|0]=8;break Y}while(1){if(s>>>0>=B>>>0){i[a>>2]=11;r=m&2?1:-4;break d}t=j[s|0]<<p|t;r=s+1|0;s=r;n=p+8|0;p=n;I=g[q+42348|0];if(n>>>0<I>>>0){continue}break}s=r;r=q;p=n;q=1;break _}while(1){if(s>>>0>=B>>>0){i[a>>2]=14;r=m&2?1:-4;break d}t=j[s|0]<<p|t;n=s+1|0;s=n;p=p+8|0;if(p>>>0<3){continue}break}s=n;n=1;break Z}if(s>>>0>=B>>>0){i[a>>2]=16;r=m&2?1:-4;break d}t=j[s|0]<<p|t;s=s+1|0;p=p+8|0;if(p>>>0<15){break fa}break ea}while(1){if(s>>>0>=B>>>0){i[a>>2]=18;r=m&2?1:-4;break d}t=j[s|0]<<p|t;n=s+1|0;s=n;p=p+8|0;if(p>>>0<z>>>0){continue}break}O=C+ -16|0;s=n;n=3;break X}if(s>>>0>=B>>>0){i[a>>2]=23;r=m&2?1:-4;break d}t=j[s|0]<<p|t;s=s+1|0;p=p+8|0;if(p>>>0<15){break da}break ca}if(w>>>0>=G>>>0){A=2;y=24;break f}g[w|0]=q;w=w+1|0;u=t;break W}while(1){if(s>>>0>=B>>>0){i[a>>2]=25;r=m&2?1:-4;break d}t=j[s|0]<<p|t;n=s+1|0;s=n;p=p+8|0;if(p>>>0<z>>>0){continue}break}s=n;n=3;break V}if(s>>>0>=B>>>0){i[a>>2]=26;r=m&2?1:-4;break d}t=j[s|0]<<p|t;s=s+1|0;p=p+8|0;if(p>>>0<15){break ba}break aa}while(1){if(s>>>0>=B>>>0){i[a>>2]=27;r=m&2?1:-4;break d}t=j[s|0]<<p|t;n=s+1|0;s=n;p=p+8|0;if(p>>>0<z>>>0){continue}break}s=n;n=6;break V}if(w>>>0>=G>>>0){A=2;y=53;break f}g[w|0]=j[(H-C&M)+d|0];w=w+1|0;H=H+1|0;break $}n=2;continue}n=8;continue}while(1){Ea:{Fa:{Ga:{Ha:{Ia:{Ja:{switch(p|0){case 0:if(q>>>0>3){break Ia}p=0;if(!n){break Ha}p=n;if(n>>>0>7){break Fa}n=3;continue P;case 1:g[(a+q|0)+10528|0]=t;n=n+ -8|0;t=t>>>8|0;break Ea;default:break Ja}}q=q+1|0;break Ga}p=n;q=k[a+10528>>1];if((q|0)==(k[a+10530>>1]^65535)){break U}break g}n=4;continue P}p=0;continue}p=1;continue}p=2;continue}}q=0;break _}n=1;break X}n=2;break X}n=0;break V}n=1;break V}n=4;break V}n=5;break V}n=7;break V}while(1){Ka:{La:{Ma:{if(!q){if(r>>>0>2){break Ma}q=r;I=g[q+42348|0];if(p>>>0>=I>>>0){break Ka}n=9;continue P}q=r<<2;i[(q+a|0)+44>>2]=i[q+42336>>2]+((-1<<I^-1)&t);r=r+1|0;p=p-I|0;t=t>>>I|0;break La}q=0;yb(a+7040|0,0,288);n=0;break Z}q=0;continue}q=1;continue}}while(1){Na:{Oa:{Pa:{if(!n){if(q>>>0>=l[a+52>>2]){break Pa}if(p>>>0>2){break Na}n=10;continue P}g[(j[q+42400|0]+a|0)+7040|0]=t&7;q=q+1|0;p=p+ -3|0;t=t>>>3|0;break Oa}i[a+52>>2]=19;D=q;break Y}n=0;continue}n=1;continue}}J=i[a+24>>2];n=0}while(1){Qa:{Ra:{Sa:{Ta:{Ua:{Va:{Wa:{Xa:{Ya:{switch(n|0){case 0:q=0;if((J|0)<0){u=t;q=D;break W}E=yb(L,0,64);r=o(J,3488)+a|0;yb(r+352|0,0,3200);y=i[a+24>>2];n=i[((y<<2)+a|0)+44>>2];if(n){while(1){v=E+(j[(q+r|0)- -64|0]<<2)|0;i[v>>2]=i[v>>2]+1;q=q+1|0;if((n|0)!=(q|0)){continue}break}}i[E+64>>2]=0;i[E+68>>2]=0;v=0;r=0;q=1;while(1){A=q<<2;q=q+1|0;A=i[A+E>>2];v=A+v<<1;i[(E- -64|0)+(q<<2)>>2]=v;r=r+A|0;if((q|0)!=16){continue}break}if(!((v|0)==65536|r>>>0<2)){q=D;break i}if(n){n=-1;F=0;K=o(J,3488)+a|0;while(1){y=j[(F+K|0)- -64|0];Za:{if(!y){break Za}r=(E- -64|0)+(y<<2)|0;q=i[r>>2];i[r>>2]=q+1;r=0;v=y;while(1){A=r;r=q&1|r<<1;q=q>>>1|0;v=v+ -1|0;if(v){continue}break}if(y>>>0<=10){if(r>>>0>1023){break Za}q=y<<9|F;v=1<<y;while(1){h[((r<<1)+K|0)+352>>1]=q;r=r+v|0;if(r>>>0<1024){continue}break}break Za}r=((r&1023)<<1)+K|0;q=h[r+352>>1];_a:{if(q){r=n;n=q;break _a}h[r+352>>1]=n;r=n+ -2|0}q=A>>>8&8388607;if(y>>>0>=12){while(1){q=q>>>1|0;v=(((q&1)+(n^-1)<<1)+K|0)+2400|0;n=h[v>>1];if(!n){h[v>>1]=r;n=r;r=n+ -2|0}y=y+ -1|0;if(y>>>0>11){continue}break}}h[(((q>>>1&1)+(n^-1)<<1)+K|0)+2400>>1]=F;n=r}F=F+1|0;y=i[a+24>>2];if(F>>>0<l[((y<<2)+a|0)+44>>2]){continue}break}}q=0;if((y|0)!=2){break Ra}break Va;case 1:n=h[(((t&1023)<<1)+a|0)+7328>>1];$a:{if((n|0)>=0){if((n>>9)+ -1>>>0>=p>>>0){break $a}break Ua}if(p>>>0<11){break $a}r=10;while(1){n=h[(((t>>>r&1)+(n^-1)<<1)+a|0)+9376>>1];if((n|0)<=-1){v=r+2|0;r=r+1|0;if(p>>>0>=v>>>0){continue}}break}if((n|0)>-1){break Ua}}n=11;continue P;case 2:r=h[(((t&1023)<<1)+a|0)+7328>>1];if((r|0)>=0){break Xa}n=10;while(1){v=t>>>n|0;n=n+1|0;r=h[(((v&1)+(r^-1)<<1)+a|0)+9376>>1];if((r|0)<0){continue}break}break Wa;default:break Ya}}n=g[O+42356|0]+((-1<<z^-1)&t)|0;p=p-z|0;t=t>>>z|0;r=a+q|0;yb(r+10532|0,(C|0)==16?j[r+10531|0]:0,n);q=n+q|0;break Va}n=r>>9;r=r&511}p=p-n|0;t=t>>>n|0;C=r;if(r>>>0>15){break Ta}g[(a+q|0)+10532|0]=C;q=q+1|0}r=i[a+48>>2];n=i[a+44>>2];v=r+n|0;if(q>>>0>=v>>>0){break Sa}if(p>>>0>14){break Ua}if((B-s|0)<=1){n=1;continue}t=j[s|0]<<p|t|j[s+1|0]<<p+8;p=p+16|0;s=s+2|0}n=2;continue}if(!((C|0)!=16|q)){C=16;q=0;break j}O=C+ -16|0;z=g[O+42352|0];if(p>>>0>=z>>>0){break Qa}n=12;continue P}if((q|0)!=(v|0)){break k}D=a+10532|0;Tb(a- -64|0,D,n);Tb(a+3552|0,n+D|0,r);y=i[a+24>>2];D=q}J=y+ -1|0;i[a+24>>2]=J;n=0;continue}n=3;continue}}n=2}ab:while(1){bb:{cb:{db:{eb:{fb:{gb:{hb:{ib:{jb:{kb:{lb:{mb:{nb:{ob:{pb:{switch(n|0){case 0:n=h[(((t&1023)<<1)+a|0)+352>>1];qb:{if((n|0)>=0){if((n>>9)+ -1>>>0>=p>>>0){break qb}break bb}if(p>>>0<11){break qb}r=10;while(1){n=h[(((t>>>r&1)+(n^-1)<<1)+a|0)+2400>>1];if((n|0)<=-1){v=r+2|0;r=r+1|0;if(p>>>0>=v>>>0){continue}}break}if((n|0)>-1){break bb}}n=13;continue P;case 1:r=h[(((t&1023)<<1)+a|0)+352>>1];if((r|0)>=0){break ob}n=10;while(1){q=t>>>n|0;n=n+1|0;r=h[(((q&1)+(r^-1)<<1)+a|0)+2400>>1];if((r|0)<0){continue}break}q=r;break nb;case 3:break eb;case 4:break fb;case 5:break jb;case 6:break kb;case 2:break pb;default:break lb}}while(1){n=B-s|0;if(!((G-w|0)>1?(n|0)>=4:0)){if(p>>>0>14){t=u;break bb}if((n|0)<=1){t=u;n=0;continue ab}t=j[s|0]<<p|u|j[s+1|0]<<p+8;p=p+16|0;s=s+2|0;break bb}rb:{if(p>>>0>14){t=p;n=s;break rb}t=p+16|0;u=(j[s|0]|j[s+1|0]<<8)<<p|u;n=s+2|0}q=h[(((u&1023)<<1)+a|0)+352>>1];sb:{if((q|0)<0){s=10;while(1){p=u>>>s|0;s=s+1|0;q=h[(((p&1)+(q^-1)<<1)+a|0)+2400>>1];if((q|0)<0){continue}break}break sb}s=q>>9}p=t-s|0;t=u>>>s|0;if(q&256){s=n;break mb}if(p>>>0>14){r=p}else{t=(j[n|0]|j[n+1|0]<<8)<<p|t;n=n+2|0;r=p+16|0}s=n;n=h[(((t&1023)<<1)+a|0)+352>>1];tb:{if((n|0)<0){u=10;while(1){p=t>>>u|0;u=u+1|0;n=h[(((p&1)+(n^-1)<<1)+a|0)+2400>>1];if((n|0)<0){continue}break}break tb}u=n>>9}g[w|0]=q;p=r-u|0;u=t>>>u|0;if(!(n&256)){g[w+1|0]=n;w=w+2|0;continue}break}w=w+1|0;t=u;q=n;break mb}n=r>>9;q=r&511}p=p-n|0;t=t>>>n|0;if(q>>>0>255){break mb}n=14;continue P}D=256;r=q&511;if((r|0)==256){break Q}z=0;n=t;v=(r<<2)+ -1028|0;q=i[v+41824>>2];A=q;if(r+ -265>>>0>19){break db}z=i[v+41952>>2];if(p>>>0<z>>>0){n=15;continue P}n=3;continue}if(!q){u=t;q=-1;break hb}q=q+ -1|0;n=18;continue P}p=p-z|0;u=t>>>z|0;C=((-1<<z^-1)&t)+C|0;break ib}z=h[(((t&1023)<<1)+a|0)+3840>>1];ub:{if((z|0)<0){n=10;while(1){r=t>>>n|0;n=n+1|0;z=h[(((r&1)+(z^-1)<<1)+a|0)+5888>>1];if((z|0)<0){continue}break}r=z;break ub}n=z>>9;r=z&511}v=r<<2;C=i[v+42080>>2];p=p-n|0;t=t>>>n|0;z=0;if(r+ -4>>>0>25){u=t;break ib}z=i[v+42208>>2];if(p>>>0>=z>>>0){break gb}n=17;continue P}H=w-d|0;if(!(!N|H>>>0>=C>>>0)){t=u;break l}n=(H-C&M)+d|0;if((w>>>0>n>>>0?w:n)+q>>>0>G>>>0){t=u;n=7;continue}if(q>>>0>2){while(1){g[w|0]=j[n|0];g[w+1|0]=j[n+1|0];g[w+2|0]=j[n+2|0];n=n+3|0;w=w+3|0;q=q+ -3|0;if(q>>>0>2){continue}break}}if(!q){break hb}g[w|0]=j[n|0];if((q|0)!=1){g[w+1|0]=j[n+1|0]}w=q+w|0}n=2;continue}n=6;continue}n=h[(((t&1023)<<1)+a|0)+3840>>1];vb:{if((n|0)>=0){if((n>>9)+ -1>>>0>=p>>>0){break vb}break cb}if(p>>>0<11){break vb}r=10;while(1){n=h[(((t>>>r&1)+(n^-1)<<1)+a|0)+5888>>1];if((n|0)<=-1){v=r+2|0;r=r+1|0;if(p>>>0>=v>>>0){continue}}break}if((n|0)>-1){break cb}}n=16;continue P}p=p-z|0;n=t>>>z|0;A=((-1<<z^-1)&t)+q|0}q=A;t=n;if(p>>>0>14){break cb}if((B-s|0)<=1){n=4;continue}t=t|j[s|0]<<p|j[s+1|0]<<p+8;p=p+16|0;s=s+2|0}n=5;continue}n=1;continue}}if(n?q:0){break S}p=n}D=0;if(!q){break Q}n=5;continue}p=n;if(n>>>0>7){break R}n=6;continue}p=n+ -8|0;C=t&255;t=t>>>8|0;n=7;continue}if(g[a+20|0]&1){break o}n=0;continue}}u=p&-8;if(!(!u|s>>>0<=b>>>0)){q=u+ -8|0;d=q>>>3|0;n=(b^-1)+s|0;d=d>>>0<n>>>0?d:n;u=q-(d<<3)|0;s=(d^-1)+s|0}if(!u){t=((32<=(u&63)>>>0?0:-1<<u)^-1)&t>>>(p&7);v=0;n=0;q=D;p=0;if(!(m&1)){break m}u=0;break n}V(42360,41792,2787,42370);x()}while(1){wb:{xb:{yb:{zb:{Ab:{Bb:{switch(u|0){case 0:if(v>>>0>3){q=v;p=n;break m}p=0;if(n){break Ab}q=v;u=1;continue;case 1:break Bb;default:break zb}}if(s>>>0<B>>>0){break xb}i[a>>2]=42;r=m&2?1:-4;break d}q=v;p=n;if(n>>>0>7){break yb}u=2;continue}while(1){if(s>>>0>=B>>>0){i[a>>2]=41;r=m&2?1:-4;break d}t=j[s|0]<<p|t;u=p>>>0>4294967287;d=s+1|0;s=d;n=p+8|0;p=n;if(u){continue}break}s=d;v=q}u=t&255;t=t>>>8|0;n=n+ -8|0;break wb}u=j[s|0];s=s+1|0;v=q;n=p}i[a+16>>2]=i[a+16>>2]<<8|u;v=v+1|0;u=0;continue}}A=0;y=34;break f}y=37;A=-1;break f}y=21;A=-1;break f}y=17;A=-1;break f}y=35;A=-1;break f}y=10;A=-1;break f}y=39;A=-1}i[a>>2]=y;if(!(p>>>0<8|s>>>0<=b>>>0)){n=p+ -8|0;d=n>>>3|0;p=(b^-1)+s|0;d=d>>>0<p>>>0?d:p;s=(d^-1)+s|0;p=n-(d<<3)|0}r=A;break d}r=m&2?1:-4}i[a+4>>2]=p;i[a+60>>2]=H;i[a+40>>2]=z;i[a+36>>2]=q;i[a+32>>2]=C;i[a+56>>2]=((32<=(p&63)>>>0?0:-1<<p)^-1)&t;i[c>>2]=s-b;n=w-e|0;i[f>>2]=n;if(!(m&9)|(r|0)<0){break b}b=i[a+28>>2];p=b>>>16|0;t=b&65535;if(n){q=(n>>>0)%5552|0;while(1){s=0;if(q>>>0>7){while(1){b=j[e|0]+t|0;c=b+j[e+1|0]|0;d=c+j[e+2|0]|0;f=d+j[e+3|0]|0;u=f+j[e+4|0]|0;D=u+j[e+5|0]|0;v=D+j[e+6|0]|0;t=v+j[e+7|0]|0;p=t+(v+(D+(u+(f+(d+(c+(b+p|0)|0)|0)|0)|0)|0)|0)|0;e=e+8|0;s=s+8|0;if((s|7)>>>0<q>>>0){continue}break}s=q&8184}if(q>>>0>s>>>0){b=q-s|0;u=e;while(1){t=j[u|0]+t|0;p=t+p|0;u=u+1|0;s=s+1|0;if((s|0)!=(q|0)){continue}break}e=b+e|0}n=n-q|0;p=(p>>>0)%65521|0;t=(t>>>0)%65521|0;q=5552;if(n){continue}break}}b=p<<16|t;i[a+28>>2]=b;if(r){break b}r=0;if(m&1){break a}}Xa=L+144|0;return r}Xa=L+144|0;return i[a+16>>2]==(b|0)?0:-2}function dya(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,m=0,n=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,H=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,U=0,V=0,W=0,X=0,Y=0,Z=0;f=Xa-416|0;Xa=f;pc(b);t=f+208|0;e=Gxa(b,t);if(!e){_M(t)}a:{b:{c:{d:{e:{f:{g:{h:{i:{if(!e){break i}if(!dN(f+208|0)){break i}if(!c){d=1;break i}md(a,134217728);d=Bb(f+192|0,17344);i[114610]=0;D(219,f+144|0,d|0);t=i[114610];i[114610]=0;j:{k:{l:{m:{n:{o:{p:{q:{if((t|0)!=1){i[114610]=0;v=f+208|4;G(1005,f+16|0,f+144|0,v|0);t=i[114610];i[114610]=0;if((t|0)==1){break q}mb(a+1304436|0,f+16|0);eb(f+16|0);ob(f+144|0);eb(d);d=Bb(f+16|0,17368);mb(a+1304448|0,d);eb(d);i[a+480188>>2]=4;i[a+1304496>>2]=2;d=j[f+344|0]|j[f+345|0]<<8;i[a+480196>>2]=(d<<24|d<<8&16711680)>>>16;d=j[f+348|0]|j[f+349|0]<<8;i[a+480260>>2]=56;i[a+480264>>2]=13696;Y=a,Z=cN((d<<8&16711680|d<<24)>>>16|0),i[Y+480204>>2]=Z;fn(Db(a+484360|0),f+216|0,j[f+208|6],65535,65535);z=a+480190|0;w=f+176|0;Sxa(w);y=mn(f+160|0);if(j[f+408|0]|j[f+409|0]<<8){break o}break n}a=B()|0;A()|0;break p}a=B()|0;A()|0;ob(f+144|0)}eb(d);break a}t=0;while(1){i[114610]=0;d=F(484,b|0)|0;e=i[114610];i[114610]=0;if((e|0)==1){break e}h[f+120>>1]=d;if((d+ -1&65535)>>>0>3998){break k}d=j[f+410|0]|j[f+411|0]<<8;d=(d<<8&16711680|d<<24)>>>16|0;r:{if((j[v|0]|j[v+1|0]<<8)!=512){break r}i[114610]=0;d=F(494,b|0)|0;e=i[114610];i[114610]=0;if((e|0)==1){break f}d=d+ -2|0}i[114610]=0;G(341,f+144|0,b|0,d|0);d=i[114610];i[114610]=0;s:{t:{u:{if((d|0)!=1){i[114610]=0;d=C(452,z|0,f+120|0)|0;e=i[114610];i[114610]=0;if((e|0)==1){break u}K=k[d>>1];h[a+480190>>1]=K;i[114610]=0;d=o(k[f+120>>1],104)+a|0;u=d+484380|0;D(386,u|0,1);e=i[114610];i[114610]=0;v:{if((e|0)==1){break v}e=j[v|0]|j[v+1|0]<<8;if((e<<24|e<<8&16711680)>>>16>>>0>1){break t}i[114610]=0;I(1006,f+144|0,d+484423|0,31)|0;e=i[114610];i[114610]=0;if((e|0)==1){break v}i[114610]=0;C(338,f+144|0,1)|0;e=i[114610];i[114610]=0;if((e|0)==1){break v}i[114610]=0;I(388,f+144|0,((k[f+120>>1]<<5)+a|0)+946300|0,30)|0;e=i[114610];i[114610]=0;if((e|0)!=1){break s}}a=B()|0;A()|0;break c}a=B()|0;A()|0;break b}a=B()|0;A()|0;break c}e=Ab(f+16|0);i[114610]=0;I(600,f+144|0,e|0,257)|0;q=i[114610];i[114610]=0;w:{x:{if((q|0)==1){break x}i[114610]=0;C(370,d+484423|0,e|0)|0;q=i[114610];i[114610]=0;if((q|0)==1){break x}i[114610]=0;C(338,f+144|0,1)|0;q=i[114610];i[114610]=0;if((q|0)==1){break x}i[114610]=0;I(600,f+144|0,e|0,31)|0;q=i[114610];i[114610]=0;if((q|0)==1){break x}i[114610]=0;C(369,((k[f+120>>1]<<5)+a|0)+946300|0,e|0)|0;q=i[114610];i[114610]=0;if((q|0)==1){break x}if(!(i[f+152>>2]&1)){break w}i[114610]=0;C(338,f+144|0,1)|0;q=i[114610];i[114610]=0;if((q|0)!=1){break w}}a=B()|0;A()|0;eb(e);break c}eb(e)}i[114610]=0;C(1007,f+144|0,f+16|0)|0;e=i[114610];i[114610]=0;if((e|0)==1){break m}i[114610]=0;D(1008,f+16|0,u|0);e=i[114610];i[114610]=0;if((e|0)==1){break m}if((j[v|0]|j[v+1|0]<<8)==512){g[d+484417|0]=j[f+34|0]<<3}y:{if(!(j[v|0]|j[v+1|0]<<8)){break y}i[114610]=0;D(384,y|0,K|0);e=i[114610];i[114610]=0;if((e|0)==1){break m}i[114610]=0;D(1009,w|0,K|0);e=i[114610];i[114610]=0;if((e|0)==1){break m}e=Yc(w,k[f+120>>1]+ -1|0);cc(e);aN(e);os(e);i[114610]=0;u=F(484,b|0)|0;q=i[114610];i[114610]=0;if((q|0)==1){break g}i[114610]=0;D(1010,e|0,u|0);q=i[114610];i[114610]=0;if((q|0)==1){break g}m=0;i[f+136>>2]=0;if(!u){if(!(j[d+484414|0]&2)){break y}u=i[d+484384>>2];i[f+128>>2]=u;d=i[d+484388>>2];i[114610]=0;i[f+132>>2]=d-u;D(1011,e|0,f+128|0);d=i[114610];i[114610]=0;if((d|0)!=1){break y}a=B()|0;A()|0;break c}while(1){i[114610]=0;d=F(494,b|0)|0;q=i[114610];i[114610]=0;if((q|0)==1){break h}i[114610]=0;i[f+128>>2]=d;d=F(494,b|0)|0;q=i[114610];i[114610]=0;if((q|0)==1){break h}i[114610]=0;i[f+132>>2]=d;D(1011,e|0,f+128|0);d=i[114610];i[114610]=0;if((d|0)==1){break h}m=m+1|0;if((m&65535)>>>0<u>>>0){continue}break}}hb(f+144|0);t=t+1|0;d=j[f+408|0]|j[f+409|0]<<8;if((t&65535)>>>0<(d<<24|d<<8&16711680)>>>16>>>0){continue}break}}L=128;if(j[v|0]|j[v+1|0]<<8){break l}i[114610]=0;L=F(484,b|0)|0;d=i[114610];i[114610]=0;if((d|0)!=1){break l}a=B()|0;A()|0;break b}a=B()|0;A()|0;break c}t=a+480188|0;M=j[f+208|7];h[f+126>>1]=4;z:{A:{B:{if(!(j[v|0]|j[v+1|0]<<8)){m=k[t>>1];break B}e=i[b+8>>2];C:{if(!L){break C}d=0;while(1){i[114610]=0;u=F(484,b|0)|0;q=i[114610];i[114610]=0;if((q|0)==1){break A}if((u|0)==65535){break C}i[114610]=0;M=F(484,b|0)|0;u=i[114610];i[114610]=0;if((u|0)==1){break A}i[114610]=0;u=F(484,b|0)|0;q=i[114610];i[114610]=0;if((q|0)==1){break A}i[114610]=0;h[f+126>>1]=u;u=C(452,t|0,f+126|0)|0;q=i[114610];i[114610]=0;if((q|0)==1){break A}h[t>>1]=k[u>>1];i[114610]=0;C(338,b|0,o(k[f+126>>1],M)<<2)|0;u=i[114610];i[114610]=0;if((u|0)==1){break A}d=d+1|0;if((d&65535)>>>0<L>>>0){continue}break}}d=0;i[114610]=0;C(256,b|0,e|0)|0;e=i[114610];i[114610]=0;if((e|0)==1){break z}m=k[t>>1];if(m>>>0>127){break j}}i[114610]=0;P=C(1012,f+144|0,m&65535)|0;d=i[114610];i[114610]=0;if((d|0)!=1){D:{if(!L){break D}U=a+484344|0;X=c&1;Q=j[f+347|0];t=0;u=0;while(1){d=u;if(j[v|0]|j[v+1|0]<<8){i[114610]=0;d=F(484,b|0)|0;e=i[114610];i[114610]=0;if((e|0)==1){break d}if((d|0)==65535){break D}i[114610]=0;M=F(484,b|0)|0;e=i[114610];i[114610]=0;if((e|0)==1){break d}i[114610]=0;e=F(484,b|0)|0;q=i[114610];i[114610]=0;if((q|0)==1){break d}h[f+126>>1]=e}N=M&65535;E:{F:{if(!X){break F}i[114610]=0;V=d&65535;d=I(402,U|0,V|0,N|0)|0;e=i[114610];i[114610]=0;if((e|0)==1){break d}if(!d){break F}if(!N){break E}H=0;while(1){d=Fb(U,V);i[114610]=0;r=C(497,d|0,H|0)|0;d=i[114610];i[114610]=0;G:{if((d|0)!=1){m=0;J=0;H:{I:{switch((Q&3)+ -1|0){case 0:J=!(H&3);break H;case 1:J=!(H&1);break H;case 2:break I;default:break H}}J=(H&3)!=3}R=0;if(!k[f+126>>1]){break G}while(1){d=i[P>>2];i[114610]=0;D(598,f+128|0,b|0);e=i[114610];i[114610]=0;if((e|0)==1){break d}p=o(m,9)+d|0;d=Nc(f+128|0);q=yf(f+128|0);n=li(f+128|0);s=o(m,6)+r|0;g[s+1|0]=j[f+128|0];e=j[d|0];g[s|0]=e;d=j[n|0];g[s+5|0]=d;n=s+5|0;if(e){g[s|0]=e+25;g[p+8|0]=0;g[p|0]=0;g[p+1|0]=0;g[p+2|0]=0;g[p+3|0]=0;g[p+4|0]=0;g[p+5|0]=0;g[p+6|0]=0;g[p+7|0]=0;d=j[n|0]}e=d;S=j[q|0];J:{if(S>>>0>=240){d=e|(S&15)<<8;if(d){d=cN(d);i[114610]=0;d=la(1013,+(+(d>>>0)*1e-4))|0;e=i[114610];i[114610]=0;if((e|0)!=1){g[n|0]=d;g[s+3|0]=17;break J}break d}g[s+3|0]=0;break J}O=e>>>4|0;W=e<<4;q=O|W;K:{switch(S|0){case 0:e=o(m,6)+r|0;if(d){g[e+3|0]=1;break J}g[e+3|0]=0;break J;case 1:g[(o(m,6)+r|0)+3|0]=2;break J;case 2:g[(o(m,6)+r|0)+3|0]=3;break J;case 3:i[114610]=0;g[f+16|0]=15;d=C(391,n|0,f+16|0)|0;e=i[114610];i[114610]=0;if((e|0)!=1){g[p|0]=j[d|0]|16;g[p+7|0]=0;g[p+1|0]=0;g[p+2|0]=0;g[(o(m,6)+r|0)+3|0]=0;break J}break d;case 4:i[114610]=0;g[f+16|0]=15;d=C(391,n|0,f+16|0)|0;e=i[114610];i[114610]=0;if((e|0)!=1){g[p|0]=j[d|0]|32;g[p+7|0]=0;g[p+1|0]=0;g[p+2|0]=0;g[(o(m,6)+r|0)+3|0]=0;break J}break d;case 5:g[p+7|0]=0;g[p+2|0]=0;g[p+1|0]=d;g[p|0]=0;g[(o(m,6)+r|0)+3|0]=0;break J;case 6:g[p+7|0]=0;g[p+2|0]=d;g[p|0]=0;g[p+1|0]=0;g[(o(m,6)+r|0)+3|0]=0;break J;case 7:g[(o(m,6)+r|0)+3|0]=23;t=0;break J;case 8:g[(o(m,6)+r|0)+3|0]=0;t=q;break J;case 9:g[(o(m,6)+r|0)+3|0]=19;i[114610]=0;g[f+16|0]=15;d=C(391,n|0,f+16|0)|0;e=i[114610];i[114610]=0;if((e|0)!=1){g[n|0]=j[d|0]|16;break J}break d;case 10:g[(o(m,6)+r|0)+3|0]=19;i[114610]=0;g[f+16|0]=15;d=C(391,n|0,f+16|0)|0;e=i[114610];i[114610]=0;if((e|0)!=1){g[n|0]=j[d|0]|32;break J}break d;case 11:g[p+3|0]=q;g[(o(m,6)+r|0)+3|0]=0;break J;case 12:e=o(m,6)+r|0;g[e+4|0]=d;g[e+2|0]=1;g[p+3|0]=0;g[e+3|0]=0;break J;case 13:q=o(m,6)+r|0;L:{M:{if(e&240){g[(o(m,6)+r|0)+2|0]=4;d=(d&240)>>>4|0;break M}if(!(e&15)){break L}g[(o(m,6)+r|0)+2|0]=3;d=d&15}g[q+4|0]=d}g[p+3|0]=0;g[(o(m,6)+r|0)+3|0]=0;break J;case 14:g[(o(m,6)+r|0)+3|0]=19;g[n|0]=!d;break J;case 15:g[(o(m,6)+r|0)+3|0]=16;g[n|0]=(d&240)>>>4;Q=d&15;break J;case 16:g[p+5|0]=0;g[p+4|0]=d;g[(o(m,6)+r|0)+3|0]=0;break J;case 17:g[p+6|0]=e&15?d:0;g[(o(m,6)+r|0)+3|0]=0;break J;case 18:g[(o(m,6)+r|0)+3|0]=14;break J;case 19:g[p+8|0]=0;g[p+7|0]=d;g[p+2|0]=0;g[p|0]=0;g[p+1|0]=0;g[(o(m,6)+r|0)+3|0]=0;break J;case 20:g[(o(m,6)+r|0)+3|0]=12;break J;case 22:N:{d=j[s+1|0];O:{if(!d){break O}if(cc(w)>>>0<d>>>0){break O}d=Yc(w,j[s+1|0]+ -1|0);e=j[n|0]+ -1|0;g[n|0]=e;i[114610]=0;C(1014,f+16|0,0)|0;q=i[114610];i[114610]=0;if((q|0)==1){break d}i[f+120>>2]=9;d=cc(d);i[114610]=0;i[f+12>>2]=d;d=C(33,f+120|0,f+12|0)|0;q=i[114610];i[114610]=0;if((q|0)==1){break N}if(l[d>>2]<=(e&255)>>>0){break O}d=o(m,6)+r|0;g[d+2|0]=15;g[d+4|0]=j[n|0]}g[(o(m,6)+r|0)+3|0]=0;break J}break d;case 23:d=j[s+1|0];P:{if(!d){break P}if(cc(w)>>>0<d>>>0){break P}d=Yc(w,j[s+1|0]+ -1|0);e=j[n|0]+ -1|0;g[n|0]=e;if(cc(d)>>>0<=(e&255)>>>0){break P}Q:{if(k[Yc(d,j[n|0])+8>>1]){break Q}if(!bn(a)){break Q}e=k[z>>1]+1|0;h[z>>1]=e;Y=Yc(d,j[n|0]),Z=e,h[Y+8>>1]=Z}Y=s,Z=j[Yc(d,j[n|0])+8|0],g[Y+1|0]=Z}g[(o(m,6)+r|0)+3|0]=0;break J;case 24:R:{d=j[s+1|0];S:{if(!d){break S}if(cc(w)>>>0<d>>>0){break S}d=Yc(w,j[s+1|0]+ -1|0);e=j[n|0]+ -1|0;g[n|0]=e;i[114610]=0;C(1014,f+16|0,0)|0;q=i[114610];i[114610]=0;if((q|0)==1){break d}i[f+120>>2]=9;d=cc(d);i[114610]=0;i[f+12>>2]=d;d=C(33,f+120|0,f+12|0)|0;q=i[114610];i[114610]=0;if((q|0)==1){break R}if(l[d>>2]>(e&255)>>>0){d=o(m,6)+r|0;g[d+2|0]=15;g[d+4|0]=j[n|0]}T:{if(k[$b(y,j[s+1|0]+ -1|0)>>1]){break T}if(!bn(a)){break T}d=k[z>>1]+1|0;h[z>>1]=d;Y=$b(y,j[s+1|0]+ -1|0),Z=d,h[Y>>1]=Z}Y=s,Z=j[$b(y,j[s+1|0]+ -1|0)|0],g[Y+1|0]=Z}g[(o(m,6)+r|0)+3|0]=0;break J}break d;case 25:d=j[s+1|0];U:{if(!d){break U}if(cc(w)>>>0<d>>>0){break U}d=Yc(w,j[s+1|0]+ -1|0);e=j[n|0]+ -1|0;g[n|0]=e;if(cc(d)>>>0<=(e&255)>>>0){break U}V:{if(k[Yc(d,j[n|0])+10>>1]){break V}if(!bn(a)){break V}e=k[z>>1]+1|0;h[z>>1]=e;Y=Yc(d,j[n|0]),Z=e,h[Y+10>>1]=Z}Y=s,Z=j[Yc(d,j[n|0])+10|0],g[Y+1|0]=Z}g[(o(m,6)+r|0)+3|0]=0;break J;case 29:g[(o(m,6)+r|0)+3|0]=11;g[n|0]=q;if(e&15){g[n|0]=W|15;break J}if(!O){break J}g[n|0]=O|240;break J;case 32:if(e&240){g[p+3|0]=O;g[(o(m,6)+r|0)+3|0]=0;break J}g[(o(m,6)+r|0)+3|0]=19;g[n|0]=d&15|192;break J;case 33:g[(o(m,6)+r|0)+3|0]=19;i[114610]=0;g[f+16|0]=15;d=C(391,n|0,f+16|0)|0;e=i[114610];i[114610]=0;if((e|0)!=1){g[n|0]=j[d|0]|208;break J}break d;case 34:g[(o(m,6)+r|0)+3|0]=19;i[114610]=0;g[f+16|0]=15;d=C(391,n|0,f+16|0)|0;e=i[114610];i[114610]=0;if((e|0)!=1){g[n|0]=j[d|0]|144;break J}break d;case 73:g[(o(m,6)+r|0)+3|0]=10;break J;case 78:if((d&112|128)==224){g[(o(m,6)+r|0)+3|0]=19;break J}g[(o(m,6)+r|0)+3|0]=0;break J;case 79:e=o(m,6)+r|0;if(d>>>0<=31){g[e+3|0]=16;Q=0;break J}g[e+3|0]=17;break J;default:break K}}g[(o(m,6)+r|0)+3|0]=0}d=0;e=j[p+3|0];if(!(j[s+2|0]|!e)){W:{if(e>>>0>=16){g[s+2|0]=5;g[s+4|0]=e>>>4;break W}g[s+2|0]=6;g[s+4|0]=e}d=1}X:{if(j[s+3|0]){break X}e=j[p+1|0];if(e){g[s+3|0]=2;g[n|0]=e;break X}e=j[p+2|0];if(e){g[s+3|0]=3;g[n|0]=e;break X}e=j[p|0];if(e){g[s+3|0]=19;g[n|0]=e;break X}e=j[p+7|0];if(e){g[s+3|0]=4;g[p+8|0]=e;g[n|0]=e;break X}e=j[p+4|0];if(e){g[s+3|0]=5;g[p+5|0]=e;g[n|0]=e;break X}e=d;d=j[p+3|0];if(!(e|!d)){g[s+3|0]=11;g[n|0]=d;if(d&15){g[n|0]=d|240;break X}if(!(d&240)){break X}g[n|0]=d|15;break X}d=j[p+6|0];if(d){g[s+3|0]=8;g[n|0]=d;break X}if(J){g[s+3|0]=20;g[n|0]=97;J=0;break X}J=0;d=t&255;if(!d|!(R^1)){break X}g[s+3|0]=24;g[n|0]=t;if(t&15){g[n|0]=t|240;R=1;break X}R=1;if(!(d&240)){break X}g[n|0]=t|15}m=m+1|0;if(m>>>0<k[f+126>>1]){continue}break}break G}break d}H=H+1|0;if((N|0)!=(H|0)){continue}break}break E}i[114610]=0;C(338,b|0,o(k[f+126>>1],N)<<2)|0;d=i[114610];i[114610]=0;if((d|0)!=1){break E}break d}u=u+1|0;if((u&65535)>>>0<L>>>0){continue}break}}i[a+480228>>2]=256/k[a+480188>>1];i[114610]=0;D(449,a|0,1);d=i[114610];i[114610]=0;if((d|0)==1){break d}if(j[v|0]|j[v+1|0]<<8){Y:{while(1){i[114610]=0;d=C(258,b|0,2)|0;t=i[114610];i[114610]=0;if((t|0)==1){break d}if(!d){break Y}i[114610]=0;d=F(484,b|0)|0;t=i[114610];i[114610]=0;if((t|0)==1){break d}if((d|0)==65535){break Y}i[114610]=0;C(338,b|0,2)|0;d=i[114610];i[114610]=0;if((d|0)==1){break d}i[114610]=0;d=F(494,b|0)|0;t=i[114610];i[114610]=0;if((t|0)!=1){i[114610]=0;C(338,b|0,d|0)|0;d=i[114610];i[114610]=0;if((d|0)!=1){continue}}break}break d}i[114610]=0;C(338,b|0,34)|0;d=i[114610];i[114610]=0;if((d|0)==1){break d}}Z:{if(!(!(c&2)|!K)){d=1;t=1;while(1){c=(o(d,104)+a|0)+484380|0;_:{if(!i[c>>2]){break _}e=Ic(f+16|0,8,1,0,0);i[114610]=0;I(400,e|0,c|0,b|0)|0;e=i[114610];i[114610]=0;if((e|0)==1){break Z}if(cc(w)>>>0<d>>>0){break _}d=d+ -1|0;e=Yc(w,d);i[114610]=0;D(1015,c|0,e|0);e=i[114610];i[114610]=0;$:{if((e|0)!=1){if(!k[$b(y,d)>>1]){break $}e=k[$b(y,d)>>1];u=i[c>>2];i[114610]=0;T(1016,c|0,(o(e,104)+a|0)+484380|0,0,u|0,0);e=i[114610];i[114610]=0;if((e|0)!=1){break $}}break d}d=Yc(w,d);Y=f,Z=Jb(d),i[Y+16>>2]=Z;Y=f,Z=Kb(d),i[Y+128>>2]=Z;if(!pb(f+16|0,f+128|0)){break _}while(1){d=i[f+16>>2];e=k[d+8>>1];if(e){u=i[d+4>>2];q=i[d>>2];i[114610]=0;T(1016,c|0,(o(e,104)+a|0)+484380|0,q|0,u|0,1);e=i[114610];i[114610]=0;if((e|0)==1){break d}}e=k[d+10>>1];if(e){u=i[d+4>>2];d=i[d>>2];i[114610]=0;T(1016,c|0,(o(e,104)+a|0)+484380|0,d|0,u|0,0);d=i[114610];i[114610]=0;if((d|0)==1){break d}}_m(f+16|0);if(pb(f+16|0,f+128|0)){continue}break}}t=t+1|0;d=t&65535;if(d>>>0<=K>>>0){continue}break}}Zx(P);d=1;break j}break d}a=B()|0;A()|0;break b}a=B()|0;A()|0;break b}a=B()|0;A()|0;break b}d=0}df(y);bN(w)}Xa=f+416|0;return d|0}a=B()|0;A()|0;break c}a=B()|0;A()|0;break c}a=B()|0;A()|0;break b}a=B()|0;A()|0;break b}a=B()|0;A()|0;Zx(P);break b}hb(f+144|0)}df(y);bN(w)}E(a|0);x()}function v5(a){var b=0,c=0,d=0,e=0,f=0,n=0,q=0,r=0,s=0,t=0,u=0,v=0,w=p(0),y=0,z=p(0),A=0,B=0,C=0,D=p(0);t=Xa-1024|0;Xa=t;g[a+1377|0]=1;a:{if(!Rq(a)){break a}c=j[a+1375|0];if(!(c&2)){Lb(a,34);break a}if(c&4){Lb(a,34);break a}if(c&1){Lb(a,34);break a}if(i[a+1116>>2]!=1){Lb(a,34);break a}c=j[a+1120|0];if((c|0)!=30){b:{if((c|0)!=64){break b}if(!zv(a,t+1018|0,6)|j[t+1018|0]!=102|(j[t+1019|0]!=105|j[t+1020|0]!=115)){break b}if(j[t+1021|0]!=104|j[t+1022|0]!=101|j[t+1023|0]!=97){break b}if((fe(a)|0)!=100){break b}if(fe(a)){break b}Lb(a,38);break a}Lb(a,34);break a}if((fe(a)|0)!=1){Lb(a,34);break a}if(!zv(a,t+1018|0,6)){Lb(a,10);break a}if(!yv(t+1018|0)){Lb(a,34);break a}if(Kh(a)){Lb(a,34);break a}c=fe(a);i[a+4>>2]=c;if(!c){Lb(a,34);break a}if(c>>>0>=17){Lb(a,5);break a}c=Kh(a);i[a>>2]=c;if(!c){Lb(a,34);break a}Kh(a);Kh(a);Kh(a);c=fe(a);f=c>>>4|0;i[a+116>>2]=1<<f;d=c&15;i[a+112>>2]=1<<d;if(d+ -6>>>0>=8){Lb(a,20);break a}if((c<<24)+ -1610612736>>24<=-1){Lb(a,20);break a}if(d>>>0>f>>>0){Lb(a,20);break a}if(!(fe(a)&1)){Lb(a,34);break a}if(!Rq(a)){break a}if(!xv(a)){break a}if(!wv(a)){break a}c:{d:{if((lg(a)|0)==3){while(1){B=(t+1018|0)+b|0,C=lg(a),g[B|0]=C;b=b+1|0;if((b|0)!=6){continue}break}if(!yv(t+1018|0)){Lb(a,20);break c}d=vv(a);c=yd(a,d+1|0);i[a+20>>2]=c;if(c){b=0;if((d|0)>0){while(1){c=lg(a);g[i[a+20>>2]+b|0]=c;b=b+1|0;if((d|0)!=(b|0)){continue}break}c=i[a+20>>2]}g[c+d|0]=0;b=vv(a);i[a+24>>2]=b;b=yd(a,b<<2);i[a+28>>2]=b;if(b){e:{if(i[a+24>>2]>0){while(1){d=vv(a);b=yd(a,d+1|0);f=e<<2;i[f+i[a+28>>2]>>2]=b;c=i[f+i[a+28>>2]>>2];if(!c){break e}b=0;if((d|0)>0){while(1){c=lg(a);g[i[f+i[a+28>>2]>>2]+b|0]=c;b=b+1|0;if((d|0)!=(b|0)){continue}break}c=i[f+i[a+28>>2]>>2]}g[c+d|0]=0;e=e+1|0;if((e|0)<i[a+24>>2]){continue}break}}if(!(lg(a)&1)){Lb(a,20);break c}YE(a,j[a+1376|0]);g[a+1376|0]=0;while(1){b=wv(a);YE(a,b);g[a+1376|0]=0;if(b){continue}break}b=0;if(!xv(a)){break a}if(!ZE(a)){if(i[a+100>>2]!=21){break a}i[a+100>>2]=20;break a}u5();if((lg(a)|0)==5){while(1){B=(t+1018|0)+b|0,C=lg(a),g[B|0]=C;b=b+1|0;if((b|0)!=6){continue}break}if(!yv(t+1018|0)){Lb(a,20);break c}b=Rb(a,8)+1|0;i[a+120>>2]=b;b=yd(a,o(b,2096));i[a+124>>2]=b;if(!b){Lb(a,3);break c}yb(b,0,o(i[a+120>>2],2096));f:{g:{if(i[a+120>>2]>=1){while(1){b=i[a+124>>2];if((Rb(a,8)&255)!=66){Lb(a,20);break c}if((Rb(a,8)&255)!=67){Lb(a,20);break c}if((Rb(a,8)&255)!=86){Lb(a,20);break c}d=b+o(v,2096)|0;B=d,C=Rb(a,8)&255|Rb(a,8)<<8,i[B>>2]=C;b=Rb(a,8);B=d,C=Rb(a,8)<<8&65280|b&255|Rb(a,8)<<16,i[B+4>>2]=C;b=0;r=d+4|0;e=Rb(a,1);if(!e){b=Rb(a,1)}g[d+23|0]=b;if(!(i[d>>2]|!i[r>>2])){Lb(a,20);break c}c=i[r>>2];h:{if(b&255){c=fm(a,c);break h}c=yd(a,c);i[d+8>>2]=c}if(!c){Lb(a,3);break c}i:{if(!e){b=0;u=0;e=i[r>>2];if((e|0)<=0){break i}while(1){j:{k:{if(j[d+23|0]){if(!Rb(a,1)){break k}}e=Rb(a,5)+1|0;g[b+c|0]=e;if((e&255)!=32){u=u+1|0;break j}Lb(a,20);break c}g[b+c|0]=255}b=b+1|0;e=i[r>>2];if((b|0)<(e|0)){continue}break}break i}n=Rb(a,5);u=0;b=0;e=i[r>>2];if((e|0)<1){break i}while(1){e=Rb(a,Pk(e-b|0));n=n+1|0;if((n|0)>=32){Lb(a,20);break c}f=b+e|0;if((f|0)>i[r>>2]){Lb(a,20);break c}yb(b+c|0,n,e);e=i[r>>2];b=f;if((e|0)>(b|0)){continue}break}}l:{m:{if(j[d+23|0]){if((u|0)<e>>2){break m}b=d;f=a;if((e|0)>i[a+16>>2]){i[a+16>>2]=e;e=i[r>>2]}y=b;b=yd(f,e);i[y+8>>2]=b;if(!b){Lb(a,3);break c}Tb(b,c,i[r>>2]);Jh(a,c,i[r>>2]);c=i[d+8>>2];g[d+23|0]=0}n=0;b=0;e=0;f=i[r>>2];if((f|0)>=1){while(1){e=((j[b+c|0]+ -11&255)>>>0<244)+e|0;b=b+1|0;if((f|0)!=(b|0)){continue}break}}i[d+2092>>2]=e;b=yd(a,f<<2);i[d+32>>2]=b;if(b){q=d+2092|0;break l}Lb(a,3);break c}i[d+2092>>2]=u;q=d+2092|0;n:{if(!u){n=0;break n}b=yd(a,u);i[d+8>>2]=b;if(!b){Lb(a,3);break c}b=fm(a,i[q>>2]<<2);i[d+32>>2]=b;if(!b){Lb(a,3);break c}n=fm(a,i[q>>2]<<2);if(n){break n}Lb(a,3);break c}b=i[r>>2]+(i[q>>2]<<3)|0;if(b>>>0<=l[a+16>>2]){break l}i[a+16>>2]=b}if(!t5(d,c,i[r>>2],n)){if(j[d+23|0]){Jh(a,n,0)}Lb(a,20);break c}b=i[q>>2];if(b){b=yd(a,(b<<2)+4|0);i[d+2084>>2]=b;if(!b){Lb(a,3);break c}b=yd(a,(i[q>>2]<<2)+4|0);i[d+2088>>2]=b;if(!b){Lb(a,3);break c}i[d+2088>>2]=b+4;i[b>>2]=-1;r5(d,c,n)}if(j[d+23|0]){Jh(a,n,i[q>>2]<<2);Jh(a,i[d+32>>2],i[q>>2]<<2);Jh(a,c,i[r>>2]);i[d+32>>2]=0}q5(d);b=Rb(a,4);g[d+21|0]=b;b=b&255;if(b>>>0>=3){Lb(a,20);break c}if(b){B=d,D=XE(Rb(a,32)),m[B+12>>2]=D;B=d,D=XE(Rb(a,32)),m[B+16>>2]=D;B=d,C=Rb(a,4)+1|0,g[B+20|0]=C;B=d,C=Rb(a,1),g[B+22|0]=C;b=i[d>>2];c=i[r>>2];o:{if(j[d+21|0]==1){b=p5(c,b);if((b|0)>-1){break o}Lb(a,20);break c}b=o(b,c)}i[d+24>>2]=b;if(!b){Lb(a,20);break c}c=fm(a,b<<1);if(!c){break g}b=0;n=i[d+24>>2];if((n|0)>0){while(1){e=Rb(a,j[d+20|0]);if((e|0)==-1){Jh(a,c,i[d+24>>2]<<1);Lb(a,20);break c}h[c+(b<<1)>>1]=e;b=b+1|0;n=i[d+24>>2];if((b|0)<(n|0)){continue}break}}p:{if(j[d+21|0]==1){u=j[d+23|0];q:{if(u){b=i[q>>2];if(b){break q}break p}b=i[r>>2]}b=yd(a,o(i[d>>2],b)<<2);i[d+28>>2]=b;if(!b){Jh(a,c,i[d+24>>2]<<1);Lb(a,3);break c}A=i[(u?q:r)>>2];if((A|0)>=1){y=d+2088|0;w=p(0);f=0;while(1){q=u?i[i[y>>2]+(f<<2)>>2]:f;b=1;e=0;r:{n=i[d>>2];if((n|0)<1){break r}while(1){z=p(p(m[d+12>>2]+w)+p(m[d+16>>2]*p(k[c+(((q>>>0)/(b>>>0)>>>0)%l[d+24>>2]<<1)>>1])));m[i[d+28>>2]+(o(f,n)+e<<2)>>2]=z;w=j[d+22|0]?z:w;e=e+1|0;n=i[d>>2];if((e|0)>=(n|0)){break r}r=i[d+24>>2];XMa(r,0,b,0);if(!_a){b=o(b,r);continue}else{Jh(a,c,r<<1);Lb(a,20);break c}}}f=f+1|0;if((A|0)!=(f|0)){continue}break}}g[d+21|0]=2;n=i[d+24>>2];break p}b=yd(a,n<<2);i[d+28>>2]=b;n=i[d+24>>2];if(!b){break f}if((n|0)<1){break p}w=p(m[d+12>>2]+p(m[d+16>>2]*p(k[c>>1])));m[b>>2]=w;b=1;n=i[d+24>>2];if((n|0)<=1){break p}z=p(0);while(1){z=j[d+22|0]?w:z;w=p(p(m[d+12>>2]+z)+p(m[d+16>>2]*p(k[c+(b<<1)>>1])));m[i[d+28>>2]+(b<<2)>>2]=w;b=b+1|0;n=i[d+24>>2];if((b|0)<(n|0)){continue}break}}Jh(a,c,n<<1)}v=v+1|0;if((v|0)<i[a+120>>2]){continue}break}}s:{b=Rb(a,6)+1&255;if(!b){break s}while(1){if(!Rb(a,16)){s=s+1|0;if((b|0)!=(s|0)){continue}break s}break}Lb(a,20);break c}b=Rb(a,6)+1|0;i[a+128>>2]=b;b=yd(a,o(b,1596));i[a+260>>2]=b;t:{if(b){if(i[a+128>>2]>=1){break t}q=0;break d}Lb(a,3);break c}u=0;f=0;u:while(1){b=Rb(a,16);h[((u<<1)+a|0)+132>>1]=b;b=b&65535;if(b>>>0>=2){Lb(a,20);break c}if(!b){c=i[a+260>>2]+o(u,1596)|0;B=c,C=Rb(a,8),g[B|0]=C;B=c,C=Rb(a,16),h[B+2>>1]=C;B=c,C=Rb(a,16),h[B+4>>1]=C;B=c,C=Rb(a,6),g[B+6|0]=C;B=c,C=Rb(a,8),g[B+7|0]=C;b=(Rb(a,4)&255)+1|0;g[c+8|0]=b;if((b|0)==(b&255)){d=c+9|0;b=0;while(1){B=b+d|0,C=Rb(a,8),g[B|0]=C;b=b+1|0;if(b>>>0<j[c+8|0]){continue}break}}Lb(a,4);break c}d=i[a+260>>2]+o(u,1596)|0;q=Rb(a,5);g[d|0]=q;b=-1;e=0;c=0;if(q&255){while(1){q=Rb(a,4);g[(c+d|0)+1|0]=q;q=q&255;b=(q|0)>(b|0)?q:b;c=c+1|0;if(c>>>0<j[d|0]){continue}break}while(1){q=d+e|0;B=q,C=Rb(a,3)+1|0,g[B+33|0]=C;c=Rb(a,2);g[q+49|0]=c;v:{if(c&255){c=Rb(a,8);g[q+65|0]=c;if((c&255)>=i[a+120>>2]){Lb(a,20);break c}if(j[q+49|0]==31){break v}}c=0;while(1){w:{s=Rb(a,8)+ -1|0;h[((d+(e<<4)|0)+(c<<1)|0)+82>>1]=s;if(i[a+120>>2]<=s<<16>>16){break w}c=c+1|0;if((c|0)<1<<j[q+49|0]){continue}break v}break}Lb(a,20);break c}c=(b|0)!=(e|0);e=e+1|0;if(c){continue}break}}e=2;B=d,C=Rb(a,2)+1|0,g[B+1588|0]=C;b=Rb(a,4);i[d+1592>>2]=2;n=0;h[d+338>>1]=0;g[d+1589|0]=b;h[d+340>>1]=1<<b;b=d+1592|0;s=j[d|0];x:{if(s){q=d+1589|0;while(1){c=0;r=d+j[(d+n|0)+1|0]|0;if(j[r+33|0]){while(1){e=Rb(a,j[q|0]);h[(d+(i[b>>2]<<1)|0)+338>>1]=e;e=i[b>>2]+1|0;i[b>>2]=e;c=c+1|0;if(c>>>0<j[r+33|0]){continue}break}s=j[d|0]}n=n+1|0;if(n>>>0<(s&255)>>>0){continue}break}if((e|0)<1){break x}}c=0;while(1){e=k[(d+(c<<1)|0)+338>>1];q=(t+16|0)+(c<<2)|0;h[q+2>>1]=c;h[q>>1]=e;c=c+1|0;e=i[b>>2];if((c|0)<(e|0)){continue}break}}q=d+338|0;AE(t+16|0,e,2301);c=0;e=i[b>>2];s=e+ -1|0;s=(s|0)>0?s:0;while(1){if((c|0)==(s|0)){c=0;y:{if((e|0)<=0){break y}while(1){g[(c+d|0)+838|0]=j[((t+16|0)+(c<<2)|0)+2|0];c=c+1|0;e=i[b>>2];if((c|0)<(e|0)){continue}break}c=2;if((e|0)<=2){break y}while(1){i[t+12>>2]=0;i[t+8>>2]=0;n5(q,c,t+12|0,t+8|0);e=d+(c<<1)|0;g[e+1088|0]=i[t+12>>2];g[e+1089|0]=i[t+8>>2];c=c+1|0;e=i[b>>2];if((c|0)<(e|0)){continue}break}}f=(e|0)>(f|0)?e:f;u=u+1|0;if((u|0)<i[a+128>>2]){continue u}q=f<<1;break d}y=k[(t+16|0)+(c<<2)>>1];c=c+1|0;if((y|0)!=k[(t+16|0)+(c<<2)>>1]){continue}break}break}Lb(a,20);break c}Lb(a,3);break c}Jh(a,c,n<<1);Lb(a,3);break c}Lb(a,20);break c}Lb(a,3);break c}Lb(a,3);break c}Lb(a,3);break c}Lb(a,20);break c}b=Rb(a,6)+1|0;i[a+264>>2]=b;b=yd(a,o(b,24));i[a+396>>2]=b;if(!b){Lb(a,3);break c}e=0;yb(b,0,o(i[a+264>>2],24));z:{if(i[a+264>>2]>=1){while(1){b=i[a+396>>2];c=Rb(a,16);h[((e<<1)+a|0)+268>>1]=c;if((c&65535)>>>0>=3){Lb(a,20);break c}f=b+o(e,24)|0;B=f,C=Rb(a,24),i[B>>2]=C;b=Rb(a,24);i[f+4>>2]=b;if(b>>>0<l[f>>2]){Lb(a,20);break c}B=f,C=Rb(a,24)+1|0,i[B+8>>2]=C;B=f,C=Rb(a,6)+1|0,g[B+12|0]=C;b=Rb(a,8);g[f+13|0]=b;A:{B:{if((b&255)<i[a+120>>2]){b=0;if(j[f+12|0]){break B}c=0;break A}Lb(a,20);break c}while(1){c=(t+16|0)+b|0;d=Rb(a,3);if(Rb(a,1)){s=Rb(a,5)}else{s=0}g[c|0]=d+(s<<3);b=b+1|0;c=j[f+12|0];if(b>>>0<c>>>0){continue}break}}b=yd(a,c<<4);i[f+20>>2]=b;if(!b){break z}if(j[f+12|0]){n=0;while(1){c=j[(t+16|0)+n|0];b=0;while(1){C:{if(c>>>b&1){d=Rb(a,8);r=b<<1;s=n<<4;h[r+(s+i[f+20>>2]|0)>>1]=d;if(i[a+120>>2]>h[r+(s+i[f+20>>2]|0)>>1]){break C}Lb(a,20);break c}h[(i[f+20>>2]+(n<<4)|0)+(b<<1)>>1]=65535}b=b+1|0;if((b|0)!=8){continue}break}n=n+1|0;if(n>>>0<j[f+12|0]){continue}break}}b=yd(a,i[(i[a+124>>2]+o(j[f+13|0],2096)|0)+4>>2]<<2);i[f+16>>2]=b;if(!b){Lb(a,3);break c}s=0;yb(b,0,i[(i[a+124>>2]+o(j[f+13|0],2096)|0)+4>>2]<<2);b=i[a+124>>2];c=j[f+13|0];if(i[(b+o(c,2096)|0)+4>>2]>0){while(1){d=i[o(c,2096)+b>>2];b=yd(a,d);n=s<<2;i[n+i[f+16>>2]>>2]=b;D:{c=i[n+i[f+16>>2]>>2];if(c){if((d|0)<1){break D}b=d+ -1|0;g[c+b|0]=(s>>>0)%j[f+12|0];c=s;if((d|0)==1){break D}while(1){d=b+ -1|0;r=j[f+12|0];c=(c|0)/(r|0)|0;g[d+i[n+i[f+16>>2]>>2]|0]=(c|0)%(r|0);r=(b|0)>1;b=d;if(r){continue}break}break D}Lb(a,3);break c}s=s+1|0;b=i[a+124>>2];c=j[f+13|0];if((s|0)<i[(b+o(c,2096)|0)+4>>2]){continue}break}}e=e+1|0;if((e|0)<i[a+264>>2]){continue}break}}b=Rb(a,6)+1|0;i[a+400>>2]=b;b=yd(a,o(b,40));i[a+404>>2]=b;if(!b){Lb(a,3);break c}n=0;yb(b,0,o(i[a+400>>2],40));if(i[a+400>>2]>=1){while(1){b=i[a+404>>2];if(Rb(a,16)){Lb(a,20);break c}d=b+o(n,40)|0;b=yd(a,o(i[a+4>>2],3));i[d+4>>2]=b;if(!b){Lb(a,3);break c}b=d;if(Rb(a,1)){f=Rb(a,4)+1|0}else{f=1}g[b+8|0]=f;E:{if(Rb(a,1)){b=Rb(a,8)+1|0;h[d>>1]=b;F:{c=i[a+4>>2];b=b&65535;if((c|0)>=(b|0)){f=0;if(b){break F}break E}Lb(a,20);break c}while(1){c=Rb(a,Pk(c+ -1|0));b=o(f,3);g[b+i[d+4>>2]|0]=c;c=Rb(a,Pk(i[a+4>>2]+ -1|0));g[(b+i[d+4>>2]|0)+1|0]=c;c=i[a+4>>2];b=b+i[d+4>>2]|0;e=j[b|0];if((c|0)<=(e|0)){Lb(a,20);break c}b=j[b+1|0];if((c|0)<=(b|0)){Lb(a,20);break c}if((b|0)!=(e|0)){f=f+1|0;if(f>>>0>=k[d>>1]){break E}continue}break}Lb(a,20);break c}h[d>>1]=0}if(Rb(a,2)){Lb(a,20);break c}e=i[a+4>>2];G:{H:{b=j[d+8|0];if(b>>>0<=1){c=0;if((e|0)>0){while(1){g[(i[d+4>>2]+o(c,3)|0)+2|0]=0;c=c+1|0;if((c|0)<i[a+4>>2]){continue}break}b=j[d+8|0]}if(!(b&255)){break G}break H}c=0;if((e|0)<=0){break H}while(1){I:{b=Rb(a,4);e=o(c,3);g[(e+i[d+4>>2]|0)+2|0]=b;if(j[(e+i[d+4>>2]|0)+2|0]>=j[d+8|0]){break I}c=c+1|0;if((c|0)<i[a+4>>2]){continue}break H}break}Lb(a,20);break c}b=0;while(1){Rb(a,8);e=b+d|0;c=e;B=c,C=Rb(a,8),g[B+9|0]=C;e=Rb(a,8);g[c+24|0]=e;if(i[a+128>>2]<=j[c+9|0]){Lb(a,20);break c}if((e&255)<i[a+264>>2]){b=b+1|0;if(b>>>0>=j[d+8|0]){break G}continue}break}Lb(a,20);break c}n=n+1|0;if((n|0)<i[a+400>>2]){continue}break}}b=Rb(a,6)+1|0;i[a+408>>2]=b;c=0;J:{if((b|0)<=0){break J}while(1){b=o(c,6)+a|0;B=b,C=Rb(a,1),g[B+412|0]=C;B=b,C=Rb(a,16),h[B+414>>1]=C;B=b,C=Rb(a,16),h[B+416>>1]=C;d=Rb(a,8);g[b+413|0]=d;if(k[b+414>>1]){Lb(a,20);break c}if(k[b+416>>1]){Lb(a,20);break c}if((d&255)<i[a+400>>2]){c=c+1|0;if((c|0)>=i[a+408>>2]){break J}continue}break}Lb(a,20);break c}WE(a);b=0;i[a+992>>2]=0;if(i[a+4>>2]>=1){while(1){c=(b<<2)+a|0;B=c,C=yd(a,i[a+116>>2]<<2),i[B+800>>2]=C;B=c,C=yd(a,i[a+116>>2]<<1&2147483646),i[B+928>>2]=C;d=yd(a,q);i[c+996>>2]=d;e=i[c+800>>2];if(!(i[c+928>>2]?!(!e|!d):0)){Lb(a,3);break c}yb(e,0,i[a+116>>2]<<2);b=b+1|0;if((b|0)<i[a+4>>2]){continue}break}}b=0;if(!VE(a,0,i[a+112>>2])){break a}if(!VE(a,1,i[a+116>>2])){break a}i[a+104>>2]=i[a+112>>2];d=i[a+116>>2];i[a+108>>2]=d;A=a;s=d<<1&2147483646;y=s;r=i[a+264>>2];f=4;K:{if((r|0)<1){break K}d=(d|0)/2|0;u=i[a+396>>2];e=0;f=0;while(1){q=u+o(f,24)|0;v=i[q+4>>2];c=v>>>0<d>>>0?v:d;v=i[q>>2];q=(c-(v>>>0<d>>>0?v:d)>>>0)/l[q+8>>2]|0;e=(q|0)>(e|0)?q:e;f=f+1|0;if((r|0)!=(f|0)){continue}break}f=(e<<2)+4|0}c=o(f,i[a+4>>2]);c=s>>>0>c>>>0?y:c;i[A+12>>2]=c;L:{M:{if(!i[a+80>>2]){break M}d=i[a+92>>2];if((d|0)!=i[a+84>>2]){break L}if((c+i[a+88>>2]|0)+1512>>>0<=d>>>0){break M}Lb(a,3);break a}if(i[a+1380>>2]==-1){i[a+52>>2]=j[a+48|0]?0:i[a+32>>2]-i[a+36>>2]|0;b=1;break a}i[a+52>>2]=0;b=1;break a}V(51892,50448,4177,51948);x()}Lb(a,3)}b=0}Xa=t+1024|0;return b}function wya(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,l=0,m=0,n=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,H=0,J=0,K=0,M=0,N=0,O=0,P=0,Q=0;d=Xa-304|0;Xa=d;pc(b);a:{b:{c:{d:{e:{f:{g:{h:{if(!ss(b,d+208|0)){break h}if(!mN(d+208|0)){break h}if(!wb(b,Vc(lN(d+208|0),_a))){break h}if(!c){H=1;break h}md(a,2);i[a+480260>>2]=64;i[a+480264>>2]=32767;r=Oc(d+192|0);i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{n=d+248|0;switch(((j[n|0]|j[n+1|0]<<8)&61440)+ -4096>>>12|0){case 6:break q;case 5:break r;case 4:break s;case 3:break t;case 2:break u;case 1:break v;case 0:break w;default:break p}}x:{if(j[d+270|0]|j[d+271|0]<<8|(j[n|0]|j[n+1|0]<<8)!=4896|(j[d+260|0]|j[d+240|0]&15)){break x}if((j[d+246|0]|j[d+247|0]<<8)&65455){break x}i[a+1074304>>2]=18219008;i[114610]=0;e=C(2,d+32|0,17018)|0;l=i[114610];i[114610]=0;m=1;if((l|0)==1){break o}mb(r,e);eb(e);i[114610]=0;I(478,a+1074308|0,81,1)|0;l=i[114610];i[114610]=0;e=1;if((l|0)!=1){break i}break b}y:{if(j[d+270|0]|j[d+271|0]<<8|(j[n|0]|j[n+1|0]<<8)!=4896|(j[d+260|0]|(j[d+246|0]|j[d+247|0]<<8))){break y}if(j[d+261|0]){break y}i[114610]=0;l=C(2,d+32|0,17044)|0;e=i[114610];i[114610]=0;if((e|0)!=1){break j}f=B()|0;A()|0;break a}i[114610]=0;l=C(2,d+32|0,17058)|0;p=i[114610];i[114610]=0;f=1;if((p|0)!=1){mb(r,l);eb(l);break k}f=B()|0;A()|0;break a}i[114610]=0;l=C(2,d+32|0,17073)|0;p=i[114610];i[114610]=0;e=1;if((p|0)!=1){mb(r,l);eb(l);break k}f=B()|0;A()|0;break a}z:{A:{B:{C:{D:{s=j[n|0]|j[n+1|0]<<8;E:{if(s>>>0<=12820){i[114610]=0;l=C(2,d+32|0,17087)|0;e=i[114610];i[114610]=0;if((e|0)!=1){mb(r,l);break E}f=B()|0;A()|0;break a}i[114610]=0;l=C(2,d+160|0,17103)|0;e=i[114610];i[114610]=0;if((e|0)==1){break D}i[114610]=0;D(219,d+176|0,l|0);e=i[114610];i[114610]=0;if((e|0)==1){break C}e=j[n|0]|j[n+1|0]<<8;i[114610]=0;i[d+128>>2]=e+ -12820;G(245,d+32|0,d+176|0,d+128|0);e=i[114610];i[114610]=0;if((e|0)==1){break B}mb(r,d+32|0);eb(d+32|0);ob(d+176|0)}eb(l);if((j[n|0]|j[n+1|0]<<8)>>>0<12807){break l}if(j[d+264|0]|j[d+265|0]<<8|(j[d+266|0]<<16|j[d+267|0]<<24)){break z}break l}f=B()|0;A()|0;break a}f=B()|0;A()|0;break A}f=B()|0;A()|0;ob(d+176|0)}eb(l);break a}e=j[n|0]|j[n+1|0]<<8;l=j[d+264|0]|j[d+265|0]<<8|(j[d+266|0]<<16|j[d+267|0]<<24);i[114610]=0;e=C(665,e|0,l|0)|0;l=i[114610];i[114610]=0;if((l|0)==1){break n}l=mp(d+32|0);i[l+44>>2]=e;i[114610]=0;D(666,a+1304500|0,l|0);e=i[114610];i[114610]=0;if((e|0)!=1){break l}f=B()|0;A()|0;break a}f=j[n|0]|j[n+1|0]<<8;F:{if((f|0)==16640){i[114610]=0;e=C(2,d+32|0,17127)|0;l=i[114610];i[114610]=0;if((l|0)!=1){mb(r,e);eb(e);i[114610]=0;I(478,a+1074308|0,81,1)|0;e=i[114610];i[114610]=0;if((e|0)==1){break b}break F}f=B()|0;A()|0;break a}e=j[n|0]|j[n+1|0]<<8;l=j[d+262|0]|j[d+263|0]<<8;i[114610]=0;G(667,d+32|0,e|0,l|0);e=i[114610];i[114610]=0;if((e|0)==1){break m}mb(r,d+32|0);eb(d+32|0);i[a+480260>>2]=1}p=(f|0)!=16640;e=1;f=0;break i}i[114610]=0;f=C(2,d+32|0,17139)|0;l=i[114610];i[114610]=0;if((l|0)!=1){mb(r,f);eb(f);i[a+1074304>>2]=((j[n|0]|j[n+1|0]<<8)&4095)<<16;f=0;break k}f=B()|0;A()|0;break a}i[114610]=0;e=C(2,d+32|0,17127)|0;l=i[114610];i[114610]=0;if((l|0)!=1){mb(r,e);eb(e);i[114610]=0;I(478,a+1074308|0,81,1)|0;l=i[114610];i[114610]=0;e=0;if((l|0)==1){break b}break i}f=B()|0;A()|0;break a}i[114610]=0;l=C(2,d+32|0,17147)|0;e=i[114610];i[114610]=0;if((e|0)!=1){break j}f=B()|0;A()|0;break a}if((j[n|0]|j[n+1|0]<<8)!=51712){break i}i[114610]=0;l=C(2,d+32|0,17160)|0;e=i[114610];i[114610]=0;if((e|0)!=1){break j}f=B()|0;A()|0;break a}f=B()|0;A()|0;break a}f=B()|0;A()|0;break a}f=B()|0;A()|0;break a}i[114610]=0;e=1;I(478,a+1074308|0,107,1)|0;l=i[114610];i[114610]=0;if((l|0)==1){break b}i[a+480260>>2]=1;if(s>>>0>12820){break i}}i[114610]=0;l=C(2,d+144|0,17167)|0;p=i[114610];i[114610]=0;G:{H:{I:{J:{K:{if((p|0)!=1){i[114610]=0;D(219,d+176|0,l|0);p=i[114610];i[114610]=0;if((p|0)==1){break K}i[d+16>>2]=j[n+1|0]&15;p=j[n|0];i[114610]=0;i[d>>2]=p;D(664,d+128|0,d|0);p=i[114610];i[114610]=0;if((p|0)==1){break J}i[114610]=0;T(998,d+32|0,d+176|0,r|0,d+16|0,d+128|0);p=i[114610];i[114610]=0;if((p|0)==1){break I}mb(r,d+32|0);eb(d+32|0);eb(d+128|0);ob(d+176|0);eb(l);p=0;break i}f=B()|0;A()|0;break a}f=B()|0;A()|0;break G}f=B()|0;A()|0;break H}f=B()|0;A()|0;eb(d+128|0)}ob(d+176|0)}eb(l);break a}mb(r,l);eb(l);e=0}i[114610]=0;l=C(2,d+32|0,17176)|0;s=i[114610];i[114610]=0;L:{M:{N:{O:{P:{Q:{R:{S:{T:{U:{V:{W:{X:{Y:{Z:{if((s|0)!=1){mb(a+1304436|0,l);eb(l);i[114610]=0;l=C(2,d+32|0,17192)|0;s=i[114610];i[114610]=0;if((s|0)==1){break Z}mb(a+1304448|0,l);eb(l);mb(a+1304460|0,r);i[a+1304496>>2]=i[a+1074304>>2]?7:4;if(e){i[114610]=0;e=a+1074308|0;C(479,e|0,77)|0;l=i[114610];i[114610]=0;if((l|0)==1){break b}i[114610]=0;C(479,e|0,78)|0;l=i[114610];i[114610]=0;if((l|0)==1){break b}i[114610]=0;C(479,e|0,79)|0;l=i[114610];i[114610]=0;if((l|0)==1){break b}i[114610]=0;C(479,e|0,80)|0;l=i[114610];i[114610]=0;if((l|0)==1){break b}i[114610]=0;C(479,e|0,82)|0;l=i[114610];i[114610]=0;if((l|0)==1){break b}i[114610]=0;C(479,e|0,96)|0;e=i[114610];i[114610]=0;if((e|0)==1){break b}}m=((j[n|0]|j[n+1|0]<<8)&61440)>>>0<4097|((j[n|0]|j[n+1|0]<<8)>>>0<12820?((j[n|0]|j[n+1|0]<<8)&61440)==12288:0)?m:1;i[114610]=0;e=a+901404|0;L(999,e|0);l=i[114610];i[114610]=0;if((l|0)==1){break b}if(!m){i[114610]=0;L(638,e|0);e=i[114610];i[114610]=0;if((e|0)==1){break b}}i[114610]=0;G(580,d+176|0,1,d+208|0);e=i[114610];i[114610]=0;if((e|0)==1){break Y}i[114610]=0;D(415,d+32|0,d+176|0);e=i[114610];i[114610]=0;if((e|0)==1){break Y}mb(a+1304400|0,d+32|0);eb(d+32|0);if(j[d+246|0]&16){i[a+480208>>2]=i[a+480208>>2]|65536}if(g[d+246|0]&1){i[a+480208>>2]=i[a+480208>>2]|131072}if(!(j[d+246|0]&64?0:(j[n|0]|j[n+1|0]<<8)!=4864)){i[a+480208>>2]=i[a+480208>>2]|2}e=j[d+257|0];i[a+480196>>2]=e;_:{$:{if(e){if((e|0)!=255){break $}e=0;if(!f){break _}}i[a+480196>>2]=6}e=f}i[a+480204>>2]=o(j[d+258|0],1e4);if(j[d+258|0]<=32){i[a+480204>>2]=e?125e4:32e4}f=j[d+256|0];i[114610]=0;g[d+32|0]=f;g[d+176|0]=64;f=C(391,d+32|0,d+176|0)|0;l=i[114610];i[114610]=0;if((l|0)==1){break U}f=j[f|0];i[a+480200>>2]=f<<2;if(!((j[n|0]|j[n+1|0]<<8)>>>0>4895|f)){i[a+480200>>2]=256}if((j[d+250|0]|j[d+251|0]<<8)!=1|j[d+259|0]>7){break W}f=j[d+259|0];i[114610]=0;i[d+32>>2]=(f<<4)+16;i[d+176>>2]=127;f=C(462,d+32|0,d+176|0)|0;l=i[114610];i[114610]=0;if((l|0)==1){break X}i[a+480228>>2]=i[f>>2];break V}f=B()|0;A()|0;break a}f=B()|0;A()|0;break a}f=B()|0;A()|0;break a}f=B()|0;A()|0;break a}if(!(j[d+259|0]!=18?j[d+259|0]!=2:0)){i[a+480228>>2]=32;break V}f=j[d+259|0];i[114610]=0;i[d+32>>2]=f&127;i[d+176>>2]=16;f=C(555,d+32|0,d+176|0)|0;l=i[114610];i[114610]=0;if((l|0)==1){break T}i[a+480228>>2]=i[f>>2]}i[a+480232>>2]=36;if(!(!p|19763<=(j[n|0]|j[n+1|0]<<8))){i[a+480232>>2]=64}h[a+480188>>1]=4;p=Ss(d+120|0);f=0;while(1){i[114610]=0;l=(f<<5)+a|0;q=l+480280|0;L(432,q|0);m=i[114610];i[114610]=0;if((m|0)==1){break S}m=d+f|0;s=j[m+272|0];if(j[m+272|0]!=255){h[a+480188>>1]=f+1;h[l+480284>>1]=s&8?204:51}if(g[m+272|0]<=-1){i[q>>2]=1024}if(((s&127)+ -16&255)>>>0<=13){h[l+480284>>1]=128;lj(d+32|0,p,f);Od(d+32|0,1)}f=f+1|0;if((f|0)!=32){continue}break}if(!k[a+480188>>1]){h[a+480188>>1]=1}f=Db(a+484360|0);l=j[d+240|0]|j[d+241|0]<<8;i[114610]=0;S(584,f|0,b|0,l|0,255,254)|0;f=i[114610];i[114610]=0;if((f|0)==1){break c}y=qt(d+176|0);f=j[d+242|0]|j[d+243|0]<<8;i[114610]=0;I(393,b|0,y|0,f|0)|0;f=i[114610];i[114610]=0;if((f|0)==1){break e}s=qt(d+128|0);f=j[d+244|0]|j[d+245|0]<<8;i[114610]=0;I(393,b|0,s|0,f|0)|0;f=i[114610];i[114610]=0;if((f|0)!=1){if(j[d+261|0]==252){f=0;i[114610]=0;C(1e3,b|0,d+32|0)|0;l=i[114610];i[114610]=0;if((l|0)==1){break g}while(1){m=(d+32|0)+f|0;l=j[m|0];aa:{if(!(l&32)){break aa}q=((f<<5)+a|0)+480284|0;if(e){lj(d+16|0,p,f);if(ib(d+16|0)){break aa}l=j[m|0]}h[q>>1]=(((l&15)<<8|8)>>>0)/15}f=f+1|0;if((f|0)!=32){continue}break}}e=j[d+242|0]|j[d+243|0]<<8;i[114610]=0;h[d+32>>1]=e;h[d+16>>1]=3999;e=C(477,d+32|0,d+16|0)|0;f=i[114610];i[114610]=0;if((f|0)==1){break R}e=k[e>>1];h[a+480190>>1]=e;if(e){e=c&2;l=d+45|0;p=d+80|0;f=0;while(1){m=$b(y,f);m=j[m|0]|j[m+1|0]<<8;i[114610]=0;m=C(256,b|0,m<<4)|0;q=i[114610];i[114610]=0;if((q|0)==1){break Q}ba:{if(!m){break ba}i[114610]=0;m=C(1001,b|0,d+32|0)|0;q=i[114610];i[114610]=0;if((q|0)==1){break Q}if(!m){break ba}i[114610]=0;m=f+1|0;q=(o(m,104)+a|0)+484380|0;D(1002,d+32|0,q|0);t=i[114610];i[114610]=0;if((t|0)==1){break Q}i[114610]=0;G(580,d|0,1,p|0);t=i[114610];i[114610]=0;ca:{da:{ea:{if((t|0)==1){break ea}i[114610]=0;D(415,d+16|0,d|0);t=i[114610];i[114610]=0;if((t|0)==1){break ea}i[114610]=0;C(369,((m<<5)+a|0)+946300|0,d+16|0)|0;m=i[114610];i[114610]=0;if((m|0)==1){break da}eb(d+16|0);if(!(j[d+48|0]|j[d+49|0]<<8|(j[d+50|0]<<16|j[d+51|0]<<24))|(!e|j[d+32|0]>1)){break ba}m=j[d+46|0];t=j[d+47|0];w=j[l|0];i[114610]=0;m=C(256,b|0,t<<12|m<<4|w<<20)|0;t=i[114610];i[114610]=0;if((t|0)==1){break ca}if(!m){break ba}m=j[d+250|0]|j[d+251|0]<<8;i[114610]=0;G(1003,d+16|0,d+32|0,(m|0)==1|0);m=i[114610];i[114610]=0;if((m|0)!=1){i[114610]=0;I(400,d+16|0,q|0,b|0)|0;m=i[114610];i[114610]=0;if((m|0)!=1){break ba}}f=B()|0;A()|0;break f}f=B()|0;A()|0;break f}f=B()|0;A()|0;eb(d+16|0);break f}f=B()|0;A()|0;break f}f=f+1|0;if(f>>>0<k[a+480190>>1]){continue}break}}H=1;if(!(c&1)){break L}c=j[n|0]|j[n+1|0]<<8;e=j[d+244|0]|j[d+245|0]<<8;i[114610]=0;h[d+32>>1]=e;h[d+16>>1]=255;e=C(477,d+32|0,d+16|0)|0;f=i[114610];i[114610]=0;fa:{ga:{if((f|0)!=1){z=k[e>>1];i[114610]=0;q=a+484344|0;D(401,q|0,z|0);e=i[114610];i[114610]=0;if((e|0)==1){break ga}J=c>>>0<4896;if(z){break fa}t=0;w=0;break M}f=B()|0;A()|0;break f}f=B()|0;A()|0;break f}N=d+32|5;O=d+32|3;K=d+32|4;P=d+32|2;Q=d+32|1;p=0;w=0;t=0;while(1){i[114610]=0;c=I(402,q|0,p&65535,64)|0;e=i[114610];i[114610]=0;if((e|0)==1){break P}ha:{if(!c){break ha}c=$b(s,p);if(!(j[c|0]|j[c+1|0]<<8)){break ha}c=$b(s,p);c=j[c|0]|j[c+1|0]<<8;i[114610]=0;c=C(256,b|0,c<<4)|0;e=i[114610];i[114610]=0;if((e|0)==1){break P}if(!c){break ha}i[114610]=0;C(338,b|0,2)|0;c=i[114610];i[114610]=0;if((c|0)==1){break P}f=0;c=Fb(q,p);i[114610]=0;l=C(497,c|0,0)|0;c=i[114610];i[114610]=0;if((c|0)==1){break O}while(1){i[114610]=0;v=F(387,b|0)|0;c=i[114610];i[114610]=0;ia:{ja:{if((c|0)!=1){if(v){break ja}if(f>>>0>62){break ha}c=Fb(q,p);i[114610]=0;f=f+1|0;l=C(497,c|0,f|0)|0;c=i[114610];i[114610]=0;if((c|0)!=1){break ia}}f=B()|0;A()|0;break f}Tg(d+32|0);e=v&31;c=o(e,6)+l|0;m=k[a+480188>>1]>e>>>0;M=m?c:d+32|0;if(v&32){i[114610]=0;D(472,d+16|0,b|0);e=i[114610];i[114610]=0;ka:{la:{ma:{if((e|0)!=1){u=Nc(d+16|0);e=j[d+16|0];if(e>>>0>239){break ma}e=(o(e>>>4|0,12)+(e&15)|0)+13|0;break la}f=B()|0;A()|0;break f}na:{switch(e+ -254|0){case 0:break la;case 1:break na;default:break ka}}e=0}g[M|0]=e}g[(m?c+1|0:Q)|0]=j[u|0]}oa:{if(!(v&64)){break oa}i[114610]=0;e=F(387,b|0)|0;u=i[114610];i[114610]=0;pa:{if((u|0)!=1){u=m?c+2|0:P;g[d+16|0]=e;if(e<<24>>24>-1|e>>>0>192){break pa}g[u|0]=2;g[(m?c+4|0:K)|0]=j[d+16|0]^128;break oa}f=B()|0;A()|0;break f}g[u|0]=1;i[114610]=0;g[d|0]=64;e=C(391,d+16|0,d|0)|0;u=i[114610];i[114610]=0;if((u|0)==1){break N}g[(m?c+4|0:K)|0]=j[e|0]}if(!(v&128)){break ia}i[114610]=0;D(472,d+16|0,b|0);e=i[114610];i[114610]=0;qa:{if((e|0)!=1){u=Nc(d+16|0);v=m?c+3|0:O;g[v|0]=j[d+16|0];e=m?c+5|0:N;g[e|0]=j[u|0];ay(M,0);ra:{c=j[v|0];if((c|0)==20){if((j[e|0]&240)!=160){break ia}if((j[n|0]|j[n+1|0]<<8)>>>0<4896){break ra}c=j[v|0]}if((c|0)!=31){break ia}c=j[e|0];if(c>>>0<=15){break qa}J=0;break ia}g[e|0]=j[e|0]&15^136;break ia}f=B()|0;A()|0;break f}if(c>>>0<=7){w=w+1|0;break ia}t=((c|0)!=8)+t|0}if(f>>>0<64){continue}break}}p=p+1|0;if((z|0)!=(p|0)){continue}break}break M}f=B()|0;A()|0;break f}f=B()|0;A()|0;break a}f=B()|0;A()|0;break a}f=B()|0;A()|0;break a}f=B()|0;A()|0;break f}f=B()|0;A()|0;break f}f=B()|0;A()|0;break f}f=B()|0;A()|0;break f}f=B()|0;A()|0;break f}if(!J){break L}a=k[a+480188>>1];if((t+w|0)<(a|0)|(t-w|0)>=(a|0)){break L}tya(q,ke(q)+ -1&65535)}ik(s);ik(y);eb(r)}Xa=d+304|0;return H|0}f=B()|0;A()|0}ik(s);break d}f=B()|0;A()|0}ik(y);break a}f=B()|0;A()|0;break a}f=B()|0;A()|0}eb(r);E(f|0);x()}function cLa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,l=0,m=0,n=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0;e=Xa-288|0;Xa=e;pc(b);a:{if(sS(b,12222)){u=Ab(e+272|0);i[114610]=0;f=I(430,b|0,u|0,-1)|0;n=i[114610];i[114610]=0;b:{c:{d:{e:{f:{g:{h:{if((n|0)!=1){if(!f){break b}i[114610]=0;f=C(445,b|0,e+264|0)|0;n=i[114610];i[114610]=0;i:{if((n|0)==1){break i}if(!f){break b}if(!qS(e+264|0)){break b}d=pS(e+264|0);i[114610]=0;d=eg(446,d,_a);f=i[114610];i[114610]=0;if((f|0)==1){break i}i[114610]=0;f=C(258,b|0,d|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break i}d=0;if(!f){break b}if(!c){break c}i[114610]=0;D(447,a|0,4096);d=i[114610];i[114610]=0;if((d|0)==1){break i}i[114610]=0;C(448,a+1304400|0,u|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break i}d=j[e+264|2];h[a+480188>>1]=32;h[a+480192>>1]=d;i[114610]=0;D(449,a|0,1);d=i[114610];i[114610]=0;if((d|0)==1){break i}i[114610]=0;d=C(2,e+96|0,12230)|0;f=i[114610];i[114610]=0;j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{if((f|0)!=1){mb(a+1304436|0,d);eb(d);i[114610]=0;d=C(2,e+96|0,12194)|0;f=i[114610];i[114610]=0;if((f|0)==1){break t}mb(a+1304448|0,d);eb(d);i[114610]=0;d=C(2,e+248|0,12244)|0;f=i[114610];i[114610]=0;if((f|0)==1){break s}i[114610]=0;D(219,e+48|0,d|0);f=i[114610];i[114610]=0;if((f|0)==1){break r}g[e+216|0]=j[e+264|1];f=j[e+264|0];i[114610]=0;g[e+8|0]=f;D(450,e+232|0,e+8|0);f=i[114610];i[114610]=0;if((f|0)==1){break q}i[114610]=0;J(451,e+96|0,e+48|0,e+216|0,e+232|0);f=i[114610];i[114610]=0;if((f|0)==1){break p}mb(a+1304460|0,e+96|0);eb(e+96|0);eb(e+232|0);ob(e+48|0);eb(d);i[a+1304496>>2]=4;if(j[e+264|0]<2){break k}i[114610]=0;h[e+96>>1]=8192;d=F(357,b|0)|0;f=i[114610];i[114610]=0;if((f|0)==1){break m}i[114610]=0;h[e+48>>1]=d;d=C(452,e+96|0,e+48|0)|0;f=i[114610];i[114610]=0;if((f|0)==1){break m}i[a+480204>>2]=o(k[d>>1],1e4)>>>8;i[114610]=0;g[e+96|0]=1;d=F(387,b|0)|0;f=i[114610];i[114610]=0;if((f|0)==1){break l}i[114610]=0;g[e+48|0]=d;d=C(453,e+96|0,e+48|0)|0;f=i[114610];i[114610]=0;if((f|0)==1){break l}i[a+480196>>2]=j[d|0];i[114610]=0;C(338,b|0,3)|0;d=i[114610];i[114610]=0;if((d|0)!=1){i[114610]=0;d=F(357,b|0)|0;f=i[114610];i[114610]=0;if((f|0)!=1){break j}}b=B()|0;A()|0;break d}b=B()|0;A()|0;break d}b=B()|0;A()|0;break d}b=B()|0;A()|0;break d}b=B()|0;A()|0;break n}b=B()|0;A()|0;break o}b=B()|0;A()|0;eb(e+232|0)}ob(e+48|0)}eb(d);break d}b=B()|0;A()|0;break d}b=B()|0;A()|0;break d}i[114610]=0;g[e+96|0]=32;d=F(387,b|0)|0;f=i[114610];i[114610]=0;u:{v:{if((f|0)==1){break v}i[114610]=0;g[e+48|0]=d;d=C(453,e+96|0,e+48|0)|0;f=i[114610];i[114610]=0;if((f|0)==1){break v}i[a+480204>>2]=o(j[d|0],1e4);i[114610]=0;g[e+96|0]=1;d=F(387,b|0)|0;f=i[114610];i[114610]=0;if((f|0)==1){break u}i[114610]=0;g[e+48|0]=d;d=C(453,e+96|0,e+48|0)|0;f=i[114610];i[114610]=0;if((f|0)==1){break u}i[a+480196>>2]=j[d|0];i[114610]=0;d=F(387,b|0)|0;f=i[114610];i[114610]=0;if((f|0)!=1){break j}b=B()|0;A()|0;break d}b=B()|0;A()|0;break d}b=B()|0;A()|0;break d}i[a+480208>>2]=d>>>2&16|12;t=mn(e+232|0);s=mn(e+216|0);w:{x:{if(!k[a+480192>>1]){break x}n=e+80|1;v=e+96|12;p=1;while(1){i[114610]=0;f=I(454,a|0,p&65535,0)|0;d=i[114610];i[114610]=0;y:{z:{A:{if((d|0)==1){break A}if(!f){break x}i[114610]=0;d=I(431,b|0,f+492|0,-1)|0;m=i[114610];i[114610]=0;if((m|0)==1){break A}if(!d){break x}i[114610]=0;m=F(387,b|0)|0;d=i[114610];i[114610]=0;B:{C:{D:{E:{if((d|0)!=1){yb(e+96|0,0,120);if(!m){break y}if(j[e+264|0]){i[114610]=0;d=C(455,b|0,e+96|0)|0;l=i[114610];i[114610]=0;if((l|0)==1){break E}if(!d){break y}}if(!j[e+264|0]){i[114610]=0;d=I(261,b|0,v|0,96)|0;l=i[114610];i[114610]=0;if((l|0)==1){break E}if(!d){break y}}l=f+236|0;d=0;while(1){r=j[(e+96|0)+d|0];q=k[a+480190>>1];y=Mc(l,d),z=(q+r|0)+1|0,h[y>>1]=z;d=d+1|0;if((d|0)!=120){continue}break}i[114610]=0;d=f+48|0;G(456,e+8|0,d|0,b|0);l=i[114610];i[114610]=0;if((l|0)==1){break D}i[114610]=0;l=f+68|0;G(456,e+32|0,l|0,b|0);r=i[114610];i[114610]=0;if((r|0)==1){break D}i[114610]=0;r=f+88|0;G(456,e+88|0,r|0,b|0);q=i[114610];i[114610]=0;if((q|0)==1){break D}i[114610]=0;C(457,b|0,e+80|0)|0;q=i[114610];i[114610]=0;if((q|0)==1){break C}i[f>>2]=(j[n|0]|j[n+1|0]<<8)&4095;f=j[n|0]|j[n+1|0]<<8;Nz(e+80|0,d,0);Nz(e+80|0,l,1);Nz(e+80|0,r,2);y=e,z=Jb(d),i[y+48>>2]=z;y=e,z=Kb(d),i[y+72>>2]=z;if(pb(e+48|0,e+72|0)){break B}break z}b=B()|0;A()|0;break e}b=B()|0;A()|0;break e}b=B()|0;A()|0;break e}b=B()|0;A()|0;break e}while(1){F:{d=i[e+48>>2];g[e+68|0]=64;q=j[d+2|0];i[114610]=0;g[e+71|0]=((q<<6)- -64>>>0)/127;q=C(391,e+68|0,e+71|0)|0;w=i[114610];i[114610]=0;if((w|0)==1){break F}g[d+2|0]=j[q|0];Gd(e+48|0);if(pb(e+48|0,e+72|0)){continue}break z}break}b=B()|0;A()|0;break e}b=B()|0;A()|0;break e}y=e,z=Jb(l),i[y+48>>2]=z;y=e,z=Kb(l),i[y+72>>2]=z;G:{if(!pb(e+48|0,e+72|0)){break G}while(1){H:{d=i[e+48>>2];g[e+68|0]=64;l=j[d+2|0];i[114610]=0;g[e+71|0]=((l<<6)+128>>>0)/255;l=C(391,e+68|0,e+71|0)|0;q=i[114610];i[114610]=0;if((q|0)==1){break H}g[d+2|0]=j[l|0];Gd(e+48|0);if(pb(e+48|0,e+72|0)){continue}break G}break}b=B()|0;A()|0;break e}y=e,z=Jb(r),i[y+48>>2]=z;y=e,z=Kb(r),i[y+72>>2]=z;if(pb(e+48|0,e+72|0)){r=1<<(f>>>12&3)&65535;while(1){q=i[e+48>>2];d=g[q+2|0];f=XMa(d^-128,d>>31^-1,r,0);l=_a;d=l;I:{if((d|0)>-1?1:(d|0)>=-1?f>>>0>=4294967292:0){i[114610]=0;f=f+4|0;if(f>>>0<4){d=d+1|0}f=eg(458,((d&7)<<29|f>>>3)&536870911,0);d=i[114610];i[114610]=0;if((d|0)!=1){break I}break f}i[114610]=0;d=(f+ -3|0)/8|0;f=eg(458,d,d>>31);d=i[114610];i[114610]=0;if((d|0)==1){break f}}g[q+2|0]=f^128;Gd(e+48|0);if(pb(e+48|0,e+72|0)){continue}break}}d=k[a+480190>>1]+1|0;h[e+68>>1]=d;J:{K:{L:{M:{l=d&65535;if(l>>>0<=3999){f=0;d=0;while(1){i[114610]=0;I(431,b|0,((l<<5)+a|0)+946300|0,-1)|0;l=i[114610];i[114610]=0;if((l|0)==1){break M}i[114610]=0;C(459,b|0,e+48|0)|0;l=i[114610];i[114610]=0;if((l|0)==1){break L}i[114610]=0;D(460,e+48|0,(o(k[e+68>>1]+d|0,104)+a|0)+484380|0);d=i[114610];i[114610]=0;if((d|0)==1){break L}d=j[e+80|0];l=j[e+67|0];i[114610]=0;h[e+72>>1]=d|f<<8&32512|((l&3)!=0)<<15;D(461,s|0,e+72|0);d=i[114610];i[114610]=0;if((d|0)==1){break K}f=f+1|0;d=f&65535;if(d>>>0>=m>>>0){break J}l=k[e+68>>1]+d|0;if(l>>>0<=3999){continue}break}}i[114610]=0;C(338,b|0,20)|0;d=i[114610];i[114610]=0;if((d|0)!=1){break J}b=B()|0;A()|0;break e}b=B()|0;A()|0;break e}b=B()|0;A()|0;break e}b=B()|0;A()|0;break e}i[114610]=0;D(461,t|0,e+68|0);d=i[114610];i[114610]=0;if((d|0)==1){break g}i[e+48>>2]=3999;d=k[a+480190>>1];i[114610]=0;i[e+72>>2]=d+m;d=C(462,e+48|0,e+72|0)|0;f=i[114610];i[114610]=0;if((f|0)==1){break w}h[a+480190>>1]=i[d>>2]}p=p+1|0;if((p&65535)>>>0<=k[a+480192>>1]){continue}break}}i[114610]=0;f=F(387,b|0)|0;d=i[114610];i[114610]=0;N:{if((d|0)!=1){if(!f){break h}d=Ab(e+96|0);i[114610]=0;I(463,b|0,d|0,f|0)|0;f=i[114610];i[114610]=0;if((f|0)==1){break N}i[114610]=0;G(13,e+48|0,6,d|0);f=i[114610];i[114610]=0;if((f|0)==1){break N}mb(a+1304412|0,e+48|0);eb(e+48|0);eb(d);break h}b=B()|0;A()|0;break e}b=B()|0;A()|0;eb(d);break e}b=B()|0;A()|0;break e}b=B()|0;A()|0;break d}b=B()|0;A()|0;break d}f=0;O:{P:{Q:{R:{S:{T:{U:{V:{W:{X:{Y:{while(1){i[114610]=0;d=(f<<5)+a|0;L(432,d+480280|0);n=i[114610];i[114610]=0;if((n|0)==1){break Y}i[114610]=0;I(433,b|0,d+480289|0,-1)|0;d=i[114610];i[114610]=0;if((d|0)==1){break Y}f=f+1|0;if((f|0)!=32){continue}break}i[114610]=0;d=C(464,b|0,e+32|0)|0;f=i[114610];i[114610]=0;if((f|0)==1){break V}if(!d){break S}if((j[e+32|0]|j[e+33|0]<<8|(j[e+34|0]<<16|j[e+35|0]<<24))>>>0<12){break W}d=j[e+32|0]|j[e+33|0]<<8|(j[e+34|0]<<16|j[e+35|0]<<24);i[114610]=0;d=C(258,b|0,d+ -11|0)|0;f=i[114610];i[114610]=0;if((f|0)==1){break V}if(d){break X}break W}b=B()|0;A()|0;break e}d=j[e+32|0]|j[e+33|0]<<8|(j[e+34|0]<<16|j[e+35|0]<<24);p=Mt(e+96|0);i[114610]=0;m=d+ -11|0;I(436,b|0,p|0,m|0)|0;d=i[114610];i[114610]=0;Z:{if((d|0)!=1){n=Ab(e+48|0);d=e+32|4;d=j[d|0]|j[d+1|0]<<8|(j[d+2|0]<<16|j[d+3|0]<<24);i[114610]=0;D(111,n|0,d|0);d=i[114610];i[114610]=0;if((d|0)!=1){_:{if(m){d=0;while(1){$:{l=j[dc(p,d)|0];f=d+1|0;if(!((l|0)!=255|m-f>>>0<2)){f=g[dc(p,f)|0];l=j[dc(p,d+2|0)|0];y=e,z=Ye(n),i[y+8>>2]=z;Ad(e+24|0,e+8|0);i[114610]=0;N(437,n|0,i[e+24>>2],l|0,f|0)|0;f=i[114610];i[114610]=0;if((f|0)!=1){f=d+3|0;break $}break _}i[114610]=0;D(110,n|0,l<<24>>24);d=i[114610];i[114610]=0;if((d|0)!=1){break $}break _}d=f;if(d>>>0<m>>>0){continue}break}}i[114610]=0;J(438,e+8|0,4,6,n|0);d=i[114610];i[114610]=0;if((d|0)!=1){aa:{mb(n,e+8|0);eb(e+8|0);d=xb(n);i[114610]=0;d=F(439,d|0)|0;f=i[114610];i[114610]=0;if((f|0)==1){break aa}f=lb(n);i[114610]=0;S(440,a+1304424|0,d|0,f|0,74,0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break aa}eb(n);Md(p);break W}}}}b=B()|0;A()|0;eb(n);break Z}b=B()|0;A()|0}Md(p);break e}d=Db(a+484360|0);f=e+264|5;f=j[f|0]|j[f+1|0]<<8;i[114610]=0;S(441,d|0,b|0,f|0,65535,65535)|0;d=i[114610];i[114610]=0;if((d|0)==1){break V}p=c&1;if(p){d=e+264|3;d=j[d|0]|j[d+1|0]<<8;i[114610]=0;D(401,a+484344|0,d|0);d=i[114610];i[114610]=0;if((d|0)==1){break V}}d=e+264|3;ba:{if(!(j[d|0]|j[d+1|0]<<8)){break ba}n=a+484344|0;f=0;while(1){i[114610]=0;m=C(258,b|0,4)|0;l=i[114610];i[114610]=0;ca:{if((l|0)!=1){if(m){break ca}break ba}b=B()|0;A()|0;break e}i[114610]=0;m=F(390,b|0)|0;l=i[114610];i[114610]=0;if((l|0)==1){break P}i[114610]=0;G(341,e+96|0,b|0,m|0);m=i[114610];i[114610]=0;if((m|0)==1){break Q}da:{if(!p){break da}i[114610]=0;m=F(387,e+96|0)|0;l=i[114610];i[114610]=0;if((l|0)==1){break O}i[114610]=0;C(338,e+96|0,1)|0;l=i[114610];i[114610]=0;if((l|0)==1){break O}i[114610]=0;m=I(402,n|0,f&65535,m+1|0)|0;l=i[114610];i[114610]=0;if((l|0)==1){break O}if(!m){break da}i[114610]=0;I(434,e+96|0,e+48|0,-1)|0;m=i[114610];i[114610]=0;if((m|0)==1){break O}m=Fb(n,f);i[114610]=0;C(435,m|0,e+48|0)|0;m=i[114610];i[114610]=0;if((m|0)==1){break O}m=Fb(n,f);i[114610]=0;G(443,m|0,1,e+96|0);m=i[114610];i[114610]=0;if((m|0)==1){break O}}hb(e+96|0);f=f+1|0;if(f>>>0<(j[d|0]|j[d+1|0]<<8)>>>0){continue}break}}if(!(c&2)){break S}if(!k[a+480190>>1]){break T}d=0;while(1){c=d+1|0;if(!j[$b(s,d)|0]){c=d+1|0;f=o(c,104)+a|0;d=Ic(e+96|0,h[f+484414>>1]&1?16:8,1,0,h[$b(s,d)>>1]>-1?0:6);i[114610]=0;I(400,d|0,f+484380|0,b|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break U}}d=c;if(d>>>0<k[a+480190>>1]){continue}break}break T}b=B()|0;A()|0;break e}b=B()|0;A()|0;break e}if(!k[a+480190>>1]){break S}b=0;while(1){c=j[$b(s,b)|0];ea:{if(!c){break ea}c=c+ -1&65535;if(Wb(t)>>>0<=c>>>0){break ea}c=(j[$b(s,b)+1|0]&127)+k[$b(t,c)>>1]&65535;if(c>>>0>k[a+480190>>1]){break ea}f=o(c,104);n=f+a|0;d=n+484380|0;if(!ie(d)){break ea}p=a+484380|0;m=o(b+1|0,104);c=p+m|0;h[c+34>>1]=k[c+34>>1]&65534|h[(f+p|0)+34>>1]&1;i[c>>2]=i[d>>2];i[114610]=0;c=F(465,c|0)|0;f=i[114610];i[114610]=0;if((f|0)==1){break R}if(!c){break ea}c=i[(a+m|0)+484400>>2];i[114610]=0;c=F(466,c|0)|0;f=i[114610];i[114610]=0;if((f|0)==1){break a}f=i[n+484400>>2];i[114610]=0;f=F(466,f|0)|0;n=i[114610];i[114610]=0;if((n|0)==1){break a}Tb(c,f,hk(d))}b=b+1|0;if(b>>>0<k[a+480190>>1]){continue}break}}df(s);df(t);break c}b=B()|0;A()|0;break e}b=B()|0;A()|0;break e}b=B()|0;A()|0;break e}b=B()|0;A()|0;hb(e+96|0);break e}b=B()|0;A()|0;break e}b=B()|0;A()|0}df(s);df(t)}eb(u);E(b|0);x()}d=1}eb(u)}Xa=e+288|0;return d|0}a=H(0)|0;A()|0;gb(a);x()}function Zc(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,k=0,m=0,n=0,o=0,p=0,q=0,r=0;p=Xa-16|0;Xa=p;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{if(a>>>0<=244){g=i[115920];f=a>>>0<11?16:a+11&-8;a=f>>>3|0;b=g>>>a|0;if(b&3){c=a+((b^-1)&1)|0;f=c<<3;b=i[f+463728>>2];a=b+8|0;d=i[b+8>>2];f=f+463720|0;m:{if((d|0)==(f|0)){q=463680,r=aNa(-2,c)&g,i[q>>2]=r;break m}i[d+12>>2]=f;i[f+8>>2]=d}c=c<<3;i[b+4>>2]=c|3;b=b+c|0;i[b+4>>2]=i[b+4>>2]|1;break a}k=i[115922];if(f>>>0<=k>>>0){break l}if(b){c=2<<a;a=(0-c|c)&b<<a;a=(0-a&a)+ -1|0;b=a>>>12&16;c=b;a=a>>>b|0;b=a>>>5&8;c=c|b;a=a>>>b|0;b=a>>>2&4;c=c|b;a=a>>>b|0;b=a>>>1&2;c=c|b;a=a>>>b|0;b=a>>>1&1;c=(c|b)+(a>>>b|0)|0;d=c<<3;b=i[d+463728>>2];a=i[b+8>>2];d=d+463720|0;n:{if((a|0)==(d|0)){g=aNa(-2,c)&g;i[115920]=g;break n}i[a+12>>2]=d;i[d+8>>2]=a}a=b+8|0;i[b+4>>2]=f|3;e=b+f|0;c=c<<3;f=c-f|0;i[e+4>>2]=f|1;i[b+c>>2]=f;if(k){c=k>>>3|0;b=(c<<3)+463720|0;d=i[115925];c=1<<c;o:{if(!(c&g)){i[115920]=c|g;c=b;break o}c=i[b+8>>2]}i[b+8>>2]=d;i[c+12>>2]=d;i[d+12>>2]=b;i[d+8>>2]=c}i[115925]=e;i[115922]=f;break a}n=i[115921];if(!n){break l}a=(n&0-n)+ -1|0;b=a>>>12&16;c=b;a=a>>>b|0;b=a>>>5&8;c=c|b;a=a>>>b|0;b=a>>>2&4;c=c|b;a=a>>>b|0;b=a>>>1&2;c=c|b;a=a>>>b|0;b=a>>>1&1;b=i[((c|b)+(a>>>b|0)<<2)+463984>>2];e=(i[b+4>>2]&-8)-f|0;c=b;while(1){p:{a=i[c+16>>2];if(!a){a=i[c+20>>2];if(!a){break p}}d=(i[a+4>>2]&-8)-f|0;c=d>>>0<e>>>0;e=c?d:e;b=c?a:b;c=a;continue}break}o=b+f|0;if(o>>>0<=b>>>0){break k}m=i[b+24>>2];d=i[b+12>>2];if((d|0)!=(b|0)){a=i[b+8>>2];i[a+12>>2]=d;i[d+8>>2]=a;break b}c=b+20|0;a=i[c>>2];if(!a){a=i[b+16>>2];if(!a){break j}c=b+16|0}while(1){h=c;d=a;c=a+20|0;a=i[c>>2];if(a){continue}c=d+16|0;a=i[d+16>>2];if(a){continue}break}i[h>>2]=0;break b}f=-1;if(a>>>0>4294967231){break l}a=a+11|0;f=a&-8;k=i[115921];if(!k){break l}h=31;e=0-f|0;if(f>>>0<=16777215){b=a>>>8|0;a=b+1048320>>>16&8;c=b<<a;b=c+520192>>>16&4;g=c<<b;c=g+245760>>>16&2;a=(g<<c>>>15|0)-(c|(a|b))|0;h=(a<<1|f>>>a+21&1)+28|0}c=i[(h<<2)+463984>>2];q:{r:{s:{if(!c){a=0;break s}a=0;b=f<<((h|0)==31?0:25-(h>>>1|0)|0);while(1){t:{g=(i[c+4>>2]&-8)-f|0;if(g>>>0>=e>>>0){break t}d=c;e=g;if(e){break t}e=0;a=c;break r}g=i[c+20>>2];c=i[((b>>>29&4)+c|0)+16>>2];a=g?(g|0)==(c|0)?a:g:a;b=b<<1;if(c){continue}break}}if(!(a|d)){a=2<<h;a=(0-a|a)&k;if(!a){break l}a=(a&0-a)+ -1|0;b=a>>>12&16;c=b;a=a>>>b|0;b=a>>>5&8;c=c|b;a=a>>>b|0;b=a>>>2&4;c=c|b;a=a>>>b|0;b=a>>>1&2;c=c|b;a=a>>>b|0;b=a>>>1&1;a=i[((c|b)+(a>>>b|0)<<2)+463984>>2]}if(!a){break q}}while(1){c=(i[a+4>>2]&-8)-f|0;b=c>>>0<e>>>0;e=b?c:e;d=b?a:d;b=i[a+16>>2];if(b){a=b}else{a=i[a+20>>2]}if(a){continue}break}}if(!d|e>>>0>=i[115922]-f>>>0){break l}h=d+f|0;if(h>>>0<=d>>>0){break k}m=i[d+24>>2];b=i[d+12>>2];if((d|0)!=(b|0)){a=i[d+8>>2];i[a+12>>2]=b;i[b+8>>2]=a;break c}c=d+20|0;a=i[c>>2];if(!a){a=i[d+16>>2];if(!a){break i}c=d+16|0}while(1){g=c;b=a;c=a+20|0;a=i[c>>2];if(a){continue}c=b+16|0;a=i[b+16>>2];if(a){continue}break}i[g>>2]=0;break c}b=i[115922];if(b>>>0>=f>>>0){a=i[115925];c=b-f|0;u:{if(c>>>0>=16){i[115922]=c;d=a+f|0;i[115925]=d;i[d+4>>2]=c|1;i[a+b>>2]=c;i[a+4>>2]=f|3;break u}i[115925]=0;i[115922]=0;i[a+4>>2]=b|3;b=a+b|0;i[b+4>>2]=i[b+4>>2]|1}a=a+8|0;break a}d=i[115923];if(d>>>0>f>>>0){b=d-f|0;i[115923]=b;a=i[115926];c=a+f|0;i[115926]=c;i[c+4>>2]=b|1;i[a+4>>2]=f|3;a=a+8|0;break a}a=0;e=f+47|0;c=e;if(i[116038]){b=i[116040]}else{i[116041]=-1;i[116042]=-1;i[116039]=4096;i[116040]=4096;i[116038]=p+12&-16^1431655768;i[116043]=0;i[116031]=0;b=4096}g=c+b|0;h=0-b|0;c=g&h;if(c>>>0<=f>>>0){break a}b=i[116030];if(b){k=i[116028];m=k+c|0;if(m>>>0<=k>>>0|m>>>0>b>>>0){break a}}if(j[464124]&4){break f}v:{w:{b=i[115926];if(b){a=464128;while(1){k=i[a>>2];if(k+i[a+4>>2]>>>0>b>>>0?k>>>0<=b>>>0:0){break w}a=i[a+8>>2];if(a){continue}break}}b=yk(0);if((b|0)==-1){break g}g=c;a=i[116039];d=a+ -1|0;if(d&b){g=(c-b|0)+(b+d&0-a)|0}if(g>>>0<=f>>>0|g>>>0>2147483646){break g}a=i[116030];if(a){d=i[116028];h=d+g|0;if(h>>>0<=d>>>0|h>>>0>a>>>0){break g}}a=yk(g);if((b|0)!=(a|0)){break v}break e}g=h&g-d;if(g>>>0>2147483646){break g}b=yk(g);if((b|0)==(i[a>>2]+i[a+4>>2]|0)){break h}a=b}if(!((a|0)==-1|f+48>>>0<=g>>>0)){b=i[116040];b=b+(e-g|0)&0-b;if(b>>>0>2147483646){b=a;break e}if((yk(b)|0)!=-1){g=b+g|0;b=a;break e}yk(0-g|0);break g}b=a;if((a|0)!=-1){break e}break g}x()}d=0;break b}b=0;break c}if((b|0)!=-1){break e}}i[116031]=i[116031]|4}if(c>>>0>2147483646){break d}b=yk(c);a=yk(0);if(b>>>0>=a>>>0|(b|0)==-1|(a|0)==-1){break d}g=a-b|0;if(g>>>0<=f+40>>>0){break d}}a=i[116028]+g|0;i[116028]=a;if(a>>>0>l[116029]){i[116029]=a}x:{y:{z:{e=i[115926];if(e){a=464128;while(1){c=i[a>>2];d=i[a+4>>2];if((c+d|0)==(b|0)){break z}a=i[a+8>>2];if(a){continue}break}break y}a=i[115924];if(!(b>>>0>=a>>>0?a:0)){i[115924]=b}a=0;i[116033]=g;i[116032]=b;i[115928]=-1;i[115929]=i[116038];i[116035]=0;while(1){c=a<<3;d=c+463720|0;i[c+463728>>2]=d;i[c+463732>>2]=d;a=a+1|0;if((a|0)!=32){continue}break}a=g+ -40|0;c=b+8&7?-8-b&7:0;d=a-c|0;i[115923]=d;c=b+c|0;i[115926]=c;i[c+4>>2]=d|1;i[(a+b|0)+4>>2]=40;i[115927]=i[116042];break x}if(j[a+12|0]&8|b>>>0<=e>>>0|c>>>0>e>>>0){break y}i[a+4>>2]=d+g;a=e+8&7?-8-e&7:0;b=a+e|0;i[115926]=b;c=i[115923]+g|0;a=c-a|0;i[115923]=a;i[b+4>>2]=a|1;i[(c+e|0)+4>>2]=40;i[115927]=i[116042];break x}d=i[115924];if(b>>>0<d>>>0){i[115924]=b;d=0}c=b+g|0;a=464128;A:{B:{C:{D:{E:{F:{while(1){if((c|0)!=i[a>>2]){a=i[a+8>>2];if(a){continue}break F}break}if(!(j[a+12|0]&8)){break E}}a=464128;while(1){c=i[a>>2];if(c>>>0<=e>>>0){d=c+i[a+4>>2]|0;if(d>>>0>e>>>0){break D}}a=i[a+8>>2];continue}}i[a>>2]=b;i[a+4>>2]=i[a+4>>2]+g;m=(b+8&7?-8-b&7:0)+b|0;i[m+4>>2]=f|3;b=c+(c+8&7?-8-c&7:0)|0;a=(b-m|0)-f|0;h=f+m|0;if((b|0)==(e|0)){i[115926]=h;a=i[115923]+a|0;i[115923]=a;i[h+4>>2]=a|1;break B}if(i[115925]==(b|0)){i[115925]=h;a=i[115922]+a|0;i[115922]=a;i[h+4>>2]=a|1;i[a+h>>2]=a;break B}c=i[b+4>>2];if((c&3)==1){n=c&-8;G:{if(c>>>0<=255){f=c>>>3|0;c=i[b+8>>2];d=i[b+12>>2];if((d|0)==(c|0)){q=463680,r=i[115920]&aNa(-2,f),i[q>>2]=r;break G}i[c+12>>2]=d;i[d+8>>2]=c;break G}k=i[b+24>>2];g=i[b+12>>2];H:{if((g|0)!=(b|0)){c=i[b+8>>2];i[c+12>>2]=g;i[g+8>>2]=c;break H}I:{e=b+20|0;f=i[e>>2];if(f){break I}e=b+16|0;f=i[e>>2];if(f){break I}g=0;break H}while(1){c=e;g=f;e=f+20|0;f=i[e>>2];if(f){continue}e=g+16|0;f=i[g+16>>2];if(f){continue}break}i[c>>2]=0}if(!k){break G}c=i[b+28>>2];d=(c<<2)+463984|0;J:{if(i[d>>2]==(b|0)){i[d>>2]=g;if(g){break J}q=463684,r=i[115921]&aNa(-2,c),i[q>>2]=r;break G}i[k+(i[k+16>>2]==(b|0)?16:20)>>2]=g;if(!g){break G}}i[g+24>>2]=k;c=i[b+16>>2];if(c){i[g+16>>2]=c;i[c+24>>2]=g}c=i[b+20>>2];if(!c){break G}i[g+20>>2]=c;i[c+24>>2]=g}b=b+n|0;a=a+n|0}i[b+4>>2]=i[b+4>>2]&-2;i[h+4>>2]=a|1;i[a+h>>2]=a;if(a>>>0<=255){b=a>>>3|0;a=(b<<3)+463720|0;c=i[115920];b=1<<b;K:{if(!(c&b)){i[115920]=b|c;b=a;break K}b=i[a+8>>2]}i[a+8>>2]=h;i[b+12>>2]=h;i[h+12>>2]=a;i[h+8>>2]=b;break B}e=31;if(a>>>0<=16777215){c=a>>>8|0;b=c+1048320>>>16&8;d=c<<b;c=d+520192>>>16&4;f=d<<c;d=f+245760>>>16&2;b=(f<<d>>>15|0)-(d|(b|c))|0;e=(b<<1|a>>>b+21&1)+28|0}i[h+28>>2]=e;i[h+16>>2]=0;i[h+20>>2]=0;b=(e<<2)+463984|0;c=i[115921];d=1<<e;L:{if(!(c&d)){i[115921]=c|d;i[b>>2]=h;i[h+24>>2]=b;break L}e=a<<((e|0)==31?0:25-(e>>>1|0)|0);b=i[b>>2];while(1){c=b;if((i[b+4>>2]&-8)==(a|0)){break C}b=e>>>29|0;e=e<<1;d=c+(b&4)|0;b=i[d+16>>2];if(b){continue}break}i[d+16>>2]=h;i[h+24>>2]=c}i[h+12>>2]=h;i[h+8>>2]=h;break B}a=g+ -40|0;c=b+8&7?-8-b&7:0;h=a-c|0;i[115923]=h;c=b+c|0;i[115926]=c;i[c+4>>2]=h|1;i[(a+b|0)+4>>2]=40;i[115927]=i[116042];a=(d+(d+ -39&7?39-d&7:0)|0)+ -47|0;c=a>>>0<e+16>>>0?e:a;i[c+4>>2]=27;a=i[116035];i[c+16>>2]=i[116034];i[c+20>>2]=a;a=i[116033];i[c+8>>2]=i[116032];i[c+12>>2]=a;i[116034]=c+8;i[116033]=g;i[116032]=b;i[116035]=0;a=c+24|0;while(1){i[a+4>>2]=7;b=a+8|0;a=a+4|0;if(d>>>0>b>>>0){continue}break}if((c|0)==(e|0)){break x}i[c+4>>2]=i[c+4>>2]&-2;d=c-e|0;i[e+4>>2]=d|1;i[c>>2]=d;if(d>>>0<=255){b=d>>>3|0;a=(b<<3)+463720|0;c=i[115920];b=1<<b;M:{if(!(c&b)){i[115920]=b|c;b=a;break M}b=i[a+8>>2]}i[a+8>>2]=e;i[b+12>>2]=e;i[e+12>>2]=a;i[e+8>>2]=b;break x}a=31;i[e+16>>2]=0;i[e+20>>2]=0;if(d>>>0<=16777215){b=d>>>8|0;a=b+1048320>>>16&8;c=b<<a;b=c+520192>>>16&4;g=c<<b;c=g+245760>>>16&2;a=(g<<c>>>15|0)-(c|(a|b))|0;a=(a<<1|d>>>a+21&1)+28|0}i[e+28>>2]=a;b=(a<<2)+463984|0;c=i[115921];g=1<<a;N:{if(!(c&g)){i[115921]=c|g;i[b>>2]=e;i[e+24>>2]=b;break N}a=d<<((a|0)==31?0:25-(a>>>1|0)|0);b=i[b>>2];while(1){c=b;if((d|0)==(i[b+4>>2]&-8)){break A}b=a>>>29|0;a=a<<1;g=c+(b&4)|0;b=i[g+16>>2];if(b){continue}break}i[g+16>>2]=e;i[e+24>>2]=c}i[e+12>>2]=e;i[e+8>>2]=e;break x}a=i[c+8>>2];i[a+12>>2]=h;i[c+8>>2]=h;i[h+24>>2]=0;i[h+12>>2]=c;i[h+8>>2]=a}a=m+8|0;break a}a=i[c+8>>2];i[a+12>>2]=e;i[c+8>>2]=e;i[e+24>>2]=0;i[e+12>>2]=c;i[e+8>>2]=a}a=i[115923];if(a>>>0<=f>>>0){break d}b=a-f|0;i[115923]=b;a=i[115926];c=a+f|0;i[115926]=c;i[c+4>>2]=b|1;i[a+4>>2]=f|3;a=a+8|0;break a}i[114584]=48;a=0;break a}O:{if(!m){break O}a=i[d+28>>2];c=(a<<2)+463984|0;P:{if(i[c>>2]==(d|0)){i[c>>2]=b;if(b){break P}k=aNa(-2,a)&k;i[115921]=k;break O}i[m+(i[m+16>>2]==(d|0)?16:20)>>2]=b;if(!b){break O}}i[b+24>>2]=m;a=i[d+16>>2];if(a){i[b+16>>2]=a;i[a+24>>2]=b}a=i[d+20>>2];if(!a){break O}i[b+20>>2]=a;i[a+24>>2]=b}Q:{if(e>>>0<=15){a=e+f|0;i[d+4>>2]=a|3;a=a+d|0;i[a+4>>2]=i[a+4>>2]|1;break Q}i[d+4>>2]=f|3;i[h+4>>2]=e|1;i[e+h>>2]=e;if(e>>>0<=255){b=e>>>3|0;a=(b<<3)+463720|0;c=i[115920];b=1<<b;R:{if(!(c&b)){i[115920]=b|c;b=a;break R}b=i[a+8>>2]}i[a+8>>2]=h;i[b+12>>2]=h;i[h+12>>2]=a;i[h+8>>2]=b;break Q}a=31;if(e>>>0<=16777215){b=e>>>8|0;a=b+1048320>>>16&8;c=b<<a;b=c+520192>>>16&4;f=c<<b;c=f+245760>>>16&2;a=(f<<c>>>15|0)-(c|(a|b))|0;a=(a<<1|e>>>a+21&1)+28|0}i[h+28>>2]=a;i[h+16>>2]=0;i[h+20>>2]=0;b=(a<<2)+463984|0;S:{c=1<<a;T:{if(!(c&k)){i[115921]=c|k;i[b>>2]=h;break T}a=e<<((a|0)==31?0:25-(a>>>1|0)|0);f=i[b>>2];while(1){b=f;if((i[b+4>>2]&-8)==(e|0)){break S}c=a>>>29|0;a=a<<1;c=(c&4)+b|0;f=i[c+16>>2];if(f){continue}break}i[c+16>>2]=h}i[h+24>>2]=b;i[h+12>>2]=h;i[h+8>>2]=h;break Q}a=i[b+8>>2];i[a+12>>2]=h;i[b+8>>2]=h;i[h+24>>2]=0;i[h+12>>2]=b;i[h+8>>2]=a}a=d+8|0;break a}U:{if(!m){break U}a=i[b+28>>2];c=(a<<2)+463984|0;V:{if(i[c>>2]==(b|0)){i[c>>2]=d;if(d){break V}q=463684,r=aNa(-2,a)&n,i[q>>2]=r;break U}i[m+(i[m+16>>2]==(b|0)?16:20)>>2]=d;if(!d){break U}}i[d+24>>2]=m;a=i[b+16>>2];if(a){i[d+16>>2]=a;i[a+24>>2]=d}a=i[b+20>>2];if(!a){break U}i[d+20>>2]=a;i[a+24>>2]=d}W:{if(e>>>0<=15){a=e+f|0;i[b+4>>2]=a|3;a=a+b|0;i[a+4>>2]=i[a+4>>2]|1;break W}i[b+4>>2]=f|3;i[o+4>>2]=e|1;i[e+o>>2]=e;if(k){c=k>>>3|0;a=(c<<3)+463720|0;d=i[115925];c=1<<c;X:{if(!(c&g)){i[115920]=c|g;c=a;break X}c=i[a+8>>2]}i[a+8>>2]=d;i[c+12>>2]=d;i[d+12>>2]=a;i[d+8>>2]=c}i[115925]=o;i[115922]=e}a=b+8|0}Xa=p+16|0;return a|0}function hla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,l=0,m=0,n=0,p=0,q=0,r=0,s=0,t=0;d=Xa-720|0;Xa=d;pc(b);a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{if(!Se(b,d+712|0)){break D}if(!RI(d+712|0)){break D}if(!lp(b,d+704|0)){break D}if(!QI(d+704|0)){break D}n=1313423693;f=j[d+704|0]|j[d+705|0]<<8|(j[d+706|0]<<16|j[d+707|0]<<24);if((f|0)!=1179012417){n=1414090313;if((f|0)!=538987841){break D}}r=gk(d+688|0,b);p=Iw(d+672|0);E:{F:{G:{H:{I:{J:{K:{L:{M:{if(!c){i[114610]=0;J(1535,d+112|0,r|0,((f|0)==1179012417?1:2)|0,n|0);b=i[114610];i[114610]=0;if((b|0)!=1){break M}a=B()|0;A()|0;break a}i[114610]=0;G(1536,d+112|0,r|0,((f|0)==1179012417?1:2)|0);b=i[114610];i[114610]=0;if((b|0)==1){break L}}Mka(p,d+112|0);Wk(d+112|0);i[114610]=0;G(1537,d+656|0,p|0,n|0);b=i[114610];i[114610]=0;if((b|0)!=1){i[114610]=0;b=F(337,d+656|0)|0;l=i[114610];i[114610]=0;if((l|0)==1){break G}l=0;if(!b){break E}i[114610]=0;b=C(1538,d+656|0,d+576|0)|0;n=i[114610];i[114610]=0;if((n|0)==1){break G}if(!b|!j[d+641|0]){break E}b=j[d+641|0];i[114610]=0;l=C(258,d+656|0,b|0)|0;b=i[114610];i[114610]=0;if((b|0)==1){break G}if(!c|l^1){break E}i[114610]=0;D(447,a|0,8388608);b=i[114610];i[114610]=0;if((b|0)==1){break G}i[a+480208>>2]=12;i[a+480208>>2]=i[a+480208>>2]&-17|(j[d+640|0]<<4^-1)&16;b=j[d+641|0];i[114610]=0;h[d+112>>1]=b;h[d+480>>1]=127;b=C(477,d+112|0,d+480|0)|0;l=i[114610];i[114610]=0;if((l|0)==1){break K}h[a+480188>>1]=k[b>>1];i[a+480196>>2]=j[d+642|0];i[a+480204>>2]=o(j[d+643|0],1e4);i[a+480200>>2]=j[d+648|0]<<1;i[114610]=0;C(238,a+1304436|0,((f|0)==1179012417?31699:31665)|0)|0;b=i[114610];i[114610]=0;if((b|0)==1){break G}i[114610]=0;b=C(2,d+112|0,31733)|0;l=i[114610];i[114610]=0;if((l|0)==1){break I}mb(a+1304448|0,b);eb(b);i[a+1304496>>2]=4;i[114610]=0;G(1539,d+480|0,2,d+576|0);b=i[114610];i[114610]=0;if((b|0)==1){break J}i[114610]=0;D(415,d+112|0,d+480|0);b=i[114610];i[114610]=0;if((b|0)==1){break J}mb(a+1304400|0,d+112|0);eb(d+112|0);if(!k[a+480188>>1]){break H}m=(f|0)==1179012417;b=0;while(1){i[114610]=0;n=(b<<5)+a|0;e=n+480280|0;L(432,e|0);l=i[114610];i[114610]=0;N:{O:{P:{Q:{R:{if((l|0)!=1){i[114610]=0;l=F(387,d+656|0)|0;q=i[114610];i[114610]=0;if((q|0)==1){break R}if(m){break Q}if(l>>>0<129){break P}break O}a=B()|0;A()|0;break b}a=B()|0;A()|0;break b}if(l<<24>>24<=-1){break O}i[114610]=0;i[d+112>>2]=l<<2;i[d+480>>2]=256;l=C(462,d+112|0,d+480|0)|0;e=i[114610];i[114610]=0;if((e|0)!=1){h[n+480284>>1]=i[l>>2];break N}a=B()|0;A()|0;break b}h[n+480284>>1]=l<<1;break N}i[e>>2]=1024}b=b+1|0;if(b>>>0<k[a+480188>>1]){continue}break}break H}a=B()|0;A()|0;break a}a=B()|0;A()|0;break a}a=B()|0;A()|0;break b}a=B()|0;A()|0;break b}a=B()|0;A()|0;break b}i[114610]=0;b=C(1540,p|0,1380209231)|0;l=i[114610];i[114610]=0;if((l|0)!=1){break F}}a=B()|0;A()|0;break b}if(b){i[114610]=0;G(1537,d+112|0,p|0,1380209231);b=i[114610];i[114610]=0;if((b|0)==1){break c}i[114610]=0;b=F(387,d+112|0)|0;l=i[114610];i[114610]=0;if((l|0)==1){break d}l=Db(a+484360|0);i[114610]=0;S(584,l|0,d+112|0,b+1&255,255,254)|0;b=i[114610];i[114610]=0;if((b|0)==1){break d}hb(d+112|0)}if(c&1){i[114610]=0;h[d+40>>1]=0;G(1541,d+480|0,p|0,1414807888);b=i[114610];i[114610]=0;if((b|0)==1){break e}b=Wc(d+480|0);i[114610]=0;l=a+484344|0;D(401,l|0,b&65535);b=i[114610];i[114610]=0;if((b|0)==1){break k}s=d,t=Jb(d+480|0),i[s+544>>2]=t;s=d,t=Kb(d+480|0),i[s+64>>2]=t;if(pb(d+544|0,d- -64|0)){n=(f|0)!=1179012417;while(1){b=He(d+112|0,i[d+544>>2]);i[114610]=0;m=F(387,b|0)|0;e=i[114610];i[114610]=0;if((e|0)==1){break h}i[114610]=0;h[d+464>>1]=m;m=F(390,b|0)|0;e=i[114610];i[114610]=0;if((e|0)==1){break i}i[114610]=0;G(341,d+560|0,b|0,m|0);m=i[114610];i[114610]=0;if((m|0)==1){break i}i[114610]=0;J(1542,d+560|0,k[d+464>>1],n|0,a|0);m=i[114610];i[114610]=0;if((m|0)==1){break j}hb(d+560|0);i[114610]=0;m=C(452,d+40|0,d+464|0)|0;e=i[114610];i[114610]=0;if((e|0)==1){break i}h[d+40>>1]=k[m>>1];hb(b);vf(d+544|0);if(pb(d+544|0,d- -64|0)){continue}break}}if(k[d+40>>1]){b=0;while(1){i[114610]=0;n=b&65535;m=C(442,l|0,n|0)|0;e=i[114610];i[114610]=0;S:{if((e|0)!=1){if(m){break S}i[114610]=0;I(402,l|0,n|0,64)|0;n=i[114610];i[114610]=0;if((n|0)!=1){break S}}a=B()|0;A()|0;break f}b=b+1|0;if((b&65535)>>>0<k[d+40>>1]){continue}break}}Qc(d+480|0)}T:{if((f|0)==1179012417){i[114610]=0;G(1541,d- -64|0,p|0,1414745673);b=i[114610];i[114610]=0;if((b|0)==1){break B}s=d,t=Jb(d- -64|0),i[s+96>>2]=t;s=d,t=Kb(d- -64|0),i[s+24>>2]=t;U:{if(pb(d+96|0,d+24|0)){l=c&2;n=d+488|0;m=d+112|1;while(1){c=He(d+544|0,i[d+96>>2]);i[114610]=0;b=C(1543,c|0,d+112|0)|0;f=i[114610];i[114610]=0;if((f|0)==1){break U}V:{if(!b){break V}b=j[m|0];if((b|0)==255){break V}i[114610]=0;b=I(454,a|0,b+1|0,0)|0;f=i[114610];i[114610]=0;if((f|0)==1){break A}if(!b){break V}f=k[a+480190>>1];i[114610]=0;G(1544,d+112|0,b|0,f|0);b=i[114610];i[114610]=0;if((b|0)==1){break A}b=0;if(!j[d+142|0]){break V}while(1){W:{if(!bn(a)){break W}i[114610]=0;f=C(1545,c|0,d+480|0)|0;e=i[114610];i[114610]=0;if((e|0)==1){break z}if(!f){break W}f=k[a+480190>>1]+1|0;h[a+480190>>1]=f;if((j[d+480|0]|j[d+481|0]<<8|(j[d+482|0]<<16|j[d+483|0]<<24))!=1347240275){break W}i[114610]=0;G(580,d+464|0,2,n|0);e=i[114610];i[114610]=0;X:{Y:{Z:{if((e|0)==1){break Z}i[114610]=0;D(415,d+40|0,d+464|0);e=i[114610];i[114610]=0;if((e|0)==1){break Z}i[114610]=0;f=f&65535;C(369,((f<<5)+a|0)+946300|0,d+40|0)|0;e=i[114610];i[114610]=0;if((e|0)==1){break Y}eb(d+40|0);i[114610]=0;f=(o(f,104)+a|0)+484380|0;G(1546,d+480|0,d+112|0,f|0);e=i[114610];i[114610]=0;if((e|0)==1){break m}if(!l){break X}i[114610]=0;D(1547,d+40|0,d+480|0);e=i[114610];i[114610]=0;if((e|0)!=1){i[114610]=0;I(400,d+40|0,f|0,c|0)|0;f=i[114610];i[114610]=0;if((f|0)!=1){break W}}a=B()|0;A()|0;break l}a=B()|0;A()|0;break l}a=B()|0;A()|0;eb(d+40|0);break l}f=hk(f);i[114610]=0;C(338,c|0,f|0)|0;f=i[114610];i[114610]=0;if((f|0)==1){break m}}b=b+1|0;if(b>>>0<j[d+142|0]){continue}break}}hb(c);vf(d+96|0);if(pb(d+96|0,d+24|0)){continue}break}}Qc(d- -64|0);break T}a=B()|0;A()|0;break l}i[114610]=0;G(1541,d+464|0,p|0,1179011410);b=i[114610];i[114610]=0;if((b|0)==1){break y}s=d,t=Jb(d+464|0),i[s+456>>2]=t;s=d,t=Kb(d+464|0),i[s+448>>2]=t;if(pb(d+456|0,d+448|0)){f=c&2;l=d+480|4;c=d+56|4;n=d+112|5;while(1){m=gk(d+544|0,i[d+456>>2]);i[114610]=0;b=F(390,d+544|0)|0;e=i[114610];i[114610]=0;if((e|0)==1){break x}_:{if((b|0)!=538986817){break _}i[114610]=0;b=C(1548,d+544|0,d+440|0)|0;e=i[114610];i[114610]=0;if((e|0)==1){break w}if(!b|(j[d+440|0]|j[d+441|0]<<8|(j[d+442|0]<<16|j[d+443|0]<<24))!=1414745673){break _}i[114610]=0;b=C(1549,d+544|0,d+112|0)|0;e=i[114610];i[114610]=0;if((e|0)==1){break v}if(!b){break _}b=j[n|0];if((b|0)==255){break _}i[114610]=0;b=I(454,a|0,b+1|0,0)|0;e=i[114610];i[114610]=0;if((e|0)==1){break u}if(!b){break _}e=k[a+480190>>1];i[114610]=0;G(1550,d+112|0,b|0,e|0);b=i[114610];i[114610]=0;if((b|0)==1){break u}i[114610]=0;G(1536,d+480|0,m|0,2);b=i[114610];i[114610]=0;if((b|0)==1){break C}i[114610]=0;G(1541,d+96|0,d+480|0,1179011410);b=i[114610];i[114610]=0;if((b|0)==1){break t}Wk(d+480|0);s=d,t=Jb(d+96|0),i[s+88>>2]=t;s=d,t=Kb(d+96|0),i[s+80>>2]=t;$:{if(!pb(d+88|0,d+80|0)){break $}aa:{while(1){b=He(d- -64|0,i[d+88>>2]);i[114610]=0;m=F(390,b|0)|0;e=i[114610];i[114610]=0;if((e|0)==1){break s}ba:{ca:{if((m|0)!=538989377){break ca}if(!bn(a)){break ca}m=j[d+436|0]|j[d+437|0]<<8;e=m+ -1|0;g[d+436|0]=e;g[d+437|0]=e>>>8;if(!m){hb(b);break $}m=k[a+480190>>1]+1|0;h[a+480190>>1]=m;i[114610]=0;e=C(1548,b|0,d+56|0)|0;q=i[114610];i[114610]=0;if((q|0)==1){break r}da:{if(!(!e|(j[d+56|0]|j[d+57|0]<<8|(j[d+58|0]<<16|j[d+59|0]<<24))!=1347240275)){e=j[c|0]|j[c+1|0]<<8|(j[c+2|0]<<16|j[c+3|0]<<24);i[114610]=0;G(341,d+40|0,b|0,e|0);e=i[114610];i[114610]=0;ea:{if((e|0)!=1){i[114610]=0;e=C(1551,d+40|0,d+480|0)|0;q=i[114610];i[114610]=0;if((q|0)==1){break ba}if(!e){break aa}i[114610]=0;G(748,d+8|0,2,l|0);e=i[114610];i[114610]=0;if((e|0)!=1){i[114610]=0;D(415,d+24|0,d+8|0);e=i[114610];i[114610]=0;if((e|0)!=1){break ea}}a=B()|0;A()|0;break p}a=B()|0;A()|0;break o}i[114610]=0;m=m&65535;C(369,((m<<5)+a|0)+946300|0,d+24|0)|0;e=i[114610];i[114610]=0;if((e|0)==1){break q}eb(d+24|0);i[114610]=0;m=(o(m,104)+a|0)+484380|0;G(1552,d+480|0,d+112|0,m|0);e=i[114610];i[114610]=0;if((e|0)==1){break ba}if(!f){break da}e=j[d+480|0]|j[d+481|0]<<8|(j[d+482|0]<<16|j[d+483|0]<<24);i[114610]=0;C(256,d+40|0,e+4|0)|0;e=i[114610];i[114610]=0;if((e|0)==1){break ba}i[114610]=0;D(1553,d+24|0,d+480|0);e=i[114610];i[114610]=0;if((e|0)!=1){i[114610]=0;I(400,d+24|0,m|0,d+40|0)|0;m=i[114610];i[114610]=0;if((m|0)!=1){break da}}a=B()|0;A()|0;break p}hb(b);break $}hb(d+40|0)}hb(b);vf(d+88|0);if(pb(d+88|0,d+80|0)){continue}break $}break}a=B()|0;A()|0;break p}hb(d+40|0);hb(b)}Qc(d+96|0)}hb(d+544|0);vf(d+456|0);if(pb(d+456|0,d+448|0)){continue}break}}Qc(d+464|0)}l=1}hb(d+656|0);Wk(p);hb(r)}Xa=d+720|0;return l|0}a=B()|0;A()|0;break n}a=B()|0;A()|0;break b}a=B()|0;A()|0;break l}a=B()|0;A()|0;break l}a=B()|0;A()|0;break b}a=B()|0;A()|0;break n}a=B()|0;A()|0;break n}a=B()|0;A()|0;break n}a=B()|0;A()|0;break n}a=B()|0;A()|0;Wk(d+480|0);break n}a=B()|0;A()|0;break o}a=B()|0;A()|0;break o}a=B()|0;A()|0;eb(d+24|0)}hb(d+40|0)}hb(b);Qc(d+96|0)}hb(d+544|0);Qc(d+464|0);break b}a=B()|0;A()|0}hb(c);Qc(d- -64|0);break b}a=B()|0;A()|0;break f}a=B()|0;A()|0;hb(d+560|0);break g}a=B()|0;A()|0;break g}a=B()|0;A()|0}hb(b)}Qc(d+480|0);break b}a=B()|0;A()|0;break b}a=B()|0;A()|0;hb(d+112|0);break b}a=B()|0;A()|0}hb(d+656|0)}Wk(p);hb(r);E(a|0);x()}function xT(a,b,c,d){var e=0,f=0,j=0,k=0,m=0;f=Xa-32|0;Xa=f;a:{b:{c:{d:{e:{f:{g:{h:{i:{if(!a){break i}j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{I:{J:{K:{L:{M:{N:{O:{P:{Q:{R:{S:{if((b|0)<=1347628589){if((b|0)<=1297100333){if((b|0)<=1179931727){if((b|0)<=1145263149){if((b|0)==1095062094){break t}if((b|0)==1095126087){break q}if((b|0)!=1129524782|c>>>0>1){break i}if(!wb(d,c)){break i}k=a,m=Rc(d,c),g[k+23|0]=m;e=1;break i}if((b|0)<=1179463213){if((b|0)==1145263150){break I}if((b|0)!=1145979182|c>>>0>1){break i}if(!wb(d,c)){break i}k=a,m=Rc(d,c),g[k+18|0]=m;e=1;break i}if((b|0)==1179463214){break w}if((b|0)!=1179594286|c>>>0>4){break i}if(!wb(d,c)){break i}k=a,m=nk(d,c),i[k>>2]=m;e=1;break i}if((b|0)<=1229345325){if((b|0)==1179931728){break j}if((b|0)==1196830254){break S}if((b|0)!=1229341486|c>>>0>1){break i}if(!wb(d,c)){break i}k=a,m=Rc(d,c),g[k+21|0]=m;e=1;break i}if((b|0)<=1296182829){if((b|0)==1229345326){break F}if((b|0)!=1264266798|256<c>>>0){break i}a=a+236|0;ad(f+16|0,d,c);b=0;while(1){i[114610]=0;c=F(373,f+16|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break A}k=Mc(a,b),m=c,h[k>>1]=m;b=b+1|0;if(b>>>0<128){continue}break}hb(f+16|0);e=1;break i}if((b|0)==1296182830){break E}if((b|0)!=1296248366|c>>>0>1){break i}if(!wb(d,c)){break i}k=a,m=Rc(d,c),g[k+31|0]=m;e=1;break i}if((b|0)<=1346720333){if((b|0)<=1313692461){if((b|0)==1297100334){break D}if((b|0)==1297110852){break o}if((b|0)!=1298747438|c>>>0>1){break i}if(!wb(d,c)){break i}k=a,m=Rc(d,c),g[k+34|0]=m;e=1;break i}if((b|0)<=1345203757){if((b|0)==1313692462){break B}if((b|0)!=1313751342|c>>>0>1){break i}if(!wb(d,c)){break i}k=a,m=Rc(d,c),g[k+16|0]=m;e=1;break i}if((b|0)==1345203758){break R}if((b|0)!=1346711086){break i}i[f+16>>2]=240;k=f,m=nk(d,c),i[k>>2]=m;Lf(a+68|0,i[rb(f+16|0,f)>>2]);e=1;break i}if((b|0)<=1347179309){if((b|0)<=1346784326){if((b|0)==1346720334){break u}if((b|0)!=1346722606){break i}ad(f+16|0,d,c);i[114610]=0;a=C(374,a|0,1)|0;b=i[114610];i[114610]=0;if((b|0)==1){break f}if(qb(a)){b=0;while(1){i[114610]=0;c=F(375,f+16|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break f}k=vb(a,b),m=c,g[k+2|0]=m;b=b+1|0;if(b>>>0<qb(a)>>>0){continue}break}}hb(f+16|0);e=1;break i}if((b|0)==1346784327){break r}if((b|0)!=1347175726|c>>>0>1){break i}if(!wb(d,c)){break i}k=a,m=Rc(d,c),g[k+82|0]=m;e=1;break i}if((b|0)<=1347441453){if((b|0)==1347179310){break O}if((b|0)!=1347437358|c>>>0>1){break i}if(!wb(d,c)){break i}k=a,m=Rc(d,c),g[k+27|0]=m;e=1;break i}if((b|0)==1347441454){break C}if((b|0)!=1347443502){break i}ad(f+16|0,d,c);i[114610]=0;a=C(374,a|0,1)|0;b=i[114610];i[114610]=0;if((b|0)==1){break c}if(qb(a)){b=0;while(1){i[114610]=0;c=F(373,f+16|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break c}k=vb(a,b),m=c,h[k>>1]=m;b=b+1|0;if(b>>>0<qb(a)>>>0){continue}break}}hb(f+16|0);e=1;break i}if((b|0)<=1447374381){if((b|0)<=1349078084){if((b|0)<=1347831111){if((b|0)<=1347634477){if((b|0)==1347628590){break H}if((b|0)!=1347633710|c>>>0>1){break i}if(!wb(d,c)){break i}k=a,m=Rc(d,c),g[k+83|0]=m;e=1;break i}if((b|0)==1347634478){break N}if((b|0)!=1347703884){break i}k=a,m=o(Ap(d,c),1e4)+(l[a+40>>2]%1e4|0)|0,i[k+40>>2]=m;e=1;break i}if((b|0)<=1349076269){if((b|0)==1347831112){break v}if((b|0)!=1347833672|c>>>0>1){break i}if(!wb(d,c)){break i}k=a,m=Rc(d,c),g[k+36|0]=m;e=1;break i}if((b|0)==1349076270){break l}if((b|0)!=1349076315){break i}ad(f+16|0,d,c);i[114610]=0;a=C(374,a|0,2)|0;b=i[114610];i[114610]=0;if((b|0)==1){break g}if(qb(a)){b=0;while(1){i[114610]=0;c=F(375,f+16|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break g}k=vb(a,b),m=c,g[k+2|0]=m;b=b+1|0;if(b>>>0<qb(a)>>>0){continue}break}}hb(f+16|0);e=1;break i}if((b|0)<=1349079873){if((b|0)==1349078085){break L}if((b|0)==1349078099){break M}if((b|0)!=1349079131){break i}ad(f+16|0,d,c);i[114610]=0;a=C(374,a|0,2)|0;b=i[114610];i[114610]=0;if((b|0)==1){break d}if(qb(a)){b=0;while(1){i[114610]=0;c=F(373,f+16|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break d}k=vb(a,b),m=c,h[k>>1]=m;b=b+1|0;if(b>>>0<qb(a)>>>0){continue}break}}hb(f+16|0);e=1;break i}T:{switch(b+ -1349079874|0){case 3:break J;case 0:break K;case 1:case 2:break i;default:break T}}if((b|0)==1378758190){break n}if((b|0)!=1381183022|c>>>0>1){break i}if(!wb(d,c)){break i}k=a,m=Rc(d,c),g[k+24|0]=m;e=1;break i}if((b|0)<=1448226349){if((b|0)<=1447447622){if((b|0)==1447374382){break m}if((b|0)==1447383630){break s}if((b|0)!=1447385902){break i}ad(f+16|0,d,c);i[114610]=0;a=C(374,a|0,0)|0;b=i[114610];i[114610]=0;if((b|0)==1){break e}if(qb(a)){b=0;while(1){i[114610]=0;c=F(375,f+16|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break e}k=vb(a,b),m=c,g[k+2|0]=m;b=b+1|0;if(b>>>0<qb(a)>>>0){continue}break}}hb(f+16|0);e=1;break i}if((b|0)<=1447842605){if((b|0)==1447447623){break p}if((b|0)!=1447839022|c>>>0>1){break i}if(!wb(d,c)){break i}k=a,m=Rc(d,c),g[k+62|0]=m;e=1;break i}if((b|0)==1447842606){break Q}if((b|0)!=1448106798){break i}ad(f+16|0,d,c);i[114610]=0;a=C(374,a|0,0)|0;b=i[114610];i[114610]=0;if((b|0)==1){break b}if(qb(a)){b=0;while(1){i[114610]=0;c=F(373,f+16|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break b}k=vb(a,b),m=c,h[k>>1]=m;b=b+1|0;if(b>>>0<qb(a)>>>0){continue}break}}hb(f+16|0);e=1;break i}if((b|0)<=1448297773){if((b|0)==1448226350){break x}if((b|0)==1448291886){break G}if((b|0)!=1448297006|c>>>0>1){break i}if(!wb(d,c)){break i}k=a,m=Rc(d,c),g[k+63|0]=m;e=1;break i}if((b|0)<=1718508333){if((b|0)==1448297774){break P}if((b|0)!=1682320942|c>>>0>1){break i}if(!wb(d,c)){break i}k=a,m=Rc(d,c),g[k+15|0]=m;e=1;break i}if((b|0)==1718508334){break y}if((b|0)!=1851469358|32<c>>>0){break i}b=a+492|0;ad(f+16|0,d,c);d=Ab(f);if(c){a=0;while(1){i[114610]=0;e=F(376,f+16|0)|0;j=i[114610];i[114610]=0;if((j|0)==1){break z}i[114610]=0;C(377,d|0,e|0)|0;e=i[114610];i[114610]=0;if((e|0)==1){break z}a=a+1|0;if((c|0)!=(a|0)){continue}break}}i[114610]=0;C(369,b|0,d|0)|0;a=i[114610];i[114610]=0;e=1;if((a|0)==1){break z}eb(d);hb(f+16|0);break i}if(c>>>0>4){break i}if(!wb(d,c)){break i}k=a,m=nk(d,c),i[k+4>>2]=m;e=1;break i}if(c>>>0>4){break i}if(!wb(d,c)){break i}k=a,m=nk(d,c),i[k+8>>2]=m;e=1;break i}if(c>>>0>1){break i}if(!wb(d,c)){break i}k=a,m=Rc(d,c),g[k+61|0]=m;e=1;break i}if(c>>>0>1){break i}if(!wb(d,c)){break i}k=a- -64|0,m=Rc(d,c),g[k|0]=m;e=1;break i}if(c>>>0>1){break i}if(!wb(d,c)){break i}k=a,m=Rc(d,c),g[k+81|0]=m;e=1;break i}if(c>>>0>1){break i}if(!wb(d,c)){break i}k=a,m=Rc(d,c),g[k+84|0]=m;e=1;break i}if(c>>>0>1){break i}if(!wb(d,c)){break i}k=a,m=Rc(d,c),g[k+101|0]=m;e=1;break i}if(c>>>0>1){break i}if(!wb(d,c)){break i}k=a,m=Rc(d,c),g[k+102|0]=m;e=1;break i}if(c>>>0>1){break i}if(!wb(d,c)){break i}k=a,m=Rc(d,c),g[k+103|0]=m;e=1;break i}if(c>>>0>1){break i}if(!wb(d,c)){break i}k=a,m=Rc(d,c),g[k+104|0]=m;e=1;break i}if(c>>>0>1){break i}if(!wb(d,c)){break i}k=a,m=Rc(d,c),g[k+17|0]=m;e=1;break i}if(c>>>0>1){break i}if(!wb(d,c)){break i}k=a,m=Rc(d,c),g[k+19|0]=m;e=1;break i}if(c>>>0>1){break i}if(!wb(d,c)){break i}k=a,m=Rc(d,c),g[k+20|0]=m;e=1;break i}if(c>>>0>1){break i}if(!wb(d,c)){break i}k=a,m=Rc(d,c),g[k+22|0]=m;e=1;break i}if(c>>>0>2){break i}if(!wb(d,c)){break i}k=a,m=Ap(d,c),h[k+28>>1]=m;e=1;break i}if(c>>>0>1){break i}if(!wb(d,c)){break i}k=a,m=Rc(d,c),g[k+30|0]=m;e=1;break i}if(c>>>0>1){break i}if(!wb(d,c)){break i}k=a,m=cA(d,c),g[k+26|0]=m;e=1;break i}if(128<c>>>0){break i}a=a+108|0;ad(f+16|0,d,c);b=0;while(1){i[114610]=0;c=F(375,f+16|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break k}k=Nb(a,b),m=c,g[k|0]=m;b=b+1|0;if(b>>>0<128){continue}break}hb(f+16|0);e=1;break i}b=B()|0;A()|0;break a}b=B()|0;A()|0;eb(d);break a}if(32<c>>>0){break i}b=a+524|0;ad(f+16|0,d,c);d=Ab(f);if(c){a=0;while(1){i[114610]=0;e=F(376,f+16|0)|0;j=i[114610];i[114610]=0;if((j|0)==1){break h}i[114610]=0;C(377,d|0,e|0)|0;e=i[114610];i[114610]=0;if((e|0)==1){break h}a=a+1|0;if((c|0)!=(a|0)){continue}break}}i[114610]=0;C(369,b|0,d|0)|0;a=i[114610];i[114610]=0;e=1;if((a|0)!=1){eb(d);hb(f+16|0);break i}break h}if(c>>>0>2){break i}if(!wb(d,c)){break i}k=a,m=Ap(d,c),h[k+12>>1]=m;e=1;break i}if(c>>>0>1){break i}if(!wb(d,c)){break i}k=a,m=Rc(d,c),g[k+25|0]=m;e=1;break i}if(c>>>0>1){break i}if(!wb(d,c)){break i}k=a,m=Rc(d,c),g[k+35|0]=m;e=1;break i}if(c>>>0>1){break i}if(!wb(d,c)){break i}k=a,m=Rc(d,c),g[k+105|0]=m;e=1;break i}if(c>>>0>1){break i}if(!wb(d,c)){break i}k=a,m=Rc(d,c),g[k+85|0]=m;e=1;break i}if(c>>>0>1){break i}if(!wb(d,c)){break i}k=a,m=Rc(d,c),g[k+65|0]=m;e=1;break i}if(c>>>0>1){break i}if(!wb(d,c)){break i}k=a,m=Rc(d,c),g[k+100|0]=m;e=1;break i}if(c>>>0>1){break i}if(!wb(d,c)){break i}k=a,m=Rc(d,c),g[k+80|0]=m;e=1;break i}if(c>>>0>1){break i}if(!wb(d,c)){break i}k=a,m=Rc(d,c),g[k+60|0]=m;e=1;break i}if(c>>>0>1){break i}if(!wb(d,c)){break i}k=a,m=cA(d,c),g[k+33|0]=m;e=1;break i}e=1;b=nk(d,c);if(!qn(b)){break i}g[a+14|0]=b;break i}i[f+16>>2]=240;k=f,m=nk(d,c),i[k>>2]=m;Lf(a+48|0,i[rb(f+16|0,f)>>2]);e=1;break i}i[f+16>>2]=240;k=f,m=nk(d,c),i[k>>2]=m;Lf(a+88|0,i[rb(f+16|0,f)>>2]);e=1;break i}b=B()|0;A()|0;break a}b=Ap(d,c);c=a;a=i[a+40>>2];i[c+40>>2]=a-((a>>>0)%1e4|0)+(b>>>0)%1e4;e=1}Xa=f+32|0;return e}b=B()|0;A()|0;eb(d);break a}b=B()|0;A()|0;break a}b=B()|0;A()|0;break a}b=B()|0;A()|0;break a}b=B()|0;A()|0;break a}b=B()|0;A()|0;break a}b=B()|0;A()|0}hb(f+16|0);E(b|0);x()}function kJa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,l=0,m=0,n=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,D=0,G=0,H=0,J=0,K=0,L=0,M=0,N=0;e=Xa+ -64|0;Xa=e;pc(a);Se(a,e+56|0);a:{u=c+484344|0;d=e+56|2;G=hd(j[d|0]|j[d+1|0]<<8,1,1024);t=ww(u,G,0);if((t|0)!=65535){d=zp(Fb(u,t),0);h[e+8>>1]=k[c+480188>>1]+ -1;h[e+40>>1]=j[e+56|0];H=k[ef(e+8|0,e+40|0)>>1];f=H+1|0;if(k[c+480188>>1]>(f&65535)>>>0){l=f&65535;while(1){g[d+o(l,6)|0]=254;l=l+1|0;if(l>>>0<k[c+480188>>1]){continue}break}}g[b+13|0]=j[e+56|1]>>>4;d=j[b+12|0];g[e+8|0]=0;v=et(e+40|0,f,e+8|0);if(G){l=(d|0)!=0;while(1){b:{c:{if(!j[dc(v,0)|0]){i[114610]=0;f=F(387,a|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break a}q=f<<24>>24;if((q|0)<=-1){i[114610]=0;f=F(387,a|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break a}M=dc(v,0),N=f,g[M|0]=N}J=0;g[e+8|0]=0;m=q&63;d:{e:{if(!m){break e}i[114610]=0;d=F(387,a|0)|0;f=i[114610];i[114610]=0;if((f|0)==1){break a}g[e+8|0]=d;q=0;f:{switch(m+ -1|0){case 0:g[b+12|0]=0;i[114610]=0;g[e+36|0]=1;f=C(453,e+36|0,e+8|0)|0;d=i[114610];i[114610]=0;if((d|0)!=1){g[b+14|0]=j[f|0];g[b+15|0]=0;l=1;break d}break a;case 1:if(!d){break d}g[b+15|0]=d;l=1;g[b+12|0]=1;f=j[b+13|0];if(!f){break e}g[b+14|0]=o(o(d,f),15);break e;case 2:d=d>>>4|0;g[b+13|0]=d;if(d){l=j[b+12|0]!=0;break d}g[b+12|0]=0;break d;case 3:q=d;break d;case 5:if(!d){break d}f=(j[b+12|0]?15:14)+b|0;q=j[f|0];g[f|0]=256-d>>>0>q>>>0?d+q|0:-1;l=1;break e;case 6:break f;default:break d}}if(!d){break d}l=1;f=(j[b+12|0]?15:14)+b|0;q=j[f|0];g[f|0]=d+1>>>0<q>>>0?q-d|0:1}q=0}i[e+36>>2]=0;i[e+32>>2]=0;if(l&1){break c}break b}q=0;d=dc(v,0);g[d|0]=j[d|0]+ -1;i[e+36>>2]=0;i[e+32>>2]=0;J=0;if(!(l&1)){break b}}d=j[b+12|0];f=j[b+13|0];if(f?0:d){break b}g:{if(d){i[e+8>>2]=1;d=j[b+15|0];i[114610]=0;i[e+28>>2]=o(d,f)<<1;f=C(555,e+8|0,e+28|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break a}f=i[f>>2];break g}f=o(j[b+14|0],30)+30|0}l=255;i[e+36>>2]=255;while(1){s=o(f,l);if(s+ -1536>>>0>=10752){d=l+ -1|0;i[e+36>>2]=d;m=l>>>0<2;l=d;if(!m){continue}}break}i[e+32>>2]=(s|0)/48;Kd(e+32|0,32,255);i[114610]=0;i[e+8>>2]=1;f=C(555,e+8|0,e+36|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break a}g[b+16|0]=i[f>>2];J=1}d=Fb(u,t);i[114610]=0;l=I(471,d|0,r|0,1)|0;d=i[114610];i[114610]=0;if((d|0)==1){break a}if(H){K=r+ -1|0;n=1;z=1;while(1){h:{if(!j[dc(v,n)|0]){i[114610]=0;y=F(387,a|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break a}if(y&128){i[114610]=0;f=F(387,a|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break a}M=dc(v,n),N=f,g[M|0]=N}L=1;if(y&64){i[114610]=0;f=F(387,a|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break a}g[l+1|0]=f;L=!f}i:{if(!(y&32)){break i}i[114610]=0;f=F(387,a|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break a}g[l|0]=f;if((f+ -1&255)>>>0<=107){d=kp(f+24|0);g[l|0]=d;M=uc(b,n),N=d,g[M+1|0]=N;break i}if((f+127&255)>>>0<=107){d=kp((f&127)+24|0);g[l|0]=d;M=uc(b,n),N=d,g[M|0]=N;g[l|0]=0;break i}if((f|0)!=255){break i}g[l|0]=254}if(!(j[l|0]|!j[l+1|0])){d=j[uc(b,n)+1|0];g[l+1|0]=0;g[l|0]=d}i[114610]=0;f=F(556,l|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break a}if(f){M=uc(b,n),N=0,g[M+5|0]=N}g[e+28|0]=0;g[e+27|0]=0;g[e+26|0]=0;g[e+25|0]=0;if(y&16){g[l+2|0]=1;i[114610]=0;f=F(387,a|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break a}g[l+4|0]=f+2>>>2}f=0;D=0;w=0;j:{if(!(y&8)){break j}i[114610]=0;p=F(387,a|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break a}i[114610]=0;w=F(387,a|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break a}k:{switch(p+ -1|0){case 0:g[l|0]=254;break j;case 1:g[l|0]=255;break j;case 2:M=l,N=j[uc(b,n)+1|0],g[M|0]=N;M=uc(b,n),N=0,g[M+5|0]=N;break j;case 3:d=dt(w,j[b+16|0]);w=d?d|-48:0;D=d?20:0;if(j[l|0]){break j}M=l,N=j[uc(b,n)+1|0],g[M|0]=N;M=uc(b,n),N=0,g[M+5|0]=N;break j;case 4:g[e+8|0]=1;d=dt(w,j[b+16|0]);i[114610]=0;g[e+24|0]=d;m=C(453,e+8|0,e+24|0)|0;d=i[114610];i[114610]=0;if((d|0)!=1){w=j[m|0];M=uc(b,n),N=0,g[M+5|0]=N;D=15;break j}break a;case 5:case 6:case 7:case 8:l:{if(!r){break l}if((p|0)==j[uc(b,n)+4|0]){break l}s=Fb(u,t);i[114610]=0;m=I(498,e+8|0,20,(p+122|160)&255)|0;d=i[114610];i[114610]=0;if((d|0)==1){break a}d=dn(cn(Ee(m,K),z&65535));i[114610]=0;m=C(499,s|0,d|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break a}if(!m){break l}M=uc(b,n),N=p,g[M+4|0]=N}if(!j[l|0]){M=l,N=j[uc(b,n)+1|0],g[M|0]=N}M=uc(b,n),N=0,g[M+5|0]=N;D=10;break j;case 9:break k;default:break j}}m=j[uc(b,n)+5|0];d=j[uc(b,n)+5|0];M=uc(b,n),N=d^1,g[M+5|0]=N;w=m?-98:-97;D=20}m:{if(!(y&4)){break m}i[114610]=0;m=F(387,a|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break a}i[114610]=0;g[e+28|0]=m;p=F(387,a|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break a}g[e+26|0]=p;d=e;n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{m=j[e+28|0];switch(m+ -1|0){case 11:break p;case 10:break q;case 7:case 8:case 9:break r;case 6:break s;case 5:break t;case 3:case 4:break u;case 2:break v;case 1:break w;case 0:break x;default:break o}}g[e+28|0]=p<<24>>24>-1?2:3;if(p>>>0>=129){g[e+26|0]=0-p}i[114610]=0;g[e+8|0]=15;m=C(391,e+8|0,e+26|0)|0;d=i[114610];i[114610]=0;if((d|0)!=1){g[e+26|0]=j[m|0]|240;break m}break a}d=dt(p,j[b+16|0]);g[e+26|0]=d;if(d){g[e+28|0]=20;g[e+26|0]=d|208;f=1;break m}g[e+28|0]=0;f=1;break m}f=1;break n}d=j[b+16|0];i[114610]=0;f=I(557,p|0,d|0,1)|0;d=i[114610];i[114610]=0;if((d|0)==1){break a}g[e+26|0]=f;g[e+28|0]=j[e+28|0]==4?2:3;f=1;break m}if(!j[l|0]){M=l,N=j[uc(b,n)|0],g[M|0]=N;p=j[e+26|0]}d=j[b+16|0];i[114610]=0;f=I(557,p&255,d|0,0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break a}g[e+28|0]=4;g[e+26|0]=f;f=1;break m}M=l,N=kp(p+25|0),g[M|0]=N;g[e+26|0]=255;g[e+28|0]=4;f=1;break m}y:{if(!r){break y}if((m|0)==j[uc(b,n)+2|0]){break y}m=Fb(u,t);i[114610]=0;f=I(498,e+8|0,20,(j[e+28|0]+ -8|48)&255)|0;d=i[114610];i[114610]=0;if((d|0)==1){break a}d=dn(cn(Ee(f,K),z&65535));i[114610]=0;f=C(499,m|0,d|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break a}if(!f){break y}d=j[e+28|0];M=uc(b,n),N=d,g[M+2|0]=N}g[e+28|0]=5;d=j[b+16|0];i[114610]=0;f=C(558,j[e+26|0],d|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break a}g[e+26|0]=f;f=1;break m}d=pR(p,j[b+16|0]);g[e+28|0]=18;g[e+26|0]=d;f=1;break m}d=dt(p,j[b+16|0]);g[e+26|0]=d;if(d){g[e+28|0]=20;g[e+26|0]=d|192;f=1;break m}g[e+28|0]=0;g[l|0]=254;f=1;break m}f=0}g[d+28|0]=f}p=0;z:{if(!(y&2)){break z}i[114610]=0;m=F(387,a|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break a}i[114610]=0;g[e+27|0]=m;s=F(387,a|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break a}g[e+25|0]=s;A:{B:{C:{D:{E:{F:{G:{m=j[e+27|0];switch(m+ -1|0){case 9:break B;case 7:case 8:break C;case 6:break D;case 3:case 4:case 5:break E;case 2:break F;case 0:case 1:break G;default:break A}}d=j[b+16|0];i[114610]=0;m=I(559,s|0,d|0,(m|0)==1|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break a}g[e+27|0]=11;g[e+25|0]=m;p=1;break z}d=pR(s,j[b+16|0]);g[e+27|0]=18;g[e+25|0]=d;p=1;break z}H:{if(!r){break H}if((m|0)==j[uc(b,n)+3|0]){break H}s=Fb(u,t);i[114610]=0;m=I(498,e+8|0,20,(j[e+27|0]+ -4|64)&255)|0;d=i[114610];i[114610]=0;if((d|0)==1){break a}d=dn(cn(Ee(m,K),z&65535));i[114610]=0;m=C(499,s|0,d|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break a}if(!m){break H}d=j[e+27|0];M=uc(b,n),N=d,g[M+3|0]=N}g[e+27|0]=8;d=j[b+16|0];i[114610]=0;m=C(558,j[e+25|0],d|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break a}g[e+25|0]=m;p=1;break z}g[e+27|0]=9;break z}d=j[b+16|0];i[114610]=0;m=I(559,s|0,d|0,(m|0)==8|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break a}g[e+27|0]=29;g[e+25|0]=m;p=1;break z}g[e+27|0]=27;d=j[b+16|0];i[114610]=0;m=C(558,s|0,d|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break a}g[e+25|0]=m;p=1;break z}g[e+27|0]=0}if(f){oR(l,r,k[c+480188>>1],j[e+28|0],e+26|0)}if(p){oR(l,r,k[c+480188>>1],j[e+27|0],e+25|0)}I:{if(!L){break I}i[114610]=0;f=F(556,l|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break a}if(!f){break I}d=j[e+28|0];if(!d){g[e+26|0]=255;g[e+28|0]=4;break I}if(j[e+27|0]|(d|0)==4){break I}g[e+25|0]=255;g[e+27|0]=4}J:{if(j[l+2|0]!=1){break J}K:{if(!j[e+28|0]){g[e+28|0]=13;g[e+26|0]=j[l+4|0];break K}if(j[e+27|0]){break J}g[e+27|0]=13;g[e+25|0]=j[l+4|0]}g[l+2|0]=0}i[114610]=0;T(500,e+8|0,e+28|0,e+26|0,e+27|0,e+25|0);d=i[114610];i[114610]=0;if((d|0)==1){break a}L:{if(j[l+2|0]){break L}d=j[e+28|0];if(!d){break L}g[l+2|0]=d;g[l+4|0]=j[e+26|0]}M:{if(D){g[l+3|0]=D;break M}d=j[e+27|0];if(!d){break h}g[l+3|0]=d;w=j[e+25|0]}g[l+5|0]=w;break h}d=dc(v,n);g[d|0]=j[d|0]+ -1}l=l+6|0;z=z+1|0;n=z&65535;if(n>>>0<=H>>>0){continue}break}}N:{if(!J){break N}l=Fb(u,t);i[114610]=0;f=I(498,e+8|0,17,j[e+32|0])|0;d=i[114610];i[114610]=0;if((d|0)==1){break a}d=mi(cn(Ee(f,r),0));i[114610]=0;C(499,l|0,d|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break a}l=Fb(u,t);i[114610]=0;f=I(498,e+8|0,16,j[e+36|0])|0;d=i[114610];i[114610]=0;if((d|0)!=1){d=mi(Ee(f,r));i[114610]=0;C(499,l|0,d|0)|0;d=i[114610];i[114610]=0;if((d|0)!=1){break N}}break a}O:{if(!(q&240)){break O}l=Fb(u,t);i[114610]=0;f=I(498,e+8|0,20,q>>>4|224)|0;d=i[114610];i[114610]=0;if((d|0)!=1){d=nR(Ee(f,r));i[114610]=0;C(499,l|0,d|0)|0;d=i[114610];i[114610]=0;if((d|0)!=1){break O}}break a}P:{f=q&15;if(!f){break P}d=j[b+16|0];q=Fb(u,t);d=hd((o(d,f)>>>0)/15&255,1,15);i[114610]=0;f=I(498,e+8|0,20,d|96)|0;d=i[114610];i[114610]=0;if((d|0)!=1){d=nR(Ee(f,r));i[114610]=0;C(499,q|0,d|0)|0;d=i[114610];i[114610]=0;if((d|0)!=1){break P}}break a}l=0;r=r+1|0;if((G|0)!=(r|0)){continue}break}}Md(v)}Xa=e- -64|0;return t|0}a=B()|0;A()|0;Md(v);E(a|0);x()}function HD(a,b,c,d,e,f,g,h,j){var k=0,l=0,m=0,n=0,o=0,p=0,q=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0;o=Xa-192|0;Xa=o;A=h;H=j&65535;p=d;s=e&65535;D=(e^j)&-2147483648;l=j>>>16&32767;a:{v=e>>>16&32767;b:{c:{if(l+ -1>>>0<32766?v+ -1>>>0<=32765:0){break c}n=e&2147483647;k=n;m=d;if(!(!d&(k|0)==2147418112?!(b|c):(k|0)==2147418112&d>>>0<0|k>>>0<2147418112)){K=d;D=e|32768;break b}n=j&2147483647;e=n;d=h;if(!(!d&(e|0)==2147418112?!(f|g):(e|0)==2147418112&d>>>0<0|e>>>0<2147418112)){K=h;D=j|32768;b=f;c=g;break b}if(!(b|m|(k^2147418112|c))){if(!(d|f|(e^2147418112|g))){b=0;c=0;D=2147450880;break b}D=D|2147418112;b=0;c=0;break b}if(!(d|f|(e^2147418112|g))){b=0;c=0;break b}if(!(b|m|(c|k))){break a}if(!(d|f|(e|g))){D=D|2147418112;b=0;c=0;break b}if((k|0)==65535|k>>>0<65535){j=b;d=!(p|s);h=d<<6;k=r(d?b:p)+32|0;b=r(d?c:s);b=h+((b|0)==32?k:b)|0;kf(o+176|0,j,c,p,s,b+ -15|0);I=16-b|0;p=i[o+184>>2];s=i[o+188>>2];c=i[o+180>>2];b=i[o+176>>2]}if(e>>>0>65535){break c}d=!(A|H);e=d<<6;h=r(d?f:A)+32|0;d=r(d?g:H);d=e+((d|0)==32?h:d)|0;kf(o+160|0,f,g,A,H,d+ -15|0);I=(d+I|0)+ -16|0;A=i[o+168>>2];H=i[o+172>>2];f=i[o+160>>2];g=i[o+164>>2]}e=H|65536;J=e;N=A;d=A;n=e<<15|d>>>17;d=d<<15|g>>>17;h=-102865788-d|0;e=n;k=e;j=1963258675-(k+(4192101508<d>>>0)|0)|0;ch(o+144|0,d,k,h,j);m=i[o+152>>2];ch(o+128|0,0-m|0,0-(i[o+156>>2]+(0<m>>>0)|0)|0,h,j);h=i[o+136>>2];j=h<<1|i[o+132>>2]>>>31;h=i[o+140>>2]<<1|h>>>31;ch(o+112|0,j,h,d,k);m=h;h=i[o+120>>2];ch(o+96|0,j,m,0-h|0,0-(i[o+124>>2]+(0<h>>>0)|0)|0);h=i[o+104>>2];j=h<<1|i[o+100>>2]>>>31;h=i[o+108>>2]<<1|h>>>31;ch(o+80|0,j,h,d,k);m=h;h=i[o+88>>2];ch(o- -64|0,j,m,0-h|0,0-(i[o+92>>2]+(0<h>>>0)|0)|0);h=i[o+72>>2];j=h<<1|i[o+68>>2]>>>31;h=i[o+76>>2]<<1|h>>>31;ch(o+48|0,j,h,d,k);m=h;h=i[o+56>>2];ch(o+32|0,j,m,0-h|0,0-(i[o+60>>2]+(0<h>>>0)|0)|0);h=i[o+40>>2];j=h<<1|i[o+36>>2]>>>31;h=i[o+44>>2]<<1|h>>>31;ch(o+16|0,j,h,d,k);k=h;h=i[o+24>>2];ch(o,j,k,0-h|0,0-(i[o+28>>2]+(0<h>>>0)|0)|0);I=(v-l|0)+I|0;h=i[o+8>>2];m=i[o+12>>2]<<1|h>>>31;j=h<<1;n=m+ -1|0;j=(i[o+4>>2]>>>31|j)+ -1|0;if((j|0)!=-1){n=n+1|0}h=j;m=0;B=m;q=e;l=0;x=XMa(h,m,e,l);e=_a;t=e;y=n;v=0;h=d;m=XMa(n,v,d,0);d=m+x|0;k=_a+e|0;e=d;k=d>>>0<m>>>0?k+1|0:k;m=0;n=(k|0)==(t|0)&e>>>0<x>>>0|k>>>0<t>>>0;x=XMa(q,l,y,v);l=x+k|0;k=_a+(m|n)|0;k=l>>>0<x>>>0?k+1|0:k;m=l;n=e;e=0;h=XMa(j,B,h,u);d=e+h|0;l=_a+n|0;l=d>>>0<h>>>0?l+1|0:l;x=d;h=d;d=l;e=(n|0)==(d|0)&h>>>0<e>>>0|d>>>0<n>>>0;h=m+e|0;if(h>>>0<e>>>0){k=k+1|0}C=h;h=k;e=g;z=(e&131071)<<15|f>>>17;q=XMa(j,B,z,0);e=_a;u=e;k=f;w=k<<15&-32768;k=XMa(y,v,w,0);m=k+q|0;l=_a+e|0;l=m>>>0<k>>>0?l+1|0:l;e=l;F=XMa(j,B,w,F);w=0+F|0;k=m;l=k+_a|0;l=w>>>0<F>>>0?l+1|0:l;l=(k|0)==(l|0)&w>>>0<G>>>0|l>>>0<k>>>0;k=(e|0)==(u|0)&k>>>0<q>>>0|e>>>0<u>>>0;m=e;e=XMa(y,v,z,E)+e|0;n=k+_a|0;n=e>>>0<m>>>0?n+1|0:n;k=e;e=l+k|0;m=n;m=e>>>0<k>>>0?m+1|0:m;n=e;e=x+e|0;k=m+d|0;k=e>>>0<n>>>0?k+1|0:k;l=h;t=k;d=(d|0)==(k|0)&e>>>0<x>>>0|k>>>0<d>>>0;h=d+C|0;if(h>>>0<d>>>0){l=l+1|0}k=l;d=(e|0)!=0|(t|0)!=0;h=h+d|0;if(h>>>0<d>>>0){k=k+1|0}n=h;h=0-h|0;q=0;x=XMa(h,q,j,B);d=_a;u=d;w=XMa(y,v,h,q);h=_a;C=h;z=0-((0<n>>>0)+k|0)|0;k=0;q=XMa(j,B,z,k);n=q+w|0;l=_a+h|0;l=n>>>0<q>>>0?l+1|0:l;h=n;m=h;q=0+x|0;n=d+m|0;n=q>>>0<E>>>0?n+1|0:n;m=q;d=n;n=(u|0)==(d|0)&m>>>0<x>>>0|d>>>0<u>>>0;m=(l|0)==(C|0)&h>>>0<w>>>0|l>>>0<C>>>0;h=XMa(y,v,z,k)+l|0;k=m+_a|0;k=h>>>0<l>>>0?k+1|0:k;m=h;h=n+m|0;if(h>>>0<m>>>0){k=k+1|0}z=h;h=k;n=q;m=0-((0<e>>>0)+t|0)|0;e=0-e|0;E=m;t=0;C=XMa(m,t,j,B);w=_a;u=e;F=0;m=XMa(e,F,y,v);e=m+C|0;l=_a+w|0;l=e>>>0<m>>>0?l+1|0:l;m=e;e=l;u=XMa(j,B,u,F);j=0+u|0;k=m;l=k+_a|0;l=j>>>0<u>>>0?l+1|0:l;l=(k|0)==(l|0)&j>>>0<G>>>0|l>>>0<k>>>0;k=(e|0)==(w|0)&k>>>0<C>>>0|e>>>0<w>>>0;j=e;e=XMa(E,t,y,v)+e|0;m=k+_a|0;m=e>>>0<j>>>0?m+1|0:m;j=e;e=l+e|0;k=m;k=e>>>0<j>>>0?k+1|0:k;j=e;e=e+n|0;k=k+d|0;k=e>>>0<j>>>0?k+1|0:k;j=e;l=h;e=k;d=(d|0)==(k|0)&j>>>0<n>>>0|k>>>0<d>>>0;h=d+z|0;if(h>>>0<d>>>0){l=l+1|0}d=h;k=l;l=d;n=e+ -1|0;d=j+ -2|0;if(d>>>0<4294967294){n=n+1|0}h=d;m=d;d=n;e=(e|0)==(d|0)&m>>>0<j>>>0|d>>>0<e>>>0;j=l+e|0;if(j>>>0<e>>>0){k=k+1|0}e=j+ -1|0;l=k+ -1|0;l=(e|0)!=-1?l+1|0:l;j=0;y=j;v=e;m=p;w=m<<2|c>>>30;z=0;t=XMa(e,j,w,z);j=_a;m=j;j=c;E=(j&1073741823)<<2|b>>>30;x=0;F=l;j=0;k=XMa(E,x,l,j);e=k+t|0;n=_a+m|0;n=e>>>0<k>>>0?n+1|0:n;k=e;q=n;u=(m|0)==(n|0)&k>>>0<t>>>0|n>>>0<m>>>0;m=n;n=0;t=n;l=0;C=d;G=((s&1073741823)<<2|p>>>30)&-262145|262144;e=XMa(d,n,G,0);d=e+k|0;m=_a+m|0;m=d>>>0<e>>>0?m+1|0:m;p=d;e=m;d=(q|0)==(e|0)&d>>>0<k>>>0|e>>>0<q>>>0;m=d+u|0;if(m>>>0<d>>>0){l=1}c=m;m=XMa(F,j,G,L);d=c+m|0;k=_a+l|0;q=d;n=d>>>0<m>>>0?k+1|0:k;l=XMa(v,y,G,L);k=_a;s=XMa(w,z,F,j);d=s+l|0;m=_a+k|0;m=d>>>0<s>>>0?m+1|0:m;s=d;d=m;m=(k|0)==(d|0)&s>>>0<l>>>0|d>>>0<k>>>0;q=d+q|0;l=m+n|0;k=q;m=k>>>0<d>>>0?l+1|0:l;c=k;n=e+s|0;l=0;d=l+p|0;if(d>>>0<l>>>0){n=n+1|0}s=d;k=d;d=n;e=(e|0)==(d|0)&k>>>0<p>>>0|d>>>0<e>>>0;k=c+e|0;if(k>>>0<e>>>0){m=m+1|0}O=k;e=s;l=d;p=XMa(E,x,C,t);n=_a;q=h;u=XMa(h,0,w,z);h=u+p|0;k=_a+n|0;k=h>>>0<u>>>0?k+1|0:k;B=h;u=h;h=k;p=(n|0)==(k|0)&u>>>0<p>>>0|k>>>0<n>>>0;Q=e;k=0;c=p;M=b<<2&-4;p=XMa(v,y,M,0);e=p+u|0;n=_a+h|0;n=e>>>0<p>>>0?n+1|0:n;u=e;p=e;e=n;h=(h|0)==(e|0)&p>>>0<B>>>0|e>>>0<h>>>0;n=c+h|0;if(n>>>0<h>>>0){k=1}h=Q+n|0;l=k+l|0;l=h>>>0<n>>>0?l+1|0:l;p=h;n=m;h=l;d=(d|0)==(l|0)&p>>>0<s>>>0|l>>>0<d>>>0;m=d+O|0;if(m>>>0<d>>>0){n=n+1|0}c=m;s=p;B=h;O=XMa(F,j,M,P);F=_a;j=XMa(G,L,q,R);d=j+O|0;m=_a+F|0;m=d>>>0<j>>>0?m+1|0:m;G=d;k=XMa(w,z,C,t);d=d+k|0;j=m;l=m+_a|0;l=d>>>0<k>>>0?l+1|0:l;w=d;m=XMa(v,y,E,x);d=d+m|0;k=_a+l|0;v=d;k=d>>>0<m>>>0?k+1|0:k;y=0;m=n;d=k;z=(k|0)==(l|0)&v>>>0<w>>>0|k>>>0<l>>>0;k=(j|0)==(F|0)&G>>>0<O>>>0|j>>>0<F>>>0;j=(j|0)==(l|0)&w>>>0<G>>>0|l>>>0<j>>>0;n=k+j|0;n>>>0<j>>>0;l=n;j=z+l|0;l=j;k=d|0;j=k+s|0;l=(l|y)+B|0;l=j>>>0<k>>>0?l+1|0:l;B=j;s=l;h=(h|0)==(l|0)&j>>>0<p>>>0|l>>>0<h>>>0;j=h+c|0;if(j>>>0<h>>>0){m=m+1|0}z=j;j=m;p=B;y=s;l=u;C=XMa(C,t,M,P);t=_a;m=XMa(E,x,q,R);h=m+C|0;n=_a+t|0;n=h>>>0<m>>>0?n+1|0:n;m=n;n=0;k=(m|0)==(t|0)&h>>>0<C>>>0|m>>>0<t>>>0;h=m+l|0;l=(k|n)+e|0;l=h>>>0<m>>>0?l+1|0:l;m=h;k=m;k=(e|0)==(l|0)&k>>>0<u>>>0|l>>>0<e>>>0;e=l;c=k;l=v;v=0;d=v+m|0;k=e+l|0;k=d>>>0<v>>>0?k+1|0:k;d=(e|0)==(k|0)&d>>>0<m>>>0|k>>>0<e>>>0;e=c+d|0;if(e>>>0<d>>>0){n=1}d=e+p|0;m=n+y|0;h=d;k=j;m=d>>>0<e>>>0?m+1|0:m;j=m;d=(s|0)==(m|0)&d>>>0<B>>>0|m>>>0<s>>>0;e=d+z|0;if(e>>>0<d>>>0){k=k+1|0}d=e;e=k;d:{if((k|0)==131071|k>>>0<131071){m=h;y=0;w=0;n=XMa(m,y,f,w);l=_a;k=b<<17;b=0;c=(n|0)!=0|(l|0)!=0;p=b-c|0;G=k-(b>>>0<c>>>0)|0;x=0-n|0;t=0-((0<n>>>0)+l|0)|0;c=0;z=XMa(j,c,f,w);b=_a;E=b;v=0;l=XMa(m,y,g,v);k=l+z|0;n=_a+b|0;n=k>>>0<l>>>0?n+1|0:n;b=k;l=k;q=0;k=q;u=l;k=(l|0)==(t|0)&x>>>0<k>>>0|t>>>0<l>>>0;B=p-k|0;p=G-(p>>>0<k>>>0)|0;k=XMa(d,0,f,w);l=_a;s=XMa(m,y,A,0);k=s+k|0;m=_a+l|0;m=k>>>0<s>>>0?m+1|0:m;s=XMa(g,v,j,c);k=s+k|0;l=_a+m|0;l=k>>>0<s>>>0?l+1|0:l;m=l;l=(n|0)==(E|0)&b>>>0<z>>>0|n>>>0<E>>>0;b=n+k|0;l=l+m|0;l=b>>>0<n>>>0?l+1|0:l;n=b;b=l;m=XMa(h,j,J,0);l=_a;s=n;n=XMa(f,g,e,0);m=n+m|0;k=_a+l|0;k=m>>>0<n>>>0?k+1|0:k;n=XMa(d,e,g,v);m=n+m|0;l=_a+k|0;k=m;m=XMa(j,c,A,H);c=k+m|0;k=c;m=0;c=s+m|0;k=b+k|0;b=c;A=B-b|0;H=p-((B>>>0<b>>>0)+(b>>>0<m>>>0?k+1|0:k)|0)|0;I=I+ -1|0;c=x-q|0;b=t-((x>>>0<q>>>0)+u|0)|0;break d}B=j>>>1|0;n=0;m=b<<16;c=0;l=d<<31;h=(j&1)<<31|h>>>1;j=j>>>1|l;z=0;E=0;b=XMa(h,z,f,E);k=_a;l=k;k=(b|0)!=0|(k|0)!=0;t=c-k|0;L=m-(c>>>0<k>>>0)|0;q=0-b|0;u=0-((0<b>>>0)+l|0)|0;p=0;x=XMa(h,z,g,p);b=_a;G=b;m=n;l=e<<31|d>>>1;n=d<<31|B;M=l|m;m=XMa(n,0,f,E);c=m+x|0;k=_a+b|0;k=c>>>0<m>>>0?k+1|0:k;b=k;k=c;w=k;y=0;m=(k|0)==(u|0)&q>>>0<y>>>0|u>>>0<k>>>0;C=t-m|0;t=L-(t>>>0<m>>>0)|0;m=XMa(h,j,J,0);l=_a;k=XMa(f,g,e>>>1|0,0);m=k+m|0;l=_a+l|0;l=m>>>0<k>>>0?l+1|0:l;d=(e&1)<<31|d>>>1;e=e>>>1|0;L=XMa(d,e,g,p);m=L+m|0;k=_a+l|0;l=XMa(n,M,A,H);m=l+m|0;H=0;k=XMa(g,p,n,P);l=_a;v=XMa(d,0,f,E);n=v+k|0;k=_a+l|0;k=n>>>0<v>>>0?k+1|0:k;A=XMa(h,z,A,0);n=A+n|0;l=_a+k|0;l=n>>>0<A>>>0?l+1|0:l;A=n;n=((b|0)==(G|0)&c>>>0<x>>>0|b>>>0<G>>>0)+l|0;c=b;b=b+A|0;if(b>>>0<c>>>0){n=n+1|0}c=b;b=b+H|0;k=m+n|0;k=b>>>0<c>>>0?k+1|0:k;A=C-b|0;H=t-((C>>>0<b>>>0)+k|0)|0;c=q-y|0;b=u-((q>>>0<y>>>0)+w|0)|0}if((I|0)>=16384){D=D|2147418112;b=0;c=0;break b}m=I+16383|0;if((I|0)<=-16383){e:{if(m){break e}m=j;l=b<<1|c>>>31;n=c<<1;g=(g|0)==(l|0)&n>>>0>f>>>0|l>>>0>g>>>0;n=e&65535;f=A;l=H<<1|f>>>31;c=f<<1|b>>>31;e=c;b=(e|0)==(N|0)&(l|0)==(J|0)?g:(J|0)==(l|0)&e>>>0>N>>>0|l>>>0>J>>>0;c=b+h|0;if(c>>>0<b>>>0){m=m+1|0}b=c;e=b;c=m;e=d+((j|0)==(m|0)&e>>>0<h>>>0|m>>>0<j>>>0)|0;if(e>>>0<d>>>0){n=n+1|0}d=n;if(!(d&65536)){break e}K=e|K;D=d|D;break b}b=0;c=0;break b}k=j;e=e&65535;n=b<<1|c>>>31;s=c<<1;g=(g|0)==(n|0)&s>>>0>=f>>>0|n>>>0>g>>>0;f=A;n=H<<1|f>>>31;c=f<<1|b>>>31;b=(c|0)==(N|0)&(n|0)==(J|0)?g:(J|0)==(n|0)&c>>>0>=N>>>0|n>>>0>J>>>0;c=b+h|0;if(c>>>0<b>>>0){k=k+1|0}b=c;c=k;f=d;d=((j|0)==(k|0)&b>>>0<h>>>0|k>>>0<j>>>0)+d|0;k=m<<16|e;K=d|K;D=D|(d>>>0<f>>>0?k+1|0:k)}i[a>>2]=b;i[a+4>>2]=c;i[a+8>>2]=K;i[a+12>>2]=D;Xa=o+192|0;return}i[a>>2]=0;i[a+4>>2]=0;b=!(d|f|(e|g));i[a+8>>2]=b?0:K;i[a+12>>2]=b?2147450880:D;Xa=o+192|0}function _F(a,b,c,d,e,f,g){var h=0,l=0,m=0,n=0;h=Xa-128|0;Xa=h;a:{b:{if(g){ej(h+112|0,f,32);i[114610]=0;I(803,h+96|0,f|0,32)|0;l=i[114610];i[114610]=0;if((l|0)!=1){break b}c=B()|0;A()|0;break a}Ab(h+112|0);Ab(h+96|0)}c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{if($q(c)){l=b+24|0;b=i[l>>2];i[114610]=0;b=C(442,b+484344|0,c&65535)|0;m=i[114610];i[114610]=0;if((m|0)==1){break r}if(b){break q}}i[114610]=0;G(2195,a|0,h+112|0,h+96|0);a=i[114610];i[114610]=0;if((a|0)!=1){break p}}c=B()|0;A()|0;break c}b=Fb(i[l>>2]+484344|0,c);if(!(i[b+12>>2]>(d|0)?(d|0)>=0:0)){i[114610]=0;G(2195,a|0,h+112|0,h+96|0);a=i[114610];i[114610]=0;if((a|0)!=1){break p}break d}if(!(k[i[l>>2]+480188>>1]>(e|0)?(e|0)>=0:0)){i[114610]=0;G(2195,a|0,h+112|0,h+96|0);a=i[114610];i[114610]=0;if((a|0)==1){break d}break p}i[114610]=0;c=I(2196,b|0,d|0,e&65535)|0;b=i[114610];i[114610]=0;if((b|0)==1){break o}Ce(h+112|0);Ce(h+96|0);i[114610]=0;b=F(556,c|0)|0;d=i[114610];i[114610]=0;s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{if((d|0)!=1){H:{I:{if(!b){if(!zr(c)){break I}}b=i[l>>2];d=j[c+1|0];e=j[c|0];i[114610]=0;J(2197,h- -64|0,b|0,e|0,d|0);d=i[114610];i[114610]=0;b=1;if((d|0)==1){break G}i[114610]=0;G(9,h+80|0,0,h- -64|0);d=i[114610];i[114610]=0;if((d|0)!=1){break H}c=B()|0;A()|0;break E}b=0;i[114610]=0;C(85,h+80|0,38821)|0;d=i[114610];i[114610]=0;if((d|0)==1){break v}}i[114610]=0;C(1251,h+112|0,h+80|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break F}eb(h+80|0);if(b){eb(h- -64|0)}i[114610]=0;b=F(556,c|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break e}J:{if(b){i[114610]=0;C(85,h+80|0,38825)|0;b=i[114610];i[114610]=0;if((b|0)==1){break e}break J}if(zr(c)){i[114610]=0;C(85,h+80|0,38829)|0;b=i[114610];i[114610]=0;if((b|0)!=1){break J}break e}i[114610]=0;C(85,h+80|0,38821)|0;b=i[114610];i[114610]=0;if((b|0)==1){break e}}i[114610]=0;C(1251,h+96|0,h+80|0)|0;b=i[114610];i[114610]=0;if((b|0)==1){break D}eb(h+80|0);m=f+ -1|0;if(m>>>0<5){break w}i[114610]=0;b=C(85,h+80|0,38839)|0;d=i[114610];i[114610]=0;if((d|0)==1){break C}i[114610]=0;C(1251,h+112|0,b|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break B}eb(b);i[114610]=0;b=C(85,h+80|0,38839)|0;d=i[114610];i[114610]=0;if((d|0)==1){break A}i[114610]=0;C(1251,h+96|0,b|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break z}eb(b);b=c+1|0;K:{if(j[c+1|0]){i[114610]=0;D(840,h+80|0,b|0);d=i[114610];i[114610]=0;if((d|0)!=1){break K}break f}i[114610]=0;C(85,h+80|0,38833)|0;d=i[114610];i[114610]=0;if((d|0)==1){break f}}i[114610]=0;C(1251,h+112|0,h+80|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break y}eb(h+80|0);L:{if(j[b|0]){i[114610]=0;C(85,h+80|0,38836)|0;b=i[114610];i[114610]=0;if((b|0)!=1){break L}break g}i[114610]=0;C(85,h+80|0,38833)|0;b=i[114610];i[114610]=0;if((b|0)==1){break g}}i[114610]=0;C(1251,h+96|0,h+80|0)|0;b=i[114610];i[114610]=0;if((b|0)!=1){break x}c=B()|0;A()|0;eb(h+80|0);break c}c=B()|0;A()|0;break c}c=B()|0;A()|0;break c}c=B()|0;A()|0;eb(h+80|0);if(!b){break c}}eb(h- -64|0);break c}c=B()|0;A()|0;eb(h+80|0);break c}c=B()|0;A()|0;break c}c=B()|0;A()|0;eb(b);break c}c=B()|0;A()|0;break c}c=B()|0;A()|0;eb(b);break c}c=B()|0;A()|0;eb(h+80|0);break c}eb(h+80|0);if(m>>>0<8){break w}i[114610]=0;b=F(1342,c|0)|0;d=i[114610];i[114610]=0;M:{N:{O:{P:{Q:{R:{S:{if((d|0)!=1){T:{if(b){i[114610]=0;b=C(85,h+48|0,38839)|0;d=i[114610];i[114610]=0;if((d|0)==1){break S}i[114610]=0;e=F(1344,c|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break R}d=0;i[114610]=0;i[h+16>>2]=e&255;D(839,h+32|0,h+16|0);n=i[114610];i[114610]=0;e=1;if((n|0)==1){break R}i[114610]=0;G(138,h+80|0,b|0,h+32|0);b=i[114610];i[114610]=0;if((b|0)!=1){break T}c=B()|0;A()|0;break i}if(j[c+2|0]){b=i[i[l>>2]+8>>2];d=j[c+2|0];i[114610]=0;b=C(2198,b|0,d|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break N}i[114610]=0;b=I(803,h+48|0,1,b|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break N}e=0;i[114610]=0;D(840,h+32|0,c+4|0);n=i[114610];i[114610]=0;d=1;if((n|0)==1){break Q}i[114610]=0;G(138,h+80|0,b|0,h+32|0);b=i[114610];i[114610]=0;if((b|0)!=1){break T}c=B()|0;A()|0;eb(h+32|0);break k}e=0;i[114610]=0;C(85,h+80|0,38853)|0;b=i[114610];i[114610]=0;d=0;if((b|0)==1){break O}}i[114610]=0;C(1251,h+112|0,h+80|0)|0;b=i[114610];i[114610]=0;if((b|0)==1){break P}eb(h+80|0);if(d){eb(h+32|0);eb(h+48|0)}if(e){eb(h+32|0);eb(h+48|0)}i[114610]=0;b=F(1342,c|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break l}U:{if(b){i[114610]=0;C(85,h+80|0,38857)|0;b=i[114610];i[114610]=0;if((b|0)==1){break l}break U}if(j[c+2|0]){i[114610]=0;C(85,h+80|0,38861)|0;b=i[114610];i[114610]=0;if((b|0)!=1){break U}break l}i[114610]=0;C(85,h+80|0,38853)|0;b=i[114610];i[114610]=0;if((b|0)==1){break l}}i[114610]=0;C(1251,h+96|0,h+80|0)|0;b=i[114610];i[114610]=0;if((b|0)!=1){break M}c=B()|0;A()|0;eb(h+80|0);break c}c=B()|0;A()|0;break c}c=B()|0;A()|0;break c}c=B()|0;A()|0;break h}c=B()|0;A()|0;break k}c=B()|0;A()|0;eb(h+80|0);if(!d){break j}eb(h+32|0);break k}c=B()|0;A()|0;break c}c=B()|0;A()|0;break c}eb(h+80|0);if(m>>>0<12){break w}i[114610]=0;b=C(85,h+80|0,38839)|0;d=i[114610];i[114610]=0;V:{W:{X:{Y:{Z:{_:{$:{aa:{ba:{if((d|0)!=1){i[114610]=0;C(1251,h+112|0,b|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break ba}eb(b);i[114610]=0;b=C(85,h+80|0,38839)|0;d=i[114610];i[114610]=0;if((d|0)==1){break aa}i[114610]=0;C(1251,h+96|0,b|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break $}eb(b);i[114610]=0;b=F(1342,c|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break _}ca:{if(b){b=0;i[114610]=0;d=F(1343,c|0)|0;e=i[114610];i[114610]=0;if((e|0)!=1){i[114610]=0;i[h+28>>2]=d&4095;D(1062,h+80|0,h+28|0);d=i[114610];i[114610]=0;if((d|0)!=1){break ca}}c=B()|0;A()|0;break c}if(j[c+3|0]){b=i[i[l>>2]+8>>2];d=j[c+3|0];i[114610]=0;b=C(2199,b|0,d|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break Z}i[114610]=0;d=I(803,h+16|0,1,b|0)|0;b=i[114610];i[114610]=0;if((b|0)==1){break Z}i[114610]=0;D(840,h|0,c+5|0);e=i[114610];i[114610]=0;b=1;if((e|0)==1){break Y}i[114610]=0;G(138,h+80|0,d|0,h|0);d=i[114610];i[114610]=0;if((d|0)!=1){break ca}c=B()|0;A()|0;eb(h);break m}b=0;i[114610]=0;C(85,h+80|0,38821)|0;d=i[114610];i[114610]=0;if((d|0)==1){break W}}i[114610]=0;C(1251,h+112|0,h+80|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break X}eb(h+80|0);if(b){eb(h);eb(h+16|0)}i[114610]=0;b=F(1342,c|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break n}da:{if(b){i[114610]=0;C(85,h+80|0,38865)|0;b=i[114610];i[114610]=0;if((b|0)==1){break n}break da}if(j[c+3|0]){i[114610]=0;C(85,h+80|0,38865)|0;b=i[114610];i[114610]=0;if((b|0)!=1){break da}break n}i[114610]=0;C(85,h+80|0,38821)|0;b=i[114610];i[114610]=0;if((b|0)==1){break n}}i[114610]=0;C(1251,h+96|0,h+80|0)|0;b=i[114610];i[114610]=0;if((b|0)!=1){break V}c=B()|0;A()|0;eb(h+80|0);break c}c=B()|0;A()|0;break c}c=B()|0;A()|0;eb(b);break c}c=B()|0;A()|0;break c}c=B()|0;A()|0;eb(b);break c}c=B()|0;A()|0;break c}c=B()|0;A()|0;break c}c=B()|0;A()|0;break m}c=B()|0;A()|0;eb(h+80|0);if(!b){break c}eb(h);break m}c=B()|0;A()|0;break c}eb(h+80|0);if(!f){break s}}ea:{fa:{if(lb(h+112|0)>>>0>f>>>0){i[114610]=0;J(232,h+80|0,h+112|0,0,f|0);b=i[114610];i[114610]=0;if((b|0)!=1){break fa}c=B()|0;A()|0;break c}if(g){b=lb(h+112|0);i[114610]=0;b=I(803,h+80|0,f-b|0,32)|0;c=i[114610];i[114610]=0;if((c|0)==1){break u}i[114610]=0;C(1251,h+112|0,b|0)|0;c=i[114610];i[114610]=0;if((c|0)==1){c=B()|0;A()|0;eb(b);break c}eb(b);if(lb(h+96|0)>>>0>f>>>0){break t}break ea}if(lb(h+96|0)>>>0<=f>>>0){break s}break t}mb(h+112|0,h+80|0);eb(h+80|0);if(lb(h+96|0)>>>0>f>>>0){break t}if(!g){break s}}b=lb(h+96|0);i[114610]=0;b=I(803,h+80|0,f-b|0,32)|0;c=i[114610];i[114610]=0;ga:{if((c|0)!=1){i[114610]=0;C(1251,h+96|0,b|0)|0;c=i[114610];i[114610]=0;if((c|0)==1){break ga}eb(b);break s}c=B()|0;A()|0;break c}c=B()|0;A()|0;eb(b);break c}c=B()|0;A()|0;break c}c=B()|0;A()|0;break c}i[114610]=0;J(232,h+80|0,h+96|0,0,f|0);b=i[114610];i[114610]=0;if((b|0)!=1){mb(h+96|0,h+80|0);eb(h+80|0);break s}c=B()|0;A()|0;break c}i[114610]=0;G(2195,a|0,h+112|0,h+96|0);a=i[114610];i[114610]=0;if((a|0)==1){break o}}eb(h+96|0);eb(h+112|0);Xa=h+128|0;return}c=B()|0;A()|0;break c}c=B()|0;A()|0;break c}eb(h+16|0);break c}c=B()|0;A()|0;break c}eb(h+48|0)}if(!e){break c}}eb(h+32|0)}eb(h+48|0);break c}c=B()|0;A()|0;break c}c=B()|0;A()|0;break c}c=B()|0;A()|0;break c}c=B()|0;A()|0}eb(h+96|0)}eb(h+112|0);E(c|0);x()}function S2(a,b,c,d,e,f,g){var h=0,k=0,m=0,n=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;h=Xa-8976|0;Xa=h;z=d+e|0;F=0-z|0;a:{b:{while(1){if((c|0)!=48){c:{if((c|0)!=46){break a}c=i[b+4>>2];if(c>>>0>=l[b+104>>2]){break c}i[b+4>>2]=c+1;c=j[c|0];break b}}else{c=i[b+4>>2];if(c>>>0<l[b+104>>2]){n=1;i[b+4>>2]=c+1;c=j[c|0]}else{n=1;c=Hc(b)}continue}break}c=Hc(b)}p=1;if((c|0)!=48){break a}while(1){k=k+ -1|0;c=q+ -1|0;if((c|0)!=-1){k=k+1|0}q=c;c=i[b+4>>2];d:{if(c>>>0<l[b+104>>2]){i[b+4>>2]=c+1;c=j[c|0];break d}c=Hc(b)}if((c|0)==48){continue}break}n=1}i[h+784>>2]=0;e:{f:{s=(c|0)==46;t=c+ -48|0;g:{h:{i:{j:{if(s|t>>>0<=9){while(1){k:{if(s&1){if(!p){q=r;k=m;p=1;break k}n=!n;break j}r=r+1|0;if(r>>>0<1){m=m+1|0}if((v|0)<=2044){y=(c|0)==48?y:r;n=(h+784|0)+(v<<2)|0;s=n;if(u){t=(o(i[n>>2],10)+c|0)+ -48|0}i[s>>2]=t;n=1;t=u+1|0;c=(t|0)==9;u=c?0:t;v=c+v|0;break k}if((c|0)==48){break k}i[h+8960>>2]=i[h+8960>>2]|1;y=18396}c=i[b+4>>2];l:{if(c>>>0<l[b+104>>2]){i[b+4>>2]=c+1;c=j[c|0];break l}c=Hc(b)}s=(c|0)==46;t=c+ -48|0;if(s|t>>>0<10){continue}break}}q=p?q:r;k=p?k:m;if(!(!n|(c&-33)!=69)){p=FD(b,g);c=_a;s=c;m:{if(p|(c|0)!=-2147483648){break m}if(!g){break g}p=0;s=0;if(!i[b+104>>2]){break m}i[b+4>>2]=i[b+4>>2]+ -1}if(!n){break h}k=k+s|0;b=p+q|0;if(b>>>0<p>>>0){k=k+1|0}q=b;break f}n=!n;if((c|0)<0){break i}}if(!i[b+104>>2]){break i}i[b+4>>2]=i[b+4>>2]+ -1}if(!n){break f}}i[114584]=28}r=0;m=0;Gg(b,0,0);c=0;b=0;break e}b=i[h+784>>2];if(!b){Fh(h,+(f|0)*0);r=i[h>>2];m=i[h+4>>2];c=i[h+12>>2];b=i[h+8>>2];break e}if(!((q|0)!=(r|0)|(k|0)!=(m|0)|((m|0)>0?1:(m|0)>=0?r>>>0>9:0)|(b>>>d|0?(d|0)<=30:0))){Qf(h+48|0,f);Xl(h+32|0,b);_c(h+16|0,i[h+48>>2],i[h+52>>2],i[h+56>>2],i[h+60>>2],i[h+32>>2],i[h+36>>2],i[h+40>>2],i[h+44>>2]);r=i[h+16>>2];m=i[h+20>>2];c=i[h+28>>2];b=i[h+24>>2];break e}if((k|0)>0?1:(k|0)>=0?q>>>0>(e|0)/-2>>>0:0){i[114584]=68;Qf(h+96|0,f);_c(h+80|0,i[h+96>>2],i[h+100>>2],i[h+104>>2],i[h+108>>2],-1,-1,-1,2147418111);_c(h- -64|0,i[h+80>>2],i[h+84>>2],i[h+88>>2],i[h+92>>2],-1,-1,-1,2147418111);r=i[h+64>>2];m=i[h+68>>2];c=i[h+76>>2];b=i[h+72>>2];break e}b=e+ -226|0;c=q>>>0<b>>>0;b=b>>31;if((k|0)<(b|0)?1:(k|0)<=(b|0)?c:0){i[114584]=68;Qf(h+144|0,f);_c(h+128|0,i[h+144>>2],i[h+148>>2],i[h+152>>2],i[h+156>>2],0,0,0,65536);_c(h+112|0,i[h+128>>2],i[h+132>>2],i[h+136>>2],i[h+140>>2],0,0,0,65536);r=i[h+112>>2];m=i[h+116>>2];c=i[h+124>>2];b=i[h+120>>2];break e}if(u){if((u|0)<=8){c=(h+784|0)+(v<<2)|0;b=i[c>>2];while(1){b=o(b,10);u=u+1|0;if((u|0)!=9){continue}break}i[c>>2]=b}v=v+1|0}n:{p=q;if((y|0)>(p|0)|(y|0)>=9|(p|0)>17){break n}if((p|0)==9){Qf(h+192|0,f);Xl(h+176|0,i[h+784>>2]);_c(h+160|0,i[h+192>>2],i[h+196>>2],i[h+200>>2],i[h+204>>2],i[h+176>>2],i[h+180>>2],i[h+184>>2],i[h+188>>2]);r=i[h+160>>2];m=i[h+164>>2];c=i[h+172>>2];b=i[h+168>>2];break e}if((p|0)<=8){Qf(h+272|0,f);Xl(h+256|0,i[h+784>>2]);_c(h+240|0,i[h+272>>2],i[h+276>>2],i[h+280>>2],i[h+284>>2],i[h+256>>2],i[h+260>>2],i[h+264>>2],i[h+268>>2]);Qf(h+224|0,i[(0-p<<2)+57360>>2]);HD(h+208|0,i[h+240>>2],i[h+244>>2],i[h+248>>2],i[h+252>>2],i[h+224>>2],i[h+228>>2],i[h+232>>2],i[h+236>>2]);r=i[h+208>>2];m=i[h+212>>2];c=i[h+220>>2];b=i[h+216>>2];break e}b=(o(p,-3)+d|0)+27|0;c=i[h+784>>2];if(c>>>b|0?(b|0)<=30:0){break n}Qf(h+352|0,f);Xl(h+336|0,c);_c(h+320|0,i[h+352>>2],i[h+356>>2],i[h+360>>2],i[h+364>>2],i[h+336>>2],i[h+340>>2],i[h+344>>2],i[h+348>>2]);Qf(h+304|0,i[(p<<2)+57288>>2]);_c(h+288|0,i[h+320>>2],i[h+324>>2],i[h+328>>2],i[h+332>>2],i[h+304>>2],i[h+308>>2],i[h+312>>2],i[h+316>>2]);r=i[h+288>>2];m=i[h+292>>2];c=i[h+300>>2];b=i[h+296>>2];break e}while(1){c=v;v=c+ -1|0;if(!i[(h+784|0)+(v<<2)>>2]){continue}break}u=0;b=(p|0)%9|0;o:{if(!b){n=0;break o}g=(p|0)>-1?b:b+9|0;p:{if(!c){n=0;c=0;break p}t=i[(0-g<<2)+57360>>2];q=1e9/(t|0)|0;s=0;b=0;n=0;while(1){k=s;m=(h+784|0)+(b<<2)|0;r=i[m>>2];s=(r>>>0)/(t>>>0)|0;k=k+s|0;i[m>>2]=k;k=!k&(b|0)==(n|0);n=k?n+1&2047:n;p=k?p+ -9|0:p;s=o(q,r-o(s,t)|0);b=b+1|0;if((c|0)!=(b|0)){continue}break}if(!s){break p}i[(h+784|0)+(c<<2)>>2]=s;c=c+1|0}p=(p-g|0)+9|0}while(1){r=(h+784|0)+(n<<2)|0;q:{while(1){if((p|0)!=36|l[r>>2]>=10384593?(p|0)>=36:0){break q}v=c+2047|0;s=0;t=c;while(1){c=t;m=v&2047;t=(h+784|0)+(m<<2)|0;b=i[t>>2];k=b>>>3|0;g=b<<29;b=g+s|0;if(b>>>0<g>>>0){k=k+1|0}q=b;g=0;r:{if(!k&b>>>0<1000000001|k>>>0<0){break r}g=_Ma(b,k,1e9,0);q=q-XMa(g,_a,1e9,0)|0}s=g;i[t>>2]=q;t=(m|0)!=(c+ -1&2047)?c:(m|0)==(n|0)?c:q?c:m;v=m+ -1|0;if((m|0)!=(n|0)){continue}break}u=u+ -29|0;if(!s){continue}break}n=n+ -1&2047;if((t|0)==(n|0)){b=(h+784|0)+((t+2046&2047)<<2)|0;c=t+ -1&2047;i[b>>2]=i[b>>2]|i[(h+784|0)+(c<<2)>>2]}p=p+9|0;i[(h+784|0)+(n<<2)>>2]=s;continue}break}s:{t:while(1){g=c+1&2047;q=(h+784|0)+((c+ -1&2047)<<2)|0;while(1){k=(p|0)>45?9:1;u:{while(1){t=n;b=0;v:{while(1){w:{n=b+t&2047;if((n|0)==(c|0)){break w}n=i[(h+784|0)+(n<<2)>>2];m=i[(b<<2)+57312>>2];if(n>>>0<m>>>0){break w}if(n>>>0>m>>>0){break v}b=b+1|0;if((b|0)!=4){continue}}break}if((p|0)!=36){break v}q=0;k=0;b=0;r=0;m=0;while(1){g=b+t&2047;if((g|0)==(c|0)){c=c+1&2047;i[((c<<2)+h|0)+780>>2]=0}_c(h+768|0,q,k,r,m,0,0,1342177280,1075633366);Xl(h+752|0,i[(h+784|0)+(g<<2)>>2]);Ff(h+736|0,i[h+768>>2],i[h+772>>2],i[h+776>>2],i[h+780>>2],i[h+752>>2],i[h+756>>2],i[h+760>>2],i[h+764>>2]);r=i[h+744>>2];m=i[h+748>>2];q=i[h+736>>2];k=i[h+740>>2];b=b+1|0;if((b|0)!=4){continue}break}Qf(h+720|0,f);_c(h+704|0,q,k,r,m,i[h+720>>2],i[h+724>>2],i[h+728>>2],i[h+732>>2]);r=i[h+712>>2];m=i[h+716>>2];q=0;k=0;p=i[h+704>>2];s=i[h+708>>2];n=u+113|0;e=n-e|0;g=(e|0)<(d|0);d=g?(e|0)>0?e:0:d;if((d|0)<=112){break u}break s}u=k+u|0;n=c;if((c|0)==(t|0)){continue}break}m=1e9>>>k|0;r=-1<<k^-1;b=0;n=t;while(1){s=(h+784|0)+(t<<2)|0;v=i[s>>2];b=(v>>>k|0)+b|0;i[s>>2]=b;b=!b&(n|0)==(t|0);n=b?n+1&2047:n;p=b?p+ -9|0:p;b=o(m,r&v);t=t+1&2047;if((t|0)!=(c|0)){continue}break}if(!b){continue}if((g|0)!=(n|0)){i[(h+784|0)+(c<<2)>>2]=b;c=g;continue t}i[q>>2]=i[q>>2]|1;n=g;continue}break}break}Fh(h+656|0,yh(1,225-d|0));JD(h+688|0,i[h+656>>2],i[h+660>>2],i[h+664>>2],i[h+668>>2],p,s,r,m);A=i[h+696>>2];B=i[h+700>>2];C=i[h+688>>2];D=i[h+692>>2];Fh(h+640|0,yh(1,113-d|0));LB(h+672|0,p,s,r,m,i[h+640>>2],i[h+644>>2],i[h+648>>2],i[h+652>>2]);q=i[h+672>>2];k=i[h+676>>2];w=i[h+680>>2];x=i[h+684>>2];Xu(h+624|0,p,s,r,m,q,k,w,x);Ff(h+608|0,C,D,A,B,i[h+624>>2],i[h+628>>2],i[h+632>>2],i[h+636>>2]);r=i[h+616>>2];m=i[h+620>>2];p=i[h+608>>2];s=i[h+612>>2]}b=t+4&2047;x:{if((b|0)==(c|0)){break x}b=i[(h+784|0)+(b<<2)>>2];y:{if(b>>>0<=499999999){if((t+5&2047)==(c|0)?!b:0){break y}Fh(h+496|0,+(f|0)*.25);Ff(h+480|0,q,k,w,x,i[h+496>>2],i[h+500>>2],i[h+504>>2],i[h+508>>2]);w=i[h+488>>2];x=i[h+492>>2];q=i[h+480>>2];k=i[h+484>>2];break y}if((b|0)!=5e8){Fh(h+592|0,+(f|0)*.75);Ff(h+576|0,q,k,w,x,i[h+592>>2],i[h+596>>2],i[h+600>>2],i[h+604>>2]);w=i[h+584>>2];x=i[h+588>>2];q=i[h+576>>2];k=i[h+580>>2];break y}E=+(f|0);if((t+5&2047)==(c|0)){Fh(h+528|0,E*.5);Ff(h+512|0,q,k,w,x,i[h+528>>2],i[h+532>>2],i[h+536>>2],i[h+540>>2]);w=i[h+520>>2];x=i[h+524>>2];q=i[h+512>>2];k=i[h+516>>2];break y}Fh(h+560|0,E*.75);Ff(h+544|0,q,k,w,x,i[h+560>>2],i[h+564>>2],i[h+568>>2],i[h+572>>2]);w=i[h+552>>2];x=i[h+556>>2];q=i[h+544>>2];k=i[h+548>>2]}if((d|0)>111){break x}LB(h+464|0,q,k,w,x,0,0,0,1073676288);if(Lk(i[h+464>>2],i[h+468>>2],i[h+472>>2],i[h+476>>2],0,0,0,0)){break x}Ff(h+448|0,q,k,w,x,0,0,0,1073676288);w=i[h+456>>2];x=i[h+460>>2];q=i[h+448>>2];k=i[h+452>>2]}Ff(h+432|0,p,s,r,m,q,k,w,x);Xu(h+416|0,i[h+432>>2],i[h+436>>2],i[h+440>>2],i[h+444>>2],C,D,A,B);r=i[h+424>>2];m=i[h+428>>2];p=i[h+416>>2];s=i[h+420>>2];z:{if((n&2147483647)<=(-2-z|0)){break z}i[h+408>>2]=r;i[h+412>>2]=m&2147483647;i[h+400>>2]=p;i[h+404>>2]=s;_c(h+384|0,p,s,r,m,0,0,0,1073610752);c=vE(i[h+400>>2],i[h+404>>2],i[h+408>>2],i[h+412>>2],1081081856);b=(c|0)<0;r=b?r:i[h+392>>2];m=b?m:i[h+396>>2];p=b?p:i[h+384>>2];s=b?s:i[h+388>>2];u=((c|0)>-1)+u|0;if(G=!(g&(b|(d|0)!=(e|0))&(Lk(q,k,w,x,0,0,0,0)|0)!=0),H=0,I=(u+110|0)<=(F|0),I?G:H){break z}i[114584]=68}ID(h+368|0,p,s,r,m,u);r=i[h+368>>2];m=i[h+372>>2];c=i[h+380>>2];b=i[h+376>>2]}i[a>>2]=r;i[a+4>>2]=m;i[a+8>>2]=b;i[a+12>>2]=c;Xa=h+8976|0}function Vza(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,l=0,m=0,n=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,F=0,H=0,J=0,K=0,M=0,O=0,P=0,Q=0,R=0;d=Xa-304|0;Xa=d;pc(b);a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{if(!ss(b,d+208|0)){break j}if(!WN(d+208|0)){break j}if(!wb(b,Vc(VN(d+208|0),_a))){break j}if(!c){K=1;break j}if(!vc(b,j[d+208|4])){break j}md(a,268435456);Vh(a);i[a+480208>>2]=4;f=Bb(d+88|0,16635);mb(a+1304436|0,f);eb(f);f=Bb(d+88|0,16654);mb(a+1304448|0,f);eb(f);i[a+1304496>>2]=4;Ge(d+16|0,d+208|6,48,3);oc(d+88|0,d+16|0);mb(a+1304400|0,d+88|0);eb(d+88|0);h[a+480188>>1]=j[d+262|0]+1;i[a+480228>>2]=j[d+265|0];i[a+480204>>2]=o(j[d+266|0],1e4);i[a+480196>>2]=j[d+267|0];if(j[d+262|0]){f=0;while(1){h[((f<<5)+a|0)+480284>>1]=o(j[(d+f|0)+268|0],17);f=f+1|0;if(f>>>0<j[d+262|0]){continue}break}}h[a+480190>>1]=j[d+300|0];r=Uza(d+192|0,j[d+302|0]|j[d+303|0]<<8);f=j[d+302|0]|j[d+303|0]<<8;i[114610]=0;I(939,b|0,r|0,f|0)|0;f=i[114610];i[114610]=0;if((f|0)==1){break i}y=fp(d+176|0);s=fp(d+160|0);f=j[d+301|0];i[114610]=0;I(631,b|0,y|0,f|0)|0;f=i[114610];i[114610]=0;if((f|0)==1){break f}f=j[d+300|0];i[114610]=0;I(631,b|0,s|0,f|0)|0;f=i[114610];i[114610]=0;if((f|0)==1){break f}if(j[d+300|0]){t=c&2;u=d+88|4;v=d+126|0;w=d+88|6;f=0;while(1){i[114610]=0;m=f;f=f+1|0;n=o(f,104)+a|0;l=n+484380|0;D(386,l|0,0);e=i[114610];i[114610]=0;k:{l:{if((e|0)!=1){e=vb(s,m);if(!(j[e|0]|j[e+1|0]<<8|(j[e+2|0]<<16|j[e+3|0]<<24))){break k}e=vb(s,m);e=j[e|0]|j[e+1|0]<<8|(j[e+2|0]<<16|j[e+3|0]<<24);i[114610]=0;e=C(256,b|0,e|0)|0;p=i[114610];i[114610]=0;if((p|0)==1){break c}if(!e){break k}i[114610]=0;e=C(940,b|0,d+88|0)|0;p=i[114610];i[114610]=0;if((p|0)==1){break c}if(!e){break k}i[114610]=0;G(748,d+72|0,2,w|0);e=i[114610];i[114610]=0;if((e|0)!=1){i[114610]=0;D(415,d+16|0,d+72|0);e=i[114610];i[114610]=0;if((e|0)!=1){break l}}f=B()|0;A()|0;break b}f=B()|0;A()|0;break b}i[114610]=0;C(369,((f<<5)+a|0)+946300|0,d+16|0)|0;e=i[114610];i[114610]=0;m:{n:{o:{p:{q:{if((e|0)!=1){eb(d+16|0);i[114610]=0;G(941,d+72|0,2,v|0);e=i[114610];i[114610]=0;if((e|0)==1){break q}i[114610]=0;D(415,d+16|0,d+72|0);e=i[114610];i[114610]=0;if((e|0)==1){break q}i[114610]=0;C(370,n+484423|0,d+16|0)|0;e=i[114610];i[114610]=0;if((e|0)==1){break p}eb(d+16|0);if(j[d+138|0]<=15){e=n+484414|0;h[e>>1]=k[e>>1]|32;h[n+484408>>1]=o(j[d+138|0],17)}e=j[d+139|0];i[114610]=0;g[d+16|0]=e;g[d+72|0]=64;e=C(391,d+16|0,d+72|0)|0;p=i[114610];i[114610]=0;if((p|0)==1){break o}h[n+484412>>1]=j[e|0];i[n+484404>>2]=j[d+141|0]|j[d+142|0]<<8;e=n+484384|0;i[e>>2]=j[d+147|0]|j[d+148|0]<<8|(j[d+149|0]<<16|j[d+150|0]<<24);q=n+484388|0;i[q>>2]=j[d+151|0]|j[d+152|0]<<8|(j[d+153|0]<<16|j[d+154|0]<<24);i[l>>2]=j[d+155|0]|j[d+156|0]<<8|(j[d+157|0]<<16|j[d+158|0]<<24);if(g[d+140|0]&1){break n}p=i[e>>2];e=i[q>>2];break m}f=B()|0;A()|0;eb(d+16|0);break b}f=B()|0;A()|0;break b}f=B()|0;A()|0;eb(d+16|0);break b}f=B()|0;A()|0;break b}p=i[e>>2]>>>1|0;i[e>>2]=p;e=i[q>>2]>>>1|0;i[q>>2]=e;i[l>>2]=i[l>>2]>>>1}r:{if(e>>>0<=p>>>0){break r}e=n+484414|0;h[e>>1]=k[e>>1]|2;if(!(j[d+140|0]&2)){break r}h[e>>1]=k[e>>1]|4}i[114610]=0;L(942,l|0);e=i[114610];i[114610]=0;if((e|0)==1){break c}if(!t){break k}m=vb(s,m);m=j[m|0]|j[m+1|0]<<8|(j[m+2|0]<<16|j[m+3|0]<<24);e=j[u|0];i[114610]=0;C(256,b|0,e+m|0)|0;m=i[114610];i[114610]=0;if((m|0)==1){break c}m=Ic(d+16|0,g[d+140|0]&1?16:8,1,0,1);i[114610]=0;I(400,m|0,l|0,b|0)|0;m=i[114610];i[114610]=0;if((m|0)!=1){break k}f=B()|0;A()|0;break b}if(f>>>0<j[d+300|0]){continue}break}}K=1;s:{if(!(c&1)){break s}i[d+68>>2]=0;n=a+484360|0;rp(Db(n));Q=d,R=Jb(r),i[Q+64>>2]=R;Q=d,R=Kb(r),i[Q+56>>2]=R;if(pb(d- -64|0,d+56|0)){q=a+484344|0;w=d+88|5;t=d+88|4;while(1){m=i[d- -64>>2];c=m;t:{if(j[c+3|0]>=j[d+301|0]|j[c+2|0]>j[d+262|0]){break t}c=vb(y,j[c+3|0]);c=j[c|0]|j[c+1|0]<<8|(j[c+2|0]<<16|j[c+3|0]<<24);i[114610]=0;c=C(256,b|0,c|0)|0;f=i[114610];i[114610]=0;if((f|0)==1){break g}if(!c){break t}i[114610]=0;C(943,b|0,d+88|0)|0;c=i[114610];i[114610]=0;if((c|0)==1){break h}if(!j[t|0]){break t}c=j[m|0]|j[m+1|0]<<8;f=j[m|0]|j[m+1|0]<<8;g[d+16|0]=j[w|0];e=j[d+262|0];l=j[m+2|0];i[114610]=0;g[d+72|0]=e-l;e=C(391,d+16|0,d+72|0)|0;l=i[114610];i[114610]=0;if((l|0)==1){break d}u=j[e|0];e=j[m|0]|j[m+1|0]<<8;l=j[t|0];i[114610]=0;i[d+52>>2]=e+l;e=C(392,d+68|0,d+52|0)|0;l=i[114610];i[114610]=0;if((l|0)==1){break e}i[d+68>>2]=i[e>>2];i[d+40>>2]=0;i[d+44>>2]=0;i[d+32>>2]=0;i[d+36>>2]=0;i[d+24>>2]=0;i[d+28>>2]=0;i[d+16>>2]=0;i[d+20>>2]=0;if(!j[t|0]){break t}z=c>>>6|0;e=f&63;H=0;while(1){u:{v:{w:{x:{y:{z:{A:{f=e>>>0>63;z=f+z|0;c=z&65535;if(Wb(Db(n))>>>0<=c>>>0){l=Db(n);i[114610]=0;D(930,l|0,z+1&65535);l=i[114610];i[114610]=0;if((l|0)==1){break A}i[114610]=0;l=I(815,q|0,64,0)|0;p=i[114610];i[114610]=0;if((p|0)==1){break A}Q=$b(Db(n),c),R=l,h[Q>>1]=R}v=k[$b(Db(n),c)>>1];i[114610]=0;c=C(442,q|0,v|0)|0;l=i[114610];i[114610]=0;if((l|0)==1){break y}if(!c){break t}c=Fb(q,v);l=j[m+2|0];i[114610]=0;F=f?0:e;f=I(471,c|0,F|0,l|0)|0;c=i[114610];i[114610]=0;if((c|0)==1){break v}p=0;J=0;if(u){break z}break w}f=B()|0;A()|0;break b}while(1){i[114610]=0;D(944,d+72|0,b|0);c=i[114610];i[114610]=0;if((c|0)==1){break x}l=Nc(d+72|0);O=yf(d+72|0);M=li(d+72|0);P=Pb(d+72|0);e=0;c=j[d+72|0];if((c+ -1&255)>>>0<=142){e=(o((c&240)>>>4|0,12)+(c&15)|0)+13|0;g[(d+16|0)+p|0]=e}g[f|0]=e;c=j[l|0];g[f+2|0]=1;g[f+1|0]=c;c=j[O|0];B:{if((c|0)!=255){g[f+4|0]=c;break B}g[f+2|0]=0}c=j[M|0];C:{if(c>>>0>22){break C}g[f+3|0]=j[c+16672|0];l=j[P|0];g[f+5|0]=l;c=f+5|0;D:{switch(j[M|0]+ -4|0){case 3:g[c|0]=l&3|64;break C;case 4:g[c|0]=l&3|48;break C;case 7:if(qb(r)>>>0<=l>>>0){break C}l=c;c=vb(r,j[c|0]);e=j[c|0]|j[c+1|0]<<8;g[l|0]=e>>>6;c=Fb(q,v);l=k[a+480188>>1];i[114610]=0;c=I(471,c|0,F|0,l+ -1&65535)|0;l=i[114610];i[114610]=0;if((l|0)!=1){g[c+3|0]=14;g[c+5|0]=e&63;break C}f=B()|0;A()|0;break b;case 8:g[c|0]=i[d+52>>2]>>>6;c=Fb(q,v);e=k[a+480188>>1];i[114610]=0;c=I(471,c|0,F|0,e+ -1&65535)|0;e=i[114610];i[114610]=0;if((e|0)!=1){g[c+3|0]=14;g[c+5|0]=j[d+52|0]&63;break C}f=B()|0;A()|0;break b;case 10:g[c|0]=l&15|128;break C;case 12:i[114610]=0;g[d+15|0]=15;e=C(391,c|0,d+15|0)|0;l=i[114610];i[114610]=0;if((l|0)!=1){g[c|0]=j[e|0]|208;break C}f=B()|0;A()|0;break b;case 13:i[114610]=0;g[d+15|0]=15;e=C(391,c|0,d+15|0)|0;l=i[114610];i[114610]=0;if((l|0)!=1){g[c|0]=j[e|0]|192;break C}f=B()|0;A()|0;break b;case 14:i[114610]=0;g[d+15|0]=15;e=C(391,c|0,d+15|0)|0;l=i[114610];i[114610]=0;if((l|0)!=1){g[c|0]=j[e|0]|224;break C}f=B()|0;A()|0;break b;case 0:case 16:case 17:if(!(l&15)){break C}e=l&240;if(!e|(e|0)==240){break C}g[c|0]=l|15;break C;case 9:case 18:break D;default:break C}}if(e&255){break C}g[f|0]=j[(d+16|0)+p|0]}f=f+6|0;J=J+1|0;p=J&65535;if(p>>>0<u>>>0){continue}break}break w}f=B()|0;A()|0;break b}f=B()|0;A()|0;break b}if(j[w|0]<=u>>>0){break u}c=j[w|0];i[114610]=0;C(338,b|0,o(c-u|0,5)|0)|0;c=i[114610];i[114610]=0;if((c|0)!=1){break u}}f=B()|0;A()|0;break b}e=F+1|0;H=H+1|0;if(H>>>0<j[t|0]){continue}break}}Gd(d- -64|0);if(pb(d- -64|0,d+56|0)){continue}break}}E:{b=i[d+68>>2];c=b&63;if(!c){break E}f=Db(n);i[114610]=0;b=b>>>6|0;f=C(546,f|0,b&65535)|0;m=i[114610];i[114610]=0;if((m|0)!=1){if(!f){break E}b=Fb(a+484344|0,k[$b(Db(n),b&65535)>>1]);i[114610]=0;N(945,b|0,c|0,0,1)|0;b=i[114610];i[114610]=0;if((b|0)!=1){break E}}f=B()|0;A()|0;break b}b=Db(n);Q=d,R=Jb(b),i[Q+88>>2]=R;Q=d,R=Kb(b),i[Q+16>>2]=R;if(!pb(d+88|0,d+16|0)){break s}a=a+484344|0;e=65535;while(1){b=i[d+88>>2];if(k[b>>1]==65535){F:{if((e&65535)!=65535){break F}i[114610]=0;e=I(815,a|0,64,0)|0;c=i[114610];i[114610]=0;if((c|0)!=1){break F}f=B()|0;A()|0;break b}h[b>>1]=e}he(d+88|0);if(pb(d+88|0,d+16|0)){continue}break}}gi(s);gi(y);TN(r)}Xa=d+304|0;return K|0}f=B()|0;A()|0;break a}f=B()|0;A()|0;break b}f=B()|0;A()|0;break b}f=B()|0;A()|0;break b}f=B()|0;A()|0;break b}f=B()|0;A()|0;break b}f=B()|0;A()|0}gi(s);gi(y)}TN(r);E(f|0);x()}function Cma(a){var b=0,c=0,d=0,e=0,f=0,n=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0;c=Xa-32|0;Xa=c;a:{if(!Ama(a)|!i[a+1074420>>2]){break a}b=AJ(a,a+1074376|0);i[a+1074380>>2]=b;i[a+1074404>>2]=b;v=hd(k[a+480188>>1],1,31);z=a+1074328|0;b:{if(j[z+37|0]){b=i[a+24628>>2];if((b|0)>=129){b=((o(b+ -128|0,v+4|0)|0)/16|0)+128|0}A=o(i[a+480228>>2],b)>>>6|0;break b}A=i[a+480228>>2]}A=j[z+37|0]?(A<<7>>>0)/j[(v>>>1|0)+20736|0]|0:A;h[a+480212>>1]=0;y=a+1304392|0;w=a+1074308|0;C=a+480210|0;D=a+480209|0;while(1){e=o(u,896)+a|0;q=e+1075072|0;c:{if(!(i[q>>2]&4096)|(i[e+1075008>>2]|(i[e+1075004>>2]|i[e+1075680>>2]))){break c}kb(c+24|0,w,64);if(ib(c+24|0)){break c}i[e+1075060>>2]=0;b=e+1075076|0;i[b>>2]=0;i[b+4>>2]=0}b=k[a+480188>>1];n=i[q>>2];d:{if(!(i[e+1075060>>2]|u>>>0<b>>>0?!(n&1024):0)){if(u>>>0<b>>>0){pJ(a,u&65535)}h[e+1075846>>1]=0;break d}p=0;B=e+1075704|0;i[B>>2]=0;t=e+1075664|0;i[t>>2]=0;v=e+1074992|0;f=v;i[f>>2]=0;i[f+4>>2]=0;i[e+1075084>>2]=0;i[c+20>>2]=1065353216;h[c+18>>1]=0;E=e+1075640|0;r=i[E>>2];d=0;f=e+1075684|0;if(i[f>>2]){d=i[e+1075060>>2]!=0}s=e+1074984|0;e:{f:{g:{if(u>>>0>=b>>>0){break g}if(j[((u<<5)+a|0)+480288|0]){break f}if(!r){break g}p=j[r+34|0]!=0}if((d|p)!=1){break e}}i[c+8>>2]=i[e+1075672>>2];i[c+4>>2]=i[e+1075748>>2];kb(c+24|0,w,28);zma(a,s,ib(c+24|0)?c+4|0:c+8|0);yma(a,s);xma(a,s,c+8|0);n=u&65535;wma(a,n,c+8|0);Kd(c+8|0,0,256);b=i[c+8>>2]<<6;i[c+8>>2]=b;h:{i:{if(r){kb(c+24|0,w,31);if(ib(c+24|0)){Cr(a,s)}vma(a,s,c+8|0);oJ(s,c+8|0);uma(a,s);tma(s);b=i[c+8>>2];break i}if(!(j[q+1|0]&16)){break i}i[e+1075680>>2]=0;i[c+8>>2]=0;break h}if(!b){break h}if(j[q+3|0]&8){i[t>>2]=0;break h}b=i[c+8>>2];if(j[z+36|0]){p=o(i[c+4>>2],i[e+1075744>>2]);b=b<<8;H=t,I=gc(YMa(XMa(p,p>>31,b,b>>31),_a,1048576,0),_a),i[H>>2]=I;break h}p=o(i[c+4>>2],i[e+1075744>>2]);b=o(b,i[a+1074444>>2]);H=t,I=gc(YMa(XMa(p,p>>31,b,b>>31),_a,1048576,0),_a),i[H>>2]=I}i[B>>2]=i[c+8>>2];j:{if(i[a+480180>>2]==2|i[f>>2]>=i[a+480260>>2]){break j}if(wo(a)){break j}i[f>>2]=i[a+480260>>2]}kb(c+24|0,w,73);if(ib(c+24|0)){Eb(i[f>>2],1,31999)}b=i[f>>2];i[c+12>>2]=b;k:{if((i[q>>2]&1572864)!=1572864){break k}if(j[C|0]&32){if(!Ur(e+1075794|0)|j[D|0]&16){break k}b=i[c+12>>2]}p=e+1075696|0;l:{if(i[p>>2]==(b|0)){b=i[e+1075700>>2];break l}i[p>>2]=b;x=b;b=e+1075752|0;p=e+1075688|0;b=Vf(a,Lr(a,x,i[b>>2],i[p>>2]),i[b>>2],i[p>>2]);i[e+1075700>>2]=b}i[c+12>>2]=b}rma(a,n,c+12|0,c+18|0);if(!(!(j[C|0]&33)|i[c+12>>2]==2147483647)){m:{if(i[a+480180>>2]==2){b=452;n=3424;break m}n=o(i[e+1075752>>2]>>>4&15,24)+21008|0;b=k[n+22>>1];b=b>>>0<904?452:b>>>1|0;n=k[n>>1]<<1}Kd(c+12|0,b,n);Kd(f,b,n)}nJ(a,s);n=i[q>>2]}n:{if(!(n&256)|j[D|0]&64){break n}kb(c+24|0,w,37);if(!ib(c+24|0)){break n}i[e+1075668>>2]=128}b=u&65535;pJ(a,b);o:{if(!d){break o}n=mJ(a,s,c+12|0);if((n|0)<0|!(j[q+1|0]&2)){break o}if(!$c(y)){break o}Jo(i[y>>2],b,n>>>2&255,1)}p:{if(j[e+1075796|0]!=8){break p}q:{r:{n=j[e+1075797|0];switch(n+ -5|0){case 1:break p;case 0:case 2:break q;default:break r}}if((n|0)!=26){break p}}if(i[a+480180>>2]==4){if(j[D|0]&16){break p}n=e+1075823|0;g[n|0]=j[n|0]+j[e+1075827|0];break p}if(!(i[a+480180>>2]&16777248)){break p}Lj(s,j[e+1075798|0]);lJ(a,b,c+12|0,c+20|0)}lJ(a,b,c+12|0,c+20|0);if(d){i[c+8>>2]=0;qma(a,s,c+12|0,c+20|0,c+8|0);if(i[c+12>>2]<=i[a+480260>>2]){kb(c+24|0,w,81);if(ib(c+24|0)){i[e+1075060>>2]=0}i[c+12>>2]=i[a+480260>>2]}p=Vi(s);s:{if(!p){break s}d=e+1075856|0;n=j[d|0];if(i[a+1074392>>2]|!(n&4)?!(n&8):0){break s}vM(s,m[c+20>>2],h[c+18>>1],a);n=j[d|0];if(!(n&8)){g[d|0]=n&251;break s}g[d|0]=n&247}t:{if((i[q>>2]&134219264)!=512){break t}if(!$c(y)){break t}kb(c+24|0,w,99);if(!(H=!(ib(c+24|0)|!(j[q+1|0]&16)),I=0,J=i[a+480180>>2]!=2,J?H:I)){if(!(j[q+1|0]&8?i[a+480180>>2]==2:0)){if(p){f=i[f>>2]}else{f=gK(a,i[c+12>>2],i[e+1075688>>2],i[c+8>>2])}d=XMa(f,0,261625,0)+66904|0;f=_a;d=Vc(_Ma(d,d>>>0<66904?f+1|0:f,133808,0),_a);n=i[q>>2];f=1;u:{if(n&2048){break u}f=0;if(!(n&4096)){break u}f=!i[e+1075680>>2]}n=i[y>>2];kb(c+24|0,w,95);wsa(n,b,d,f,ib(c+24|0))}n=i[y>>2];d=XMa(o(i[e+1075748>>2],o(i[e+1075744>>2],i[B>>2])),0,63,0)+33554432|0;f=_a;f=d>>>0<33554432?f+1|0:f;Jo(n,b,Vc((f&67108863)<<6|d>>>26,f>>>26|0)&255,0);f=e+1075668|0;H=f,I=(vsa(i[y>>2],b,i[f>>2])<<7)+128|0,i[H>>2]=I}v:{f=i[E>>2];if(!f|(j[f+60|0]&7)!=1){break v}f=f+48|0;if(Uc(f)){break v}if(l[kJ(s,0)+4>>2]<k[Qi(f)>>1]){break v}if(j[Qi(f)+2|0]){break v}Zh(i[y>>2],b,1);kb(c+24|0,w,109);f=ib(c+24|0);b=i[q>>2];if(!f){b=b&-513;i[q>>2]=b}i[q>>2]=b|4096;i[e+1075680>>2]=0;break t}kb(c+24|0,w,99);if(!ib(c+24|0)|!(j[q+1|0]&16)|i[e+1075680>>2]){break t}Zh(i[y>>2],b,1);i[q>>2]=i[q>>2]&-513}d=XMa(Uw(a,s,i[c+12>>2],i[c+8>>2]),_a,i[a+480240>>2],0);b=_a;n=YMa(d,b,65536,0);p=_a;f=v;x=f;d=d+65535|0;if(d>>>0<65535){b=b+1|0}b=!b&d>>>0<131071|b>>>0<0;i[x>>2]=b?1:n;i[f+4>>2]=b?0:p}w:{if(!r){break w}kb(c+24|0,w,31);if(ib(c+24|0)){break w}Cr(a,s)}B=e+1075004|0;x=e+1075008|0;i[q>>2]=i[q>>2]&-65537|((i[B>>2]|(i[x>>2]|i[t>>2]))!=0)<<16;f=e+1075656|0;b=f;i[b>>2]=0;i[b+4>>2]=0;r=e+1075846|0;b=j[r|0];g[r|0]=(b>>>0>4?b:4)+ -4;n=e+1075847|0;b=j[n|0];g[n|0]=(b>>>0>4?b:4)+ -4;x:{y:{z:{A:{B:{b=e+1075088|0;d=i[b>>2];C:{if(!d){break C}if(!ie(d)|!i[e+1075060>>2]){break C}if(nh(s)){break B}}p=e+1075e3|0;i[p>>2]=0;break A}p=e+1075e3|0;b=i[i[b>>2]+20>>2];i[p>>2]=b;if(b){break z}}if(!Pi(s)|j[q+1|0]&24){break y}}F=i[t>>2];G=i[e+1075668>>2];b=(o(F,256-G|0)|0)/16384|0;d=b>>>0<127?b:127;b=g[r|0];if((b|0)<=-1){g[r|0]=d;b=d}d=d>>>1|0;if(d>>>0>(b&255)>>>0){g[r|0]=d}b=(o(F,G)|0)/16384|0;d=b>>>0<127?b:127;b=g[n|0];if((b|0)<=-1){g[n|0]=d;b=d}d=d>>>1|0;if(d>>>0<=(b&255)>>>0){break x}g[n|0]=d;break x}if(j[r|0]>=129){g[r|0]=0}if(j[n|0]<129){break x}g[n|0]=0}D:{if(i[p>>2]){b=e+1075660|0;E:{if(l[a+24624>>2]>=2){i[c+24>>2]=i[e+1075668>>2];Kd(c+24|0,0,256);r=o(i[t>>2],A)>>>(j[z+37|0]?7:8)|0;d=b;F:{G:{H:{switch(i[z+32>>2]){case 0:if(!(j[a+24616|0]&16)){break G};case 1:t=i[c+24>>2];if((t|0)<=127){i[f>>2]=r>>>1;n=(o(r,t)|0)/256|0;break F}i[f>>2]=(o(r,256-t|0)|0)/256;n=r>>>1|0;break F;case 3:break H;default:break G}}Xj(c+24|0,255);n=f;p=i[c+24>>2];x=65536;I:{if((p|0)<1){break I}x=k[(0-p<<1)+27856>>1]}i[n>>2]=o(x,r)>>>16;n=o(r,k[(p<<1)+27344>>1])>>>16|0;break F}t=i[c+24>>2];i[f>>2]=(o(r,256-t|0)|0)/256;n=(o(r,t)|0)/256|0}i[d>>2]=n;break E}d=o(i[t>>2],A)>>>8|0;i[f>>2]=d;i[b>>2]=d}d=i[E>>2];J:{if(d){d=j[d+14|0];if(qn(d)){break J}}d=j[a+480268|0];if(qn(d)){break J}if(j[C|0]&128){d=255;if(i[a+24668>>2]){break J}}d=j[a+24648|0]}t=e+1075800|0;g[t|0]=d;if(!(j[q+2|0]&2|(i[v>>2]!=0|i[v+4>>2]!=1)|(i[e+1075764>>2]|(d|0)==255))){g[t|0]=0}d=f;n=i[f>>2];f=1<<i[z+28>>2];i[d>>2]=(n|0)/(f|0);f=i[b>>2]/(f|0)|0;i[b>>2]=f;d=i[q>>2];if(!(!(d&256)|i[a+24624>>2]!=2)){i[b>>2]=0-f}if(d&128){b=i[v>>2];f=0-(i[v+4>>2]+(0<b>>>0)|0)|0;i[v>>2]=0-b;i[v+4>>2]=f}pma(a,s);if(j[q+1|0]&2){break D}b=k[a+480212>>1];h[a+480212>>1]=b+1;h[((b<<1)+a|0)+1074466>>1]=u;break D}i[B>>2]=0;i[x>>2]=0;i[e+1075060>>2]=0;if(i[e+1075076>>2]?0:!i[e+1075080>>2]){break D}b=k[a+480212>>1];h[a+480212>>1]=b+1;h[((b<<1)+a|0)+1074466>>1]=u}i[e+1075652>>2]=i[q>>2]}u=u+1|0;if((u|0)!=256){continue}break}d=1;if(l[a+24608>>2]>k[a+480212>>1]){break a}b=a+1074466|0;oma(b,b+(i[a+24608>>2]<<1)|0,b+(k[a+480212>>1]<<1)|0,a)}Xa=c+32|0;return d}function jU(a,b){var c=0,d=0,e=0,f=0,m=0,n=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0;c=Xa-112|0;Xa=c;if(b){N=a+12|0;O=a+24592|0;P=a+24588|0;Rm(N,b,O,P);if(l[a+24624>>2]>=3){Rm(a+8204|0,b,a+24600|0,a+24596|0)}h[c+30>>1]=0;L=a+1074308|0;kb(c+8|0,L,33);d=ib(c+8|0);e=k[a+480212>>1];if(e){X=d?2:1;Y=a+24648|0;Z=a+24596|0;_=a+24600|0;$=a+8204|0;aa=a+397460|0;ba=a+397456|0;ca=a+393352|0;Q=a+1074376|0;while(1){w=(M<<1)+Q|0;d=o(k[w+90>>1],896);q=d+Q|0;z=q;a:{b:{if(i[q+624>>2]){break b}n=a+d|0;if(i[n+1075080>>2]){break b}if(!i[n+1075076>>2]){break a}}f=a+d|0;m=wua(j[f+1075800|0]);s=f+1075072|0;n=i[s>>2];p=n&1;t=n>>>5|0;c:{if(!(n&8388608)){y=N;B=P;e=n;d=O;if(!(!(e&16777216)&(j[a+24612|0]&32)>>>5)){break c}}y=qea(ca,b);e=i[s>>2];B=aa;d=ba}G=d;d=m|p;m=t&2;n=n>>>12|0;if(!(!(e&256)|l[a+24624>>2]<3)){G=_;B=Z;y=$}m=d|m;p=n&8;n=q+608|0;C=ym(a,k[w+90>>1],2,1);d:{if((!C|0)==(C>>>0<251|0)){break d}e=i[(o(C,160)+a|0)+906140>>2];if(!e){break d}d=i[e+24>>2];if(!d){break d}B=e+36|0;G=e+40|0;if(!(g[e+28|0]&1)){Rm(d,b,G,B);i[e+28>>2]=i[e+28>>2]|1}y=d}da=m|p;R=f+1075809|0;ea=f+1075792|0;fa=f+1075680|0;ga=f+1075016|0;ha=f+1075012|0;ia=f+1075660|0;ja=f+1075656|0;v=f+1074992|0;D=f+1075080|0;E=f+1075076|0;S=f+1075008|0;T=f+1075004|0;J=f+1075088|0;H=f+1075068|0;t=f+1075060|0;K=f+1075064|0;F=f+1075084|0;A=0;ka=iU(c+8|0,n);w=b;while(1){e:{d=i[F>>2];d=d?w>>>0>d>>>0?d:w:w;i[c+68>>2]=d;x=i[K>>2];r=i[s>>2];m=i[v+4>>2];e=i[v>>2];i[c+56>>2]=e;i[c+60>>2]=m;f:{g:{if(!d|!(e|m)){break g}p=i[t>>2];if(!p){break g}i[z+624>>2]=i[c+8>>2];u=i[n+4>>2];d=u;f=i[n>>2];q=x&r<<30>>31;h:{if((q|0)>(d|0)){if((m|0)<-1?1:(m|0)<=-1){i[c+104>>2]=0;e=q;i[c+108>>2]=e<<1;f=Mf(c+104|0,n);m=_a;d=m;i[n>>2]=f;i[n+4>>2]=d;if(!(i[t>>2]+e>>>1>>>0>d>>>0?(e|0)<=(d|0):0)){f=0;i[n>>2]=f;d=e;i[n+4>>2]=d}p=i[c+60>>2];r=i[c+56>>2];m=r;e=0-(p+(0<m>>>0)|0)|0;m=0-m|0;i[c+56>>2]=m;i[c+60>>2]=e;i[v>>2]=m;i[v+4>>2]=e;e=i[s>>2];i:{if(e&4){e=e&-129;i[s>>2]=e;break i}e=e|128;i[s>>2]=e;u=i[t>>2]+ -1|0;d=u;i[n>>2]=f;i[n+4>>2]=d;i[v>>2]=r;i[v+4>>2]=p}j:{if(!(e&2)){e=i[t>>2];break j}e=i[t>>2];if(e>>>0>d>>>0){break h}}f=n;i[f>>2]=0;i[f+4>>2]=e;break g}if((u|0)>-1){break h}e=0;d=e;i[n>>2]=f;i[n+4>>2]=d;break h}if(p>>>0>u>>>0){break h}if(!(r&2)){break g}if(r&4){if((m|0)>0?1:(m|0)>=0?e>>>0>=1:0){d=0-((0<e>>>0)+m|0)|0;e=0-e|0;i[c+56>>2]=e;i[c+60>>2]=d;i[v>>2]=e;i[v+4>>2]=d}i[s>>2]=r|128;d=1-(0<f>>>0)|0;f=0-f|0;m=((p<<1)-u|0)-d|0;d=m;e=n;i[e>>2]=f;i[e+4>>2]=d;if(d>>>0<p>>>0?d>>>0>x>>>0:0){break h}i[c+104>>2]=X;d=p-i[rb(t,c+104|0)>>2]|0;f=i[e>>2];i[n>>2]=f;i[e+4>>2]=d;break h}if((m|0)<-1?1:(m|0)<=-1){f=0-e|0;i[c+56>>2]=f;d=0-((0<e>>>0)+m|0)|0;i[c+60>>2]=d;i[v>>2]=f;i[v+4>>2]=d}i[c+104>>2]=0;i[c+108>>2]=q-p;zb(n,c+104|0);i[s>>2]=i[s>>2]|8192;f=i[n>>2];d=i[n+4>>2]}i[c+48>>2]=f;i[c+52>>2]=d;k:{l:{e=d;m:{if((q|0)>(d|0)){if((d|i[c+60>>2])>-1){break m}break l}if((d|0)<0?1:(d|0)<=0?f>>>0<0:0){break l}}d=0;if(l[t>>2]<=e>>>0){break k}U=i[c+68>>2];i[c+44>>2]=U;d=i[c+56>>2];f=i[c+60>>2];kc(c+68|0,i[c+20>>2]);la=c,ma=Pt(c+56|0,i[c+68>>2]+ -1|0),i[la+32>>2]=ma;i[c+36>>2]=_a;e=d;m=f;d=f>>31;f=f>>31;r=m;m=d;d=r+d|0;p=f+e|0;if(p>>>0<f>>>0){d=d+1|0}x=p;p=d;d=i[c+36>>2]+i[c+52>>2]|0;e=i[c+48>>2];r=e+i[c+32>>2]|0;if(r>>>0<e>>>0){d=d+1|0}e=i[K>>2];V=e+16|0;I=i[c+52>>2];r=I;u=i[c+48>>2];W=e>>>0>r>>>0;if(!(V>>>0>r>>>0?!W:0)){i[s>>2]=i[s>>2]&-8193}x=f^x;m=m^p;f=d;n:{o:{p:{if(!i[c+12>>2]){p=i[c+60>>2];break p}d=i[c+16>>2];if(d>>>0<=I>>>0){f=c;e=i[c+60>>2];q:{if((e|0)<-1?1:(e|0)<=-1){i[c+96>>2]=u;i[c+100>>2]=r;i[c+104>>2]=0;i[c+108>>2]=d;la=c,ma=Mf(c+96|0,c+104|0),i[la+80>>2]=ma;i[c+84>>2]=_a;i[c+72>>2]=1;i[c+76>>2]=0;la=c,ma=Mf(c+80|0,c+72|0),i[la+88>>2]=ma;i[c+92>>2]=_a;d=vl(c+88|0,x,m);break q}d=i[H>>2];i[c+104>>2]=u;i[c+108>>2]=r;i[c+96>>2]=0;i[c+100>>2]=d;la=c,ma=Mf(c+96|0,c+104|0),i[la+80>>2]=ma;i[c+84>>2]=_a;i[c+72>>2]=1;i[c+76>>2]=0;la=c,ma=Mf(c+80|0,c+72|0),i[la+88>>2]=ma;i[c+92>>2]=_a;d=vl(c+88|0,x,m)}i[f+44>>2]=d+1;i[z+624>>2]=i[c+12>>2];break n}if(!(W|!(j[s+1|0]&32)|V>>>0<=I>>>0)){i[c+104>>2]=u;i[c+108>>2]=r;i[c+96>>2]=0;i[c+100>>2]=q+16;la=c,ma=Mf(c+96|0,c+104|0),i[la+80>>2]=ma;i[c+84>>2]=_a;i[c+72>>2]=1;i[c+76>>2]=0;la=c,ma=Mf(c+80|0,c+72|0),i[la+88>>2]=ma;i[c+92>>2]=_a;la=c,ma=vl(c+88|0,x,m)+1|0,i[la+44>>2]=ma;la=z,ma=i[c+12>>2]+o(i[H>>2]-q|0,xn(i[J>>2]))|0,i[la+624>>2]=ma;break n}I=i[c+60>>2];p=I;if((p|0)<0?1:(p|0)<=0?l[c+56>>2]<1:0){break p}if(U>>>0<2|d>>>0>f>>>0){break o}i[c+104>>2]=u;i[c+108>>2]=r;i[c+96>>2]=0;i[c+100>>2]=d;la=c,ma=Mf(c+96|0,c+104|0),i[la+80>>2]=ma;i[c+84>>2]=_a;i[c+72>>2]=1;i[c+76>>2]=0;la=c,ma=Mf(c+80|0,c+72|0),i[la+88>>2]=ma;i[c+92>>2]=_a;la=c,ma=vl(c+88|0,x,m)+1|0,i[la+44>>2]=ma;break n}if((p|0)>-1){break o}if((q|0)<=(f|0)){break n}i[c+96>>2]=u;i[c+100>>2]=r;i[c+104>>2]=0;i[c+108>>2]=e;la=c,ma=Mf(c+96|0,c+104|0),i[la+80>>2]=ma;i[c+84>>2]=_a;i[c+72>>2]=1;i[c+76>>2]=0;la=c,ma=Mf(c+80|0,c+72|0),i[la+88>>2]=ma;i[c+92>>2]=_a;la=c,ma=vl(c+88|0,x,m)+1|0,i[la+44>>2]=ma;break n}d=i[t>>2];if((d|0)>(f|0)){break n}i[c+104>>2]=u;i[c+108>>2]=r;i[c+96>>2]=0;i[c+100>>2]=d;la=c,ma=Mf(c+96|0,c+104|0),i[la+80>>2]=ma;i[c+84>>2]=_a;i[c+72>>2]=1;i[c+76>>2]=0;la=c,ma=Mf(c+80|0,c+72|0),i[la+88>>2]=ma;i[c+92>>2]=_a;la=c,ma=vl(c+88|0,x,m)+1|0,i[la+44>>2]=ma}wn(c+44|0,1,i[c+68>>2]);d=i[c+44>>2];break k}d=0}if((d|0)>0){break f}}i[z+624>>2]=0;i[t>>2]=0;i[n>>2]=0;i[n+4>>2]=0;i[F>>2]=0;qua(n,y,w);i[G>>2]=i[G>>2]+i[E>>2];i[B>>2]=i[B>>2]+i[D>>2];i[D>>2]=0;i[E>>2]=0;i[s>>2]=i[s>>2]&-129;break e}r:{s:{if(l[a+24608>>2]>k[c+30>>1]){A=4;if(i[F>>2]){break s}A=0;if(i[S>>2]|i[T>>2]){break s}}la=c,ma=XMa(i[v>>2],i[v+4>>2],d,d>>31),i[la+104>>2]=ma;i[c+108>>2]=_a;zb(n,c+104|0);A=0;i[D>>2]=0;i[E>>2]=0;y=(d<<3)+y|0;break r}f=(d<<3)+y|0;e=f+ -8|0;i[E>>2]=0-i[e>>2];q=f+ -4|0;i[D>>2]=0-i[q>>2];$a[i[((A|da)<<2)+77504>>2]](n,Y,y,d);i[E>>2]=i[E>>2]+i[e>>2];i[D>>2]=i[D>>2]+i[q>>2];A=1;y=f}f=i[F>>2];t:{if(!f){break t}if(f>>>0<=d>>>0){i[F>>2]=0;i[T>>2]=i[ja>>2];i[S>>2]=i[ia>>2];i[ha>>2]=0;i[ga>>2]=0;if(i[fa>>2]|!(j[s+1|0]&16)){break t}i[t>>2]=0;i[z+624>>2]=0;break t}i[F>>2]=f-d}f=0;e=0;q=i[n+4>>2];if(l[H>>2]<=q>>>0){e=(j[s|0]&2)>>>1|0}m=i[t>>2];if(!(i[s>>2]&2|(m>>>0>q>>>0|!m))){f=!k[ea>>1]}w=w-d|0;kb(c+104|0,L,85);u:{v:{w:{x:{if(!ib(c+104|0)){break x}d=j[R|0];if(!d|k[a+480190>>1]<d>>>0){break x}m=!(f|e);q=i[J>>2];d=o(j[R|0],104)+a|0;f=d+484380|0;if(m|(q|0)==(f|0)){break w}i[J>>2]=f;i[z+624>>2]=i[d+484400>>2];f=k[d+484414>>1];i[s>>2]=f|i[s>>2]&-768;e=f<<30>>31;f=i[d+484388>>2];i[t>>2]=e&f;d=i[d+484384>>2];i[K>>2]=d;i[H>>2]=f;i[n+4>>2]=d;FA(ka,n);if(!i[z+624>>2]){break e}if((w|0)>0){continue}break e}if(e){break v}break u}if(!e|(f|0)!=(q|0)){break u}}kb(c+104|0,L,83);if(!ib(c+104|0)|i[K>>2]){break u}i[n>>2]=i[n>>2];i[n+4>>2]=0;d=i[i[J>>2]+8>>2];i[t>>2]=d;i[H>>2]=d}if((w|0)>0){continue}}break}i[z+624>>2]=i[c+8>>2];h[c+30>>1]=k[c+30>>1]+A;y:{if(!A|(!C|C>>>0>250)){break y}d=i[(o(C,160)+a|0)+906140>>2];if(!d){break y}$a[i[i[d>>2]+144>>2]](d)}e=k[a+480212>>1]}M=M+1|0;if(M>>>0<(e&65535)>>>0){continue}break}}la=a,ma=k[ri(a+480214|0,c+30|0)>>1],h[la+480214>>1]=ma}Xa=c+112|0}function vHa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,l=0,m=0,n=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0;d=Xa-272|0;Xa=d;pc(b);e=d+112|0;l=sHa(b,e);if(!l){IQ(e)}a:{b:{c:{d:{e:{f:{g:{h:{i:{if(!l){break i}if(!KQ(d+112|0)){break i}if(!c){f=1;break i}md(a,i[((j[d+228|0]|j[d+229|0]<<8)<<2)+12976>>2]);e=Bb(d+16|0,13016);mb(a+1304436|0,e);eb(e);e=Bb(d+16|0,13038);mb(a+1304448|0,e);eb(e);e=Bb(d+80|0,13042);i[114610]=0;D(219,d+96|0,e|0);f=i[114610];i[114610]=0;if((f|0)==1){break c}i[114610]=0;J(427,d+16|0,d+96|0,d+191|0,d+188|0);f=i[114610];i[114610]=0;if((f|0)==1){break d}mb(a+1304460|0,d+16|0);eb(d+16|0);ob(d+96|0);eb(e);tc(a+1304484|0,((j[d+228|0]|j[d+229|0]<<8)<<2)+13072|0);tc(a+1304472|0,i[((j[d+228|0]|j[d+229|0]<<8)<<2)+77408>>2]);i[a+1304496>>2]=4;rg(d+96|0,2,d+112|4);oc(d+16|0,d+96|0);mb(a+1304400|0,d+16|0);eb(d+16|0);rg(d+96|0,2,d+148|0);oc(d+16|0,d+96|0);if(Us(d+16|0,13112)){i[114610]=0;G(13,d+96|0,4,d+16|0);e=i[114610];i[114610]=0;if((e|0)==1){break h}mb(a+1304412|0,d+96|0);eb(d+96|0)}eb(d+16|0);h[a+480188>>1]=32;e=0;j:{while(1){l=(e<<5)+a|0;n=l+480280|0;sg(n);k:{f=d+e|0;if(j[f+193|0]<=15){i[d+16>>2]=j[f+193|0]<<4|8;i[d+96>>2]=256;y=l+480284|0,z=i[Nd(d+16|0,d+96|0)>>2],h[y>>1]=z;break k}if(j[f+193|0]==16){h[l+480284>>1]=128;i[n>>2]=256;break k}if(j[f+193|0]!=255){break k}h[a+480188>>1]=e;break j}e=e+1|0;if((e|0)!=32){continue}break}e=k[a+480188>>1]}f=0;if(!(e&65535)){break i}i[d+16>>2]=j[d+225|0]<<2;i[d+96>>2]=256;y=a,z=i[rb(d+16|0,d+96|0)>>2],i[y+480200>>2]=z;i[a+480196>>2]=j[d+226|0];i[a+480204>>2]=o(j[d+227|0],1e4);if(vc(b,j[d+230|0]|j[d+231|0]<<8|(j[d+232|0]<<16|j[d+233|0]<<24))){hp(Db(a+484360|0),b,j[d+234|0]+1|0,255,254)}if(!vc(b,j[d+240|0]|j[d+241|0]<<8|(j[d+242|0]<<16|j[d+243|0]<<24))){break i}h[a+480190>>1]=j[d+248|0]+1;m=d+48|0;e=1;n=1;while(1){if(uHa(b,d+16|0)){f=o(e,104)+a|0;l=f+484380|0;kd(l,0);rg(d,2,d+16|0);oc(d+96|0,d);i[114610]=0;C(369,((e<<5)+a|0)+946300|0,d+96|0)|0;e=i[114610];i[114610]=0;if((e|0)==1){break e}eb(d+96|0);bk(d,2,m);oc(d+96|0,d);i[114610]=0;C(370,f+484423|0,d+96|0)|0;e=i[114610];i[114610]=0;if((e|0)==1){break f}eb(d+96|0);e=f+484404|0;i[e>>2]=j[d+74|0]|j[d+75|0]<<8;l:{if(!Ts(a)){break l}p=i[e>>2];e=0;while(1){if((p|0)==k[(e<<1)+13120>>1]){g[f+484417|0]=e<<4;break l}e=e+1|0;if((e|0)!=16){continue}break}}h[f+484412>>1]=64;i[l>>2]=j[d+61|0]|j[d+62|0]<<8|(j[d+63|0]<<16|j[d+64|0]<<24);if(j[d+73|0]&2){e=f+484414|0;h[e>>1]=k[e>>1]|1;i[l>>2]=i[l>>2]>>>1}i[f+484384>>2]=j[d+65|0]|j[d+66|0]<<8|(j[d+67|0]<<16|j[d+68|0]<<24);i[f+484388>>2]=(j[d+69|0]|j[d+70|0]<<8|(j[d+71|0]<<16|j[d+72|0]<<24))+ -1;if(g[d+73|0]&1){e=f+484414|0;h[e>>1]=k[e>>1]|2}m:{if(j[d+73|0]&4){g[d+96|0]=j[d+76|0];g[d|0]=64;y=f+484410|0,z=j[Xb(d+96|0,d)|0]<<2,h[y>>1]=z;break m}e=f+484414|0;h[e>>1]=k[e>>1]|32768}n:{if(!(j[d+73|0]&8)){h[f+484408>>1]=128;break n}e=f+484414|0;h[e>>1]=k[e>>1]|32;l=f+484408|0;if(j[d+77|0]<=15){f=j[d+77|0];i[d>>2]=256;i[d+96>>2]=f<<4|8;q=i[Nd(d+96|0,d)>>2]}else{q=128}h[l>>1]=q;h[e>>1]=k[e>>1]&65279|(j[d+77|0]==16)<<8}n=n+1|0;e=n&65535;if(e>>>0<=k[a+480190>>1]){continue}}break}o:{if(!(c&2)){break o}if(!vc(b,j[d+244|0]|j[d+245|0]<<8|(j[d+246|0]<<16|j[d+247|0]<<24))|!k[a+480190>>1]){break o}e=1;while(1){f=o(e&65535,104)+a|0;Xf(Ic(d+16|0,h[f+484414>>1]&1?16:8,1,0,1),f+484380|0,b);e=e+1|0;if((e&65535)>>>0<=k[a+480190>>1]){continue}break}}s=a+484344|0;Gf(s,j[d+239|0]+1|0);p=cna(ro(a));vc(b,j[d+235|0]|j[d+236|0]<<8|(j[d+237|0]<<16|j[d+238|0]<<24));v=c&1;n=0;t=1;while(1){c=_f(b);if(c>>>0>=3){ad(d+16|0,b,c+ -2|0);p:{if(!v){break p}i[114610]=0;c=F(337,d+16|0)|0;e=i[114610];i[114610]=0;if((e|0)==1){break g}if(!c){break p}i[114610]=0;c=I(402,s|0,n&65535,64)|0;e=i[114610];i[114610]=0;if((e|0)==1){break g}r=0;if(!c){break p}while(1){c=Fb(s,n);i[114610]=0;w=C(497,c|0,r|0)|0;c=i[114610];i[114610]=0;if((c|0)==1){break g}q:while(1){i[114610]=0;c=F(387,d+16|0)|0;e=i[114610];i[114610]=0;if((e|0)==1){break g}r:{if(!c){break r}e=c&31;if(k[a+480188>>1]<=e>>>0){break r}f=o(e,6)+w|0;if(c&32){i[114610]=0;D(472,d+96|0,d+16|0);e=i[114610];i[114610]=0;if((e|0)==1){break g}l=Nc(d+96|0);e=d+96|0;m=j[e|0];if(m){q=e;e=(m&127)+ -1|0;g[q|0]=e;g[f|0]=(o((e&240)>>>4|0,12)+(e&15)|0)+13;i[114610]=0;e=F(614,f|0)|0;m=i[114610];i[114610]=0;if((m|0)==1){break g}t=e&t}g[f+1|0]=j[l|0]}if(!(c&64)){continue}g[f+2|0]=0;g[f+3|0]=0;l=f+5|0;while(1){i[114610]=0;c=C(258,d+16|0,2)|0;e=i[114610];i[114610]=0;s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{if((e|0)!=1){if(!c){continue q}q=j[l|0];c=j[f+3|0];i[114610]=0;D(472,d+96|0,d+16|0);e=i[114610];i[114610]=0;if((e|0)==1){break g}m=j[Nc(d+96|0)|0];g[l|0]=m;u=d+96|0;e=j[(j[u|0]&31)+13152|0];g[f+3|0]=e;switch(e+ -2|0){case 2:case 3:case 6:case 7:case 8:case 9:case 10:case 12:case 14:case 15:case 16:break u;case 18:break y;case 13:break z;case 17:break A;case 11:break B;case 5:break C;case 4:break D;case 1:break E;case 0:break F;default:break x}}break g}if(m>>>0<224){break s}break t}if(m>>>0>=224){break t}break s}e=m&240;if(!e){break s}g[l|0]=e;break v}e=m&240;if(!e){break s}g[l|0]=e;break v}i[114610]=0;g[d|0]=64;e=C(391,l|0,d|0)|0;m=i[114610];i[114610]=0;if((m|0)!=1){g[l|0]=j[e|0];i[114610]=0;e=C(615,p|0,1)|0;m=i[114610];i[114610]=0;if((m|0)==1){break g}if(!e){break v}g[f+2|0]=1;g[f+4|0]=j[l|0];g[f+3|0]=c;g[l|0]=q;e=c;break u}break g}i[114610]=0;e=C(616,p|0,19)|0;m=i[114610];i[114610]=0;if((m|0)==1){break g}if(e){break v}i[114610]=0;L(617,f|0);e=i[114610];i[114610]=0;if((e|0)!=1){break v}break g}i[114610]=0;e=C(616,p|0,15)|0;m=i[114610];i[114610]=0;if((m|0)==1){break g}if(e){break v}i[114610]=0;e=C(616,p|0,19)|0;m=i[114610];i[114610]=0;if((m|0)==1){break g}if(!e){break v}g[f+3|0]=19;g[l|0]=j[l|0]&15|144;break s}G:{e=m>>>4|0;if((e|0)!=8){if(e){break G}H:{switch(m&15){case 4:g[f+3|0]=20;g[l|0]=158;break s;case 0:case 1:break w;case 5:break H;default:break G}}g[f+3|0]=20;g[l|0]=159;break s}i[114610]=0;e=C(616,p|0,20)|0;m=i[114610];i[114610]=0;if((m|0)==1){break g}if(e){break v}g[f+3|0]=19;break s}g[f+3|0]=0;break s}if((e|0)!=31){break u}g[f+3|0]=17;break s}g[l|0]=m+ -112}e=j[f+3|0]}if((e&255)!=20){break s}e=j[l|0];if(j[f+2|0]|(e&240)!=128){break s}g[f+2|0]=2;g[f+4|0]=(((e&15)<<6|8)>>>0)/15;g[f+3|0]=c;g[l|0]=q;break s}g[l|0]=223}if(j[u|0]&32){continue}break}continue}break}r=r+1|0;if((r|0)!=64){continue}break}}hb(d+16|0)}c=n>>>0<j[d+239|0];n=n+1|0;if(c){continue}break}c=a;if((t^-1|k[a+480188>>1]!=4)&1|i[a+480180>>2]!=1){e=i[a+480208>>2]&-8454145}else{e=i[a+480208>>2]|8454144}i[c+480208>>2]=e;f=1;if(!(j[d+253|0]|j[d+254|0]<<8|(j[d+255|0]<<16|j[d+256|0]<<24))){break i}if(!vc(b,j[d+249|0]|j[d+250|0]<<8|(j[d+251|0]<<16|j[d+252|0]<<24))){break i}Sx(a+1304424|0,b,j[d+253|0]|j[d+254|0]<<8|(j[d+255|0]<<16|j[d+256|0]<<24),4)}Xa=d+272|0;return f|0}f=B()|0;A()|0;eb(d+16|0);break a}f=B()|0;A()|0;hb(d+16|0);break a}f=B()|0;A()|0;eb(d+96|0);break a}f=B()|0;A()|0;eb(d+96|0);break a}f=B()|0;A()|0;ob(d+96|0);break b}f=B()|0;A()|0}eb(e)}E(f|0);x()}function pMa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,m=0,n=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,H=0,J=0;e=Xa-176|0;Xa=e;pc(b);a:{b:{c:{d:{e:{f:{g:{h:{if(!aT(b,e+128|0)){break h}if(!bT(e+128|0)){break h}if(!c){t=1;break h}md(a,2048);Vh(a);d=Bb(e+96|0,12026);i[114610]=0;D(219,e+112|0,d|0);p=i[114610];i[114610]=0;if((p|0)==1){break c}i[114610]=0;r=e+128|3;G(383,e+80|0,e+112|0,r|0);p=i[114610];i[114610]=0;if((p|0)==1){break d}mb(a+1304436|0,e+80|0);eb(e+80|0);ob(e+112|0);eb(d);d=Bb(e+80|0,12022);mb(a+1304448|0,d);eb(d);i[a+1304496>>2]=4;h[a+480188>>1]=j[e+168|0];h[a+480190>>1]=j[e+164|0];rg(e+112|0,2,e+128|4);oc(e+80|0,e+112|0);mb(a+1304400|0,e+80|0);eb(e+80|0);if(j[r|0]<=9){h[a+480188>>1]=4;tg(b,1);Ni(a,1)}d=j[r|0];i:{if(j[r|0]>=11){p=d>>>0>11?32:16;d=0;while(1){n=((d<<5)+a|0)+480284|0;m=rT(b)<<1;m=(m|0)>-128?m:-128;j:{if((m|0)<129){d=m+128|0;break j}i[((d<<5)+a|0)+480280>>2]=256;d=128}h[n>>1]=d;f=f+1|0;d=f&65535;if(p>>>0>d>>>0){continue}break}break i}if((d|0)!=10){break i}$S(b,e+80|0);d=0;while(1){h[((d<<5)+a|0)+480284>>1]=g[(e+80|0)+d|0]&1?64:192;d=d+1|0;if((d|0)!=16){continue}break}}k:{if(j[r|0]>=13){rt(e+80|0,b);f=Nc(e+80|0);p=a;n=e+80|0;d=j[n|0];if(d>>>0<=31){g[n|0]=125;d=125}i[p+480204>>2]=o(d,1e4);i[a+480196>>2]=j[f|0];break k}i[a+480196>>2]=6;i[a+480204>>2]=125e4}p=a+484360|0;Zf(Db(p),j[e+165|0]);u=mn(e+112|0);w=i[b+8>>2];q=j[r|0];l:{if(j[r|0]<14){break l}d=j[e+165|0];i[114610]=0;D(384,u|0,d|0);d=i[114610];i[114610]=0;if((d|0)!=1){break l}b=B()|0;A()|0;break e}m:{n:{o:{p:{q:{r:{s:{t:{u:{if(j[e+165|0]){d=0;while(1){H=$b(Db(p),d),J=d,h[H>>1]=J;if(j[r|0]>=14){i[114610]=0;f=F(357,b|0)|0;n=i[114610];i[114610]=0;if((n|0)==1){break u}H=$b(u,d),J=f,h[H>>1]=J}f=k[a+480188>>1];i[114610]=0;C(338,b|0,f<<1)|0;f=i[114610];i[114610]=0;if((f|0)==1){break u}d=d+1|0;if(d>>>0<j[e+165|0]){continue}break}}d=k[a+480190>>1];i[114610]=0;i[e+80>>2]=0;v=I(385,e- -64|0,d|0,e+80|0)|0;d=i[114610];i[114610]=0;f=1;if((d|0)!=1){i[e+60>>2]=0;v:{if(k[a+480190>>1]){p=1;while(1){i[114610]=0;n=o(f,104)+a|0;m=n+484380|0;D(386,m|0,0);d=i[114610];i[114610]=0;if((d|0)==1){break v}i[114610]=0;s=F(387,b|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break g}i[114610]=0;I(388,b|0,((f<<5)+a|0)+946300|0,32)|0;d=i[114610];i[114610]=0;if((d|0)==1){break g}i[114610]=0;I(389,b|0,n+484423|0,13)|0;d=i[114610];i[114610]=0;if((d|0)==1){break g}i[114610]=0;d=F(390,b|0)|0;t=i[114610];i[114610]=0;if((t|0)==1){break g}t=f+ -1|0;H=vb(v,t),J=d,i[H>>2]=J;w:{if(j[r|0]<=9){i[114610]=0;f=F(357,b|0)|0;d=i[114610];i[114610]=0;if((d|0)!=1){break w}break g}i[114610]=0;f=F(390,b|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break g}}i[m>>2]=f;i[114610]=0;d=F(357,b|0)|0;f=i[114610];i[114610]=0;if((f|0)==1){break g}i[n+484404>>2]=d;i[114610]=0;d=F(387,b|0)|0;f=i[114610];i[114610]=0;x:{y:{z:{if((f|0)!=1){i[114610]=0;g[e+80|0]=d;g[e+48|0]=64;d=C(391,e+80|0,e+48|0)|0;f=i[114610];i[114610]=0;if((f|0)==1){break z}h[n+484410>>1]=j[d|0]<<2;if(j[r|0]>9){break y}i[114610]=0;d=F(357,b|0)|0;f=i[114610];i[114610]=0;if((f|0)==1){break g}i[n+484384>>2]=d;i[114610]=0;d=F(357,b|0)|0;break x}b=B()|0;A()|0;break f}b=B()|0;A()|0;break f}i[114610]=0;d=F(390,b|0)|0;f=i[114610];i[114610]=0;if((f|0)==1){break g}i[n+484384>>2]=d;i[114610]=0;d=F(390,b|0)|0}f=i[114610];i[114610]=0;if((f|0)==1){break g}f=n+484388|0;i[f>>2]=d;if(s){s=n+484384|0;A:{if(!(d>>>0<=i[s>>2]+2>>>0|d>>>0>l[m>>2])){d=n+484414|0;h[d>>1]=k[d>>1]|2;break A}i[f>>2]=0;i[s>>2]=0}d=vb(v,t);i[114610]=0;d=C(392,e+60|0,d|0)|0;f=i[114610];i[114610]=0;if((f|0)==1){break g}i[e+60>>2]=i[d>>2]}p=p+1|0;f=p&65535;if(f>>>0<=k[a+480190>>1]){continue}break}}n=qt(e+48|0);d=j[e+166|0]|j[e+167|0]<<8;i[114610]=0;t=I(393,b|0,n|0,d|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break t}if(!t){break m}p=0;B:{if(!Uc(n)){d=Jb(n);p=Kb(n);i[114610]=0;d=C(394,d|0,p|0)|0;p=i[114610];i[114610]=0;if((p|0)==1){break B}i[e+80>>2]=d;d=i[e+80>>2];p=j[d|0]|j[d+1|0]<<8}i[114610]=0;f=p;s=C(395,e+32|0,f|0)|0;d=i[114610];i[114610]=0;if((d|0)!=1){C:{if(f){d=0;while(1){i[114610]=0;C(396,b|0,e+24|0)|0;m=i[114610];i[114610]=0;if((m|0)==1){break s}i[114610]=0;G(341,e+80|0,b|0,o(j[e+24|0]|j[e+25|0]<<8|j[e+26|0]<<16,3)|0);m=i[114610];i[114610]=0;if((m|0)==1){break C}Cd(_b(s,d),e+80|0);hb(e+80|0);d=d+1|0;if((f|0)!=(d|0)){continue}break}}if(c&2){y=Ic(e+24|0,8,1,0,1);i[114610]=0;m=C(397,e+80|0,v|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break q}d=Jb(m);f=Kb(m);i[114610]=0;D(398,d|0,f|0);d=i[114610];i[114610]=0;if((d|0)==1){break r}d=Jb(m);f=Kb(m);i[114610]=0;d=C(399,d|0,f|0)|0;f=i[114610];i[114610]=0;if((f|0)==1){break r}i[e+16>>2]=d;H=e,J=Jb(m),i[H+8>>2]=J;D:{if(!pb(e+8|0,e+16|0)){break D}while(1){i[114610]=0;d=C(258,b|0,1)|0;f=i[114610];i[114610]=0;E:{if((f|0)!=1){if(!d){break D}d=0;if(!k[a+480190>>1]){break E}while(1){i[114610]=0;f=C(258,b|0,1)|0;z=i[114610];i[114610]=0;if((z|0)==1){break r}if(!f){break E}f=d+1|0;if(i[i[e+8>>2]>>2]!=i[vb(v,d)>>2]){d=f;if(d>>>0>=k[a+480190>>1]){break E}continue}break}i[114610]=0;I(400,y|0,(o(f,104)+a|0)+484380|0,b|0)|0;d=i[114610];i[114610]=0;if((d|0)!=1){break E}break r}break r}WS(e+8|0);if(pb(e+8|0,e+16|0)){continue}break}}Sd(m)}if(!(c&1)){break n}c=j[e+165|0];i[114610]=0;m=a+484344|0;D(401,m|0,c|0);c=i[114610];i[114610]=0;F:{if((c|0)!=1){if(!j[e+165|0]){break n}w=w+((q>>>0>13)<<1)|0;c=0;while(1){G:{f=64;if(Wb(u)>>>0>c>>>0){f=k[$b(u,c)>>1]}i[114610]=0;d=I(402,m|0,c&65535,f&65535)|0;f=i[114610];i[114610]=0;if((f|0)==1){break F}H:{if(d){d=k[a+480188>>1];f=j[r|0];i[114610]=0;C(256,b|0,w+o(((f>>>0>13)<<1)+(d<<1)|0,c)|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break F}f=qt(e+80|0);d=k[a+480188>>1];i[114610]=0;d=I(393,b|0,f|0,d|0)|0;q=i[114610];i[114610]=0;if((q|0)==1){break H}I:{if(!d){break I}d=0;if(!k[a+480188>>1]){break I}while(1){J:{q=$b(f,d);if(!(j[q|0]|j[q+1|0]<<8)){break J}q=$b(f,d);if((j[q|0]|j[q+1|0]<<8)>>>0>(j[e+166|0]|j[e+167|0]<<8)>>>0){break J}q=$b(f,d);q=$b(n,(j[q|0]|j[q+1|0]<<8)+ -1|0);q=(j[q|0]|j[q+1|0]<<8)+ -1&65535;if(q>>>0>=p>>>0){break J}y=Fb(m,c);q=_b(s,q);i[114610]=0;G(403,y|0,d&65535,q|0);q=i[114610];i[114610]=0;if((q|0)!=1){break J}break G}d=d+1|0;if(d>>>0<k[a+480188>>1]){continue}break}}ik(f)}c=c+1|0;if(c>>>0>=j[e+165|0]){break n}continue}}break}b=B()|0;A()|0;ik(f);break p}b=B()|0;A()|0;break p}b=B()|0;A()|0;break p}b=B()|0;A()|0;break p}b=B()|0;A()|0;break o}b=B()|0;A()|0;break o}b=B()|0;A()|0;break f}b=B()|0;A()|0;break e}b=B()|0;A()|0;break e}b=B()|0;A()|0;break o}b=B()|0;A()|0;break p}b=B()|0;A()|0;Sd(m);break p}b=B()|0;A()|0}Qc(s)}ik(n);break f}Qc(s)}ik(n);Sd(v);df(u)}Xa=e+176|0;return t|0}b=B()|0;A()|0}Sd(v)}df(u);break a}b=B()|0;A()|0;ob(e+112|0);break b}b=B()|0;A()|0}eb(d)}E(b|0);x()}function KBa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,l=0,m=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,C=0,H=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0;d=Xa-336|0;Xa=d;a:{if(!vc(b,1080)){break a}if(!$m(b,d+332|0)){break a}md(a,1);v=KO(d+312|0);if(!JO(d+332|0,v)){break a}e=k[v+8>>1];if((e+ -1&65535)>>>0>126){break a}if(!c){f=1;break a}h[a+480188>>1]=e;q=j[v+12|0];S=j[v+11|0];e=j[v+10|0];O=1;if(!Hd(d+332|0,15603)){O=Hd(d+332|0,15608)}if(j[v+13|0]){tb(a+1074308|0,5,1)}L=a+480188|0;H=S?k[L>>1]==8:0;J=Hd(d+332|0,15613);s=1;if(!Hd(d+332|0,15618)){s=Hd(d+332|0,15623)}vc(b,0);Mz(b,a+1304400|0,20);h[a+480190>>1]=31;u=(e|0)!=0;z=d+201|0;t=d+204|0;l=d+198|0;y=d+200|0;f=1;e=J;while(1){C=o(f,104)+a|0;w=C+484380|0;K=wy(b,d+176|0,w,((f<<5)+a|0)+946300|0,k[a+480188>>1]==4);w=i[w>>2];b:{if(s){g[C+484417|0]=0-(j[y|0]<<3);break b}u=w>>>0<65536&u}P=j[l|0]|j[l+1|0]<<8?!(j[t|0]|j[t+1|0]<<8)|P:P;C=e&1;e=0;c:{if(!C){break c}r=p;p=j[l|0]|j[l+1|0]<<8;p=r+((p<<24|p<<8&16711680)>>>15|0)|0;if(j[y|0]){break c}if(!(j[l|0]|j[l+1|0]<<8)){e=1;break c}e=j[z|0]==64}Q=K+Q|0;m=m+w|0;f=f+1|0;if((f|0)!=32){continue}break}d:{e:{f:{g:{h:{i:{j:{k:{T=i[v+4>>2];if(Q>>>0<=T>>>0){vy(b,d+176|0);Ib(b,4);y=d+176|1;s=j[y|0];f=128;l=a+484360|0;fn(Db(l),d+176|2,128,65535,65535);s=!s&e;t=s?p:0;e=j[d+176|0];l:{if(e>>>0>128){break l}f=e;if(e){break l}e=128;while(1){p=e+ -1|0;if(!k[$b(Db(l),p)>>1]){f=1;e=p;if(e>>>0>1){continue}break l}break}f=e}U=(q|0)!=0;e=HO(b,Db(l),f&65535,m,L,t);if(!(!s|k[a+480188>>1]!=8)){i[v>>2]=15628;U=1}m:{if(!H){break m}m=Db(l);da=d,ea=Jb(m),i[da+160>>2]=ea;da=d,ea=Kb(m),i[da+144>>2]=ea;if(!pb(d+160|0,d+144|0)){break m}while(1){m=i[d+160>>2];h[m>>1]=k[m>>1]>>>1;he(d+160|0);if(pb(d+160|0,d+144|0)){continue}break}}Fe(Db(l),j[y|0]);V=f+ -1&65535;if(!(j[y|0]!=120|k[L>>1]!=4?V>>>0>=j[y|0]:0)){Fe(Db(l),0)}i[a+480260>>2]=56;i[a+480264>>2]=13696;i[a+480204>>2]=125e4;i[a+480196>>2]=6;f=0;m=Eb(256/k[a+480188>>1]|0,32,128);i[a+480208>>2]=0;i[a+480228>>2]=m;Ni(a,0);g[d+175|0]=0;w=1;W=1;if(!(u&1)){n:{if(!e){s=0;p=0;m=J;break n}z=d+160|5;m=J;u=0;p=0;s=0;while(1){t=0;f=0;while(1){l=aj(d+160|0);Bs(b,l);l=JQ(l);q=j[d+163|0];o:{if((q+ -7&255)>>>0>=3){m=l?m:0;p:{q:{switch(q+ -13|0){case 1:q=j[d+165|0];m=q>>>0>1?0:m;if((q&240)!=128){break o}g[d+144|0]=q<<4;da=d,ea=j[Ug(d+175|0,d+144|0)|0],g[da+175|0]=ea;break o;case 2:if(j[d+165|0]>31){break p}break o;case 0:break q;default:break o}}f=f+1|0;if((f&65535)>>>0<2){break o}}m=0;break o}m=0;if((q|0)!=8){break o}da=d,ea=j[Ug(d+175|0,z)|0],g[da+175|0]=ea;q=g[d+165|0];if((q|0)>-1){s=1;break o}p=(q|0)!=-92&(q&255)>>>0>143|p}w=l&w;t=t+1|0;if((t|0)!=256){continue}break}u=u+1|0;if((u&65535)>>>0<e>>>0){continue}break}}W=m&1;f=(p^1)&s}vc(b,1084);s=4;s=H?s:k[L>>1];z=a+484344|0;M=e+H&65535;Gf(z,M);r:{s:{t:{u:{v:{if(!M){C=0;K=0;break v}$=a+1074308|0;aa=f^1;ba=c&1;u=0;K=0;C=0;while(1){f=!ba;w:{if(H){e=(u&65534)>>>1|0;m=u&1;if(!m){if(!Sf(z,e,64)){break v}}p=Qe(Fb(z,e),0,m<<2);break w}if(!Sf(z,u&65535,64)){break v}p=Qe(Fb(z,u),0,0)}if(f|!p){break v}e=k[a+480188>>1];g[d+144|0]=0;q=et(d+160|0,e,d+144|0);e=k[a+480188>>1];i[114610]=0;g[d+64|0]=0;N=I(886,d+144|0,e|0,d- -64|0)|0;e=i[114610];i[114610]=0;if((e|0)==1){break u}R=0;while(1){f=0;X=0;t=0;m=0;if(s){while(1){i[114610]=0;l=o(t,6)+p|0;D(887,b|0,l|0);e=i[114610];i[114610]=0;x:{y:{z:{if((e|0)==1){break z}e=j[l+3|0];A:{B:{C:{if(!e){if(j[l+5|0]){break C}break B}if(!S){break C}D:{switch(e+ -14|0){case 0:g[l+3|0]=0;g[l+5|0]=0;break C;case 1:break D;default:break C}}if(j[l+5|0]<32){break C}g[l+5|0]=31}Xi(l);e=1;E:{F:{G:{r=j[l+3|0];switch(r+ -14|0){case 2:break A;case 0:break F;case 3:break G;default:break E}}C=j[l+5|0]<100|C;X=1;break B}if(!W){break B}g[l+5|0]=0;break B}if(!(((r|0)!=9|aa)&1)){e=j[l+5|0];if((e|0)==164){g[l+3|0]=20;g[l+5|0]=145;break B}i[114610]=0;e=F(888,e<<1)|0;r=i[114610];i[114610]=0;if((r|0)==1){break z}g[l+5|0]=e;break B}if((r|0)!=19){break B}e=j[l+5|0];if(e>>>0>15){break B}r=e&1;e=r^1;ca=!r;r=Y&1;Y=(r|0)==(e|0)?Y:ca;Z=((e|0)!=(r|0))+Z|0}e=f}if(j[l|0]){break y}if(!j[l+1|0]|H){break x}if(!j[dc(q,t)|0]){break x}if(j[dc(q,t)|0]==j[l+1|0]){break x}r=dc(N,t);f=j[r|0]+1|0;g[r|0]=f;if((f&255)>>>0<4){break x}i[114610]=0;I(478,$|0,85,1)|0;f=i[114610];i[114610]=0;if((f|0)!=1){break x}}f=B()|0;A()|0;Md(N);break t}da=dc(N,t),ea=0,g[da|0]=ea}f=j[l+1|0];if(f){da=dc(q,t),ea=f,g[da|0]=ea}f=e;m=m+1|0;t=m&65535;if(s>>>0>t>>>0){continue}break}}K=f&X|K;p=o(k[L>>1],6)+p|0;R=R+1|0;if((R|0)!=64){continue}break}Md(N);Md(q);u=u+1|0;if((M|0)!=(u|0)){continue}break}}H:{f=w^1;if((f|P)&1){break H}I:{if(Hd(d+332|0,15613)){break I}if(Hd(d+332|0,15640)){break I}if(!Hd(d+332|0,15645)){break H}}i[a+480208>>2]=i[a+480208>>2]|2162688;e=a+1074308|0;tb(e,85,1);tb(e,91,1);tb(e,92,1);J:{if(j[d+175|0]>47){break J}tb(e,84,1);if(j[y|0]==127){break J}tb(e,83,1)}if(!w){break r}break s}if(w){break s}if(J^1|j[y|0]!=127|j[y|0]+1>>>0<V>>>0){break r}i[v>>2]=15650;break r}f=B()|0;A()|0}Md(q);break d}if(!(U^1)|(Z|0)>6){break r}i[a+480208>>2]=i[a+480208>>2]|8388608}if(O){tb(a+1074308|0,84,1)}if(c&2){vc(b,(o(s,M)<<8)+1084|0);m=f|J^1;f=1;while(1){p=o(f,104)+a|0;c=p+484380|0;if(i[c>>2]){r=d+160|0;if(O){e=2}else{e=GO(b,15664)?11:0}e=Ic(r,8,1,0,e);H=i[b+8>>2]+xQ(e,i[c>>2])|0;if(!m){da=c,ea=i[Jc(c,p+484388|0)>>2],i[da>>2]=ea}Xf(e,c,b);vc(b,H)}f=f+1|0;if((f|0)!=32){continue}break}}K:{if((C&J^-1|K)&1){break K}b=FO(d+120|0,0);c=i[b+20>>2];i[d+40>>2]=i[b+16>>2];i[d+44>>2]=c;c=i[b+12>>2];i[d+32>>2]=i[b+8>>2];i[d+36>>2]=c;c=i[b+4>>2];i[d+24>>2]=i[b>>2];i[d+28>>2]=c;Tr(d+160|0,a,0,d+24|0);_=n[i[d+160>>2]>>3];hl(d+160|0);if(_<600){break K}c=a+1074308|0;tb(c,5,1);b=EO(d+96|0,_);e=i[b+20>>2];i[d+16>>2]=i[b+16>>2];i[d+20>>2]=e;e=i[b+12>>2];i[d+8>>2]=i[b+8>>2];i[d+12>>2]=e;e=i[b+4>>2];i[d>>2]=i[b>>2];i[d+4>>2]=e;Tr(d+160|0,a,0,d);b=j[i[d+160>>2]+26|0];hl(d+160|0);if(b){ng(c,5);break K}i[v>>2]=15670}IBa(d+332|0,Pb(d+332|0),d+332|0);b=Bb(d+80|0,15690);i[114610]=0;D(219,d+144|0,b|0);c=i[114610];i[114610]=0;if((c|0)==1){break k}c=Pb(d+332|0);i[114610]=0;c=I(889,d+48|0,d+332|0,c|0)|0;e=i[114610];i[114610]=0;if((e|0)==1){break j}i[114610]=0;G(13,d- -64|0,1,c|0);e=i[114610];i[114610]=0;if((e|0)==1){break i}i[114610]=0;G(247,d+160|0,d+144|0,d- -64|0);e=i[114610];i[114610]=0;if((e|0)==1){break h}mb(a+1304436|0,d+160|0);eb(d+160|0);eb(d- -64|0);eb(c);ob(d+144|0);eb(b);b=Bb(d+160|0,15710);mb(a+1304448|0,b);eb(b);b=i[v>>2];if(b){tc(a+1304460|0,b)}i[a+1304496>>2]=2}f=Q>>>0<=T>>>0;break a}f=B()|0;A()|0;break e}f=B()|0;A()|0;break f}f=B()|0;A()|0;break g}f=B()|0;A()|0;eb(d- -64|0)}eb(c)}ob(d+144|0)}eb(b)}E(f|0);x()}Xa=d+336|0;return f|0}function iza(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,l=0,m=0,n=0,p=0,q=0,r=0,s=0,t=0;d=Xa-272|0;Xa=d;pc(b);e=d+120|0;l=Fya(b,e);if(!l){sN(e)}a:{b:{c:{d:{e:{if(!l){break e}if(!CN(d+120|0)){break e}if(!c){n=1;break e}md(a,4194304);e=Bb(d+40|0,16854);mb(a+1304436|0,e);eb(e);e=Bb(d+40|0,16850);mb(a+1304448|0,e);eb(e);i[a+1304496>>2]=4;s=a,t=hd(j[d+198|0]|j[d+199|0]<<8,j[d+200|0]|j[d+201|0]<<8,127),h[s+480188>>1]=t;e=j[d+189|0];i[a+480228>>2]=(e|0)==255?48:e;i[a+480196>>2]=j[d+187|0];i[a+480204>>2]=o(j[d+188|0],1e4);Ge(d+104|0,d+120|4,59,3);oc(d+40|0,d+104|0);mb(a+1304400|0,d+40|0);eb(d+40|0);f:{if((j[d+202|0]|j[d+203|0]<<8|(j[d+204|0]<<16|j[d+205|0]<<24))>>>0<5){break f}if(!vc(b,(j[d+202|0]|j[d+203|0]<<8|(j[d+204|0]<<16|j[d+205|0]<<24))+ -4|0)){break f}if(!sh(b,16888)){break f}hp(Db(a+484360|0),b,j[d+192|0]|j[d+193|0]<<8,65535,65535)}g:{if((j[d+206|0]|j[d+207|0]<<8|(j[d+208|0]<<16|j[d+209|0]<<24))>>>0<5){break g}if(!vc(b,(j[d+206|0]|j[d+207|0]<<8|(j[d+208|0]<<16|j[d+209|0]<<24))+ -4|0)){break g}if(!sh(b,16893)){break g}while(1){e=(n<<5)+a|0;sg(e+480280|0);s=e+480284|0,t=((((id(b)^-1)&15)<<8|8)>>>0)/15|0,h[s>>1]=t;n=n+1|0;if((n|0)!=32){continue}break}}h:{if((j[d+214|0]|j[d+215|0]<<8|(j[d+216|0]<<16|j[d+217|0]<<24))>>>0<5){break h}if(!vc(b,(j[d+214|0]|j[d+215|0]<<8|(j[d+216|0]<<16|j[d+217|0]<<24))+ -4|0)){break h}if(!sh(b,16898)){break h}ad(d+104|0,b,(j[d+196|0]|j[d+197|0]<<8)<<6);i:{if(!(j[d+196|0]|j[d+197|0]<<8)){break i}n=c&2;l=a+480190|0;q=d+53|0;while(1){i[114610]=0;e=C(981,d+104|0,d+40|0)|0;p=i[114610];i[114610]=0;if((p|0)==1){break d}if(!e){break i}e=j[d+85|0]|j[d+86|0]<<8;h[d+38>>1]=e;j:{if((e+ -1&65535)>>>0>3998){break j}if(ie((o(e,104)+a|0)+484380|0)){break j}i[114610]=0;e=C(452,l|0,d+38|0)|0;p=i[114610];i[114610]=0;if((p|0)==1){break c}h[a+480190>>1]=k[e>>1];i[114610]=0;D(982,d+40|0,(o(k[d+38>>1],104)+a|0)+484380|0);e=i[114610];i[114610]=0;if((e|0)==1){break c}i[114610]=0;G(983,d+8|0,1,q|0);e=i[114610];i[114610]=0;k:{l:{if((e|0)==1){break l}i[114610]=0;D(415,d+24|0,d+8|0);e=i[114610];i[114610]=0;if((e|0)==1){break l}i[114610]=0;C(369,((k[d+38>>1]<<5)+a|0)+946300|0,d+24|0)|0;e=i[114610];i[114610]=0;if((e|0)==1){break k}eb(d+24|0);if(!n){break j}e=j[d+77|0]|j[d+78|0]<<8|(j[d+79|0]<<16|j[d+80|0]<<24);i[114610]=0;C(256,b|0,e|0)|0;e=i[114610];i[114610]=0;if((e|0)==1){break c}i[114610]=0;D(984,d+24|0,d+40|0);e=i[114610];i[114610]=0;if((e|0)!=1){i[114610]=0;I(400,d+24|0,(o(k[d+38>>1],104)+a|0)+484380|0,b|0)|0;e=i[114610];i[114610]=0;if((e|0)!=1){break j}}b=B()|0;A()|0;break b}b=B()|0;A()|0;break b}b=B()|0;A()|0;eb(d+24|0);break b}m=m+1|0;if((m&65535)>>>0<(j[d+196|0]|j[d+197|0]<<8)>>>0){continue}break}}hb(d+104|0)}n=1;if(!(c&1)){break e}m:{if((j[d+210|0]|j[d+211|0]<<8|(j[d+212|0]<<16|j[d+213|0]<<24))>>>0<5){break m}if(!vc(b,(j[d+210|0]|j[d+211|0]<<8|(j[d+212|0]<<16|j[d+213|0]<<24))+ -4|0)){break m}if(!sh(b,16903)){break m}p=a+484344|0;Gf(p,j[d+194|0]|j[d+195|0]<<8);if(!(j[d+194|0]|j[d+195|0]<<8)){break m}q=d+24|2;l=0;while(1){if(!lp(b,d+24|0)){break m}if((j[d+24|0]|j[d+25|0]<<8)>>>0>3){ad(d+40|0,b,((j[d+24|0]|j[d+25|0]<<8)+15&131056)+ -4|0);c=j[q|0];i[114610]=0;c=I(402,p|0,l&65535,c|0)|0;e=i[114610];i[114610]=0;n:{if((e|0)!=1){o:{m=0;if(!c){break n}while(1){i[114610]=0;c=C(258,d+40|0,1)|0;e=i[114610];i[114610]=0;p:{q:{r:{if((e|0)!=1){if(!c|m>>>0>=j[q|0]){break q}i[114610]=0;e=F(387,d+40|0)|0;c=i[114610];i[114610]=0;if((c|0)==1){break o}if(e){break r}m=m+1|0;continue}break o}c=Fb(p,l);h[d+104>>1]=e&31;f=k[a+480188>>1];i[114610]=0;h[d+8>>1]=f+ -1;f=C(477,d+104|0,d+8|0)|0;r=i[114610];i[114610]=0;if((r|0)==1){break o}f=k[f>>1];i[114610]=0;c=I(471,c|0,m|0,f|0)|0;f=i[114610];i[114610]=0;if((f|0)==1){break o}if(e&128){i[114610]=0;D(472,d+104|0,d+40|0);f=i[114610];i[114610]=0;if((f|0)==1){break o}f=Nc(d+104|0);g[c|0]=j[d+104|0]+36;g[c+1|0]=j[f|0]}if(!(e&64)){break p}g[c+2|0]=1;i[114610]=0;f=F(387,d+40|0)|0;r=i[114610];i[114610]=0;s:{if((r|0)!=1){i[114610]=0;g[d+104|0]=f;g[d+8|0]=64;f=C(391,d+104|0,d+8|0)|0;r=i[114610];i[114610]=0;if((r|0)==1){break s}g[c+4|0]=j[f|0];break p}break o}break o}if(j[q|0]==64){break n}c=Fb(p,l);i[114610]=0;e=I(498,d+104|0,14,0)|0;m=i[114610];i[114610]=0;if((m|0)!=1){e=mi(Ee(e,j[q|0]+ -1|0));i[114610]=0;C(499,c|0,e|0)|0;c=i[114610];i[114610]=0;if((c|0)!=1){break n}}break o}if(!(e&32)){continue}i[114610]=0;D(472,d+104|0,d+40|0);e=i[114610];i[114610]=0;t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{I:{J:{K:{L:{M:{N:{O:{P:{Q:{R:{S:{T:{U:{V:{W:{X:{Y:{if((e|0)!=1){e=j[Nc(d+104|0)|0];g[c+5|0]=e;switch(j[d+104|0]+ -1|0){case 71:break u;case 70:break v;case 69:break w;case 60:break x;case 59:break y;case 52:break z;case 51:break A;case 50:break B;case 49:break C;case 42:break D;case 41:break E;case 40:break F;case 39:break G;case 30:break H;case 29:break I;case 22:break J;case 21:break K;case 20:break L;case 19:break M;case 16:break N;case 15:break O;case 14:break P;case 13:break Q;case 12:break R;case 11:break S;case 10:break T;case 9:break U;case 3:break V;case 2:break W;case 1:break X;case 0:break Y;default:break t}}break o}g[c+3|0]=11;g[c+5|0]=e<<4|15;continue}g[c+3|0]=11;g[c+5|0]=e<<4;continue}g[c+3|0]=11;g[c+5|0]=e|240;continue}g[c+3|0]=11;g[c+5|0]=e&15;continue}g[c+3|0]=2;g[c+5|0]=e|240;continue}g[c+3|0]=2;continue}g[c+3|0]=3;g[c+5|0]=e|240;continue}g[c+3|0]=3;continue}g[c+3|0]=4;continue}g[c+3|0]=20;g[c+5|0]=e|16;continue}g[c+3|0]=6;g[c+5|0]=e<<4;continue}g[c+3|0]=6;g[c+5|0]=e&15;continue}g[c+3|0]=5;continue}g[c+3|0]=20;g[c+5|0]=e|48;continue}g[c+3|0]=7;g[c+5|0]=e<<4;continue}g[c+3|0]=7;g[c+5|0]=e&15;continue}g[c+3|0]=8;continue}g[c+3|0]=20;g[c+5|0]=e|64;continue}g[c+3|0]=10;i[114610]=0;e=F(387,d+40|0)|0;f=i[114610];i[114610]=0;if((f|0)!=1){g[c+5|0]=e;i[114610]=0;C(338,d+40|0,1)|0;c=i[114610];i[114610]=0;if((c|0)!=1){continue}}break o}g[c+3|0]=15;g[c+5|0]=e&15;continue}g[c+3|0]=20;g[c+5|0]=e|192;continue}g[c+3|0]=20;g[c+5|0]=e|208;continue}g[c+3|0]=12;continue}g[c+3|0]=14;continue}g[c+3|0]=20;g[c+5|0]=e|176;continue}g[c+3|0]=20;g[c+5|0]=e|224;continue}g[c+3|0]=16;continue}g[c+3|0]=17;continue}g[c+3|0]=1;continue}g[c+3|0]=20;g[c+5|0]=e&15|32;continue}g[c+3|0]=20;g[c+5|0]=e&15|128;continue}g[c+3|0]=0;continue}}}b=B()|0;A()|0;hb(d+40|0);break a}hb(d+40|0)}l=l+1|0;if(l>>>0<(j[d+194|0]|j[d+195|0]<<8)>>>0){continue}break}}if(!(j[d+218|0]|j[d+219|0]<<8|(j[d+220|0]<<16|j[d+221|0]<<24))){break e}vc(b,j[d+218|0]|j[d+219|0]<<8|(j[d+220|0]<<16|j[d+221|0]<<24));Sx(a+1304424|0,b,_f(b),4)}Xa=d+272|0;return n|0}b=B()|0;A()|0;break b}b=B()|0;A()|0}hb(d+104|0)}E(b|0);x()}function U$(a,b,c,d,e,f,h,k,l,m,n){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;h=h|0;k=k|0;l=l|0;m=m|0;n=n|0;var o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,H=0;o=Xa-560|0;Xa=o;i[o+548>>2]=n;i[o+552>>2]=b;i[o+96>>2]=2482;s=wd(o+136|0,o+144|0,o+96|0);b=i[s>>2];i[o+132>>2]=b;i[o+128>>2]=b+400;u=Ab(o+96|0);r=Ke(o+80|0);p=Ke(o- -64|0);q=Ke(o+48|0);t=Ke(o+32|0);i[114610]=0;$(2494,c|0,d|0,o+120|0,o+116|0,o+112|0,u|0,r|0,p|0,q|0,o+28|0);b=i[114610];i[114610]=0;if((b|0)!=1){a:{i[m>>2]=i[l>>2];v=e&512;w=v>>>9|0;n=0;e=0;while(1){b=e;b:{c:{d:{e:{if((n|0)==4){break e}i[114610]=0;c=C(2454,a|0,o+552|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break a}if(!c){break e}c=0;f:{g:{h:{i:{j:{switch(g[(o+120|0)+n|0]){case 1:if((n|0)==3){break c}i[114610]=0;c=F(2456,a|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break a}i[114610]=0;c=I(2495,k|0,8192,c|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break a}if(c){i[114610]=0;G(2496,o+16|0,a|0,0);c=i[114610];i[114610]=0;if((c|0)!=1){c=i[o+16>>2];i[114610]=0;D(112,t|0,c|0);c=i[114610];i[114610]=0;if((c|0)!=1){break i}}break a}i[f>>2]=i[f>>2]|4;a=0;break d;case 3:break h;case 0:break j;case 4:break f;case 2:break g;default:break b}}if((n|0)==3){break c}}while(1){i[114610]=0;c=C(2454,a|0,o+552|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break a}if(!c){break c}i[114610]=0;c=F(2456,a|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break a}i[114610]=0;c=I(2495,k|0,8192,c|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break a}if(!c){break c}i[114610]=0;G(2496,o+16|0,a|0,0);c=i[114610];i[114610]=0;if((c|0)!=1){c=i[o+16>>2];i[114610]=0;D(112,t|0,c|0);c=i[114610];i[114610]=0;if((c|0)!=1){continue}}break}break a}if((lb(p)|0)==(0-lb(q)|0)){break c}k:{if(lb(p)){if(lb(q)){break k}}if(lb(p)){i[114610]=0;c=F(2456,a|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break a}if((c|0)==i[xb(p)>>2]){i[114610]=0;F(2458,a|0)|0;c=i[114610];i[114610]=0;if((c|0)==1){break a}e=lb(p)>>>0>1?p:b;break b}g[h|0]=1;break c}i[114610]=0;c=F(2456,a|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break a}if((c|0)!=i[xb(q)>>2]){break c}i[114610]=0;F(2458,a|0)|0;c=i[114610];i[114610]=0;if((c|0)==1){break a}g[h|0]=1;e=lb(q)>>>0>1?q:b;break b}i[114610]=0;c=F(2456,a|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break a}if((c|0)==i[xb(p)>>2]){i[114610]=0;F(2458,a|0)|0;c=i[114610];i[114610]=0;if((c|0)==1){break a}e=lb(p)>>>0>1?p:b;break b}i[114610]=0;c=F(2456,a|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break a}if((c|0)==i[xb(q)>>2]){i[114610]=0;F(2458,a|0)|0;c=i[114610];i[114610]=0;if((c|0)==1){break a}g[h|0]=1;e=lb(q)>>>0>1?q:b;break b}i[f>>2]=i[f>>2]|4;a=0;break d}if(!(b|n>>>0<2)){e=0;if(!((n|0)==2&j[o+123|0]!=0|w)){break b}}z=o,H=ld(r),i[z+8>>2]=H;c=Ad(o+16|0,o+8|0);l:{if(!n|j[(n+o|0)+119|0]>1){break l}m:{while(1){z=o,H=rj(r),i[z+8>>2]=H;if(!pb(c,o+8|0)){break m}d=i[i[c>>2]>>2];i[114610]=0;d=I(2495,k|0,8192,d|0)|0;e=i[114610];i[114610]=0;if((e|0)!=1){if(!d){break m}Gd(c);continue}break}break a}z=o,H=ld(r),i[z+8>>2]=H;c=Hs(c,o+8|0);if(c>>>0<=lb(t)>>>0){z=o,H=rj(t),i[z+8>>2]=H;c=tM(o+8|0,c);d=rj(t);e=ld(r);i[114610]=0;c=UC(c,d,e);d=i[114610];i[114610]=0;if((d|0)==1){break a}if(c){break l}}z=o,H=ld(r),i[z>>2]=H;Ad(o+8|0,o);i[o+16>>2]=i[o+8>>2]}i[o+8>>2]=i[o+16>>2];n:{while(1){z=o,H=rj(r),i[z>>2]=H;if(!pb(o+8|0,o)){break n}i[114610]=0;c=C(2454,a|0,o+552|0)|0;d=i[114610];i[114610]=0;o:{if((d|0)==1){break o}if(!c){break n}i[114610]=0;c=F(2456,a|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break o}if((c|0)!=i[i[o+8>>2]>>2]){break n}i[114610]=0;F(2458,a|0)|0;c=i[114610];i[114610]=0;if((c|0)==1){break a}Gd(o+8|0);continue}break}break a}if(!v){break c}z=o,H=rj(r),i[z>>2]=H;if(!pb(o+8|0,o)){break c}i[f>>2]=i[f>>2]|4;a=0;break d}p:{while(1){q:{i[114610]=0;d=C(2454,a|0,o+552|0)|0;e=i[114610];i[114610]=0;if((e|0)==1){break q}if(!d){break p}i[114610]=0;e=F(2456,a|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break a}i[114610]=0;d=I(2495,k|0,2048,e|0)|0;y=i[114610];i[114610]=0;if((y|0)==1){break a}r:{if(d){d=i[m>>2];if((d|0)==i[o+548>>2]){i[114610]=0;G(2498,l|0,m|0,o+548|0);d=i[114610];i[114610]=0;if((d|0)==1){break a}d=i[m>>2]}i[m>>2]=d+4;i[d>>2]=e;c=c+1|0;break r}if(!c|!lb(u)|(e|0)!=i[o+112>>2]){break p}e=i[o+132>>2];if((e|0)==i[o+128>>2]){i[114610]=0;G(2489,s|0,o+132|0,o+128|0);d=i[114610];i[114610]=0;if((d|0)==1){break a}e=i[o+132>>2]}i[o+132>>2]=e+4;i[e>>2]=c;c=0}i[114610]=0;F(2458,a|0)|0;d=i[114610];i[114610]=0;if((d|0)!=1){continue}}break}break a}d=i[s>>2];s:{if(!c){break s}e=i[o+132>>2];if((d|0)==(e|0)){break s}if(i[o+128>>2]==(e|0)){i[114610]=0;G(2489,s|0,o+132|0,o+128|0);d=i[114610];i[114610]=0;if((d|0)==1){break a}e=i[o+132>>2]}i[o+132>>2]=e+4;i[e>>2]=c}t:{if(i[o+28>>2]<1){break t}i[114610]=0;c=C(2455,a|0,o+552|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break a}u:{if(!c){i[114610]=0;c=F(2456,a|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break a}if((c|0)==i[o+116>>2]){break u}}i[f>>2]=i[f>>2]|4;a=0;break d}i[114610]=0;F(2458,a|0)|0;c=i[114610];i[114610]=0;if((c|0)==1){break a}while(1){if(i[o+28>>2]<1){break t}i[114610]=0;c=C(2455,a|0,o+552|0)|0;d=i[114610];i[114610]=0;v:{if((d|0)==1){break v}w:{if(!c){i[114610]=0;c=F(2456,a|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break v}i[114610]=0;c=I(2495,k|0,2048,c|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break v}if(c){break w}}i[f>>2]=i[f>>2]|4;a=0;break d}if(i[m>>2]==i[o+548>>2]){i[114610]=0;G(2498,l|0,m|0,o+548|0);c=i[114610];i[114610]=0;if((c|0)==1){break v}}i[114610]=0;c=F(2456,a|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break v}d=i[m>>2];i[m>>2]=d+4;i[d>>2]=c;i[114610]=0;i[o+28>>2]=i[o+28>>2]+ -1;F(2458,a|0)|0;c=i[114610];i[114610]=0;if((c|0)!=1){continue}}break}break a}e=b;if(i[l>>2]!=i[m>>2]){break b}i[f>>2]=i[f>>2]|4;a=0;break d}x:{if(!b){break x}e=1;while(1){if(e>>>0>=lb(b)>>>0){break x}i[114610]=0;c=C(2455,a|0,o+552|0)|0;d=i[114610];i[114610]=0;y:{if((d|0)==1){break y}z:{if(!c){i[114610]=0;c=F(2456,a|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break y}if((c|0)==i[Ki(b,e)>>2]){break z}}i[f>>2]=i[f>>2]|4;a=0;break d}i[114610]=0;F(2458,a|0)|0;c=i[114610];i[114610]=0;e=e+1|0;if((c|0)!=1){continue}}break}break a}A:{if(i[s>>2]==i[o+132>>2]){break A}i[o+16>>2]=0;a=i[s>>2];i[114610]=0;je(u,a,i[o+132>>2],o+16|0);a=i[114610];i[114610]=0;if((a|0)!=1){if(!i[o+16>>2]){break A}i[f>>2]=i[f>>2]|4;a=0;break d}break a}a=1}nc(t);nc(q);nc(p);nc(r);eb(u);lc(s);Xa=o+560|0;return a|0}e=b}n=n+1|0;continue}}}a=B()|0;A()|0;nc(t);nc(q);nc(p);nc(r);eb(u);lc(s);E(a|0);x()}function Rr(a,b,c,d,e,f,m){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;m=m|0;var n=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;n=Xa-32|0;Xa=n;i[n+28>>2]=c;a:{if((c|0)<1){break a}q=i[b+104>>2];p=i[b+656>>2];if(!(!p|i[a+480180>>2]!=16777216)){u=i[p+44>>2]!=0}b:{if(!(!p|128<(c|0))){r=k[Mc(p+236|0,c+ -1|0)>>1];c:{if((r+ -1&65535)>>>0<=3998){q=(o(r,104)+a|0)+484380|0;break c}kb(n+16|0,a+1074308|0,43);if(!ib(n+16|0)){break c}if(!Pi(b)){break a}}r=j[Nb(p+108|0,i[n+28>>2]+ -1|0)|0];i[n+28>>2]=r;break b}r=c}if((r|0)>=121){d:{if(!(i[a+480180>>2]&16777248?(r|0)!=255:0)){Bm(a,b);if(d){break d}kb(n+16|0,a+1074308|0,100);if(!ib(n+16|0)|!(j[a+480208|0]&4)|!j[b+811|0]){break d}i[b+88>>2]=i[b+88>>2]&-6145;break d}if(!k[a+480192>>1]){break d}i[b+88>>2]=i[b+88>>2]|4096}e:{if(i[n+28>>2]!=254){break e}f:{c=i[b+88>>2];if(!(c&512)){break f}c=i[b+88>>2];if(i[a+480180>>2]!=2){break f}i[b+88>>2]=c|2048;break e}i[b+88>>2]=c|2101248;g:{if(i[a+480180>>2]&16777248){if(!k[a+480192>>1]){break g}kb(n+16|0,a+1074308|0,50);if(ib(n+16|0)){break g}}i[b+688>>2]=0}kb(n+16|0,a+1074308|0,50);if(ib(n+16|0)){i[b+8>>2]=0;i[b+12>>2]=0}i[b+696>>2]=0}kb(n+16|0,a+1074308|0,20);if(!ib(n+16|0)){break a}g[b+819|0]=0;g[b+824|0]=0;break a}h:{i:{j:{if(u){if(d){s=j[b+819|0];if(s){break j}}i[b+708>>2]=0}if(d){break i}if(!(!q|!(i[a+480180>>2]&1048588))){i[b+772>>2]=g[q+36|0];i[b+768>>2]=g[q+37|0]}if(q){kb(n+16|0,a+1074308|0,24);r=0;t=1;if(!ib(n+16|0)){break h}i[b+704>>2]=i[q+24>>2];break h}r=0;break h}t=i[p+44>>2];h[n>>1]=s;h[n+14>>1]=r;i[n+16>>2]=0;r=(i[n+16>>2]+o(h[t+36>>1]+1|0,h[n+14>>1]-h[n>>1]|0)|0)-i[b+876>>2]|0;i[b+708>>2]=r;i[b+876>>2]=0-r}t=(q|0)!=0;r=1;if(nh(b)){break h}r=a+1074308|0;kb(n+16|0,r,54);if(ib(n+16|0)){i[b+700>>2]=0;break a}kb(n+16|0,r,39);r=(ib(n+16|0)^-1)&d}k:{if(Ts(a)){i[n+28>>2]=i[n+28>>2]+i[b+772>>2];Kd(n+28|0,12,131);break k}mO(n+28|0)}s=a+1074308|0;kb(n+16|0,s,34);d=b;l:{if(ib(n+16|0)){c=kp(c);break l}c=i[n+28>>2]}g[d+819|0]=c;g[b+872|0]=j[b+872|0]|8;if(!(i[a+480180>>2]&16777250?0:r)){g[b+825|0]=0}d=Vf(a,i[n+28>>2],i[b+768>>2],i[b+704>>2]);g[b+851|0]=0;kb(n+16|0,s,48);if(ib(n+16|0)){GK(a,b,p,q)}m:{if(e^1|r){break m}i[b+788>>2]=0;i[b+792>>2]=0;if(!p){break m}kb(n+16|0,s,29);if(ib(n+16|0)){g[b+820|0]=j[p+16|0]}if(!(j[p+60|0]&8)){Wh(b+724|0)}if(!(j[p+80|0]&8)){Wh(b+736|0)}if(!(j[p+100|0]&8)){Wh(b+748|0)}if(j[p+20|0]){c=Or(Am(a));v=j[p+20|0];kb(n+16|0,s,28);w=((o(c,v)<<16>>16)/64<<16)+65536>>16;c=b;n:{if(ib(n+16|0)){v=i[b+764>>2];break n}v=(i[b+688>>2]+1|0)/2|0}h[c+788>>1]=(o(v,w)|0)/199}o:{if(!j[p+19|0]){break o}x=b,y=(o(Or(Am(a)),j[p+19|0])<<16>>16)/32|0,h[x+790>>1]=y;kb(n+16|0,s,28);if(ib(n+16|0)|k[b+796>>1]){break o}h[b+796>>1]=k[b+692>>1]+1}c=j[p+23|0];if(c){v=Or(Am(a));w=j[b+857|0];g[b+818|0]=w+1;h[b+792>>1]=(o(w,(o(c,v+1|0)<<16>>16)/128<<16>>16)+1|0)/128}c=j[p+24|0];if(!c){break m}v=Or(Am(a));w=j[b+858|0];g[b+817|0]=w+1;h[b+794>>1]=(o(w,(o(c,v+1|0)<<16>>16)/128<<16>>16)+1|0)/128}if(!t){break a}t=0;p:{q:{if(!d){break q}r:{s:{t:{if(r){u:{if(!i[b+700>>2]){i[b+700>>2]=d;if(!u){break u}break t}if(u){break t}}i[b+708>>2]=d;break t}i[b+700>>2]=d;if(u){break s}kb(n+16|0,s,69);if(ib(n+16|0)){break s}kb(n,s,46);if(ib(n)|i[a+480180>>2]==1){break s}i[b+708>>2]=d;break s}if(i[b+76>>2]|i[a+480180>>2]&2){break r}}i[b+104>>2]=q;c=i[q>>2];i[b+84>>2]=c;i[b+76>>2]=c;i[b+80>>2]=0;i[b>>2]=0;i[b+4>>2]=0;v:{w:{if(!(i[a+480208>>2]&2097152)){kb(n+16|0,s,96);if(!ib(n+16|0)){break w}}if(j[b+811|0]){break w}i[n+16>>2]=i[b+76>>2]+ -1;x=b,y=i[rb(b+660|0,n+16|0)>>2],i[x+4>>2]=y;break v}i[b+660>>2]=0}c=k[q+34>>1];d=c&1023;u=d|i[b+88>>2]&-525056;i[b+88>>2]=u;x:{if(c&8){i[b+80>>2]=i[q+12>>2];c=i[q+16>>2];i[b+88>>2]=(d&16?u|4:u&-524295)|2;i[b+84>>2]=c;if(l[b+76>>2]<=c>>>0){break x}i[b+76>>2]=c;break x}if(!(d&2)){break x}i[b+80>>2]=i[q+4>>2];c=i[q+8>>2];i[b+84>>2]=c;if(l[b+76>>2]<=c>>>0){break x}i[b+76>>2]=c}kb(n+16|0,s,83);if(!(!ib(n+16|0)|i[b+80>>2])){c=i[q>>2];i[b+84>>2]=c;i[b+76>>2]=c}c=i[b+88>>2];if(c&128){i[b+88>>2]=c|128;i[b+4>>2]=i[b+76>>2]+ -1}y:{if(j[b+842|0]>3){break y}kb(n+16|0,s,21);if(!(ib(n+16|0)|!(i[a+480180>>2]&16777248)|i[a+480208>>2]&4)){g[b+839|0]=16;break y}if(i[a+480180>>2]==16){g[b+839|0]=32;break y}if(i[a+480180>>2]&67633152){break y}g[b+839|0]=0}kb(n+16|0,s,21);if(ib(n+16|0)|j[b+845|0]>3){break r}g[b+840|0]=0}d=i[b>>2];if(l[b+76>>2]<=l[b+4>>2]){c=d;d=i[b+80>>2];i[b>>2]=c;i[b+4>>2]=d}if(!r){break q}t=1;if(!(i[a+480180>>2]&17301536)|(i[b+696>>2]?0:j[b+89|0]&16)){break q}if(!(j[a+480208|0]&8)|!j[b+811|0]){break p}}if(!(i[b+696>>2]|(!(i[a+480180>>2]&17301536)|!(j[b+89|0]&16)))){_k(b);kb(n+16|0,s,21);if(!ib(n+16|0)){g[b+838|0]=0;i[b+780>>2]=0}i[b+696>>2]=65536;i[b+88>>2]=i[b+88>>2]&-4097}if(!(j[b+811|0]|(!t|!(j[a+480208|0]&8)))){t=1;break p}if(j[b+811|0]?0:i[a+480180>>2]&1048580){break p}i[b+696>>2]=65536;i[b+88>>2]=i[b+88>>2]&-4097}kb(n+16|0,s,40);z:{A:{if(ib(n+16|0)){if(t){if(!(!(j[a+480208|0]&8)|!j[b+811|0])){i[b+88>>2]=i[b+88>>2]&-4196353;q=1;break z}i[b+88>>2]=i[b+88>>2]&-4194305;q=1;break z}c=i[b+88>>2]&-4196353;i[b+88>>2]=c;break A}c=i[b+88>>2]&-4196353;i[b+88>>2]=c;q=1;if(t){break z}}h[b+862>>1]=65535;i[b+88>>2]=c&-6326273|2097152;kb(n+16|0,s,23);B:{if(ib(n+16|0)){break B}kb(n,s,22);if(ib(n)){break B}kb(n+16|0,s,52);if(ib(n+16|0)){break B}kb(n,s,71);if(ib(n)){break B}g[b+859|0]=0;h[b+798>>1]=0}if(e){g[b+838|0]=0;i[b+780>>2]=0}i[b+20>>2]=0;i[b+24>>2]=0;c=i[a+480208>>2]&8192;C:{if(p){D:{E:{if(!oA(p)){if(Ct(p)){break E}c=c>>>13^1;if(c){break D}c=(c|0)!=0;break C}x=b,y=pA(p),g[x+858|0]=y;if(!Ct(p)){break D}}x=b,y=qA(p),g[x+857|0]=y}c=1;d=j[p+25|0];if((d|0)==255){break C}g[b+865|0]=d;break C}i[b+788>>2]=0;i[b+792>>2]=0;c=!c}F:{if(j[b+857|0]>=127){kb(n+16|0,s,36);if(!ib(n+16|0)){break F}}q=0;if(!c){break z}if((Eo(a,b,1,256)|0)<0|!(j[b+89|0]&2)){break z}c=a+1304392|0;if(!$c(c)|(m|0)==65535){break z}Jo(i[c>>2],m,j[b+857|0]>>>1|0,1);break z}q=0}c=i[b+88>>2];if(f){c=c&-1025;i[b+88>>2]=c}G:{H:{if(j[a+24618|0]&16?c&1024:0){break H}a=i[b+104>>2];if(f?0:!(!a|!(j[a+35|0]&4))){break H}a=i[b+656>>2];if(!a|!(j[a+15|0]&2)){break G}}if(f){break G}i[b+700>>2]=0}if(q){break a}h[b+136>>1]=0;i[b+132>>2]=4194304;i[b+112>>2]=0;i[b+116>>2]=0}Xa=n+32|0}function fW(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,h=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,D=0,J=0,L=0,N=0,O=0;e=Xa-1424|0;Xa=e;pc(b);Yp(a);a:{if(!rB(b,e+1408|0)){break a}if(!tB(e+1408|0)){break a}if(!qB(b,e+1392|0)){break a}if(!sB(e+1392|0)){break a}b:{if(!c){break b}J=e+1400|0;c=J;if((j[c|0]|j[c+1|0]<<8|(j[c+2|0]<<16|j[c+3|0]<<24))>>>0>hj(b)>>>0){break a}c=J;u=e+1392|2;if((j[c|0]|j[c+1|0]<<8|(j[c+2|0]<<16|j[c+3|0]<<24))+((j[u|0]|j[u+1|0]<<8)<<2)>>>0>hj(b)>>>0){break a}ju(a);iu(e+40|0);hu(wg(a)+28|0,e+40|0);Xp(e+40|0);q=i[wg(a)+28>>2];c=e+1392|4;Kn(q,j[c|0]|j[c+1|0]<<8|(j[c+2|0]<<16|j[c+3|0]<<24));yb(e+1136|0,0,256);c:{d:{if(j[u|0]|j[u+1|0]<<8){o=e+1112|4;p=e+1128|0;D=e+1130|0;v=e+1126|0;l=e+1124|0;while(1){d=0;c=J;if(!vc(b,(j[c|0]|j[c+1|0]<<8|(j[c+2|0]<<16|j[c+3|0]<<24))+(L<<2)|0)){break a}if(!wb(b,4)){break a}f=Cf(b);if(!vc(b,f)){break a}if(!gu(b,e+1112|0)){break a}y=cW(e+1096|0,j[l|0]|j[l+1|0]<<8);c=0;e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{if(!(j[l|0]|j[l+1|0]<<8)){break v}w:{while(1){d=uk(y,c);i[114610]=0;d=C(254,b|0,d|0)|0;m=i[114610];i[114610]=0;if((m|0)==1){break w}if(d){c=c+1|0;if(c>>>0>=(j[l|0]|j[l+1|0]<<8)>>>0){break v}continue}break}break u}d=B()|0;A()|0;break c}if(j[l|0]|j[l+1|0]<<8){d=i[y>>2]}else{d=0}c=j[l|0]|j[l+1|0]<<8;i[114610]=0;m=F(255,b|0)|0;n=i[114610];i[114610]=0;if((n|0)==1){break t}h=c<<3;c=f+20|0;if(h+c>>>0<m>>>0){n=c+((j[l|0]|j[l+1|0]<<8)<<3)|0;x:{if(!(g[v|0]&1)){f=0;if(!(j[l|0]|j[l+1|0]<<8)){break e}while(1){if(!d){break x}if(!Fn(q,d)){break x}i[114610]=0;c=C(256,b|0,n|0)|0;m=i[114610];i[114610]=0;if((m|0)==1){break s}if(!c){break x}m=dc(q,j[d|0]|j[d+1|0]<<8|(j[d+2|0]<<16|j[d+3|0]<<24));c=d;r=j[c+4|0]|j[c+5|0]<<8|(j[c+6|0]<<16|j[c+7|0]<<24);i[114610]=0;m=I(257,b|0,m|0,r|0)|0;r=i[114610];i[114610]=0;if((r|0)==1){break s}if((m|0)!=(j[c+4|0]|j[c+5|0]<<8|(j[c+6|0]<<16|j[c+7|0]<<24))){break x}d=d+8|0;f=f+1|0;if(f>>>0<(j[l|0]|j[l+1|0]<<8)>>>0){continue}break}break e}y:{z:{A:{B:{if(j[v|0]&4){if(!d){break y}if(!Fn(q,d)){break y}r=dc(q,j[d|0]|j[d+1|0]<<8|(j[d+2|0]<<16|j[d+3|0]<<24));z=j[d+4|0]|j[d+5|0]<<8|(j[d+6|0]<<16|j[d+7|0]<<24);m=j[D|0]|j[D+1|0]<<8;c=j[p|0]|j[p+1|0]<<8;i[114610]=0;c=C(256,b|0,c+n|0)|0;f=i[114610];i[114610]=0;if((f|0)==1){break r}if(!c){break y}c=j[o|0]|j[o+1|0]<<8|(j[o+2|0]<<16|j[o+3|0]<<24);f=j[p|0]|j[p+1|0]<<8;i[114610]=0;c=C(258,b|0,c-f|0)|0;f=i[114610];i[114610]=0;if((f|0)==1){break r}if(!c){break y}c=j[o|0]|j[o+1|0]<<8|(j[o+2|0]<<16|j[o+3|0]<<24);f=j[p|0]|j[p+1|0]<<8;i[114610]=0;G(259,e+24|0,b|0,c-f|0);c=i[114610];i[114610]=0;if((c|0)==1){break d}s=Gl(e+40|0,e+24|0);hb(e+24|0);w=0;f=0;n=0;if(!(j[l|0]|j[l+1|0]<<8)){break h}while(1){C:{i[114610]=0;c=C(260,s|0,m+1|0)|0;h=i[114610];i[114610]=0;if((h|0)==1){break C}h=m&15;t=k[(h<<1)+11024>>1];D:{E:{if(c>>>0>=t>>>0){i[114610]=0;h=j[h+11104|0];N=C(260,s|0,h|0)|0;O=i[114610];i[114610]=0;if((O|0)==1){break j}c=N+(c-t<<h)|0;if((c|0)!=(m|0)){m=c&15;break D}i[114610]=0;c=C(260,s|0,4)|0;h=i[114610];i[114610]=0;if((h|0)==1){break j}if((c|0)==15){i[114610]=0;h=C(260,s|0,1)|0;c=i[114610];i[114610]=0;if((c|0)==1){break j}c=65535;if(!h){break E}hb(e+40|0);break e}c=c+65520|0}if(c>>>0>65535){break D}}c=c&1?0-(c+1>>>1|0)|0:c>>>1|0;h=f+r|0;t=h;F:{if(j[v|0]&2){w=c+w|0;c=w;break F}c=j[v+1|0]&2?c:c^32768}g[t|0]=c;g[h+1|0]=c>>>8;f=f+2|0}if(f>>>0>=z>>>0){n=n+1|0;if(n>>>0>=(j[l|0]|j[l+1|0]<<8)>>>0){break z}c=(n<<3)+d|0;if(!Fn(q,c)){break B}z=j[c+4|0]|j[c+5|0]<<8|(j[c+6|0]<<16|j[c+7|0]<<24);r=dc(q,j[c|0]|j[c+1|0]<<8|(j[c+2|0]<<16|j[c+3|0]<<24));f=0}if(n>>>0<(j[l|0]|j[l+1|0]<<8)>>>0){continue}break h}break}d=H(77024)|0;break i}if(!d){break y}if(!Fn(q,d)){break y}w=dc(q,j[d|0]|j[d+1|0]<<8|(j[d+2|0]<<16|j[d+3|0]<<24));z=j[d+4|0]|j[d+5|0]<<8|(j[d+6|0]<<16|j[d+7|0]<<24);m=j[D|0]|j[D+1|0]<<8;if((j[p|0]|j[p+1|0]<<8)>>>0>256){break y}i[114610]=0;c=C(256,b|0,n|0)|0;f=i[114610];i[114610]=0;if((f|0)==1){break q}if(!c){break y}c=j[p|0]|j[p+1|0]<<8;i[114610]=0;c=I(261,b|0,e+1136|0,c|0)|0;f=i[114610];i[114610]=0;if((f|0)==1){break q}if(c>>>0<(j[p|0]|j[p+1|0]<<8)>>>0){break y}c=j[o|0]|j[o+1|0]<<8|(j[o+2|0]<<16|j[o+3|0]<<24);f=j[p|0]|j[p+1|0]<<8;i[114610]=0;c=C(258,b|0,c-f|0)|0;f=i[114610];i[114610]=0;if((f|0)==1){break q}if(!c){break y}c=j[o|0]|j[o+1|0]<<8|(j[o+2|0]<<16|j[o+3|0]<<24);f=j[p|0]|j[p+1|0]<<8;i[114610]=0;G(259,e+24|0,b|0,c-f|0);c=i[114610];i[114610]=0;if((c|0)==1){break k}s=Gl(e+40|0,e+24|0);hb(e+24|0);r=0;f=0;n=0;if(!(j[l|0]|j[l+1|0]<<8)){break n}G:{while(1){H:{i[114610]=0;c=C(260,s|0,m+1|0)|0;h=i[114610];i[114610]=0;if((h|0)==1){break H}h=m&7;t=j[h+11056|0];I:{J:{if(c>>>0>=t>>>0){i[114610]=0;h=j[h+11064|0];N=C(260,s|0,h|0)|0;O=i[114610];i[114610]=0;if((O|0)==1){break p}c=N+(c-t<<h)|0;if((c|0)!=(m|0)){m=c&7;break I}i[114610]=0;c=C(260,s|0,3)|0;h=i[114610];i[114610]=0;if((h|0)==1){break p}if((c|0)==7){i[114610]=0;h=C(260,s|0,1)|0;c=i[114610];i[114610]=0;if((c|0)==1){break p}c=255;if(!h){break J}hb(e+40|0);break e}c=c+248|0}if(c>>>0>255){break I}}c=j[(e+1136|0)+c|0];h=c+r|0;t=c;c=(j[v|0]|j[v+1|0]<<8)&2;g[f+w|0]=c?h:t;r=c?h:r;f=f+1|0}if(f>>>0>=z>>>0){n=n+1|0;if(n>>>0>=(j[l|0]|j[l+1|0]<<8)>>>0){break G}c=(n<<3)+d|0;if(!Fn(q,c)){break A}z=j[c+4|0]|j[c+5|0]<<8|(j[c+6|0]<<16|j[c+7|0]<<24);w=dc(q,j[c|0]|j[c+1|0]<<8|(j[c+2|0]<<16|j[c+3|0]<<24));f=0}if(n>>>0<(j[l|0]|j[l+1|0]<<8)>>>0){continue}break n}break}d=H(77024)|0;break o}hb(e+40|0);break e}hb(e+40|0);break u}hb(e+40|0);break u}hb(e+40|0);break e}}}}fu(y);d=0;break a}d=B()|0;A()|0;break c}d=B()|0;A()|0;break c}d=B()|0;A()|0;break c}d=B()|0;A()|0;break c}d=H(77024)|0}if((A()|0)!=(U(77024)|0)){break l}M(d|0)|0;i[114610]=0;K(20);c=i[114610];i[114610]=0;if((c|0)==1){break m}}hb(e+40|0);break e}d=B()|0;A()|0}hb(e+40|0);break c}d=B()|0;A()|0;break c}d=H(77024)|0}if((A()|0)!=(U(77024)|0)){break f}M(d|0)|0;i[114610]=0;K(20);c=i[114610];i[114610]=0;if((c|0)==1){break g}}hb(e+40|0);break e}d=B()|0;A()|0}hb(e+40|0);break c}fu(y);L=L+1|0;if(L>>>0<(j[u|0]|j[u+1|0]<<8)>>>0){continue}break}}ui(e+8|0,q);eu(e+16|0,e+8|0);b=Dn(e+40|0,e+16|0);Cd(wg(a)+12|0,b);hb(b);break b}d=B()|0;A()|0}fu(y);E(d|0);x()}d=1}Xa=e+1424|0;return d|0}function c0(a,b,c,d,e,f,h,k,l,m,n){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;h=h|0;k=k|0;l=l|0;m=m|0;n=n|0;var o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0;o=Xa-560|0;Xa=o;i[o+548>>2]=n;i[o+552>>2]=b;i[o+104>>2]=2482;s=wd(o+136|0,o+144|0,o+104|0);b=i[s>>2];i[o+132>>2]=b;i[o+128>>2]=b+400;u=Ab(o+104|0);r=Ab(o+88|0);p=Ab(o+72|0);q=Ab(o+56|0);t=Ab(o+40|0);i[114610]=0;$(2485,c|0,d|0,o+120|0,o+119|0,o+118|0,u|0,r|0,p|0,q|0,o+36|0);b=i[114610];i[114610]=0;if((b|0)!=1){a:{i[m>>2]=i[l>>2];v=e&512;w=v>>>9|0;b=0;e=0;while(1){n=e;b:{c:{d:{e:{if((b|0)==4){break e}i[114610]=0;c=C(2422,a|0,o+552|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break a}if(!c){break e}c=0;f:{g:{h:{i:{j:{switch(g[(o+120|0)+b|0]){case 1:if((b|0)==3){break c}i[114610]=0;c=F(2424,a|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break a}if(jg(k,8192,c)){i[114610]=0;G(2486,o+24|0,a|0,0);c=i[114610];i[114610]=0;if((c|0)!=1){c=g[o+24|0];i[114610]=0;D(110,t|0,c|0);c=i[114610];i[114610]=0;if((c|0)!=1){break i}}break a}i[f>>2]=i[f>>2]|4;a=0;break d;case 3:break h;case 0:break j;case 4:break f;case 2:break g;default:break b}}if((b|0)==3){break c}}while(1){i[114610]=0;c=C(2422,a|0,o+552|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break a}if(!c){break c}i[114610]=0;c=F(2424,a|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break a}if(!jg(k,8192,c)){break c}i[114610]=0;G(2486,o+24|0,a|0,0);c=i[114610];i[114610]=0;if((c|0)!=1){c=g[o+24|0];i[114610]=0;D(110,t|0,c|0);c=i[114610];i[114610]=0;if((c|0)!=1){continue}}break}break a}if((lb(p)|0)==(0-lb(q)|0)){break c}k:{if(lb(p)){if(lb(q)){break k}}if(lb(p)){i[114610]=0;c=F(2424,a|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break a}if(j[Sb(p,0)|0]==(c&255)){i[114610]=0;F(2426,a|0)|0;c=i[114610];i[114610]=0;if((c|0)==1){break a}e=lb(p)>>>0>1?p:n;break b}g[h|0]=1;break c}i[114610]=0;c=F(2424,a|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break a}if(j[Sb(q,0)|0]!=(c&255)){break c}i[114610]=0;F(2426,a|0)|0;c=i[114610];i[114610]=0;if((c|0)==1){break a}g[h|0]=1;e=lb(q)>>>0>1?q:n;break b}i[114610]=0;c=F(2424,a|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break a}if(j[Sb(p,0)|0]==(c&255)){i[114610]=0;F(2426,a|0)|0;c=i[114610];i[114610]=0;if((c|0)==1){break a}e=lb(p)>>>0>1?p:n;break b}i[114610]=0;c=F(2424,a|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break a}if(j[Sb(q,0)|0]==(c&255)){i[114610]=0;F(2426,a|0)|0;c=i[114610];i[114610]=0;if((c|0)==1){break a}g[h|0]=1;e=lb(q)>>>0>1?q:n;break b}i[f>>2]=i[f>>2]|4;a=0;break d}if(!(n|b>>>0<2)){e=0;if(!((b|0)==2&j[o+123|0]!=0|w)){break b}}y=o,z=ld(r),i[y+16>>2]=z;c=Ad(o+24|0,o+16|0);l:{if(!b|j[(b+o|0)+119|0]>1){break l}while(1){m:{y=o,z=Ye(r),i[y+16>>2]=z;if(!pb(c,o+16|0)){break m}if(!jg(k,8192,g[i[c>>2]])){break m}Tf(c);continue}break}y=o,z=ld(r),i[y+16>>2]=z;c=En(c,o+16|0);if(c>>>0<=lb(t)>>>0){y=o,z=Ye(t),i[y+16>>2]=z;c=Ze(o+16|0,0-c|0);d=Ye(t);e=ld(r);i[114610]=0;c=ZC(c,d,e);d=i[114610];i[114610]=0;if((d|0)==1){break a}if(c){break l}}y=o,z=ld(r),i[y+8>>2]=z;Ad(o+16|0,o+8|0);i[o+24>>2]=i[o+16>>2]}i[o+16>>2]=i[o+24>>2];n:{while(1){y=o,z=Ye(r),i[y+8>>2]=z;if(!pb(o+16|0,o+8|0)){break n}i[114610]=0;c=C(2422,a|0,o+552|0)|0;d=i[114610];i[114610]=0;o:{if((d|0)==1){break o}if(!c){break n}i[114610]=0;c=F(2424,a|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break o}if(j[i[o+16>>2]]!=(c&255)){break n}i[114610]=0;F(2426,a|0)|0;c=i[114610];i[114610]=0;if((c|0)==1){break a}Tf(o+16|0);continue}break}break a}if(!v){break c}y=o,z=Ye(r),i[y+8>>2]=z;if(!pb(o+16|0,o+8|0)){break c}i[f>>2]=i[f>>2]|4;a=0;break d}p:{while(1){q:{i[114610]=0;d=C(2422,a|0,o+552|0)|0;e=i[114610];i[114610]=0;if((e|0)==1){break q}if(!d){break p}i[114610]=0;e=F(2424,a|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break a}r:{if(jg(k,2048,e)){d=i[m>>2];if((d|0)==i[o+548>>2]){i[114610]=0;G(2488,l|0,m|0,o+548|0);d=i[114610];i[114610]=0;if((d|0)==1){break a}d=i[m>>2]}i[m>>2]=d+1;g[d|0]=e;c=c+1|0;break r}if(!c|!lb(u)|j[o+118|0]!=(e&255)){break p}e=i[o+132>>2];if((e|0)==i[o+128>>2]){i[114610]=0;G(2489,s|0,o+132|0,o+128|0);d=i[114610];i[114610]=0;if((d|0)==1){break a}e=i[o+132>>2]}i[o+132>>2]=e+4;i[e>>2]=c;c=0}i[114610]=0;F(2426,a|0)|0;d=i[114610];i[114610]=0;if((d|0)!=1){continue}}break}break a}d=i[s>>2];s:{if(!c){break s}e=i[o+132>>2];if((d|0)==(e|0)){break s}if(i[o+128>>2]==(e|0)){i[114610]=0;G(2489,s|0,o+132|0,o+128|0);d=i[114610];i[114610]=0;if((d|0)==1){break a}e=i[o+132>>2]}i[o+132>>2]=e+4;i[e>>2]=c}t:{if(i[o+36>>2]<1){break t}i[114610]=0;c=C(2423,a|0,o+552|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break a}u:{if(!c){i[114610]=0;c=F(2424,a|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break a}if(j[o+119|0]==(c&255)){break u}}i[f>>2]=i[f>>2]|4;a=0;break d}i[114610]=0;F(2426,a|0)|0;c=i[114610];i[114610]=0;if((c|0)==1){break a}while(1){if(i[o+36>>2]<1){break t}i[114610]=0;c=C(2423,a|0,o+552|0)|0;d=i[114610];i[114610]=0;v:{if((d|0)==1){break v}w:{if(!c){i[114610]=0;c=F(2424,a|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break v}if(jg(k,2048,c)){break w}}i[f>>2]=i[f>>2]|4;a=0;break d}if(i[m>>2]==i[o+548>>2]){i[114610]=0;G(2488,l|0,m|0,o+548|0);c=i[114610];i[114610]=0;if((c|0)==1){break v}}i[114610]=0;c=F(2424,a|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break v}d=i[m>>2];i[m>>2]=d+1;g[d|0]=c;i[114610]=0;i[o+36>>2]=i[o+36>>2]+ -1;F(2426,a|0)|0;c=i[114610];i[114610]=0;if((c|0)!=1){continue}}break}break a}e=n;if(i[l>>2]!=i[m>>2]){break b}i[f>>2]=i[f>>2]|4;a=0;break d}x:{if(!n){break x}e=1;while(1){if(e>>>0>=lb(n)>>>0){break x}i[114610]=0;b=C(2423,a|0,o+552|0)|0;c=i[114610];i[114610]=0;y:{if((c|0)==1){break y}z:{if(!b){i[114610]=0;b=F(2424,a|0)|0;c=i[114610];i[114610]=0;if((c|0)==1){break y}if(j[Sb(n,e)|0]==(b&255)){break z}}i[f>>2]=i[f>>2]|4;a=0;break d}i[114610]=0;F(2426,a|0)|0;b=i[114610];i[114610]=0;e=e+1|0;if((b|0)!=1){continue}}break}break a}A:{if(i[s>>2]==i[o+132>>2]){break A}i[o+24>>2]=0;a=i[s>>2];i[114610]=0;je(u,a,i[o+132>>2],o+24|0);a=i[114610];i[114610]=0;if((a|0)!=1){if(!i[o+24>>2]){break A}i[f>>2]=i[f>>2]|4;a=0;break d}break a}a=1}eb(t);eb(q);eb(p);eb(r);eb(u);lc(s);Xa=o+560|0;return a|0}e=n}b=b+1|0;continue}}}a=B()|0;A()|0;eb(t);eb(q);eb(p);eb(r);eb(u);lc(s);E(a|0);x()}function qJa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,l=0,m=0,n=0,p=0,q=0,r=0,s=0,t=0,u=0;d=Xa-272|0;Xa=d;pc(b);a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{if(!xz(b,d+200|0)){break l}if(!vR(d+200|0)){break l}if(!c){q=1;break l}md(a,131072);e=Bb(d+184|0,12688);i[114610]=0;D(219,d+32|0,e|0);g=i[114610];i[114610]=0;m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{if((g|0)!=1){i[114610]=0;G(537,d+136|0,d+32|0,d+200|4);g=i[114610];i[114610]=0;if((g|0)==1){break B}mb(a+1304436|0,d+136|0);eb(d+136|0);ob(d+32|0);eb(e);e=Bb(d+136|0,12702);mb(a+1304448|0,e);eb(e);i[a+1304496>>2]=4;SR(d+32|0,3,d+213|0);oc(d+136|0,d+32|0);mb(a+1304400|0,d+136|0);eb(d+136|0);en(d+120|0,3,d+243|0);oc(d+32|0,d+120|0);i[114610]=0;G(13,d+136|0,4,d+32|0);e=i[114610];i[114610]=0;if((e|0)==1){break j}mb(a+1304412|0,d+136|0);eb(d+136|0);eb(d+32|0);e=mp(d+136|0);t=e,u=hd(j[d+263|0],1,31),i[t+12>>2]=u;t=e,u=hd(j[d+264|0],1,12)+ -1|0,i[t+16>>2]=u;i[e+20>>2]=j[d+265|0];g=a+1304500|0;wz(g);uR(g,e);r=gk(d+120|0,b);i[114610]=0;G(538,d+104|0,r|0,1);b=i[114610];i[114610]=0;if((b|0)==1){break z}i[114610]=0;b=F(277,d+88|0)|0;e=i[114610];i[114610]=0;if((e|0)==1){break y}i[114610]=0;G(539,d+32|0,d+104|0,1431389523);e=i[114610];i[114610]=0;if((e|0)==1){break k}Cd(b,d+32|0);hb(d+32|0);i[114610]=0;q=C(540,b|0,d+80|0)|0;e=i[114610];i[114610]=0;if((e|0)==1){break p}if(!q){break m}g=a+484360|0;e=Db(g);i[114610]=0;f=F(255,b|0)|0;l=i[114610];i[114610]=0;if((l|0)==1){break p}i[114610]=0;S(441,e|0,b|0,f+ -4>>>1|0,65535,65535)|0;e=i[114610];i[114610]=0;if((e|0)==1){break p}i[114610]=0;G(539,d+32|0,d+104|0,1414807888);e=i[114610];i[114610]=0;if((e|0)==1){break x}Cd(b,d+32|0);hb(d+32|0);i[114610]=0;e=F(337,b|0)|0;f=i[114610];i[114610]=0;if((f|0)==1){break p}if(!(c&1)|e^1){break q}i[114610]=0;C(541,b|0,d+72|0)|0;e=i[114610];i[114610]=0;if((e|0)==1){break w}t=a,u=hd(j[d+72|2],1,32)+1|0,h[t+480188>>1]=u;e=j[d+72|0]|j[d+73|0]<<8;i[114610]=0;e=C(395,d|0,e|0)|0;f=i[114610];i[114610]=0;if((f|0)==1){break v}t=d,u=Jb(e),i[t+64>>2]=u;t=d,u=Kb(e),i[t+56>>2]=u;if(pb(d- -64|0,d+56|0)){f=d+16|4;while(1){l=i[d- -64>>2];i[114610]=0;C(542,b|0,d+16|0)|0;m=i[114610];i[114610]=0;if((m|0)==1){break u}tg(b,8);m=j[f|0]|j[f+1|0]<<8|(j[f+2|0]<<16|j[f+3|0]<<24);i[114610]=0;G(341,d+32|0,b|0,m+8|0);m=i[114610];i[114610]=0;if((m|0)==1){break t}Cd(l,d+32|0);hb(d+32|0);vf(d- -64|0);if(pb(d- -64|0,d+56|0)){continue}break}}f=k[a+480188>>1];i[114610]=0;l=C(543,d+32|0,f|0)|0;f=i[114610];i[114610]=0;if((f|0)==1){break s}f=Db(g);i[114610]=0;f=F(544,f|0)|0;m=i[114610];i[114610]=0;if((m|0)==1){break f}i[114610]=0;m=a+484344|0;D(401,m|0,f|0);f=i[114610];i[114610]=0;if((f|0)==1){break f}f=Db(g);t=d,u=Jb(f),i[t+16>>2]=u;t=d,u=Kb(f),i[t+64>>2]=u;if(pb(d+16|0,d- -64|0)){while(1){f=i[d+16>>2];n=k[f>>1];if(Wc(e)>>>0>n>>>0){n=_b(e,k[f>>1]);i[114610]=0;n=I(545,n|0,l|0,a|0)|0;p=i[114610];i[114610]=0;if((p|0)==1){break f}h[f>>1]=n}he(d+16|0);if(pb(d+16|0,d- -64|0)){continue}break}}n=Db(g);f=d+80|2;p=j[f|0]|j[f+1|0]<<8;i[114610]=0;n=C(546,n|0,p|0)|0;p=i[114610];i[114610]=0;if((p|0)==1){break f}if(!n){break r}if(!(j[d+80|0]|j[d+81|0]<<8)){n=j[f|0]|j[f+1|0]<<8;p=Db(g);i[114610]=0;p=F(547,p|0)|0;s=i[114610];i[114610]=0;if((s|0)==1){break f}if(n>>>0>=p>>>0){break r}}g=k[$b(Db(g),j[f|0]|j[f+1|0]<<8)>>1];f=Fb(m,g);n=j[d+80|0];i[114610]=0;n=I(498,d+16|0,12,n|0)|0;p=i[114610];i[114610]=0;if((p|0)!=1){g=dn(Ee(n,i[Fb(m,g)+12>>2]+ -1|0));i[114610]=0;C(499,f|0,g|0)|0;g=i[114610];i[114610]=0;if((g|0)!=1){break r}}break f}a=B()|0;A()|0;break A}a=B()|0;A()|0;ob(d+32|0)}eb(e);break a}a=B()|0;A()|0;break b}a=B()|0;A()|0;break c}a=B()|0;A()|0;break d}a=B()|0;A()|0;break d}a=B()|0;A()|0;break d}a=B()|0;A()|0;break e}a=B()|0;A()|0;break e}a=B()|0;A()|0;break e}mR(l);Qc(e)}i[114610]=0;G(539,d+32|0,d+104|0,1196641603);e=i[114610];i[114610]=0;if((e|0)==1){break o}Cd(b,d+32|0);hb(d+32|0);i[114610]=0;e=F(337,b|0)|0;g=i[114610];i[114610]=0;if((g|0)==1){break p}if(!e){break n}i[114610]=0;C(338,b|0,1)|0;e=i[114610];i[114610]=0;if((e|0)==1){break p}i[114610]=0;e=F(548,b|0)|0;g=i[114610];i[114610]=0;if((g|0)==1){break p}i[114610]=0;S(549,a+1304424|0,b|0,e|0,40,0)|0;e=i[114610];i[114610]=0;if((e|0)!=1){break n}}a=B()|0;A()|0;break d}a=B()|0;A()|0;break d}i[114610]=0;G(539,d+32|0,d+104|0,1146113363);e=i[114610];i[114610]=0;if((e|0)==1){break i}i[114610]=0;G(539,d+16|0,d+104|0,1229999443);e=i[114610];i[114610]=0;C:{if((e|0)!=1){Cd(b,d+16|0);hb(d+16|0);i[114610]=0;e=F(387,b|0)|0;g=i[114610];i[114610]=0;D:{if((g|0)!=1){h[a+480190>>1]=e;if(k[a+480190>>1]){g=c&2;c=1;e=1;while(1){i[114610]=0;I(431,b|0,((c<<5)+a|0)+946300|0,-1)|0;f=i[114610];i[114610]=0;E:{if((f|0)!=1){i[114610]=0;C(550,b|0,d+16|0)|0;f=i[114610];i[114610]=0;if((f|0)==1){break h}i[114610]=0;c=o(c,104)+a|0;f=c+484380|0;D(551,d+16|0,f|0);l=i[114610];i[114610]=0;if((l|0)==1){break h}if(j[d+204|0]<8){break E}i[114610]=0;I(552,b|0,c+484423|0,8)|0;l=i[114610];i[114610]=0;if((l|0)!=1){break E}break h}a=B()|0;A()|0;break g}i[114610]=0;C(338,b|0,6)|0;l=i[114610];i[114610]=0;if((l|0)==1){break h}i[114610]=0;l=F(390,d+32|0)|0;m=i[114610];i[114610]=0;F:{G:{if((m|0)==1){break G}i[114610]=0;G(341,d|0,d+32|0,l|0);l=i[114610];i[114610]=0;if((l|0)==1){break G}i[114610]=0;l=F(337,d|0)|0;m=i[114610];i[114610]=0;if((m|0)==1){break D}if(!g|l^1){break F}c=Ic(d- -64|0,h[c+484414>>1]&1?16:8,1,0,(j[d+31|0]&12)==4?7:0);i[114610]=0;I(400,c|0,f|0,d|0)|0;c=i[114610];i[114610]=0;if((c|0)!=1){break F}break D}a=B()|0;A()|0;break g}hb(d);e=e+1|0;c=e&65535;if(c>>>0<=k[a+480190>>1]){continue}break}}i[114610]=0;L(476,a|0);c=i[114610];i[114610]=0;if((c|0)!=1){break C}}a=B()|0;A()|0;break g}a=B()|0;A()|0;hb(d);break g}a=B()|0;A()|0;break g}i[a+480204>>2]=12e5;i[a+480208>>2]=24;i[a+480196>>2]=6;i[a+480200>>2]=256;i[a+480228>>2]=48;i[a+480232>>2]=48;hb(d+32|0)}hb(b);uz(d+104|0);hb(r)}Xa=d+272|0;return q|0}a=B()|0;A()|0;break d}a=B()|0;A()|0;eb(d+32|0);break a}a=B()|0;A()|0;break d}a=B()|0;A()|0}hb(d+32|0);break d}a=B()|0;A()|0;mR(l)}Qc(e)}hb(b)}uz(d+104|0)}hb(r)}E(a|0);x()}function JGa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,m=0,n=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,H=0,J=0,K=0,L=0,M=0,N=0;e=Xa-176|0;Xa=e;a:{b:{c:{d:{e:{f:{g:{h:{if(!sh(b,14021)){break h}if(d){g[d|0]=1}r=a+1074308|0;Rs(r);i:{if(!wb(b,7)){break i}t=a+480216|0;u=a+480220|0;v=a+480224|0;w=a+1074368|0;y=a+480228|0;z=a+480232|0;H=a+480200|0;J=a+484360|0;s=a+480268|0;K=a+1304412|0;L=a+480248|0;while(1){f=Cf(b);d=_f(b);if((f|0)==(j[14475]|j[14476]<<8|(j[14477]<<16|j[14478]<<24))){tg(b,6);break i}if(!(f&1616928864)|f&-2139062144){break i}if(!wb(b,d)){break i}ad(e+160|0,b,d);j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{if((f|0)<=1347243309){if((f|0)<=1146367533){if((f|0)<=1130917458){if((f|0)==1127099950){break y}if((f|0)!=1129797166){break j}i[114610]=0;i[e>>2]=0;G(675,e+160|0,d|0,e|0);d=i[114610];i[114610]=0;if((d|0)==1){break v}i[a+1074300>>2]=i[e>>2];break j}if((f|0)==1130917459){break q}if((f|0)!=1145525806){break j}i[114610]=0;G(675,e+160|0,d|0,H|0);d=i[114610];i[114610]=0;if((d|0)==1){break b}break j}if((f|0)<=1213486400){if((f|0)==1146367534){break A}if((f|0)!=1196316499|d>>>0<3){break j}i[114610]=0;D(676,e+144|0,e+160|0);d=i[114610];i[114610]=0;if((d|0)==1){break o}i[114610]=0;m=I(677,e|0,e+144|0,8)|0;d=i[114610];i[114610]=0;if((d|0)==1){break n}eb(e+144|0);i[114610]=0;f=F(255,e+160|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break m}i[114610]=0;G(678,e|0,L|0,f|0);d=i[114610];i[114610]=0;if((d|0)==1){break m}Ve(m);break j}if((f|0)==1213486401){break r}if((f|0)==1280530262){break u}if((f|0)!=1297303086){break j}Rs(r);n=0;break l}if((f|0)<=1380994349){if((f|0)<=1380340803){if((f|0)==1347243310){break w}if((f|0)!=1347244882){break j}i[114610]=0;G(679,e+160|0,d|0,s|0);d=i[114610];i[114610]=0;if((d|0)==1){break b}if(qn(j[s|0])){break j}g[s|0]=5;break j}if((f|0)==1380340804){break z}if((f|0)==1380986414){break s}if((f|0)!=1380991534){break j}i[114610]=0;G(675,e+160|0,d|0,t|0);d=i[114610];i[114610]=0;if((d|0)==1){break b}break j}if((f|0)<=1397768493){if((f|0)==1380994350){break k}if((f|0)!=1397052739|d>>>0<3){break j}i[114610]=0;f=F(357,e+160|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break c}if(!f|f>>>0>k[a+480190>>1]){break j}f=o(f,104)+a|0;d=f+484448|0;q=f+484484|0;while(1){i[114610]=0;m=F(390,e+160|0)|0;f=i[114610];i[114610]=0;if((f|0)==1){break p}i[d>>2]=m;d=d+4|0;if((q|0)!=(d|0)){continue}break}break j}if((f|0)==1397768494){break t}if((f|0)==1414344238){break x}if((f|0)!=1448301654){break j}i[114610]=0;G(675,e+160|0,d|0,z|0);d=i[114610];i[114610]=0;if((d|0)==1){break b}break j}i[114610]=0;G(675,e+160|0,d|0,e|0);d=i[114610];i[114610]=0;if((d|0)==1){break g}i[a+480204>>2]=o(i[e>>2],1e4)+(l[a+480204>>2]%1e4|0);break j}i[114610]=0;G(675,e+160|0,d|0,e|0);d=i[114610];i[114610]=0;if((d|0)!=1){d=i[a+480204>>2];i[a+480204>>2]=d-((d>>>0)%1e4|0)+l[e>>2]%1e4;break j}d=B()|0;A()|0;break a}if(c){break j}i[114610]=0;h[e>>1]=0;G(680,e+160|0,d|0,e|0);d=i[114610];i[114610]=0;if((d|0)!=1){M=a,N=hd(k[e>>1],k[a+480188>>1],127),h[M+480188>>1]=N;break j}d=B()|0;A()|0;break a}i[114610]=0;G(681,e+160|0,d|0,v|0);d=i[114610];i[114610]=0;if((d|0)==1){break b}break j}i[114610]=0;G(682,e+160|0,d|0,w|0);d=i[114610];i[114610]=0;if((d|0)==1){break b}break j}d=B()|0;A()|0;break a}i[114610]=0;i[e>>2]=0;G(675,e+160|0,d|0,e|0);d=i[114610];i[114610]=0;if((d|0)==1){break f}d=i[e>>2];if(!d){break j}i[a+1074304>>2]=d;break j}i[114610]=0;G(675,e+160|0,d|0,y|0);d=i[114610];i[114610]=0;if((d|0)!=1){break j}break b}if(i[a+480180>>2]==4){break j}i[114610]=0;G(680,e+160|0,d|0,e|0);d=i[114610];i[114610]=0;if((d|0)!=1){Fe(Db(J),k[e>>1]);break j}d=B()|0;A()|0;break a}m=Ab(e);i[114610]=0;f=F(255,e+160|0)|0;d=i[114610];i[114610]=0;B:{if((d|0)==1){break B}i[114610]=0;I(463,e+160|0,m|0,f|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break B}i[114610]=0;G(13,e+144|0,0,m|0);d=i[114610];i[114610]=0;if((d|0)==1){break B}mb(K,e+144|0);eb(e+144|0);eb(m);break j}d=B()|0;A()|0;eb(m);break a}if(d&1|d>>>0>126){break j}h[e>>1]=(d>>>1|0)- -64;i[114610]=0;h[e+144>>1]=127;f=C(477,e|0,e+144|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break e}q=k[f>>1];if(q>>>0<65){break j}n=64;while(1){i[114610]=0;D(472,e|0,e+160|0);d=i[114610];i[114610]=0;if((d|0)==1){break d}d=Nc(e);f=e;C:{if(j[e|0]==255){break C}d=j[d|0];p=(n<<5)+a|0;m=p+480284|0;h[m>>1]=128;h[p+480286>>1]=d;p=p+480280|0;i[p>>2]=0;i[p>>2]=(j[f|0]&128)<<3;d=j[f|0]&127;g[f|0]=d;if(d>>>0<65){h[m>>1]=d<<2;d=j[f|0]}if((d|0)!=100){break C}i[p>>2]=i[p>>2]|256}n=n+1|0;if((q|0)!=(n|0)){continue}break}break j}d=B()|0;A()|0;break a}d=B()|0;A()|0;break a}d=B()|0;A()|0;eb(e+144|0);break a}d=B()|0;A()|0;Ve(m);break a}D:{E:{F:while(1){i[114610]=0;f=C(258,e+160|0,1)|0;d=i[114610];i[114610]=0;if((d|0)==1){break E}if(!f|n>>>0>=110){break j}i[114610]=0;m=F(387,e+160|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break D}d=0;while(1){G:{if(!(!(m>>>d&1)|n>>>0>=110)){i[114610]=0;I(478,r|0,n|0,1)|0;f=i[114610];i[114610]=0;if((f|0)==1){break G}}n=n+1|0;d=d+1|0;if((d|0)!=8){continue}continue F}break}break}d=B()|0;A()|0;break a}d=B()|0;A()|0;break a}d=B()|0;A()|0;break a}i[114610]=0;G(675,e+160|0,d|0,u|0);d=i[114610];i[114610]=0;if((d|0)==1){break b}}hb(e+160|0);if(wb(b,7)){continue}break}}wn(a+480204|0,o(i[i[a+8>>2]+20>>2],1e4),o(i[i[a+8>>2]+24>>2],1e4));if(i[a+480224>>2]>=3){i[a+480224>>2]=0}if(i[a+1074368>>2]>=6){i[a+1074368>>2]=0}kc(a+480200|0,256);b=a+480248|0;if(Uc(b)){break h}_y(b,i[a+480216>>2],16777216)}Xa=e+176|0;return}d=B()|0;A()|0;break a}d=B()|0;A()|0;break a}d=B()|0;A()|0;break a}d=B()|0;A()|0;break a}d=B()|0;A()|0;break a}d=B()|0;A()|0}hb(e+160|0);E(d|0);x()}function Uea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=p(0),f=p(0),h=p(0),k=p(0),l=p(0),n=0,o=p(0),q=p(0),r=p(0),s=p(0),t=0,u=0,v=p(0),w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=p(0),U=0,V=0,W=0,X=p(0);a:{if(!j[a+5046|0]){break a}k=m[a+4268>>2];bH(a);if(k==m[a+4268>>2]){break a}dw(a)}b:{if(!j[a+5045|0]){break b}w=a+44|0;if(!Wg(w)){break b}x=ud(w,0);B=ud(w,1);t=Pc(w,0);u=Pc(w,1);c:{if(!(!j[a+5044|0]|(!d|j[a+4264|0]&2))){m[t>>2]=m[a+5036>>2];m[u>>2]=m[a+5040>>2];g[a+5044|0]=0;B=B+4|0;x=x+4|0;u=u+4|0;t=t+4|0;n=d+ -1|0;break c}n=d}y=n;d:{if(!y){break d}S=a+4960|0;D=a+4648|0;E=a+4672|0;O=a+4936|0;F=a+4696|0;G=a+4720|0;H=a+4744|0;I=a+4768|0;P=a+4840|0;C=a+4504|0;J=a+4528|0;Q=a+4912|0;K=a+4552|0;L=a+4576|0;M=a+4600|0;N=a+4624|0;R=a+4816|0;z=a+4888|0;A=a+4864|0;while(1){k=m[x>>2];k=p(p(p(m[a+5008>>2]-k)*m[a+4276>>2])+k);m[a+5008>>2]=k;W=hc(A,i[a+4880>>2]),X=k,m[W>>2]=X;k=m[B>>2];k=p(p(p(m[a+5012>>2]-k)*m[a+4276>>2])+k);m[a+5012>>2]=k;W=hc(z,i[a+4904>>2]),X=k,m[W>>2]=X;k=Jg(A,i[a+4356>>2]);f=Jg(A,i[a+4360>>2]);e=Jg(A,i[a+4364>>2]);h=Jg(A,i[a+4368>>2]);k=p(p(p(k*p(.6800000071525574))+p(p(e+Jg(A,i[a+4372>>2]))*p(-.6200000047683716)))+p(p(h+f)*p(-.5)));if(g[a+4264|0]&1){f=k;k=p(m[hc(R,i[a+4836>>2])>>2]+p(f*p(.6180340051651001)));W=hc(R,i[a+4832>>2]),X=p(f-p(k*p(.6180340051651001))),m[W>>2]=X}T=m[a+4280>>2];W=a,X=p(Jg(A,i[a+4352>>2])+m[a+5020>>2]),m[W+5020>>2]=X;f=p(Jg(z,i[a+4376>>2])+m[a+5024>>2]);m[a+5024>>2]=f;e=m[a+5020>>2];h=m[a+4980>>2];r=m[hc(N,i[a+4644>>2])>>2];s=m[a+4444>>2];h=p(m[hc(N,i[a+4644>>2])>>2]+p(s*p(h-r)));m[a+4980>>2]=h;r=m[a+4272>>2];s=p(e*p(-.7070000171661377));o=p(f*p(.7070000171661377));e=p(s+o);f=p(p(r*e)+p(m[a+4440>>2]*h));W=hc(N,i[a+4640>>2]),X=p(e-p(r*f)),m[W>>2]=X;e=m[a+4976>>2];h=m[hc(M,i[a+4620>>2])>>2];r=m[a+4436>>2];e=p(m[hc(M,i[a+4620>>2])>>2]+p(r*p(e-h)));m[a+4976>>2]=e;h=m[a+4272>>2];e=p(p(h*f)+p(m[a+4432>>2]*e));W=hc(M,i[a+4616>>2]),X=p(f-p(h*e)),m[W>>2]=X;r=p(p(f*p(-.15000000596046448))+p(e*p(-.20000000298023224)));if(g[a+4264|0]&1){f=m[a+4972>>2];h=m[hc(L,i[a+4596>>2])>>2];l=m[a+4428>>2];f=p(m[hc(L,i[a+4596>>2])>>2]+p(l*p(f-h)));m[a+4972>>2]=f;h=m[a+4272>>2];f=p(p(h*e)+p(m[a+4424>>2]*f));W=hc(L,i[a+4592>>2]),X=p(e-p(h*f)),m[W>>2]=X;e=m[a+4968>>2];h=m[hc(K,i[a+4572>>2])>>2];l=m[a+4420>>2];e=p(m[hc(K,i[a+4572>>2])>>2]+p(l*p(e-h)));m[a+4968>>2]=e;h=m[a+4272>>2];e=p(p(h*f)+p(m[a+4416>>2]*e));W=hc(K,i[a+4568>>2]),X=p(f-p(h*e)),m[W>>2]=X;r=p(p(p(f*p(.3499999940395355))+r)+p(e*p(-.3799999952316284)))}o=p(s-o);W=hc(Q,i[a+4928>>2]),X=e,m[W>>2]=X;n=hc(Q,i[a+4932>>2]);f=p(m[a+4496>>2]*m[n>>2]);m[a+5028>>2]=p(p(m[a+5028>>2]-f)*m[a+4500>>2])+f;f=m[a+4964>>2];e=m[hc(J,i[a+4548>>2])>>2];h=m[a+4412>>2];f=p(m[hc(J,i[a+4548>>2])>>2]+p(h*p(f-e)));m[a+4964>>2]=f;e=p(m[a+4408>>2]*f);f=m[a+4272>>2];h=m[a+5028>>2];e=p(e+p(f*h));W=hc(J,i[a+4544>>2]),X=p(h-p(f*e)),m[W>>2]=X;f=m[a+4960>>2];h=m[hc(C,i[a+4524>>2])>>2];s=m[a+4404>>2];f=p(m[hc(C,i[a+4524>>2])>>2]+p(s*p(f-h)));m[a+4960>>2]=f;h=m[a+4272>>2];s=p(p(h*e)+p(m[a+4400>>2]*f));W=hc(C,i[a+4520>>2]),X=p(e-p(h*s)),m[W>>2]=X;m[a+5020>>2]=s;f=Jg(z,i[a+4380>>2]);h=Jg(z,i[a+4384>>2]);l=Jg(z,i[a+4388>>2]);v=Jg(z,i[a+4392>>2]);f=p(p(p(f*p(.7070000171661377))+p(p(l+Jg(z,i[a+4396>>2]))*p(-.5)))+p(p(v+h)*p(-.6000000238418579)));l=p(e*p(.3799999952316284));if(g[a+4264|0]&1){e=f;f=p(m[hc(P,i[a+4860>>2])>>2]+p(e*p(.6180340051651001)));W=hc(P,i[a+4856>>2]),X=p(e-p(f*p(.6180340051651001))),m[W>>2]=X}v=m[a+4280>>2];e=m[a+5004>>2];h=m[hc(I,i[a+4788>>2])>>2];q=m[a+4492>>2];e=p(m[hc(I,i[a+4788>>2])>>2]+p(q*p(e-h)));m[a+5004>>2]=e;q=m[a+4272>>2];h=p(p(q*o)+p(m[a+4488>>2]*e));W=hc(I,i[a+4784>>2]),X=p(o-p(q*h)),m[W>>2]=X;e=m[a+5e3>>2];o=m[hc(H,i[a+4764>>2])>>2];q=m[a+4484>>2];e=p(m[hc(H,i[a+4764>>2])>>2]+p(q*p(e-o)));m[a+5e3>>2]=e;o=m[a+4272>>2];e=p(p(o*h)+p(m[a+4480>>2]*e));W=hc(H,i[a+4760>>2]),X=p(h-p(o*e)),m[W>>2]=X;o=p(p(e*p(-.20000000298023224))+p(l+p(h*p(-.15000000596046448))));if(g[a+4264|0]&1){h=m[a+4996>>2];l=m[hc(G,i[a+4740>>2])>>2];q=m[a+4476>>2];h=p(m[hc(G,i[a+4740>>2])>>2]+p(q*p(h-l)));m[a+4996>>2]=h;l=m[a+4272>>2];h=p(p(l*e)+p(m[a+4472>>2]*h));W=hc(G,i[a+4736>>2]),X=p(e-p(l*h)),m[W>>2]=X;e=m[a+4992>>2];l=m[hc(F,i[a+4716>>2])>>2];q=m[a+4468>>2];e=p(m[hc(F,i[a+4716>>2])>>2]+p(q*p(e-l)));m[a+4992>>2]=e;l=m[a+4272>>2];e=p(p(l*h)+p(m[a+4464>>2]*e));W=hc(F,i[a+4712>>2]),X=p(h-p(l*e)),m[W>>2]=X;o=p(p(p(h*p(.3499999940395355))+o)+p(e*p(-.3799999952316284)))}U=B+4|0;V=x+4|0;h=p(v*f);W=hc(O,i[a+4952>>2]),X=e,m[W>>2]=X;n=hc(O,i[a+4956>>2]);f=p(m[a+4496>>2]*m[n>>2]);m[a+5032>>2]=p(p(m[a+5032>>2]-f)*m[a+4500>>2])+f;f=m[a+4988>>2];e=m[hc(E,i[a+4692>>2])>>2];l=m[a+4460>>2];f=p(m[hc(E,i[a+4692>>2])>>2]+p(l*p(f-e)));m[a+4988>>2]=f;e=m[a+4272>>2];l=m[a+5032>>2];f=p(p(m[a+4456>>2]*f)+p(e*l));W=hc(E,i[a+4688>>2]),X=p(l-p(e*f)),m[W>>2]=X;l=m[a+4284>>2];e=m[a+4984>>2];v=m[hc(D,i[a+4668>>2])>>2];q=m[a+4452>>2];e=p(m[hc(D,i[a+4668>>2])>>2]+p(q*p(e-v)));m[a+4984>>2]=e;v=m[a+4272>>2];e=p(p(v*f)+p(m[a+4448>>2]*e));W=hc(D,i[a+4664>>2]),X=p(f-p(v*e)),m[W>>2]=X;m[a+5024>>2]=e;e=p(e*p(.3799999952316284));k=p(p(l*p(p(p(f-s)*p(.3799999952316284))+r))+p(T*k));f=m[a+4288>>2];n=C;while(1){Yea(n);n=n+24|0;if((S|0)!=(n|0)){continue}break}f=p(p(f*p(o-e))+h);e:{f:{if(j[a+4264|0]&2){x=V;n=U;break f}m[t>>2]=p(m[a+5036>>2]+k)*p(.5);m[u>>2]=p(m[a+5040>>2]+f)*p(.5);m[a+5040>>2]=f;m[a+5036>>2]=k;if((y|0)==1){break e}y=y+ -1|0;x=x+8|0;u=u+4|0;t=t+4|0;n=B+8|0}B=n;m[t>>2]=k;m[u>>2]=f;u=u+4|0;t=t+4|0;y=y+ -1|0;if(y){continue}break d}break}g[a+5044|0]=1}Oh(a,b,c,Pc(w,0),Pc(w,1),d)}}function Co(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var m=0,n=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;p=Xa-16|0;Xa=p;m=k[a+480192>>1]>=c>>>0?i[((c<<2)+a|0)+900380>>2]:m;y=i[b+764>>2];n=j[b+824|0];a:{if(!n){kb(p+8|0,a+1074308|0,11);if(ib(p+8|0)){break a}}b:{c:{if(!m){break c}if(!Jd(n)){break c}d:{q=m+236|0;r=n+ -1|0;if(k[Mc(q,r)>>1]){break d}kb(p+8|0,a+1074308|0,43);if(!ib(p+8|0)){break d}if(Xh(m)){break d}i[b+656>>2]=m;break a}if(j[Nb(m+108|0,r)|0]>120){break a}r=k[Mc(q,r)>>1];r=(r+ -1&65535)>>>0<3999?(o(r,104)+a|0)+484380|0:0;break b}r=(o(c,104)+a|0)+484380|0;if(!k[a+480192>>1]){break b}if(n>>>0>250){break a}kb(p+8|0,a+1074308|0,43);if(ib(p+8|0)){if(m){r=0;if(Xh(m)){break b}}g[b+825|0]=0;i[b+656>>2]=0;break a}r=0}q=i[b+656>>2];x=i[a+480180>>2];t=!d;s=i[b+104>>2];u=!s|(r|0)==(s|0);v=u;n=0;e:{if(!m){break e}n=0;if((x|0)!=16777216){break e}n=i[m+44>>2]!=0}x=n;if(i[b+656>>2]==(m|0)?!(!n|v|t):0){break a}n=(r|0)!=(s|0);s=(s|0)!=0;v=d^1;f:{if(u|v){break f}t=a+1074308|0;kb(p+8|0,t,32);if(!(!ib(p+8|0)|!(j[a+480208|0]&8))){r=i[b+8>>2]|i[b+12>>2]?i[b+104>>2]:r}g:{if(i[a+480180>>2]==268435456|(i[a+480180>>2]&1048580?!(!m|(m|0)!=(q|0)):0)){break g}if(i[a+480180>>2]==1){if(nh(b)){break g}}kb(p+8|0,t,79);if(!ib(p+8|0)){break f}if(!nh(b)){break f}}w=1}t=n&s;h:{if(!i[b+16>>2]|(!t|(!k[a+480192>>1]|(m|0)!=(q|0)))){break h}kb(p+8|0,a+1074308|0,87);if(!ib(p+8|0)){break h}w=Jf(b+810|0)^1|w}i:{j:{k:{l:{if(!(nh(b)|!(i[a+480180>>2]&16777248))){if(!m){break l}if(!Xh(m)){break l}}if((m|0)==(q|0)){break k}}m:{n:{if(!d){break n}kb(p+8|0,a+1074308|0,61);if(!ib(p+8|0)){break n}q=i[b+656>>2];if(q){break m}s=0;q=0;n=i[b+104>>2];if(n){break i}}s=1;break j}n=i[b+104>>2];s=0;break i}s=0}i[b+656>>2]=m;n=r;q=m}o:{p:{q:{if(!e){break q}r:{if(i[a+480180>>2]&3){if(n){if(ie(n)){break r}}if(!Pi(b)){break q}}if(!n){break p}}if(h[n+34>>1]<0){break q}i[b+688>>2]=k[n+30>>1]}m=(n|0)!=0;if(!(t&m&w)){break o}kb(p+8|0,a+1074308|0,85);if(ib(p+8|0)){i[b+768>>2]=g[n+37|0]}m=1;if(i[a+480180>>2]!=2){break o}if(!ie(n)){break o}i[b+704>>2]=i[n+24>>2];break o}if(!(!q|!j[q+34|0])){m=b;r=b;u=i[b+656>>2];s:{if(u){r=i[u+4>>2]<<2;break s}r=i[r+688>>2]}i[m+688>>2]=r;m=0;break o}m=0;i[b+688>>2]=0}if(w){break a}g[b+825|0]=0;t:{if(!q){break t}kb(p+8|0,a+1074308|0,29);if(z=0,A=!((ib(p+8|0)^1)&m),B=j[q+34|0]!=0|s,B?z:A){break t}g[b+820|0]=j[q+16|0]}kua(b,n,q);u:{if(i[a+480180>>2]&1048580?!e:0){break u}kb(p+8|0,a+1074308|0,48);if(ib(p+8|0)){break u}GK(a,b,q,n)}v:{w:{x:{if(!f){break x}e=a+1074308|0;kb(p+8|0,e,19);y:{z:{A:{B:{C:{D:{E:{F:{if(ib(p+8|0)){if(!i[b+76>>2]){r=1;break E}if(!(!c|v)){r=(j[a+480208|0]&8)>>>3|0;if(r){break E}break F}r=0;if(c){break F}break E}r=1;G:{if(!d|!(i[a+480180>>2]&17301536)|(!i[b+76>>2]|j[a+480208|0]&8)){break G}r=0;if(!(j[b+89|0]&16)){break G}r=!i[b+696>>2]}if(!(i[a+480180>>2]&17301536)|(!q|s)){break C}if(!r){break B}c=i[b+88>>2];f=c&6144;break D}if(d){break E}if(!(j[b+89|0]&24)){r=0;break E}r=(j[a+480208|0]&4)>>>2|0}if(!i[b+696>>2]|s){break C}if(!r){break B}c=i[b+88>>2];f=c&2048}i[b+88>>2]=c|2097152;if(!q){break y}if(f){break z}if(!(j[q+60|0]&8)){Wh(b+724|0)}if(!(j[q+80|0]&8)){Wh(b+736|0)}if(j[q+100|0]&8){break y}Wh(b+748|0);break y}if(r){break A}}if(q){if(g[q+60|0]&1){break x}kb(p+8|0,e,32);if(ib(p+8|0)){Wh(b+724|0);break x}_k(b);break x}c=0;if(!n){break w}break v}i[b+88>>2]=i[b+88>>2]|2097152;if(!q){break y}}_k(b)}kb(p+8|0,e,21);if(ib(p+8|0)){break x}g[b+838|0]=0;i[b+780>>2]=0}c=0;if(n){break v}if(!q){break w}c=1;if(Xh(q)){break v}}i[b+764>>2]=0;i[b+104>>2]=0;break a}H:{I:{J:{K:{L:{if(!(!d|(m^1|i[b+104>>2]!=(n|0)))){if(i[b+76>>2]?i[a+480180>>2]&16777250:0){break a}if(i[a+480180>>2]!=4){break L}kb(p+8|0,a+1074308|0,40);if(!ib(p+8|0)|j[b+811|0]){break L}m=i[b+88>>2];break K}i[b+88>>2]=i[b+88>>2]&-6145;m=a+1074308|0;kb(p+8|0,m,18);e=b;M:{if(!(z=!ib(p+8|0),A=0,B=i[a+480180>>2]&16777248,B?z:A)){f=-640;if(!(i[b+104>>2]!=(n|0)|s)){break M}}f=-768}i[e+88>>2]=f&i[b+88>>2];N:{if(!q){break N}g[b+724|0]=j[q+60|0];g[b+736|0]=j[q+80|0];g[b+748|0]=j[q+100|0];O:{if((j[q+100|0]&17)!=17){break O}kb(p+8|0,m,36);if(ib(p+8|0)|j[b+857|0]){break O}g[b+857|0]=127}if(Ct(q)){z=b,A=qA(q),g[z+857|0]=A}if(!oA(q)){break N}z=b,A=pA(q),g[z+858|0]=A}if(c){break J}if(!d){break H}break I}m=i[b+88>>2]&-6145;i[b+88>>2]=m}i[b+88>>2]=m&-640;if(!c){break I}}i[b+76>>2]=0;i[b+104>>2]=0;break a}if(i[b+76>>2]){break H}c=a+1074308|0;kb(p+8|0,c,54);if(!ib(p+8|0)){kb(p,c,39);if(!ib(p)){break H}}i[b+8>>2]=0;i[b+12>>2]=0}P:{if(j[b+810|0]!=255){break P}kb(p+8|0,a+1074308|0,100);if(!ib(p+8|0)|(!(i[a+480208>>2]&4)|t^1)){break P}c=i[b+104>>2];if(c){i[b+88>>2]=i[b+88>>2]|k[c+34>>1]&1023}i[b+764>>2]=y;i[b+688>>2]=k[n+30>>1];if(!(j[n+34|0]&32)){break a}is(b,k[n+28>>1],a);break a}i[b+104>>2]=n;i[b+76>>2]=i[n>>2];i[b+80>>2]=i[n+4>>2];i[b+84>>2]=i[n+8>>2];d=a+1074308|0;kb(p+8|0,d,83);if(!(!ib(p+8|0)|i[b+80>>2])){i[b+84>>2]=i[n>>2]}i[b+88>>2]=i[b+88>>2]|k[n+34>>1]&1023;kb(p+8|0,d,21);if(ib(p+8|0)){g[b+838|0]=0;i[b+780>>2]=0}c=b;Q:{R:{if(x){i[b+704>>2]=i[n+24>>2];g[b+872|0]=j[b+872|0]|8;e=0;break R}if(i[a+480180>>2]&5?!(t|v):0){break Q}i[b+704>>2]=i[n+24>>2];e=g[n+37|0]}i[c+768>>2]=e}i[b+772>>2]=g[n+36|0];kb(p+8|0,d,69);if(!(ib(p+8|0)|i[a+480180>>2]==1)){i[b+708>>2]=0}i[b+876>>2]=0;m=i[b+88>>2];if(m&8){i[b+80>>2]=i[n+12>>2];i[b+84>>2]=i[n+16>>2];if(m&16){m=m|4;i[b+88>>2]=m}m=m|2;i[b+88>>2]=m}S:{if(!(m&2)){m=i[b+76>>2];break S}c=i[b+84>>2];m=i[b+76>>2];if(c>>>0>=m>>>0){break S}i[b+76>>2]=c;m=c}if(!(i[a+480180>>2]&16777248)|m>>>0>l[b+4>>2]){break a}i[b>>2]=0;i[b+4>>2]=0}Xa=p+16|0}function R2(a,b,c){var d=0,e=0,f=0,k=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=p(0),F=0;f=Xa-304|0;Xa=f;e=j[b|0];a:{if(!e){break a}b:{c:{d:{while(1){e:{f:{if(Yl(e&255)){while(1){e=b;b=b+1|0;if(Yl(j[e+1|0])){continue}break}Gg(a,0,0);while(1){b=i[a+4>>2];g:{if(b>>>0<l[a+104>>2]){i[a+4>>2]=b+1;b=j[b|0];break g}b=Hc(a)}if(Yl(b)){continue}break}b=i[a+4>>2];if(i[a+104>>2]){b=b+ -1|0;i[a+4>>2]=b}d=b-i[a+8>>2]|0;b=d;d=d>>31;k=b;r=r+i[a+124>>2]|0;b=v+i[a+120>>2]|0;if(b>>>0<v>>>0){r=r+1|0}v=k+b|0;r=d+r|0;r=v>>>0<b>>>0?r+1|0:r;break f}h:{i:{j:{e=j[b|0];if((e|0)==37){d=j[b+1|0];if((d|0)==42){break j}if((d|0)!=37){break i}}Gg(a,0,0);e=((e|0)==37)+b|0;b=i[a+4>>2];k:{if(b>>>0<l[a+104>>2]){i[a+4>>2]=b+1;b=j[b|0];break k}b=Hc(a)}if((b|0)!=j[e|0]){if(i[a+104>>2]){i[a+4>>2]=i[a+4>>2]+ -1}A=0;if((b|0)>=0){break a}break c}b=v+1|0;if(b>>>0<1){r=r+1|0}v=b;break f}t=0;e=b+2|0;break h}if(!(!Hg(d)|j[b+2|0]!=36)){t=P2(c,j[b+1|0]+ -48|0);e=b+3|0;break h}t=i[c>>2];c=c+4|0;e=b+1|0}A=0;b=0;if(Hg(j[e|0])){while(1){b=(j[e|0]+o(b,10)|0)+ -48|0;d=j[e+1|0];e=e+1|0;if(Hg(d)){continue}break}}d=e;k=j[d|0];l:{if((k|0)!=109){break l}u=0;A=(t|0)!=0;k=j[e+1|0];w=0;d=e+1|0}e=d+1|0;s=3;m:{n:{switch(k+ -65|0){case 39:k=d+2|0;d=j[d+1|0]==104;e=d?k:e;s=d?-2:-1;break m;case 43:k=d+2|0;d=j[d+1|0]==108;e=d?k:e;s=d?3:1;break m;case 51:case 57:s=1;break m;case 11:s=2;break m;case 41:break m;case 0:case 2:case 4:case 5:case 6:case 18:case 23:case 26:case 32:case 34:case 35:case 36:case 37:case 38:case 40:case 45:case 46:case 47:case 50:case 52:case 55:break n;default:break c}}s=0;e=d}k=j[e|0];d=(k&47)==3;z=d?1:s;x=d?k|32:k;o:{if((x|0)==91){break o}p:{if((x|0)!=110){if((x|0)!=99){break p}b=(b|0)>1?b:1;break o}CD(t,z,v,r);break f}Gg(a,0,0);while(1){d=i[a+4>>2];q:{if(d>>>0<l[a+104>>2]){i[a+4>>2]=d+1;d=j[d|0];break q}d=Hc(a)}if(Yl(d)){continue}break}d=i[a+4>>2];if(i[a+104>>2]){d=d+ -1|0;i[a+4>>2]=d}d=d-i[a+8>>2]|0;k=d;d=d>>31;q=k;k=r+i[a+124>>2]|0;r=v+i[a+120>>2]|0;if(r>>>0<v>>>0){k=k+1|0}v=q+r|0;d=d+k|0;d=v>>>0<r>>>0?d+1|0:d;r=d}k=b;C=b>>31;Gg(a,b,C);q=i[a+4>>2];d=i[a+104>>2];r:{if(q>>>0<d>>>0){i[a+4>>2]=q+1;break r}if((Hc(a)|0)<0){break c}d=i[a+104>>2]}if(d){i[a+4>>2]=i[a+4>>2]+ -1}d=16;s:{t:{u:{v:{w:{x:{y:{switch(x+ -88|0){default:b=x+ -65|0;if(b>>>0>6|!(1<<b&113)){break s};case 9:case 13:case 14:case 15:GD(f,a,z,0);d=i[a+4>>2]-i[a+8>>2]|0;if(i[a+120>>2]==(0-d|0)&i[a+124>>2]==(0-((d>>31)+(0<d>>>0)|0)|0)){break b}if(!t){break s}q=i[f+8>>2];k=i[f+12>>2];d=i[f>>2];b=i[f+4>>2];switch(z|0){case 2:break u;case 1:break v;case 0:break w;default:break s};case 3:case 11:case 27:if((x&239)==99){yb(f+32|0,-1,257);g[f+32|0]=0;if((x|0)!=115){break t}g[f+65|0]=0;g[f+46|0]=0;h[f+42>>1]=0;h[f+44>>1]=0;break t}y=j[e+1|0];q=(y|0)==94;yb(f+32|0,q,257);g[f+32|0]=0;d=q?e+2|0:e+1|0;z:{A:{B:{e=j[(q?2:1)+e|0];if((e|0)!=45){if((e|0)==93){break B}s=(y|0)!=94;break z}s=(y|0)!=94;g[f+78|0]=s;break A}s=(y|0)!=94;g[f+126|0]=s}d=d+1|0}e=d;while(1){d=j[e|0];C:{if((d|0)!=45){if(!d){break c}if((d|0)!=93){break C}break t}d=45;y=j[e+1|0];if(!y|(y|0)==93){break C}q=e+1|0;e=j[e+ -1|0];D:{if(e>>>0>=y>>>0){d=y;break D}while(1){e=e+1|0;g[e+(f+32|0)|0]=s;d=j[q|0];if(e>>>0<d>>>0){continue}break}}e=q}g[(d+f|0)+33|0]=s;e=e+1|0;continue};case 23:d=8;break x;case 12:case 29:d=10;break x;case 1:case 2:case 4:case 5:case 6:case 7:case 8:case 10:case 16:case 18:case 19:case 20:case 21:case 22:case 25:case 26:case 28:case 30:case 31:break s;case 0:case 24:case 32:break x;case 17:break y}}d=0}q=ED(a,d,0,-1,-1);k=_a;d=i[a+4>>2]-i[a+8>>2]|0;if(i[a+120>>2]==(0-d|0)&i[a+124>>2]==(0-((d>>31)+(0<d>>>0)|0)|0)){break b}if(!(!t|(x|0)!=112)){i[t>>2]=q;break s}CD(t,z,q,k);break s}D=t,E=DD(d,b,q,k),m[D>>2]=E;break s}D=t,F=nv(d,b,q,k),n[D>>3]=F;break s}i[t>>2]=d;i[t+4>>2]=b;i[t+8>>2]=q;i[t+12>>2]=k;break s}x=(x|0)==99;s=x?b+1|0:31;y=(z|0)!=1;E:{if(!y){d=t;if(A){d=Zc(s<<2);if(!d){break d}}i[f+296>>2]=0;i[f+300>>2]=0;b=0;u=(A|0)!=0;while(1){w=d;F:{while(1){d=i[a+4>>2];G:{if(d>>>0<l[a+104>>2]){i[a+4>>2]=d+1;d=j[d|0];break G}d=Hc(a)}if(!j[(d+f|0)+33|0]){break F}g[f+27|0]=d;d=Qn(f+28|0,f+27|0,1,f+296|0);if((d|0)==-2){continue}if((d|0)==-1){break e}if(w){i[(b<<2)+w>>2]=i[f+28>>2];b=b+1|0}if(u^1|(b|0)!=(s|0)){continue}break}s=s<<1|1;d=dq(w,s<<2);if(d){continue}break e}break}d=f+296|0;q=1;H:{if(!d){break H}q=!i[d>>2]}if(!q){break e}u=0;break E}if(A){b=0;d=Zc(s);if(!d){break d}while(1){u=d;while(1){d=i[a+4>>2];I:{if(d>>>0<l[a+104>>2]){i[a+4>>2]=d+1;d=j[d|0];break I}d=Hc(a)}if(!j[(d+f|0)+33|0]){w=0;break E}g[b+u|0]=d;b=b+1|0;if((s|0)!=(b|0)){continue}break}w=0;s=s<<1|1;d=dq(u,s);if(d){continue}break}break c}b=0;if(t){while(1){d=i[a+4>>2];J:{if(d>>>0<l[a+104>>2]){i[a+4>>2]=d+1;d=j[d|0];break J}d=Hc(a)}if(j[(d+f|0)+33|0]){g[b+t|0]=d;b=b+1|0;continue}else{w=0;u=t;break E}}}while(1){b=i[a+4>>2];K:{if(b>>>0<l[a+104>>2]){i[a+4>>2]=b+1;b=j[b|0];break K}b=Hc(a)}if(j[(b+f|0)+33|0]){continue}break}u=0;w=0;b=0}d=i[a+4>>2];if(i[a+104>>2]){d=d+ -1|0;i[a+4>>2]=d}d=d-i[a+8>>2]|0;q=d;z=d+i[a+120>>2]|0;d=i[a+124>>2]+(d>>31)|0;d=z>>>0<q>>>0?d+1|0:d;q=z;if(!(d|q)|(x?(k|0)!=(q|0)|(d|0)!=(C|0):0)){break b}L:{if(!A){break L}if(!y){i[t>>2]=w;break L}i[t>>2]=u}if(x){break s}if(w){i[(b<<2)+w>>2]=0}if(!u){u=0;break s}g[b+u|0]=0}d=i[a+4>>2]-i[a+8>>2]|0;b=d;d=d>>31;k=b;r=r+i[a+124>>2]|0;b=v+i[a+120>>2]|0;if(b>>>0<v>>>0){r=r+1|0}v=k+b|0;r=d+r|0;r=v>>>0<b>>>0?r+1|0:r;B=((t|0)!=0)+B|0}b=e+1|0;e=j[e+1|0];if(e){continue}break a}break}u=0;break c}u=0;w=0}B=B?B:-1}if(!A){break a}Cb(u);Cb(w)}Xa=f+304|0;return B}function J4(a,b,c,d,e,f){a=a|0;b=+b;c=c|0;d=d|0;e=e|0;f=f|0;var h=0,k=0,l=0,m=0,n=0,p=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0;p=Xa-560|0;Xa=p;i[p+44>>2]=0;gNa(+b);h=dNa(1)|0;dNa(0)|0;a:{if((h|0)<-1?1:(h|0)<=-1){B=1;b=-b;gNa(+b);h=dNa(1)|0;dNa(0)|0;w=55600;break a}B=1;w=55603;if(e&2048){break a}w=55606;if(e&1){break a}B=0;A=1;w=55601}b:{if((h&2146435072)==2146435072){n=B+3|0;lf(a,32,c,n,e&-65537);ue(a,w,B);d=f&32;ue(a,b!=b?d?55627:55631:d?55619:55623,3);break b}x=p+16|0;c:{d:{e:{b=FE(b,p+44|0);b=b+b;if(b!=0){h=i[p+44>>2];i[p+44>>2]=h+ -1;C=f|32;if((C|0)!=97){break e}break c}C=f|32;if((C|0)==97){break c}n=i[p+44>>2];r=(d|0)<0?6:d;break d}n=h+ -29|0;i[p+44>>2]=n;b=b*268435456;r=(d|0)<0?6:d}t=(n|0)<0?p+48|0:p+336|0;m=t;while(1){d=m;if(b<4294967296&b>=0){h=~~b>>>0}else{h=0}i[d>>2]=h;m=m+4|0;b=(b- +(h>>>0))*1e9;if(b!=0){continue}break}f:{if((n|0)<1){d=n;h=m;k=t;break f}k=t;d=n;while(1){s=(d|0)<29?d:29;h=m+ -4|0;g:{if(h>>>0<k>>>0){break g}d=s;l=0;while(1){v=h;D=l;E=i[h>>2];u=d&31;if(32<=(d&63)>>>0){l=E<<u;E=0}else{l=(1<<u)-1&E>>>32-u;E=E<<u}u=D+E|0;l=l+F|0;l=u>>>0<E>>>0?l+1|0:l;l=_Ma(u,l,1e9,0);D=v;v=XMa(l,_a,1e9,0);i[D>>2]=u-v;h=h+ -4|0;if(h>>>0>=k>>>0){continue}break}if(!l){break g}k=k+ -4|0;i[k>>2]=l}while(1){h=m;if(h>>>0>k>>>0){m=h+ -4|0;if(!i[m>>2]){continue}}break}d=i[p+44>>2]-s|0;i[p+44>>2]=d;m=h;if((d|0)>0){continue}break}}if((d|0)<=-1){y=((r+25|0)/9|0)+1|0;s=(C|0)==102;while(1){l=(d|0)<-9?9:0-d|0;h:{if(k>>>0>=h>>>0){k=i[k>>2]?k:k+4|0;break h}v=1e9>>>l|0;u=-1<<l^-1;d=0;m=k;while(1){D=d;d=i[m>>2];i[m>>2]=D+(d>>>l|0);d=o(v,d&u);m=m+4|0;if(m>>>0<h>>>0){continue}break}k=i[k>>2]?k:k+4|0;if(!d){break h}i[h>>2]=d;h=h+4|0}d=i[p+44>>2]+l|0;i[p+44>>2]=d;m=s?t:k;h=h-m>>2>(y|0)?m+(y<<2)|0:h;if((d|0)<0){continue}break}}m=0;i:{if(k>>>0>=h>>>0){break i}m=o(t-k>>2,9);d=10;l=i[k>>2];if(l>>>0<10){break i}while(1){m=m+1|0;d=o(d,10);if(l>>>0>=d>>>0){continue}break}}d=(r-((C|0)==102?0:m)|0)-((C|0)==103&(r|0)!=0)|0;if((d|0)<(o(h-t>>2,9)+ -9|0)){l=d+9216|0;s=(l|0)/9|0;n=((s<<2)+((n|0)<0?p+48|4:p+340|0)|0)+ -4096|0;d=10;l=l-o(s,9)|0;if((l|0)<=7){while(1){d=o(d,10);l=l+1|0;if((l|0)!=8){continue}break}}s=i[n>>2];v=(s>>>0)/(d>>>0)|0;y=n+4|0;l=s-o(d,v)|0;j:{if(l?0:(y|0)==(h|0)){break j}u=d>>>1|0;z=l>>>0<u>>>0?.5:(h|0)==(y|0)?(u|0)==(l|0)?1:1.5:1.5;b=v&1?9007199254740994:9007199254740992;if(!(j[w|0]!=45|A)){z=-z;b=-b}l=s-l|0;i[n>>2]=l;if(b+z==b){break j}d=d+l|0;i[n>>2]=d;if(d>>>0>=1e9){while(1){i[n>>2]=0;n=n+ -4|0;if(n>>>0<k>>>0){k=k+ -4|0;i[k>>2]=0}d=i[n>>2]+1|0;i[n>>2]=d;if(d>>>0>999999999){continue}break}}m=o(t-k>>2,9);d=10;l=i[k>>2];if(l>>>0<10){break j}while(1){m=m+1|0;d=o(d,10);if(l>>>0>=d>>>0){continue}break}}d=n+4|0;h=h>>>0>d>>>0?d:h}while(1){d=h;n=h>>>0<=k>>>0;if(!n){h=d+ -4|0;if(!i[h>>2]){continue}}break}k:{if((C|0)!=103){A=e&8;break k}h=r?r:1;l=(h|0)>(m|0)&(m|0)>-5;r=(l?m^-1:-1)+h|0;f=(l?-1:-2)+f|0;A=e&8;if(A){break k}h=-9;l:{if(n){break l}s=i[d+ -4>>2];if(!s){break l}l=10;h=0;if((s>>>0)%10|0){break l}while(1){n=h;h=h+1|0;l=o(l,10);if(!((s>>>0)%(l>>>0)|0)){continue}break}h=n^-1}n=o(d-t>>2,9);if((f&-33)==70){A=0;h=(h+n|0)+ -9|0;h=(h|0)>0?h:0;r=(r|0)<(h|0)?r:h;break k}A=0;h=((m+n|0)+h|0)+ -9|0;h=(h|0)>0?h:0;r=(r|0)<(h|0)?r:h}s=r|A;v=(s|0)!=0;D=a;l=c;u=f&-33;h=(m|0)>0?m:0;m:{if((u|0)==70){break m}h=m>>31;h=dm(h+m^h,0,x);if((x-h|0)<=1){while(1){h=h+ -1|0;g[h|0]=48;if((x-h|0)<2){continue}break}}y=h+ -2|0;g[y|0]=f;g[h+ -1|0]=(m|0)<0?45:43;h=x-y|0}n=(h+(v+(r+B|0)|0)|0)+1|0;lf(D,32,l,n,e);ue(a,w,B);lf(a,48,c,n,e^65536);n:{o:{p:{if((u|0)==70){f=p+16|8;m=p+16|9;l=k>>>0>t>>>0?t:k;k=l;while(1){h=dm(i[k>>2],0,m);q:{if((k|0)!=(l|0)){if(h>>>0<=p+16>>>0){break q}while(1){h=h+ -1|0;g[h|0]=48;if(h>>>0>p+16>>>0){continue}break}break q}if((h|0)!=(m|0)){break q}g[p+24|0]=48;h=f}ue(a,h,m-h|0);k=k+4|0;if(k>>>0<=t>>>0){continue}break}if(s){ue(a,55635,1)}if((r|0)<1|k>>>0>=d>>>0){break p}while(1){h=dm(i[k>>2],0,m);if(h>>>0>p+16>>>0){while(1){h=h+ -1|0;g[h|0]=48;if(h>>>0>p+16>>>0){continue}break}}ue(a,h,(r|0)<9?r:9);h=r+ -9|0;k=k+4|0;if(k>>>0>=d>>>0){break o}f=(r|0)>9;r=h;if(f){continue}break}break o}r:{if((r|0)<0){break r}t=d>>>0>k>>>0?d:k+4|0;d=p+16|8;f=p+16|9;m=k;while(1){h=dm(i[m>>2],0,f);if((f|0)==(h|0)){g[p+24|0]=48;h=d}s:{if((k|0)!=(m|0)){if(h>>>0<=p+16>>>0){break s}while(1){h=h+ -1|0;g[h|0]=48;if(h>>>0>p+16>>>0){continue}break}break s}ue(a,h,1);h=h+1|0;if((r|0)<1?!A:0){break s}ue(a,55635,1)}v=h;h=f-h|0;ue(a,v,(r|0)>(h|0)?h:r);r=r-h|0;m=m+4|0;if(m>>>0>=t>>>0){break r}if((r|0)>-1){continue}break}}lf(a,48,r+18|0,18,0);ue(a,y,x-y|0);break n}h=r}lf(a,48,h+9|0,9,0)}break b}n=f&32;r=n?w+9|0:w;t:{if(d>>>0>11){break t}h=12-d|0;if(!h){break t}z=8;while(1){z=z*16;h=h+ -1|0;if(h){continue}break}if(j[r|0]==45){b=-(z+(-b-z));break t}b=b+z-z}k=i[p+44>>2];h=k>>31;h=dm(h^h+k,0,x);if((x|0)==(h|0)){g[p+15|0]=48;h=p+15|0}t=B|2;k=i[p+44>>2];m=h+ -2|0;g[m|0]=f+15;g[h+ -1|0]=(k|0)<0?45:43;l=e&8;k=p+16|0;while(1){f=k;v=k;k=n;if(q(b)<2147483648){h=~~b}else{h=-2147483648}g[v|0]=k|j[h+55584|0];k=f+1|0;b=(b- +(h|0))*16;if(!((k-(p+16|0)|0)!=1|(b==0?!(l|(d|0)>0):0))){g[f+1|0]=46;k=f+2|0}if(b!=0){continue}break}d=!d|((k-p|0)+ -18|0)>=(d|0)?((x-(p+16|0)|0)-m|0)+k|0:((d+x|0)-m|0)+2|0;n=d+t|0;lf(a,32,c,n,e);ue(a,r,t);lf(a,48,c,n,e^65536);f=k-(p+16|0)|0;ue(a,p+16|0,f);h=d;d=x-m|0;lf(a,48,h-(d+f|0)|0,0,0);ue(a,m,d)}lf(a,32,c,n,e^8192);Xa=p+560|0;return((n|0)<(c|0)?c:n)|0}function xla(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,h=0,m=0,n=0,p=0,q=0,r=0;e=Xa-48|0;Xa=e;d=a+1074304|0;if(!(i[d>>2]==18284544|l[a+1074304>>2]>=18285126)){ng(a+1074308|0,0)}f=a+1074308|0;kb(e+32|0,f,0);if(ib(e+32|0)){m=(i[a+480180>>2]&16777248)!=0}kb(e+32|0,f,0);if(ib(e+32|0)){p=i[a+480180>>2]==4}if(l[d>>2]<18874368){a:{if(!k[a+480192>>1]){break a}c=1;while(1){b:{b=i[(((c&65535)<<2)+a|0)+900380>>2];if(!b){break b}i[e+32>>2]=o(j[b+20|0],100)>>>6;i[e+16>>2]=100;q=b,r=i[rb(e+32|0,e+16|0)>>2],g[q+20|0]=r;c:{d:{if(m){if(l[d>>2]<18350080){h=g[b+26|0];g[b+26|0]=(((h|0)>-1?1:-1)+h|0)/2}if(l[d>>2]<18285314){break d}break c}h=g[b+26|0];g[b+26|0]=(((h|0)>-1?1:-1)+h|0)/2}uM(xt(b,2),4,i[a+480180>>2])}e:{if(!j[b+34|0]|(l[d>>2]<18284544|l[d>>2]>=18285136)){break e}if(!Xh(b)){break e}tb(f,2,1)}if(!(j[b+24|0]|(j[b+23|0]|(j[b+19|0]|j[b+20|0])))|l[d>>2]>=18285136){break b}tb(f,1,1);break a}c=c+1|0;if((c&65535)>>>0<=k[a+480192>>1]){continue}break}}f:{if(!(i[a+480180>>2]&16777248)){break f}b=1;if(!k[a+480190>>1]|(m^1?0:l[d>>2]>=18285314)){break f}while(1){c=o(b&65535,104)+a|0;h=c+484419|0;if(!(j[h|0]|!(j[c+484421|0]|j[c+484420|0]))){g[h|0]=255}b=b+1|0;if((b&65535)>>>0<=k[a+480190>>1]){continue}break}}uwa(a+901404|0)}g:{if(i[d>>2]==18874368|l[d>>2]>=18874896|(!(i[a+480180>>2]&16777252)|!k[a+480192>>1])){break g}b=1;c=0;while(1){h:{h=i[(((b&65535)<<2)+a|0)+900380>>2];if(!(j[h+31|0]?h:0)){b=b+1|0;if((b&65535)>>>0<=k[a+480192>>1]){continue}if(c){break h}break g}g[h+33|0]=13;c=1;b=b+1|0;if((b&65535)>>>0<=k[a+480192>>1]){continue}}break}tb(f,3,1)}i:{if(!(i[a+480180>>2]&16777248)|(i[d>>2]==19005440|l[d>>2]>=19006226)){break i}kb(e+32|0,f,0);if(!ib(e+32|0)){kb(e+16|0,f,1);if(!ib(e+16|0)){break i}}if(!k[a+480192>>1]){break i}b=1;while(1){c=i[(((b&65535)<<2)+a|0)+900380>>2];if(!(!c|!j[c+19|0]|!(g[c+80|0]&1))){g[c+19|0]=0}b=b+1|0;if((b&65535)>>>0<=k[a+480192>>1]){continue}break}}j:{k:{l:{if(l[d>>2]<19007233){c=a+946300|0;b=a+906300|0;while(1){h=b+80|0;wla(e+16|0,h);i[114610]=0;J(438,e+32|0,0,7,e+16|0);n=i[114610];i[114610]=0;if((n|0)==1){break k}eb(e+16|0);i[114610]=0;C(507,h|0,e+32|0)|0;h=i[114610];i[114610]=0;if((h|0)==1){break l}eb(e+32|0);b=b+160|0;if((c|0)!=(b|0)){continue}break}}if(!(i[a+480180>>2]!=4|l[d>>2]<19007257|(i[a+1074368>>2]!=4|l[d>>2]>=19071236))){dx(a,5)}if(!(!k[a+480192>>1]|(i[d>>2]==19202048|l[d>>2]>=19202055))){c=1;while(1){n=(((c&65535)<<2)+a|0)+900380|0;b=i[n>>2];m:{if(!b|!j[b+20|0]|!j[b+31|0]){break m}b=b+236|0;h=ms(b);if((b|0)!=(h|0)){while(1){if(k[b>>1]){break m}b=b+2|0;if((h|0)!=(b|0)){continue}break}}g[i[n>>2]+20|0]=0}c=c+1|0;if((c&65535)>>>0<=k[a+480192>>1]){continue}break}}if(!(!k[a+480192>>1]|l[d>>2]>=19267584)){c=1;while(1){b=i[(((c&65535)<<2)+a|0)+900380>>2];n:{if(!b){break n}h=g[b+26|0];g[b+26|0]=(((h|0)>-1?1:-1)+h|0)/2;if(l[d>>2]>=18350080?m:0){break n}g[b+19|0]=j[b+19|0]+3>>>2}c=c+1|0;if((c&65535)>>>0<=k[a+480192>>1]){continue}break}}o:{if(!k[a+480192>>1]|l[d>>2]>=19398674){break o}b=1;while(1){c=i[(((b&65535)<<2)+a|0)+900380>>2];if(!(!c|j[c+65|0]==255)){tb(f,94,1);break o}b=b+1|0;if((b&65535)>>>0<=k[a+480192>>1]){continue}break}}p:{if(!k[a+480192>>1]|l[d>>2]>=19399428){break p}b=1;while(1){c=i[(((b&65535)<<2)+a|0)+900380>>2];if(!(!c|j[c+36|0]>1)){tb(f,101,1);break p}b=b+1|0;if((b&65535)>>>0<=k[a+480192>>1]){continue}break}}b=vla(e+8|0,a);c=i[b+4>>2];i[e>>2]=i[b>>2];i[e+4>>2]=c;ula(e+32|0,a+484344|0,e);q:{r:{if(!m){break r}b=i[d>>2];if(b>>>0>=19267584){break r}tb(f,8,(b|0)==18284544|b>>>0>18285313);b=30888;while(1){c=i[d>>2];m=i[b+4>>2];tb(f,i[b>>2],c>>>0>=m>>>0|(c|0)==(m&-65536));b=b+8|0;if((b|0)!=31224){continue}break}break q}if(!p){break q}b=i[d>>2];if(b>>>0>=19267584){break q}tb(f,8,b>>>0>18285313);b=31240;while(1){tb(f,i[b>>2],l[d>>2]>=l[b+4>>2]);b=b+8|0;if((b|0)!=31472){continue}break}}s:{if(i[a+480180>>2]&16777248){b=31472;while(1){c=i[d>>2];m=i[b+4>>2];h=m&-65536;if(!(c>>>0<=h>>>0|c>>>0>=m>>>0?c>>>0>=h>>>0:0)){ng(f,i[b>>2])}b=b+8|0;if((b|0)!=31520){continue}break}break s}if(i[a+480180>>2]==4){b=31520;while(1){if(l[d>>2]<l[b+4>>2]){ng(f,i[b>>2])}b=b+8|0;if((b|0)!=31576){continue}break}break s}if(i[a+480180>>2]!=2){break s}b=31584;while(1){if(l[d>>2]<l[b+4>>2]){ng(f,i[b>>2])}b=b+8|0;if((b|0)!=31664){continue}break}}if(!(i[a+480180>>2]!=4|l[d>>2]>=18415616)){tb(f,98,1)}if(!(l[d>>2]<19333159|l[d>>2]>=19333193)){b=0;while(1){c=b+77|0;kb(e+32|0,f,c);tb(f,b+86|0,ib(e+32|0));ng(f,c);b=b+1|0;if((b|0)!=5){continue}break}}t:{if(l[d>>2]<18284544){tb(f,8,1);break t}if(l[d>>2]<18284544|l[d>>2]>18874627|i[d>>2]==18874368){break t}tb(f,6,1)}u:{if(l[d>>2]<19136512){ng(f,7);break u}if(!(i[a+480180>>2]&16777248)|(l[d>>2]<19136512|l[d>>2]>=19267584)){break u}tb(f,7,1)}kb(e+32|0,f,31);v:{if(!ib(e+32|0)|l[d>>2]<19071234|(!k[a+480192>>1]|l[d>>2]>=19398723)){break v}b=1;while(1){w:{c=i[(((b&65535)<<2)+a|0)+900380>>2];if(!c){break w}m=j[c+65|0];if(!(j[c+60|0]&4)|(m|0)==255|m>>>0<=j[c- -64|0]){break w}tb(f,97,1);break v}b=b+1|0;if((b&65535)>>>0<=k[a+480192>>1]){continue}break}}x:{if(!k[a+480192>>1]|i[a+480180>>2]!=16777216|(l[d>>2]<19398688|l[d>>2]>19485952)){break x}if(!k[a+480190>>1]){break x}b=1;while(1){if(!(j[(o(b&65535,104)+a|0)+484415|0]&2)){b=b+1|0;if((b&65535)>>>0<=k[a+480190>>1]){continue}break x}break}tb(f,109,1)}Xa=e+48|0;return}a=B()|0;A()|0;eb(e+32|0);break j}a=B()|0;A()|0;eb(e+16|0)}E(a|0);x()}function uBa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,l=0,m=0,n=0,p=0,q=0;d=Xa-224|0;Xa=d;pc(b);a:{b:{c:{d:{e:{f:{if(!Xs(b,d+208|0)){break f}if(!zO(d+208|0)){break f}m=wh(d+192|0);n=Oc(d+176|0);yb(d+112|0,0,64);i[114610]=0;f=C(890,b|0,d+104|0)|0;e=i[114610];i[114610]=0;if((e|0)==1){break c}g:{if(!f){break g}f=d+104|4;l=j[f|0]|j[f+1|0]<<8|(j[f+2|0]<<16|j[f+3|0]<<24);l=(l<<8&16711680|l<<24|(l>>>8&65280|l>>>24))+ -4|0;l=l<<24|l<<8&16711680|(l>>>8&65280|l>>>24);g[f|0]=l;g[f+1|0]=l>>>8;g[f+2|0]=l>>>16;g[f+3|0]=l>>>24;l=0;h:{i:{j:{while(1){e=j[f|0]|j[f+1|0]<<8|(j[f+2|0]<<16|j[f+3|0]<<24);e=(e<<8&16711680|e<<24|(e>>>8&65280|e>>>24))+ -8|0;e=e<<24|e<<8&16711680|(e>>>8&65280|e>>>24);g[f|0]=e;g[f+1|0]=e>>>8;g[f+2|0]=e>>>16;g[f+3|0]=e>>>24;k:{if(c){break k}e=d+104|0;if((j[e|0]|j[e+1|0]<<8|(j[e+2|0]<<16|j[e+3|0]<<24))!=1413764176){break k}l=1;break g}e=j[f|0]|j[f+1|0]<<8|(j[f+2|0]<<16|j[f+3|0]<<24);i[114610]=0;G(341,d+24|0,b|0,e<<8&16711680|e<<24|(e>>>8&65280|e>>>24));e=i[114610];i[114610]=0;l:{m:{n:{o:{p:{if((e|0)!=1){i[114610]=0;e=F(337,d+24|0)|0;p=i[114610];i[114610]=0;if((p|0)==1){break o}if(e){break p}hb(d+24|0);break l}a=B()|0;A()|0;break a}e=d+104|0;e=j[e|0]|j[e+1|0]<<8|(j[e+2|0]<<16|j[e+3|0]<<24);e=e<<24|e<<8&16711680|(e>>>8&65280|e>>>24);if((e|0)<=1347699795){if((e|0)==1129139796){break n}if((e|0)!=1229866575){break m}i[114610]=0;q=C(891,d+24|0,d+112|0)|0;e=i[114610];i[114610]=0;if((e|0)==1){break o}break m}if((e|0)!=1347699796){if((e|0)!=1447383635){break m}i[114610]=0;C(338,d+24|0,4)|0;e=i[114610];i[114610]=0;if((e|0)==1){break o}i[114610]=0;e=C(892,d+24|0,16103)|0;p=i[114610];i[114610]=0;if((p|0)==1){break o}if(!e){break m}e=j[f|0]|j[f+1|0]<<8|(j[f+2|0]<<16|j[f+3|0]<<24);if((e<<24|e<<8&16711680|(e>>>8&65280|e>>>24))>>>0<7){break m}e=j[f|0]|j[f+1|0]<<8|(j[f+2|0]<<16|j[f+3|0]<<24);i[114610]=0;N(893,d+24|0,n|0,2,(e<<8&16711680|e<<24|(e>>>8&65280|e>>>24))+ -6|0)|0;e=i[114610];i[114610]=0;if((e|0)==1){break o}break m}i[114610]=0;l=I(894,a|0,d+24|0,c|0)|0;e=i[114610];i[114610]=0;if((e|0)!=1){break m}}a=B()|0;A()|0;hb(d+24|0);break a}xO(m,d+24|0)}hb(d+24|0);i[114610]=0;e=C(890,b|0,d+104|0)|0;p=i[114610];i[114610]=0;if((p|0)==1){break j}if(e){continue}}break}if(Cc(n)){i[114610]=0;b=C(2,d+24|0,16106)|0;c=i[114610];i[114610]=0;if((c|0)==1){break i}mb(n,b);eb(b)}if(!(l&q&1)){break h}b=d+154|0;b=j[b|0]|j[b+1|0]<<8;i[114610]=0;f=b&1;I(478,a+1074308|0,5,!f|0)|0;b=i[114610];i[114610]=0;q:{r:{s:{if((b|0)!=1){b=d+150|0;if(j[b|0]|j[b+1|0]<<8){h[d+24>>1]=64;b=j[b|0]|j[b+1|0]<<8;i[114610]=0;h[d+88>>1]=(b<<8&16711680|b<<24)>>>16;b=C(477,d+24|0,d+88|0)|0;c=i[114610];i[114610]=0;if((c|0)==1){break s}i[a+480228>>2]=k[b>>1]}b=d+152|0;if(!(!f|!(j[b|0]|j[b+1|0]<<8))){b=j[b|0]|j[b+1|0]<<8;i[a+480204>>2]=o((b<<24|b<<8&16711680)>>>16|0,1e4)}if(j[d+112|0]){i[114610]=0;G(748,d+88|0,2,d+112|0);b=i[114610];i[114610]=0;if((b|0)==1){break r}i[114610]=0;D(415,d+24|0,d+88|0);b=i[114610];i[114610]=0;if((b|0)==1){break r}mb(a+1304400|0,d+24|0);eb(d+24|0)}b=k[d+158>>1];h[d+86>>1]=b;h[d+22>>1]=b;if(!Vo(d+22|0,1,12)){break h}b=k[d+156>>1];h[d+84>>1]=b;h[d+20>>1]=b;if(!Vo(d+20|0,1,31)){break h}b=k[d+162>>1];h[d+82>>1]=b;h[d+18>>1]=b;if(!Vo(d+18|0,0,23)){break h}b=k[d+164>>1];h[d+80>>1]=b;h[d+16>>1]=b;if(!Vo(d+16|0,0,59)){break h}b=k[d+166>>1];h[d+78>>1]=b;h[d+14>>1]=b;if(Vo(d+14|0,0,59)){break q}break h}a=B()|0;A()|0;break a}a=B()|0;A()|0;break a}a=B()|0;A()|0;break a}b=mp(d+24|0);c=d+160|0;c=j[c|0]|j[c+1|0]<<8;i[b+20>>2]=(c<<24|c<<8&16711680)>>>16;c=d+158|0;c=j[c|0]|j[c+1|0]<<8;i[b+16>>2]=((c<<24|c<<8&16711680)>>>16|0)+ -1;c=d+156|0;c=j[c|0]|j[c+1|0]<<8;i[b+12>>2]=(c<<24|c<<8&16711680)>>>16;c=d+162|0;c=j[c|0]|j[c+1|0]<<8;i[b+8>>2]=(c<<24|c<<8&16711680)>>>16;c=d+164|0;c=j[c|0]|j[c+1|0]<<8;i[b+4>>2]=(c<<24|c<<8&16711680)>>>16;c=d+166|0;c=j[c|0]|j[c+1|0]<<8;i[b>>2]=(c<<24|c<<8&16711680)>>>16;i[114610]=0;D(666,a+1304500|0,b|0);b=i[114610];i[114610]=0;if((b|0)!=1){break h}a=B()|0;A()|0;break a}a=B()|0;A()|0;break a}a=B()|0;A()|0;break a}if(l&1){i[114610]=0;b=F(337,m|0)|0;c=i[114610];i[114610]=0;if((c|0)==1){break c}if(b){b=Ab(d+24|0);i[114610]=0;I(481,m|0,b|0,32)|0;c=i[114610];i[114610]=0;if((c|0)==1){break b}if(Us(b,16110)){i[114610]=0;G(13,d+88|0,2,b|0);c=i[114610];i[114610]=0;if((c|0)==1){break b}mb(a+1304412|0,d+88|0);eb(d+88|0)}i[114610]=0;c=F(895,m|0)|0;f=i[114610];i[114610]=0;if((f|0)==1){break b}if(!c){i[114610]=0;c=F(548,m|0)|0;f=i[114610];i[114610]=0;if((f|0)==1){break b}i[114610]=0;S(549,a+1304424|0,m|0,c|0,40,0)|0;c=i[114610];i[114610]=0;if((c|0)==1){break b}}eb(b)}i[114610]=0;b=C(2,d+88|0,16125)|0;c=i[114610];i[114610]=0;if((c|0)==1){break e}i[114610]=0;G(723,d+24|0,b|0,n|0);c=i[114610];i[114610]=0;if((c|0)==1){break d}mb(a+1304460|0,d+24|0);eb(d+24|0);eb(b)}i[a+480208>>2]=i[a+480208>>2]|2097152;i[114610]=0;a=a+1074308|0;I(478,a|0,84,1)|0;b=i[114610];i[114610]=0;if((b|0)==1){break c}i[114610]=0;I(478,a|0,83,1)|0;b=i[114610];i[114610]=0;if((b|0)==1){break c}i[114610]=0;I(478,a|0,85,1)|0;a=i[114610];i[114610]=0;if((a|0)==1){break c}}eb(n);hb(m)}Xa=d+224|0;return l&1}a=B()|0;A()|0;break a}a=B()|0;A()|0;eb(b);break a}a=B()|0;A()|0;break a}a=B()|0;A()|0;eb(b)}eb(n);hb(m);E(a|0);x()}function sG(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,k=0,l=0;e=Xa-448|0;Xa=e;a:{if(Oi(b)){break a}g=j[Dj(b)|0];f=1;b:{if((g|0)==33){break b}if((g|0)!=63){break a}f=0}d=f;Oj(e+184|0,b,i[b+4>>2]+ -1|0);f=i[e+188>>2];i[b>>2]=i[e+184>>2];i[b+4>>2]=f}jd(e+184|0);f=i[e+184>>2];jd(e+416|0);h=Cj(f,i[e+420>>2],b);jd(e+184|0);f=i[b>>2];g=i[b+4>>2];c:{d:{e:{f:{if((h|0)==i[e+188>>2]){i[e+440>>2]=f;i[e+444>>2]=g;a=Zb(e+432|0,38187);f=i[e+444>>2];i[e+16>>2]=i[e+440>>2];i[e+20>>2]=f;f=i[a+4>>2];i[e+8>>2]=i[a>>2];i[e+12>>2]=f;if(mc(e+16|0,e+8|0)){a=P(8)|0;i[114610]=0;d=C(2142,e+416|0,c|0)|0;b=i[114610];i[114610]=0;g:{h:{i:{if((b|0)!=1){i[114610]=0;G(2119,e+184|0,39252,d|0);b=i[114610];i[114610]=0;if((b|0)==1){break i}Ub(a,e+184|0);c=0;i[114610]=0;G(2009,a|0,83568,2017);b=i[114610];i[114610]=0;if((b|0)!=1){break c}b=B()|0;A()|0;eb(e+184|0);break h}b=B()|0;A()|0;break g}b=B()|0;c=1;A()|0}eb(d);if(!c){break d}}Q(a|0);break d}if(!d){break f}d=P(8)|0;i[114610]=0;f=C(2142,e+384|0,b|0)|0;b=i[114610];i[114610]=0;a=1;j:{k:{l:{m:{n:{o:{p:{q:{r:{if((b|0)!=1){i[114610]=0;G(2119,e+400|0,39131,f|0);a=i[114610];i[114610]=0;if((a|0)==1){break r}i[114610]=0;G(2137,e+416|0,e+400|0,39267);b=i[114610];i[114610]=0;a=1;if((b|0)==1){break q}i[114610]=0;c=C(2142,e+368|0,c|0)|0;a=i[114610];i[114610]=0;if((a|0)==1){break p}i[114610]=0;G(138,e+184|0,e+416|0,c|0);b=i[114610];i[114610]=0;a=1;if((b|0)==1){break o}Ub(d,e+184|0);i[114610]=0;G(2009,d|0,83568,2017);a=i[114610];i[114610]=0;if((a|0)!=1){break c}b=B()|0;A()|0;eb(e+184|0);a=0;break n}b=B()|0;A()|0;break j}b=B()|0;a=1;A()|0;break k}b=B()|0;A()|0;break l}b=B()|0;a=1;A()|0;break m}b=B()|0;A()|0}eb(c)}eb(e+416|0)}eb(e+400|0)}eb(f)}if(!a){break d}Q(d|0);break d}i[e+360>>2]=f;i[e+364>>2]=g;d=Zb(e+352|0,38187);f=i[e+364>>2];i[e+176>>2]=i[e+360>>2];i[e+180>>2]=f;f=i[d+4>>2];i[e+168>>2]=i[d>>2];i[e+172>>2]=f;if(mc(e+176|0,e+168|0)){a=P(8)|0;i[114610]=0;d=C(2142,e+416|0,c|0)|0;b=i[114610];i[114610]=0;s:{t:{u:{if((b|0)!=1){i[114610]=0;G(2119,e+184|0,39252,d|0);b=i[114610];i[114610]=0;if((b|0)==1){break u}Ub(a,e+184|0);c=0;i[114610]=0;G(2009,a|0,83568,2017);b=i[114610];i[114610]=0;if((b|0)!=1){break c}b=B()|0;A()|0;eb(e+184|0);break t}b=B()|0;A()|0;break s}b=B()|0;c=1;A()|0}eb(d);if(!c){break d}}Q(a|0);break d}d=i[b+4>>2];i[e+344>>2]=i[b>>2];i[e+348>>2]=d;d=Zb(e+336|0,39010);f=i[e+348>>2];i[e+160>>2]=i[e+344>>2];i[e+164>>2]=f;f=i[d+4>>2];i[e+152>>2]=i[d>>2];i[e+156>>2]=f;if(mc(e+160|0,e+152|0)){b=i[c+4>>2];i[e+328>>2]=i[c>>2];i[e+332>>2]=b;b=Zb(e+320|0,39203);d=i[e+332>>2];i[e+64>>2]=i[e+328>>2];i[e+68>>2]=d;d=i[b+4>>2];i[e+56>>2]=i[b>>2];i[e+60>>2]=d;if(mc(e- -64|0,e+56|0)){i[a+52>>2]=0;break f}b=i[c+4>>2];i[e+312>>2]=i[c>>2];i[e+316>>2]=b;b=Zb(e+304|0,39211);d=i[e+316>>2];i[e+48>>2]=i[e+312>>2];i[e+52>>2]=d;d=i[b+4>>2];i[e+40>>2]=i[b>>2];i[e+44>>2]=d;if(mc(e+48|0,e+40|0)){i[a+52>>2]=1;break f}b=i[c+4>>2];i[e+296>>2]=i[c>>2];i[e+300>>2]=b;b=Zb(e+288|0,39220);d=i[e+300>>2];i[e+32>>2]=i[e+296>>2];i[e+36>>2]=d;d=i[b+4>>2];i[e+24>>2]=i[b>>2];i[e+28>>2]=d;if(mc(e+32|0,e+24|0)){i[a+52>>2]=2;break f}a=P(8)|0;i[114610]=0;d=C(2142,e+416|0,c|0)|0;b=i[114610];i[114610]=0;v:{w:{x:{if((b|0)!=1){i[114610]=0;G(2119,e+184|0,39314,d|0);b=i[114610];i[114610]=0;if((b|0)==1){break x}Ub(a,e+184|0);c=0;i[114610]=0;G(2009,a|0,83568,2017);b=i[114610];i[114610]=0;if((b|0)!=1){break c}b=B()|0;A()|0;eb(e+184|0);break w}b=B()|0;A()|0;break v}b=B()|0;c=1;A()|0}eb(d);if(!c){break d}}Q(a|0);break d}d=i[b+4>>2];i[e+280>>2]=i[b>>2];i[e+284>>2]=d;b=Zb(e+272|0,39053);d=i[e+284>>2];i[e+144>>2]=i[e+280>>2];i[e+148>>2]=d;d=i[b+4>>2];i[e+136>>2]=i[b>>2];i[e+140>>2]=d;if(!mc(e+144|0,e+136|0)){break f}b=i[c+4>>2];i[e+264>>2]=i[c>>2];i[e+268>>2]=b;b=Zb(e+256|0,39225);d=i[e+268>>2];i[e+128>>2]=i[e+264>>2];i[e+132>>2]=d;d=i[b+4>>2];i[e+120>>2]=i[b>>2];i[e+124>>2]=d;b=0;y:{if(mc(e+128|0,e+120|0)){break y}b=i[c+4>>2];i[e+248>>2]=i[c>>2];i[e+252>>2]=b;b=Zb(e+240|0,39230);d=i[e+252>>2];i[e+112>>2]=i[e+248>>2];i[e+116>>2]=d;d=i[b+4>>2];i[e+104>>2]=i[b>>2];i[e+108>>2]=d;b=1;if(mc(e+112|0,e+104|0)){break y}b=i[c+4>>2];i[e+232>>2]=i[c>>2];i[e+236>>2]=b;b=Zb(e+224|0,39236);d=i[e+236>>2];i[e+96>>2]=i[e+232>>2];i[e+100>>2]=d;d=i[b+4>>2];i[e+88>>2]=i[b>>2];i[e+92>>2]=d;b=2;if(mc(e+96|0,e+88|0)){break y}b=i[c+4>>2];i[e+216>>2]=i[c>>2];i[e+220>>2]=b;b=Zb(e+208|0,39247);c=i[e+220>>2];i[e+80>>2]=i[e+216>>2];i[e+84>>2]=c;c=i[b+4>>2];i[e+72>>2]=i[b>>2];i[e+76>>2]=c;b=3;if(mc(e+80|0,e+72|0)){break y}a=P(8)|0;i[114610]=0;c=C(85,e+184|0,39339)|0;b=i[114610];i[114610]=0;if((b|0)==1){break e}Ub(a,c);i[114610]=0;G(2009,a|0,83568,2017);a=i[114610];i[114610]=0;if((a|0)!=1){break c}b=B()|0;A()|0;eb(c);break d}i[a+56>>2]=b;b=a+24|0;if(!i[i[b>>2]+24668>>2]){break f}c=i[b>>2];d=c+24664|0;f=i[d+4>>2];i[e+200>>2]=i[d>>2];i[e+204>>2]=f;d=c+24656|0;f=i[d+4>>2];i[e+192>>2]=i[d>>2];i[e+196>>2]=f;d=i[c+24652>>2];i[e+184>>2]=i[c+24648>>2];i[e+188>>2]=d;k=e,l=ZF(i[a+56>>2]),i[k+204>>2]=l;if(!Yv(e+184|0,i[b>>2]+24648|0)){break f}Vw(i[b>>2],e+184|0)}Xa=e+448|0;return}b=B()|0;A()|0;Q(a|0)}E(b|0)}x()}function BBa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,l=0,m=0,n=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;d=Xa-1824|0;Xa=d;pc(b);f=d+1224|0;e=eBa(b,f);if(!e){sO(f)}a:{if(!e){break a}if(!CO(d+1224|0)){break a}if(!uy(b,16,0)){break a}i[d+1216>>2]=i[d+1240>>2];f=i[d+1228>>2];i[d+1200>>2]=i[d+1224>>2];i[d+1204>>2]=f;f=d+1232|0;e=i[f+4>>2];i[d+1208>>2]=i[f>>2];i[d+1212>>2]=e;md(a,1);f=a+1074308|0;ng(f,83);tb(f,84,1);tb(f,85,1);h[a+480188>>1]=4;i[d+1196>>2]=0;h[a+480190>>1]=15;vc(b,20);s=a+480188|0;l=1;r=1;f=0;while(1){m=o(l,104)+a|0;p=m+484380|0;e=((l<<5)+a|0)+946300|0;wy(b,d+16|0,p,e,1);n=i[p>>2];b:{if(!j[Nb(e,0)|0]){break b}c:{if(Xc(e,15714,3)){if(Xc(e,15718,3)){break c}}if(j[Nb(e,5)|0]==58){break b}}r=0}e=j[d+44|0]|j[d+45|0]<<8;if((e<<24|e<<8&16711680)>>>16>>>0>=2){e=j[d+42|0]|j[d+43|0]<<8;i[m+484384>>2]=(e<<24|e<<8&16711680)>>>16;e=j[d+44|0]|j[d+45|0]<<8;q=(e<<24|e<<8&16711680)>>>15|0;e=j[d+42|0]|j[d+43|0]<<8;i[m+484388>>2]=q+((e<<8&16711680|e<<24)>>>16|0);Nm(p)}e=j[d+38|0]|j[d+39|0]<<8;d:{if((e<<24|e<<8&16711680)>>>16>>>0<=4999){e=j[d+42|0]|j[d+43|0]<<8;if((e<<24|e<<8&16711680)>>>16>>>0<1e4){break d}}i[d+1064>>2]=5;z=d,A=i[wf(d+1196|0,d+1064|0)>>2],i[z+1196>>2]=A}f=f+n|0;l=l+1|0;if((l|0)!=16){continue}break}vy(b,d+1064|0);q=a+484360|0;fn(Db(q),d+1064|2,128,65535,65535);l=0;s=HO(b,Db(q),j[d+1064|0],f,s,0);e=d+1064|1;if(j[d+1064|0]?0:!(j[e|0]|s>>>0>1)){break a}if(cf(b)+65536>>>0<(s<<10)+f>>>0){break a}if(!c){l=1;break a}if(!j[e|0]){g[e|0]=120}if(!Xc(d+1200|0,15722,6)){g[e|0]=120}i[a+480204>>2]=125e4;e:{if(j[e|0]==120){break e}f=a;w=145364549.18032786/+(240-j[e|0]|0);f:{if(w<4294967296&w>=0){e=~~w>>>0;break f}e=0}i[f+480204>>2]=e;if(i[d+1196>>2]>=2){i[d+16>>2]=r&1?4:5;z=d,A=i[wf(d+1196|0,d+16|0)>>2],i[z+1196>>2]=A;break e}i[d+16>>2]=r&1?1:2;z=d,A=i[wf(d+1196|0,d+16|0)>>2],i[z+1196>>2]=A}i[a+480260>>2]=452;i[a+480264>>2]=3424;i[a+480228>>2]=64;i[a+480208>>2]=i[a+480208>>2]|2097152;en(d+1048|0,3,d+1200|0);oc(d+16|0,d+1048|0);mb(a+1304400|0,d+16|0);eb(d+16|0);Ni(a,0);x=i[b+8>>2];h[d+1046>>1]=0;g:{if(s){y=r&1;r=0;while(1){z=d,A=sy(Jb(Db(q)),Kb(Db(q)),d+1046|0),i[z+16>>2]=A;z=d,A=Kb(Db(q)),i[z+1048>>2]=A;f=pb(d+16|0,d+1048|0);BO(b,d+16|0);if(f){r=ry(d+16|0,0)+r|0;if(r>>>0>512){break g}}p=0;f=0;t=0;while(1){l=0;while(1){e=f;m=Ae(AO(d+16|0,p),l);u=j[Nb(m,2)|0]&15;n=j[Nb(m,3)|0];f=0;h:{if(!(e&255)|(j[m|0]|j[m+1|0]<<8|(j[m+2|0]<<16|j[m+3|0]<<24))){break h}f=e+1|0;if((f&255)>>>0<33){break h}i[d+1196>>2]=6}i:{j:{k:{switch(u+ -1|0){case 0:case 1:e=i[d+1196>>2];if((e|0)==1?n>>>0>=32:0){break j}m=(u|0)!=1;if(!(m|(n+ -1&255)>>>0>1)){i[d+1048>>2]=2;z=d,A=i[wf(d+1196|0,d+1048|0)>>2],i[z+1196>>2]=A;break i}if(m|((n|0)!=55?(n|0)!=71:0)){break i}if((e|0)<=2){break j}break i;case 10:i[d+1196>>2]=6;break i;case 11:case 12:case 13:i[d+1048>>2]=2;z=d,A=i[wf(d+1196|0,d+1048|0)>>2],i[z+1196>>2]=A;if((u|0)!=13){break i}t=((n|p)!=0)+t|0;f=1;break i;case 14:break k;default:break i}}i[d+1048>>2]=3;z=d,A=i[wf(d+1196|0,d+1048|0)>>2],i[z+1196>>2]=A;break i}i[d+1196>>2]=y}l=l+1|0;if((l|0)!=4){continue}break}p=p+1|0;if((p|0)!=64){continue}break}if((t+ -1&255)>>>0<2){i[d+1196>>2]=6}v=(t&255)+v|0;f=k[d+1046>>1]+1|0;h[d+1046>>1]=f;if((f&65535)>>>0<s>>>0){continue}break}}if(!(i[d+1196>>2]!=6|v>>>0<=s+32>>>0)){i[d+1196>>2]=5}vc(b,x);u=c&1;if(u){Gf(a+484344|0,s)}if(s){t=a+484344|0;r=0;while(1){BO(b,d+16|0);l:{if(!u){break l}if(!Sf(t,r&65535,64)){break l}i[d+1048>>2]=0;p=0;while(1){v=Qe(Fb(t,r),p,0);m=0;while(1){f=Ae(AO(d+16|0,p),m);f=j[f|0]|j[f+1|0]<<8|(j[f+2|0]<<16|j[f+3|0]<<24);i[d+8>>2]=f;i[d+12>>2]=f;e=v+o(m,6)|0;As(d+8|0,e);m:{n:{o:{p:{f=j[e+5|0];if(f){n=e+3|0;q=(d+1048|0)+m|0;l=j[e+3|0];if((l|0)!=14){break p}g[q|0]=0;l=14;break o}n=(d+1048|0)+m|0;g[n|0]=0;l=j[e+3|0];if(!l){break n}n=e+3|0;break o}q=j[q|0];if(!q){break o}if(q>>>0>=16){g[e+2|0]=3;g[e+4|0]=q>>>4;break o}g[e+2|0]=4;g[e+4|0]=q}q:{r:{s:{switch(l+ -12|0){case 1:if(i[d+1196>>2]!=6){l=10;g[n|0]=10;break r}f=0;g[e+5|0]=0;l=13;break r;case 0:f=f&127;g[e+5|0]=f;l=12;break r;case 2:if(i[d+1196>>2]>3?f>>>0<=1:0){break q}l=10;g[n|0]=10;g[(d+1048|0)+m|0]=f;break r;case 3:break s;default:break r}}l=15;f=f&15;g[e+5|0]=f}if(i[d+1196>>2]>1){break q}t:{u:{v:{switch(l|0){case 0:if(f>>>0>2){break u}break;case 2:break t;case 1:break u;default:break v}}g[n|0]=0;break m}g[n|0]=1;break m}l=f&15;if(l){g[n|0]=2;g[e+5|0]=l;break m}if(!(f&240)){break m}g[n|0]=3;g[e+5|0]=f>>>4;break m}Xi(e);break m}g[n|0]=0}m=m+1|0;if((m|0)!=4){continue}break}p=p+1|0;if((p|0)!=64){continue}break}}r=r+1|0;if((s|0)!=(r|0)){continue}break}}e=i[d+1196>>2];f=15728;w:{if(e>>>0>=7){break w}f=i[(e<<2)+77448>>2]}e=Bb(d+16|0,15993);mb(a+1304436|0,e);eb(e);e=Bb(d+16|0,16006);mb(a+1304448|0,e);eb(e);tc(a+1304460|0,f);i[a+1304496>>2]=2;l=1;if(!(c&2)){break a}m=1;while(1){c=o(m,104)+a|0;f=c+484384|0;Ib(b,i[f>>2]);e=i[f>>2];i[f>>2]=0;f=c+484380|0;i[f>>2]=i[f>>2]-e;c=c+484388|0;i[c>>2]=i[c>>2]-e;Ic(d+16|0,8,1,1,0);Xf(d+16|0,f,b);m=m+1|0;if((m|0)!=16){continue}break}break a}l=0}Xa=d+1824|0;return l|0}function _c(a,b,c,d,e,f,g,h,j){var k=0,l=0,m=0,n=0,o=0,p=0,q=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0;m=Xa-96|0;Xa=m;u=c;l=g;w=(l&131071)<<15|f>>>17;k=j&65535;n=k;s=h;l=h;z=l<<15|g>>>17;p=(e^j)&-2147483648;l=e&65535;o=l;q=d;v=l;A=(k&131071)<<15|h>>>17;F=j>>>16&32767;G=e>>>16&32767;a:{b:{if(G+ -1>>>0<=32765){l=0;if(F+ -1>>>0<32766){break b}}t=e&2147483647;k=t;l=d;if(!(!d&(k|0)==2147418112?!(b|c):(k|0)==2147418112&d>>>0<0|k>>>0<2147418112)){x=d;p=e|32768;break a}t=j&2147483647;e=t;d=h;if(!(!d&(e|0)==2147418112?!(f|g):(e|0)==2147418112&d>>>0<0|e>>>0<2147418112)){x=h;p=j|32768;b=f;c=g;break a}if(!(b|l|(k^2147418112|c))){if(!(d|f|(e|g))){p=2147450880;b=0;c=0;break a}p=p|2147418112;b=0;c=0;break a}if(!(d|f|(e^2147418112|g))){d=b|l;e=c|k;b=0;c=0;if(!(d|e)){p=2147450880;break a}p=p|2147418112;break a}if(!(b|l|(c|k))){b=0;c=0;break a}if(!(d|f|(e|g))){b=0;c=0;break a}if((k|0)==65535|k>>>0<65535){j=b;d=!(o|q);h=d<<6;l=r(d?b:q)+32|0;b=r(d?c:o);b=h+((b|0)==32?l:b)|0;d=b;kf(m+80|0,j,c,q,o,d+ -15|0);q=i[m+88>>2];u=i[m+84>>2];v=i[m+92>>2];C=16-d|0;b=i[m+80>>2]}l=C;if(e>>>0>65535){break b}c=!(n|s);d=c<<6;e=r(c?f:s)+32|0;c=r(c?g:n);c=d+((c|0)==32?e:c)|0;h=c;kf(m- -64|0,f,g,s,n,c+ -15|0);f=i[m+76>>2];c=f;j=i[m+68>>2];e=i[m+72>>2];d=e;z=d<<15|j>>>17;d=j;f=i[m+64>>2];w=(d&131071)<<15|f>>>17;A=(c&131071)<<15|e>>>17;l=(C-h|0)+16|0}C=l;o=z;t=0;h=XMa(o,t,q,0);d=_a;j=0;n=w;v=v|65536;l=XMa(n,0,v,y);e=l+h|0;c=_a+d|0;c=e>>>0<l>>>0?c+1|0:c;l=e;k=e;e=c;g=(d|0)==(c|0)&k>>>0<h>>>0|c>>>0<d>>>0;A=A&2147483647|-2147483648;s=u;h=XMa(A,0,s,0);d=h+k|0;k=_a+c|0;D=d;c=d;k=c>>>0<h>>>0?k+1|0:k;d=k;c=(e|0)==(d|0)&c>>>0<l>>>0|d>>>0<e>>>0;e=g+c|0;if(e>>>0<c>>>0){j=1}M=e;h=j;l=d;e=XMa(n,H,s,I);c=_a;k=c;j=0;E=f<<15&-32768;g=XMa(E,0,q,B);f=g+e|0;c=_a+c|0;c=f>>>0<g>>>0?c+1|0:c;g=f;f=(k|0)==(c|0)&g>>>0<e>>>0|c>>>0<k>>>0;u=b;e=XMa(o,t,b,0);b=e+g|0;k=_a+c|0;k=b>>>0<e>>>0?k+1|0:k;w=b;e=k;b=(c|0)==(k|0)&b>>>0<g>>>0|k>>>0<c>>>0;c=f+b|0;if(c>>>0<b>>>0){j=1}b=c+D|0;f=j+l|0;z=b;k=h;f=b>>>0<c>>>0?f+1|0:f;g=f;b=(d|0)==(f|0)&b>>>0<D>>>0|f>>>0<d>>>0;c=b+M|0;if(c>>>0<b>>>0){k=k+1|0}b=c;c=XMa(v,y,A,J);b=b+c|0;l=_a+k|0;l=b>>>0<c>>>0?l+1|0:l;d=XMa(q,B,A,J);c=_a;j=b;h=XMa(o,t,v,y);b=h+d|0;f=_a+c|0;f=b>>>0<h>>>0?f+1|0:f;h=b;k=b;b=f;f=(c|0)==(b|0)&k>>>0<d>>>0|b>>>0<c>>>0;d=j+b|0;k=f+l|0;c=d;f=c>>>0<b>>>0?k+1|0:k;c=h;h=0;b=h+z|0;j=c+g|0;j=b>>>0<h>>>0?j+1|0:j;h=b;c=b;b=j;c=(g|0)==(b|0)&c>>>0<z>>>0|b>>>0<g>>>0;d=d+c|0;if(d>>>0<c>>>0){f=f+1|0}D=d;c=h;z=b;B=XMa(q,B,n,H);q=_a;g=XMa(E,K,v,y);d=g+B|0;l=_a+q|0;l=d>>>0<g>>>0?l+1|0:l;v=d;k=XMa(o,t,s,I);d=d+k|0;g=l;j=l+_a|0;j=d>>>0<k>>>0?j+1|0:j;o=d;l=XMa(u,L,A,J);d=d+l|0;k=_a+j|0;y=d;k=d>>>0<l>>>0?k+1|0:k;d=k;t=d;k=0;l=f;d=(d|0)==(j|0)&y>>>0<o>>>0|d>>>0<j>>>0;f=(g|0)==(j|0)&o>>>0<v>>>0|j>>>0<g>>>0;g=f+((g|0)==(q|0)&v>>>0<B>>>0|g>>>0<q>>>0)|0;g>>>0<f>>>0;j=g;g=d+j|0;j=g;f=t;c=c+f|0;k=(j|k)+z|0;k=c>>>0<f>>>0?k+1|0:k;j=c;g=k;b=(b|0)==(k|0)&c>>>0<h>>>0|k>>>0<b>>>0;c=b+D|0;if(c>>>0<b>>>0){l=l+1|0}B=c;b=l;o=g;k=w;t=XMa(u,L,n,H);n=_a;h=XMa(E,K,s,I);c=h+t|0;f=_a+n|0;q=c;f=c>>>0<h>>>0?f+1|0:f;h=f;f=0;c=(h|0)==(n|0)&c>>>0<t>>>0|h>>>0<n>>>0;n=h+k|0;k=(c|f)+e|0;k=n>>>0<h>>>0?k+1|0:k;f=n;c=k;s=(e|0)==(c|0)&f>>>0<w>>>0|c>>>0<e>>>0;h=j;f=0;k=c+y|0;l=0;d=l+n|0;if(d>>>0<l>>>0){k=k+1|0}e=d;d=k;c=(c|0)==(d|0)&e>>>0<n>>>0|d>>>0<c>>>0;l=c+s|0;if(l>>>0<c>>>0){f=1}k=l;c=h+k|0;l=f+o|0;l=c>>>0<k>>>0?l+1|0:l;y=c;k=b;b=l;c=(g|0)==(b|0)&c>>>0<j>>>0|b>>>0<g>>>0;f=c+B|0;if(f>>>0<c>>>0){k=k+1|0}o=f;c=k;f=c&65536;k=f;n=0;s=k>>>16|0;g=(s+(C+(F+G|0)|0)|0)+ -16383|0;if((g|0)>=32767){p=p|2147418112;b=0;c=0;break a}l=o;j=c<<1|l>>>31;f=l<<1|b>>>31;w=!(k|n);l=w;o=l?f:o;n=l?j:c;j=d;h=0;f=XMa(u,L,E,K);d=h+f|0;k=q;c=k+_a|0;c=d>>>0<f>>>0?c+1|0:c;q=d;f=c;c=e+((k|0)==(c|0)&d>>>0<h>>>0|c>>>0<k>>>0)|0;if(c>>>0<e>>>0){j=j+1|0}u=c;c=j;h=c;e=u;l=s^1;j=l;d=j&31;if(32<=(j&63)>>>0){k=e<<d;h=0}else{k=(1<<d)-1&e>>>32-d|h<<d;h=e<<d}e=k;u=h;d=f;k=d>>>1|0;h=(d&1)<<31|q>>>1;j=s|62;d=j&31;if(32<=(j&63)>>>0){j=0;d=k>>>d|0}else{j=k>>>d|0;d=((1<<d)-1&k)<<32-d|h>>>d}d=u|d;e=e|j;j=y;k=b<<1|j>>>31;h=w?j<<1|c>>>31:j;j=w?k:b;c=q;b=l&31;if(32<=(l&63)>>>0){f=c<<b;b=0}else{f=(1<<b)-1&c>>>32-b|f<<b;b=c<<b}c=f;c:{if((g|0)<=0){f=1-g|0;if(f>>>0>=128){b=0;c=0;break a}g=g+127|0;kf(m+48|0,b,c,d,e,g);kf(m+32|0,h,j,o,n,g);cm(m+16|0,b,c,d,e,f);cm(m,h,j,o,n,f);b=(i[m+48>>2]|i[m+56>>2])!=0|(i[m+52>>2]|i[m+60>>2])!=0|(i[m+32>>2]|i[m+16>>2]);c=i[m+36>>2]|i[m+20>>2];d=i[m+40>>2]|i[m+24>>2];e=i[m+44>>2]|i[m+28>>2];h=i[m>>2];j=i[m+4>>2];g=i[m+12>>2];o=i[m+8>>2];break c}g=n&65535|g<<16}x=o|x;p=g|p;if(!(!d&(e|0)==-2147483648?!(b|c):(e|0)>-1)){k=p;l=j;b=h+1|0;if(b>>>0<1){l=l+1|0}d=b;c=l;d=(j|0)==(c|0)&d>>>0<h>>>0|c>>>0<j>>>0;e=d+x|0;if(e>>>0<d>>>0){k=k+1|0}x=e;p=k;break a}if(b|d|(e^-2147483648|c)){b=h;c=j;break a}l=p;f=j;b=h&1;c=b+h|0;if(c>>>0<b>>>0){f=f+1|0}b=c;d=c;c=f;d=(j|0)==(c|0)&d>>>0<h>>>0|c>>>0<j>>>0;e=d+x|0;if(e>>>0<d>>>0){l=l+1|0}x=e;p=l}i[a>>2]=b;i[a+4>>2]=c;i[a+8>>2]=x;i[a+12>>2]=p;Xa=m+96|0}function qya(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,l=0,m=0,n=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0;d=Xa-352|0;Xa=d;vc(b,60);e=15;a:{if(!sh(b,17196)){vc(b,124);e=31;if(!sh(b,17201)){break a}}md(a,536870912);h[a+480190>>1]=e;pc(b);b:{if(k[a+480190>>1]){while(1){e=Bz(b);i[(d+224|0)+(f<<2)>>2]=e;if(e>>>0>131072){break b}f=f+1|0;if(f>>>0<k[a+480190>>1]){continue}break}}i[a+480260>>2]=56;i[a+480264>>2]=13696;i[a+480196>>2]=6;f=0;h[a+480192>>1]=0;h[a+480188>>1]=4;i[a+480228>>2]=64;Ni(a,1);Ib(b,4);e=pp(b);if(e>>>0<178){break a}f=a;s=177693e5/+(e>>>0);c:{if(s<4294967296&s>=0){e=~~s>>>0;break c}e=0}i[f+480204>>2]=e;Ib(b,14);d:{e:{f:{if(k[a+480190>>1]){r=d+78|0;m=1;e=0;n=1;while(1){DO(b,d+56|0);pya(d+56|0,(o(m,104)+a|0)+484380|0,i[((m<<2)+d|0)+220>>2]);f=d+56|0;while(1){if((j[f|0]+ -1&255)>>>0<=30){g[f|0]=32;e=e+1|0}f=f+1|0;if((r|0)!=(f|0)){continue}break}if(e>>>0>127){break b}on(d+192|0,3,d+56|0);oc(d+208|0,d+192|0);i[114610]=0;C(369,((m<<5)+a|0)+946300|0,d+208|0)|0;f=i[114610];i[114610]=0;if((f|0)==1){break f}eb(d+208|0);n=n+1|0;m=n&65535;if(m>>>0<=k[a+480190>>1]){continue}break}}e=Bb(d+56|0,17206);i[114610]=0;f=a+946332|0;m=C(1004,f|0,e|0)|0;n=i[114610];i[114610]=0;r=1;g:{h:{i:{j:{if((n|0)!=1){if(!m){i[114610]=0;m=C(85,d+208|0,17217)|0;n=i[114610];i[114610]=0;if((n|0)==1){break j}i[114610]=0;r=C(1004,f|0,m|0)|0;f=i[114610];i[114610]=0;if((f|0)==1){break i}eb(m)}eb(e);f=0;if(!vy(b,d+56|0)){break a}if(!jN(d+56|0)){break a}if(c){break g}break d}f=B()|0;A()|0;break h}f=B()|0;A()|0;break h}f=B()|0;A()|0;eb(m)}eb(e);break e}h[d+54>>1]=0;if(j[d+56|0]){while(1){h[d+208>>1]=j[(d+f|0)+58|0]+1;w=d,y=k[ri(d+54|0,d+208|0)>>1],h[w+54>>1]=y;f=f+1|0;if(f>>>0<j[d+56|0]){continue}break}}f=d+56|1;e=j[f|0];m=j[d+56|0];n=a+484360|0;Fe(Db(n),e>>>0<m>>>0?j[f|0]:0);fn(Db(n),d+56|2,j[d+56|0],65535,65535);if(k[a+480190>>1]==31){Ib(b,4)}i[d+48>>2]=0;i[d+44>>2]=0;i[d+40>>2]=0;g[d+39|0]=0;t=c&1;if(t){Gf(a+484344|0,k[d+54>>1])}if(k[d+54>>1]){u=a+484344|0;m=0;while(1){k:{l:{if(t){n=0;if(Sf(u,m&65535,64)){break l}}Ib(b,1024);break k}while(1){v=Qe(Fb(u,m),n,0);f=0;while(1){nn(d+208|0,b);e=o(f,6)+v|0;m:{n:{if(j[Nb(d+208|0,0)|0]!=255){break n}g[(d+48|0)+f|0]=0;g[(d+40|0)+f|0]=0;o:{if(!r){break o}if(j[Nb(d+208|0,1)|0]!=252){break o}w=Nb(d+208|0,1),y=254,g[w|0]=y}p:{switch(j[Nb(d+208|0,1)|0]+ -252|0){case 2:g[e+3|0]=13;break m;case 1:break m;case 0:break p;default:break n}}g[e+3|0]=14;g[d+39|0]=9;break m}l=i[d+208>>2];i[d+32>>2]=l;i[d+12>>2]=l;As(d+12|0,e);l=j[e|0];q:{if(!l){break q}g[(d+40|0)+f|0]=0;g[(d+48|0)+f|0]=l;if(l>>>0>48){break q}g[d+192|0]=8;w=d,y=j[Ug(d+39|0,d+192|0)|0],g[w+39|0]=y}r:{s:{t:{u:{v:{switch(j[e+3|0]){case 0:if(j[e+5|0]){break s}break r;case 1:g[e+3|0]=1;break m;case 2:l=j[e+5|0];if(l&240){g[e+3|0]=3;g[e+5|0]=l>>>4;break m}l=l&15;if(l){g[e+3|0]=2;g[e+5|0]=l;break m}g[e+5|0]=0;break s;case 3:if(j[(d+40|0)+f|0]){break t}g[e+3|0]=19;g[e+5|0]=0;break m;case 4:if(j[(d+40|0)+f|0]){break t}g[e+3|0]=19;g[e+5|0]=1;break m;case 5:if(!j[e+1|0]){break t}g[e+3|0]=13;g[d+192|0]=63;g[d+31|0]=j[e+5|0]+(k[(o(j[e+1|0],104)+a|0)+484410>>1]>>>2|0);l=j[Xb(d+192|0,d+31|0)|0];g[e+5|0]=l;if(!j[(d+40|0)+f|0]){break u}g[e+4|0]=l;g[e+2|0]=1;g[e+5|0]=0;break s;case 6:l=j[e+1|0];if(!l){break t}g[e+3|0]=13;l=k[(o(l,104)+a|0)+484410>>1]>>>2|0;p=j[e+5|0];l=l>>>0<p>>>0?0:l-p|0;g[e+5|0]=l;if(!j[(d+40|0)+f|0]){break u}g[e+4|0]=l;g[e+2|0]=1;g[e+5|0]=0;break s;case 8:p=j[(d+48|0)+f|0];l=j[e+5|0];q=p+(l>>>4|0)|0;g[(d+44|0)+f|0]=q;g[e+3|0]=2;l=l&15;g[(d+40|0)+f|0]=l;w=e,y=iN(l,p,q&255),g[w+5|0]=y;break u;case 9:g[d+192|0]=8;w=d,y=j[Ug(d+39|0,d+192|0)|0],g[w+39|0]=y;break s;case 7:break v;default:break s}}l=j[(d+48|0)+f|0];p=j[e+5|0];q=l-(p>>>4|0)|0;g[(d+44|0)+f|0]=q;g[e+3|0]=3;p=p&15;g[(d+40|0)+f|0]=p;w=e,y=iN(p,q&255,l),g[w+5|0]=y}if(j[e+3|0]){break m}break r}g[e+5|0]=0}g[e+3|0]=0}p=j[(d+40|0)+f|0];if(!p){break m}q=(d+44|0)+f|0;l=j[q|0];if(l){g[(d+48|0)+f|0]=l;g[e|0]=l;g[e+5|0]=p;g[q|0]=0}g[e+3|0]=4}f=f+1|0;if((f|0)!=4){continue}break}n=n+1|0;if((n|0)!=64){continue}break}}m=m+1|0;if(m>>>0<k[d+54>>1]){continue}break}}e=k[a+480190>>1];w:{x:{y:{z:{A:{B:{if(c&2){if(!(e&65535)){break B}f=1;while(1){c=(o(f&65535,104)+a|0)+484380|0;if(i[c>>2]){Xf(Ic(d+208|0,8,1,0,0),c,b);e=k[a+480190>>1]}f=f+1|0;if((f&65535)>>>0<=(e&65535)>>>0){continue}break}}if((e&65535)==15){break A}}f=0;i[114610]=0;C(2,d+208|0,17239)|0;b=i[114610];i[114610]=0;if((b|0)!=1){break z}f=B()|0;A()|0;break e}b=Bb(d+16|0,17226);i[114610]=0;D(219,d+192|0,b|0);c=i[114610];i[114610]=0;f=1;if((c|0)==1){break x}i[114610]=0;G(537,d+208|0,d+192|0,d+39|0);c=i[114610];i[114610]=0;if((c|0)==1){break y}}mb(a+1304436|0,d+208|0);eb(d+208|0);if(f){ob(d+192|0);eb(d+16|0)}tc(a+1304448|0,k[a+480190>>1]==15?17270:17274);i[a+1304496>>2]=2;break d}f=B()|0;A()|0;ob(d+192|0);break w}f=B()|0;A()|0}eb(b);break e}f=B()|0;A()|0;eb(d+208|0)}E(f|0);x()}f=1;break a}f=0}Xa=d+352|0;return f|0}function qv(a,b,c,d,e,f,k){var l=0,m=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;l=Xa-80|0;Xa=l;i[l+76>>2]=b;B=l+55|0;y=l+56|0;b=0;a:{b:while(1){c:{if((w|0)<0){break c}if((b|0)>(2147483647-w|0)){i[114584]=61;w=-1;break c}w=b+w|0}d:{e:{f:{q=i[l+76>>2];b=q;m=j[b|0];if(m){while(1){g:{m=m&255;h:{if(!m){m=b;break h}if((m|0)!=37){break g}m=b;while(1){if(j[b+1|0]!=37){break h}p=b+2|0;i[l+76>>2]=p;m=m+1|0;r=j[b+2|0];b=p;if((r|0)==37){continue}break}}b=m-q|0;if(a){ue(a,q,b)}if(b){continue b}m=l;p=!Hg(g[i[l+76>>2]+1|0]);b=i[l+76>>2];i:{if(!(p|j[b+2|0]!=36)){x=g[b+1|0]+ -48|0;z=1;b=b+3|0;break i}x=-1;b=b+1|0}i[m+76>>2]=b;s=0;t=g[b|0];p=t+ -32|0;j:{if(p>>>0>31){m=b;break j}m=b;p=1<<p;if(!(p&75913)){break j}while(1){m=b+1|0;i[l+76>>2]=m;s=p|s;t=g[b+1|0];p=t+ -32|0;if(p>>>0>=32){break j}b=m;p=1<<p;if(p&75913){continue}break}}k:{if((t|0)==42){p=l;l:{m:{if(!Hg(g[m+1|0])){break m}b=i[l+76>>2];if(j[b+2|0]!=36){break m}i[((g[b+1|0]<<2)+e|0)+ -192>>2]=10;u=i[((g[b+1|0]<<3)+d|0)+ -384>>2];z=1;b=b+3|0;break l}if(z){break f}z=0;u=0;if(a){b=i[c>>2];i[c>>2]=b+4;u=i[b>>2]}b=i[l+76>>2]+1|0}i[p+76>>2]=b;if((u|0)>-1){break k}u=0-u|0;s=s|8192;break k}u=DE(l+76|0);if((u|0)<0){break f}b=i[l+76>>2]}r=-1;n:{if(j[b|0]!=46){break n}if(j[b+1|0]==42){o:{if(!Hg(g[b+2|0])){break o}b=i[l+76>>2];if(j[b+3|0]!=36){break o}i[((g[b+2|0]<<2)+e|0)+ -192>>2]=10;r=i[((g[b+2|0]<<3)+d|0)+ -384>>2];b=b+4|0;i[l+76>>2]=b;break n}if(z){break f}if(a){b=i[c>>2];i[c>>2]=b+4;b=i[b>>2]}else{b=0}r=b;b=i[l+76>>2]+2|0;i[l+76>>2]=b;break n}i[l+76>>2]=b+1;r=DE(l+76|0);b=i[l+76>>2]}m=0;while(1){A=m;v=-1;if(g[b|0]+ -65>>>0>57){break a}t=b+1|0;i[l+76>>2]=t;m=g[b|0];b=t;m=j[(m+o(A,58)|0)+55055|0];if(m+ -1>>>0<8){continue}break}p:{q:{if((m|0)!=19){if(!m){break a}if((x|0)>=0){i[(x<<2)+e>>2]=m;b=(x<<3)+d|0;m=i[b+4>>2];i[l+64>>2]=i[b>>2];i[l+68>>2]=m;break q}if(!a){break d}CE(l- -64|0,m,c,k);t=i[l+76>>2];break p}if((x|0)>-1){break a}}b=0;if(!a){continue b}}p=s&-65537;m=s&8192?p:s;v=0;x=55088;s=y;r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{b=g[t+ -1|0];b=A?(b&15)==3?b&-33:b:b;switch(b+ -88|0){case 11:break r;case 9:case 13:case 14:case 15:break s;case 27:break x;case 12:case 17:break A;case 23:break B;case 0:case 32:break C;case 24:break D;case 22:break E;case 29:break F;case 1:case 2:case 3:case 4:case 5:case 6:case 7:case 8:case 10:case 16:case 18:case 19:case 20:case 21:case 25:case 26:case 28:case 30:case 31:break e;default:break G}}H:{switch(b+ -65|0){case 0:case 4:case 5:case 6:break s;case 2:break v;case 1:case 3:break e;default:break H}}if((b|0)==83){break w}break e}b=i[l+64>>2];q=i[l+68>>2];p=55088;break z}b=0;I:{switch(A&255){case 0:i[i[l+64>>2]>>2]=w;continue b;case 1:i[i[l+64>>2]>>2]=w;continue b;case 2:m=i[l+64>>2];i[m>>2]=w;i[m+4>>2]=w>>31;continue b;case 3:h[i[l+64>>2]>>1]=w;continue b;case 4:g[i[l+64>>2]]=w;continue b;case 6:i[i[l+64>>2]>>2]=w;continue b;case 7:break I;default:continue b}}m=i[l+64>>2];i[m>>2]=w;i[m+4>>2]=w>>31;continue b}r=r>>>0>8?r:8;m=m|8;b=120}q=L4(i[l+64>>2],i[l+68>>2],y,b&32);if(!(m&8)|!(i[l+64>>2]|i[l+68>>2])){break y}x=(b>>>4|0)+55088|0;v=2;break y}q=K4(i[l+64>>2],i[l+68>>2],y);if(!(m&8)){break y}b=y-q|0;r=(r|0)>(b|0)?r:b+1|0;break y}p=i[l+68>>2];q=p;b=i[l+64>>2];if((p|0)<-1?1:(p|0)<=-1){q=0-(q+(0<b>>>0)|0)|0;b=0-b|0;i[l+64>>2]=b;i[l+68>>2]=q;v=1;p=55088;break z}if(m&2048){v=1;p=55089;break z}v=m&1;p=v?55090:55088}x=p;q=dm(b,q,y)}m=(r|0)>-1?m&-65537:m;b=i[l+68>>2];p=b;t=i[l+64>>2];if(!(!!(b|t)|r)){r=0;q=y;break e}b=!(p|t)+(y-q|0)|0;r=(r|0)>(b|0)?r:b;break e}b=i[l+64>>2];q=b?b:55098;b=Pq(q,0,r);s=b?b:r+q|0;m=p;r=b?b-q|0:r;break e}p=i[l+64>>2];if(r){break u}b=0;lf(a,32,u,0,m);break t}i[l+12>>2]=0;i[l+8>>2]=i[l+64>>2];i[l+64>>2]=l+8;r=-1;p=l+8|0}b=0;J:{while(1){q=i[p>>2];if(!q){break J}q=GE(l+4|0,q);s=(q|0)<0;if(!(s|q>>>0>r-b>>>0)){p=p+4|0;b=b+q|0;if(r>>>0>b>>>0){continue}break J}break}v=-1;if(s){break a}}lf(a,32,u,b,m);if(!b){b=0;break t}t=0;p=i[l+64>>2];while(1){q=i[p>>2];if(!q){break t}q=GE(l+4|0,q);t=q+t|0;if((t|0)>(b|0)){break t}ue(a,l+4|0,q);p=p+4|0;if(t>>>0<b>>>0){continue}break}}lf(a,32,u,b,m^8192);b=(u|0)>(b|0)?u:b;continue b}b=$a[f|0](a,n[l+64>>3],u,r,m,b)|0;continue b}g[l+55|0]=i[l+64>>2];r=1;q=B;m=p;break e}p=b+1|0;i[l+76>>2]=p;m=j[b+1|0];b=p;continue}}v=w;if(a){break a}if(!z){break d}b=1;while(1){a=i[(b<<2)+e>>2];if(a){CE((b<<3)+d|0,a,c,k);v=1;b=b+1|0;if((b|0)!=10){continue}break a}break}v=1;if(b>>>0>=10){break a}while(1){if(i[(b<<2)+e>>2]){break f}b=b+1|0;if((b|0)!=10){continue}break}break a}v=-1;break a}s=s-q|0;r=(r|0)<(s|0)?s:r;p=r+v|0;b=(u|0)<(p|0)?p:u;lf(a,32,b,p,m);ue(a,x,v);lf(a,48,b,p,m^65536);lf(a,48,r,s,0);ue(a,q,s);lf(a,32,b,p,m^8192);continue}break}v=0}Xa=l+80|0;return v}function Ama(a){var b=0,c=0,d=0,e=0,f=0,m=0,n=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;m=Xa-16|0;Xa=m;c=a+1074392|0;b=i[c>>2]+1|0;i[c>>2]=b;a:{b:{c:{if(b>>>0<Zk(a)>>>0){break c}v=a+1074984|0;q=a+1074308|0;p=a+1304360|0;n=a+484344|0;d=a+484360|0;f=a+1074438|0;s=a+1074424|0;t=a+480210|0;while(1){r=0;d:{if(!i[a+1074396>>2]){break d}r=0;if(!(j[t|0]&8)){break d}r=i[a+480180>>2]==1}e:{if(i[a+480180>>2]!=2|(j[t|0]&8?0:i[a+1074428>>2])){break e}b=0;if(!k[a+480188>>1]){break e}while(1){i[(o(b,896)+a|0)+1075788>>2]=0;b=b+1|0;if(b>>>0<k[a+480188>>1]){continue}break}}i[a+1074400>>2]=0;i[a+1074392>>2]=0;i[a+1074396>>2]=0;i[a+1074424>>2]=i[a+1074428>>2];c=k[a+1074440>>1];h[a+1074438>>1]=c;if(!(j[a+480208|0]&32)){b=a;f:{if(Wb(Db(d))>>>0>c>>>0){c=k[$b(Db(d),k[f>>1])>>1];break f}c=65535}h[b+1074436>>1]=c;g:{if((c&65535)>>>0>=ke(n)>>>0){break g}if(rh(Fb(n,k[a+1074436>>1]))){break g}h[a+1074436>>1]=65534}if(k[a+1074436>>1]>=ke(n)>>>0){while(1){h:{i:{j:{k:{if(k[a+1074436>>1]!=65535){b=k[f>>1];if(Wb(Db(d))>>>0>b>>>0){break k}}b=k[Db(d)+28>>1];if(b){break i}b=k[f>>1];if(Wb(Db(d))>>>0<b>>>0){break j}c=k[f>>1];if(!c){break j}while(1){b=c;c=b+ -1|0;e=c&65535;if(!e){break j}if(k[$b(Db(d),e)>>1]!=65535){continue}break}break i}b=k[f>>1]+1|0;h[f>>1]=b;break h}b=0}h[a+1074438>>1]=b;i[a+480208>>2]=i[a+480208>>2]&-524289;l:{if(Wb(Db(d))>>>0<=(b&65535)>>>0){break l}while(1){if(k[$b(Db(d),k[f>>1])>>1]!=65534){break l}b=k[f>>1]+1|0;h[f>>1]=b;if(Wb(Db(d))>>>0>(b&65535)>>>0){continue}break}}b=k[f>>1];m:{if(Wb(Db(d))>>>0<=b>>>0){break m}if(!Lo(Db(d),k[f>>1])){break m}b=k[f>>1];break h}Ri(p,1);break b}c=a;n:{if(Wb(Db(d))>>>0>(b&65535)>>>0){b=k[$b(Db(d),k[f>>1])>>1];break n}b=65535}h[c+1074436>>1]=b;o:{if((b&65535)>>>0>=ke(n)>>>0){break o}if(rh(Fb(n,k[a+1074436>>1]))){break o}h[a+1074436>>1]=65534}if(k[a+1074436>>1]>=ke(n)>>>0){continue}break}}h[a+1074440>>1]=k[a+1074438>>1]}if(!pg(n,k[a+1074436>>1])){break b}if(l[a+1074424>>2]>=l[Fb(n,k[a+1074436>>1])+12>>2]){i[s>>2]=0}if(i[a+480272>>2]==-1){b=0}else{b=(j[a+480208|0]&32)>>>5|0}if(r){c=p+12|0;if(Uc(c)){c=-1}else{c=i[Qi(c)>>2]}c=(c|0)==i[s>>2]}else{c=1}p:{if(b|c^1){break p}if(!lL(p,k[f>>1],i[s>>2],1)){break p}b=i[a+480272>>2];if(b){if((b|0)>=1){i[a+480272>>2]=b+ -1}Ri(p,1);jJ(p,k[f>>1],i[s>>2]);break p}q:{if(j[t|0]&64){if(kL(p,f,s,1)){break q}h[a+1074438>>1]=0;h[a+1074440>>1]=0;i[a+1074424>>2]=0;i[a+1074428>>2]=0;b=j[d+16|0];if((ph(d)+ -1|0)<=(b|0)){Ko(d,0);Ri(p,1);a=0;break a}Ko(d,j[d+16|0]+1&255);Ri(p,1);break q}Ri(p,1);break b}b=0;while(1){Pm((o(b,896)+a|0)+1074984|0,a,b&65535);b=b+1|0;if((b|0)!=256){continue}break}EJ(a);i[a+1074416>>2]=i[a+480196>>2];i[a+1074420>>2]=i[a+480204>>2];i[a+1074444>>2]=i[a+480200>>2];h[a+1074440>>1]=k[a+1074438>>1];i[a+1074428>>2]=i[a+1074424>>2];c=p;u=Wb(Db(d));b=k[a+1074438>>1];if(u>>>0>b>>>0){w=a,x=k[$b(Db(d),k[a+1074438>>1])>>1],h[w+1074436>>1]=x;b=k[a+1074438>>1]}jJ(c,b&65535,i[a+1074424>>2]);if(!pg(n,k[a+1074436>>1])){break b}}b=i[a+1074424>>2]+1|0;i[a+1074428>>2]=b;r:{if(b>>>0<l[Fb(n,k[a+1074436>>1])+12>>2]){break r}if(!(j[a+480208|0]&32)){h[a+1074440>>1]=k[a+1074438>>1]+1}i[a+1074428>>2]=0;kb(m+8|0,q,63);if(!ib(m+8|0)){break r}b=i[a+1074432>>2];i[a+1074432>>2]=0;i[a+1074428>>2]=b}c=Qe(Fb(n,k[a+1074436>>1]),i[a+1074424>>2],0);b=k[a+480188>>1];if(b){u=(o(b,896)+a|0)+1074984|0;b=v;while(1){kb(m+8|0,q,82);s:{if(!ib(m+8|0)|j[b+827|0]!=1){break s}e=j[c+3|0];if((e|0)!=3?(e|0)!=2:0){break s}w=b,x=Vf(a,j[b+822|0],i[b+768>>2],i[b+704>>2]),i[w+700>>2]=x}kb(m+8|0,q,91);t:{if(!ib(m+8|0)){break t}if(Jf(c)){break t}if(!Jf(b+810|0)|j[b+813|0]!=19){break t}e=j[b+815|0];if((e&240)!=208|(e&15)>>>0<l[a+1074416>>2]){break t}w=b,x=Vf(a,j[b+810|0],i[b+768>>2],0),i[w+700>>2]=x}kb(m+8|0,q,92);u:{if(!ib(m+8|0)){break u}kb(m,q,5);if(ib(m)|i[a+1074416>>2]!=1|j[b+813|0]!=17){break u}i[a+1074420>>2]=o(j[b+815|0],1e4)}e=j[c|0]|j[c+1|0]<<8|(j[c+2|0]<<16|j[c+3|0]<<24);g[b+810|0]=e;g[b+811|0]=e>>>8;g[b+812|0]=e>>>16;g[b+813|0]=e>>>24;e=j[c+4|0]|j[c+5|0]<<8;g[b+814|0]=e;g[b+815|0]=e>>>8;e=i[b+676>>2];i[b+20>>2]=i[b+672>>2];i[b+24>>2]=e;i[b+88>>2]=i[b+88>>2]&-393217;kb(m+8|0,q,21);if(!ib(m+8|0)){g[b+851|0]=0}i[b+884>>2]=0;g[b+827|0]=0;c=c+6|0;b=b+896|0;if((u|0)!=(b|0)){continue}break}}Joa(a);if(!r){break c}b=i[a+1074416>>2]+1|0;i[a+1074392>>2]=b;if(b>>>0>=Zk(a)>>>0){continue}break}}if(!i[a+1074416>>2]){i[a+1074416>>2]=1}b=i[a+480208>>2];v:{if(i[a+1074392>>2]){i[a+480208>>2]=b&-4097;if(i[a+480180>>2]&1048580|(j[a+480210|0]&32?0:i[a+480180>>2]==1)){break v}if(l[a+1074392>>2]>=Zk(a)>>>0|l[a+1074392>>2]%(i[a+1074400>>2]+i[a+1074416>>2]>>>0)){break v}i[a+480208>>2]=i[a+480208>>2]|4096;break v}i[a+480208>>2]=b&-528385|4096}a=Yoa(a);break a}a=0}Xa=m+16|0;return a}function pHa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,l=0,m=0,n=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,G=0,H=0,J=0;d=Xa-1328|0;Xa=d;pc(b);m=d+752|0;f=hHa(b,m);if(!f){DQ(m)}a:{b:{c:{if(!f){break c}if(!GQ(d+752|0)){break c}if(!wb(b,Vc(FQ(d+752|0),_a))){break c}if(!c){e=1;break c}v=Ss(d+744|0);w=1;d:{while(1){m=(e<<5)+a|0;f=m+480280|0;sg(f);n=(d+752|0)+(e<<4)|0;h[m+480284>>1]=((j[n+78|0]<<8&65280)>>>0)/255;bk(d+480|0,1,n- -64|0);oc(d+96|0,d+480|0);i[114610]=0;C(378,m+480289|0,d+96|0)|0;m=i[114610];i[114610]=0;if((m|0)==1){break b}eb(d+96|0);e:{f:{switch(j[n+79|0]){case 0:p=e+1|0;break e;case 1:i[f>>2]=1024;p=l+1|0;break e;case 2:break f;default:break d}}i[f>>2]=1024;lj(d+96|0,v,e);Od(d+96|0,1)}w=e>>>0<31;l=l+1|0;e=e+1|0;if((e|0)!=32){continue}break}md(a,33554432);h[a+480188>>1]=p&255;e=Bb(d+96|0,13326);mb(a+1304436|0,e);eb(e);e=Bb(d+96|0,13340);mb(a+1304448|0,e);eb(e);i[a+1304496>>2]=4;g:{if(j[d+831|0]){break g}f=1;while(1){if(j[((f<<4)+d|0)+831|0]!=1){break g}e=1;f=f+1|0;if((f|0)!=16){continue}break}while(1){l=((e<<5)+a|0)+480280|0;i[l>>2]=i[l>>2]&-1025;e=e+1|0;if((e|0)!=16){continue}break}}rg(d+480|0,1,d+752|0);oc(d+96|0,d+480|0);mb(a+1304400|0,d+96|0);eb(d+96|0);i[a+480208>>2]=i[a+480208>>2]&-17|(j[d+790|0]|j[d+791|0]<<8)<<4&16;i[a+480196>>2]=j[d+800|0];i[a+480204>>2]=o(j[d+801|0],1e4);H=a,J=hd(j[d+802|0],0,64)<<2,i[H+480200>>2]=J;H=a,J=hd(j[d+803|0],4,127),i[H+480228>>2]=J;e=j[d+788|0]|j[d+789|0]<<8;h[a+480190>>1]=0;h[a+480192>>1]=e;Wz(b,d+480|0);st(Db(a+484360|0),d+480|0,j[d+784|0]|j[d+785|0]<<8,65535,255);y=c&1;if(y){Gf(a+484344|0,j[d+786|0]|j[d+787|0]<<8)}if(j[d+786|0]|j[d+787|0]<<8){z=a+484344|0;p=0;while(1){e=_f(b);t=_f(b);ad(d+96|0,b,e+ -4|0);h:{if(!y){break h}i[114610]=0;e=I(402,z|0,p&65535,t|0)|0;l=i[114610];i[114610]=0;if((l|0)!=1){i:{if(!e){break h}r=0;s=aj(d+16|0);if(!t){break h}while(1){j:{i[114610]=0;m=F(387,d+96|0)|0;e=i[114610];i[114610]=0;k:{l:{if((e|0)!=1){if(m){break l}r=r+1|0;break k}break i}e=s;u=m&31;if(k[a+480188>>1]>u>>>0){e=Fb(z,p);i[114610]=0;e=I(471,e|0,r|0,u|0)|0;l=i[114610];i[114610]=0;if((l|0)==1){break i}}m:{if(!(m&32)){break m}i[114610]=0;D(472,d+32|0,d+96|0);f=i[114610];i[114610]=0;l=e;n:{o:{if((f|0)!=1){n=Nc(d+32|0);f=j[d+32|0];g[e|0]=f;g[e+1|0]=j[n|0];if((f|0)!=160){break o}f=255;break n}break i}if((f|0)!=255){g[e|0]=(o(f>>>4|0,12)+(f&15)|0)+13;i[114610]=0;n=F(618,e|0)|0;f=i[114610];i[114610]=0;if((f|0)!=1){f=0;if(!n){break n}break m}break i}f=0}g[l|0]=f}l=m&192;p:{if(!l){break p}if((l|0)==192){i[114610]=0;D(598,d+32|0,d+96|0);l=i[114610];i[114610]=0;q:{r:{s:{if((l|0)!=1){n=Nc(d+32|0);f=yf(d+32|0);l=li(d+32|0);q=d+32|0;G=j[q|0];if((G|0)!=12){break s}i[114610]=0;g[d+8|0]=64;m=C(391,n|0,d+8|0)|0;n=i[114610];i[114610]=0;if((n|0)==1){break i}g[e+4|0]=j[m|0];m=1;break r}break i}m=j[f|0];t:{if((m|0)==12){i[114610]=0;g[d+8|0]=64;l=C(391,l|0,d+8|0)|0;m=i[114610];i[114610]=0;if((m|0)!=1){g[e+4|0]=j[l|0];m=1;break t}break i}if((G|0)==10){g[e+4|0]=(j[n|0]<<6>>>0)/255;m=2;break r}if((m|0)!=10){break q}g[e+4|0]=(j[l|0]<<6>>>0)/255;m=2}f=q;l=n}g[e+2|0]=m;m=j[f|0]}g[e+3|0]=m;g[e+5|0]=j[l|0];break p}i[114610]=0;D(472,d+32|0,d+96|0);l=i[114610];i[114610]=0;if((l|0)==1){break i}l=Nc(d+32|0);g[e+3|0]=j[d+32|0];g[e+5|0]=j[l|0]}if(j[e+3|0]){i[114610]=0;L(619,e|0);l=i[114610];i[114610]=0;if((l|0)==1){break i}}lj(d+32|0,v,u);if(!ib(d+32|0)){break k}i[114610]=0;l=F(620,e|0)|0;m=i[114610];i[114610]=0;if((m|0)==1){break j}if(!l){break k}g[e+3|0]=0}if(r>>>0<t>>>0){continue}break h}break}}}e=B()|0;A()|0;hb(d+96|0);break a}hb(d+96|0);p=p+1|0;if(p>>>0<(j[d+786|0]|j[d+787|0]<<8)>>>0){continue}break}}if(!k[a+480192>>1]){break d}n=c&2;m=0;l=1;while(1){m=m+1|0;s=m&65535;c=zJ(a,s,0);if(!(!c|!jHa(b,d+96|0))){mHa(d+96|0,c,l&65535);e=0;u:{if(!(j[d+474|0]|j[d+475|0]<<8)){break u}while(1){v:{ip(b,d+32|0);w:{if((j[d+92|0]|j[d+93|0]<<8|(j[d+94|0]<<16|j[d+95|0]<<24))!=808538953){break w}f=e+l|0;c=f&65535;if(c>>>0>3999){break w}h[a+480190>>1]=f;f=o(c,104)+a|0;q=f+484380|0;lHa(d+32|0,q);lA(d+16|0,f+484423|0);i[114610]=0;C(369,((c<<5)+a|0)+946300|0,d+16|0)|0;c=i[114610];i[114610]=0;if((c|0)==1){break v}eb(d+16|0);if(!(j[d+48|0]|j[d+49|0]<<8|(j[d+50|0]<<16|j[d+51|0]<<24))){break w}ad(d+16|0,b,j[d+48|0]|j[d+49|0]<<8|(j[d+50|0]<<16|j[d+51|0]<<24));x:{if(!n){break x}c=Ic(d+8|0,h[f+484414>>1]&1?16:8,1,0,0);i[114610]=0;I(400,c|0,q|0,d+16|0)|0;c=i[114610];i[114610]=0;if((c|0)!=1){break x}e=B()|0;A()|0;hb(d+16|0);break a}hb(d+16|0)}e=e+1|0;if(e>>>0<(j[d+474|0]|j[d+475|0]<<8)>>>0){continue}break u}break}e=B()|0;A()|0;eb(d+16|0);break a}l=(j[d+474|0]|j[d+475|0]<<8)+l|0}if(s>>>0<k[a+480192>>1]){continue}break}}e=w^1}Xa=d+1328|0;return e&1}e=B()|0;A()|0;eb(d+96|0)}E(e|0);x()}function Dya(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,l=0,m=0,n=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,H=0,K=0,M=0,N=0;d=Xa-768|0;Xa=d;pc(b);e=d+160|0;f=yya(b,e);if(!f){oN(e)}a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{if(!f){break n}if(!qN(d+160|0)){break n}if(!wb(b,Vc(pN(d+160|0),_a))){break n}if(!c){u=1;break n}md(a,262144);Ws(d+104|0,2,d+160|0);oc(d+24|0,d+104|0);mb(a+1304400|0,d+24|0);eb(d+24|0);e=Bb(d+24|0,16976);mb(a+1304436|0,e);eb(e);e=Bb(d+24|0,16988);mb(a+1304448|0,e);eb(e);f=Bb(d+144|0,16992);i[114610]=0;D(219,d+104|0,f|0);e=i[114610];i[114610]=0;if((e|0)==1){break c}g[d+8|0]=j[d+190|0];e=j[d+189|0];i[114610]=0;g[d+127|0]=e;D(995,d+128|0,d+127|0);e=i[114610];i[114610]=0;if((e|0)==1){break e}e=0;i[114610]=0;J(451,d+24|0,d+104|0,d+8|0,d+128|0);l=i[114610];i[114610]=0;if((l|0)==1){break f}mb(a+1304460|0,d+24|0);eb(d+24|0);eb(d+128|0);ob(d+104|0);eb(f);i[a+480208>>2]=12;i[a+1304496>>2]=4;h[a+480188>>1]=j[d+198|0]|j[d+199|0]<<8;h[d+24>>1]=j[d+194|0]|j[d+195|0]<<8;h[d+104>>1]=3999;M=a,N=k[ef(d+24|0,d+104|0)>>1],h[M+480190>>1]=N;hz(Db(a+484360|0),d+256|0,j[d+192|0]|j[d+193|0]<<8,255,254);if(k[a+480188>>1]){while(1){f=(e<<5)+a|0;sg(f+480280|0);h[f+480284>>1]=(j[(d+e|0)+224|0]<<4|4)&244;e=e+1|0;if(e>>>0<k[a+480188>>1]){continue}break}}ad(d+104|0,b,o(j[d+194|0]|j[d+195|0]<<8,80));if(k[a+480190>>1]){l=c&2;p=d+72|0;e=0;while(1){i[114610]=0;C(996,d+104|0,d+24|0)|0;f=i[114610];i[114610]=0;if((f|0)==1){break m}i[114610]=0;G(580,d+8|0,2,p|0);f=i[114610];i[114610]=0;o:{p:{q:{if((f|0)==1){break q}i[114610]=0;D(415,d+128|0,d+8|0);f=i[114610];i[114610]=0;if((f|0)==1){break q}i[114610]=0;e=e+1|0;C(369,((e<<5)+a|0)+946300|0,d+128|0)|0;f=i[114610];i[114610]=0;if((f|0)==1){break p}eb(d+128|0);i[114610]=0;f=(o(e,104)+a|0)+484380|0;G(997,d+128|0,d+24|0,f|0);m=i[114610];i[114610]=0;r:{if((m|0)==1){break r}if(!l|!i[f>>2]){break o}m=j[d+42|0]|j[d+43|0]<<8|(j[d+44|0]<<16|j[d+45|0]<<24);i[114610]=0;m=C(256,b|0,m|0)|0;n=i[114610];i[114610]=0;if((n|0)==1){break r}if(!m){break o}i[114610]=0;I(400,d+128|0,f|0,b|0)|0;f=i[114610];i[114610]=0;if((f|0)!=1){break o}}a=B()|0;A()|0;break g}a=B()|0;A()|0;break g}a=B()|0;A()|0;eb(d+128|0);break g}if(e>>>0<k[a+480190>>1]){continue}break}}u=1;s:{if(!(c&1)){break s}c=j[d+196|0]|j[d+197|0]<<8;i[114610]=0;q=a+484344|0;D(401,q|0,c|0);c=i[114610];i[114610]=0;if((c|0)==1){break l}if(!(j[d+196|0]|j[d+197|0]<<8)){break s}v=d+24|4;w=d+24|2;y=d+24|5;z=d+24|3;H=d+24|1;p=0;while(1){i[114610]=0;c=I(402,q|0,p&65535,64)|0;e=i[114610];i[114610]=0;if((e|0)==1){break k}t:{if(!c){break t}c=(p<<1)+d|0;e=c+512|0;if(!(j[e|0]|j[e+1|0]<<8)){break t}c=j[c+512|0]|j[c+513|0]<<8;i[114610]=0;c=C(256,b|0,c<<4)|0;e=i[114610];i[114610]=0;if((e|0)==1){break k}if(!c){break t}r=0;c=Fb(q,p);i[114610]=0;s=I(471,c|0,0,0)|0;c=i[114610];i[114610]=0;if((c|0)==1){break h}while(1){i[114610]=0;c=C(258,b|0,1)|0;e=i[114610];i[114610]=0;u:{v:{w:{if((e|0)!=1){if(!c){break t}i[114610]=0;m=F(387,b|0)|0;c=i[114610];i[114610]=0;if((c|0)==1){break w}if(m){break v}r=r+1|0;s=o(k[a+480188>>1],6)+s|0;break u}a=B()|0;A()|0;break g}a=B()|0;A()|0;break g}h[d+28>>1]=0;i[d+24>>2]=0;c=m&31;f=o(c,6)+s|0;t=aj(d+24|0);l=k[a+480188>>1]>c>>>0;x:{y:{z:{A:{B:{C:{D:{if(!(m&32)){break D}i[114610]=0;D(472,d+128|0,b|0);c=i[114610];i[114610]=0;if((c|0)==1){break C}e=Nc(d+128|0);n=l?f:d+24|0;c=j[d+128|0];g[n|0]=c;g[(l?f+1|0:H)|0]=j[e|0];E:{if(c){if((c|0)==254){break E}if(c>>>0<121){break D}}c=0}g[n|0]=c}if(!(m&64)){break x}i[114610]=0;D(472,d+128|0,b|0);c=i[114610];i[114610]=0;if((c|0)==1){break j}K=Nc(d+128|0);c=l?f+3|0:z;e=j[d+128|0];g[c|0]=e;n=l?f+5|0:y;g[n|0]=j[K|0];if(e>>>0>15){break B}i[114610]=0;L(577,(l?f:t)|0);e=i[114610];i[114610]=0;if((e|0)!=1){break A}a=B()|0;A()|0;break g}a=B()|0;A()|0;break g}if(e>>>0>23){break y}t=c;c=j[e+16994|0];g[t|0]=c;break z}c=j[c|0]}c=c&255;if((c|0)!=23){if((c|0)!=9){break x}c=j[n|0];F:{G:{if(c>>>0>=136){e=c&127;break G}e=128;if(c>>>0<129){break F}}g[n|0]=e;c=e}g[n|0]=(o(c&127,255)>>>0)/127;break x}i[114610]=0;g[d+8|0]=64;c=C(391,n|0,d+8|0)|0;e=i[114610];i[114610]=0;if((e|0)!=1){g[n|0]=j[c|0]<<1;break x}a=B()|0;A()|0;break g}g[c|0]=0}if(!(m&128)){break u}g[(l?f+2|0:w)|0]=1;i[114610]=0;c=F(387,b|0)|0;e=i[114610];i[114610]=0;if((e|0)==1){break i}g[(l?f+4|0:v)|0]=c}if(r>>>0<64){continue}break}}p=p+1|0;if(p>>>0<(j[d+196|0]|j[d+197|0]<<8)>>>0){continue}break}}hb(d+104|0)}Xa=d+768|0;return u|0}a=B()|0;A()|0;break g}a=B()|0;A()|0;break g}a=B()|0;A()|0;break g}a=B()|0;A()|0;break g}a=B()|0;A()|0;break g}a=B()|0;A()|0}hb(d+104|0);break a}a=B()|0;A()|0;eb(d+128|0);break d}a=B()|0;A()|0}ob(d+104|0);break b}a=B()|0;A()|0}eb(f)}E(a|0);x()}function wLa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,l=0,m=0,n=0,p=0,q=0,r=0;e=Xa-128|0;Xa=e;pc(b);a:{if(!sS(b,12168)){break a}if(!Rz(b,e+112|0)){break a}if(!uS(e+112|0)){break a}if(!wb(b,Vc(tS(e+112|0),_a))){break a}if(!Ib(b,j[e+121|0]|j[e+122|0]<<8)){break a}b:{if(!c){break b}md(a,4096);i[a+480208>>2]=12;h[a+480188>>1]=(j[e+112|2]&31)+1;f=e+112|3;h[a+480190>>1]=j[f|0];Ni(a,1);d=Bb(e+56|0,12176);mb(a+1304436|0,d);eb(d);d=Bb(e+56|0,12194);mb(a+1304448|0,d);eb(d);d=Bb(e+80|0,12198);i[114610]=0;D(219,e+96|0,d|0);g=i[114610];i[114610]=0;c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{if((g|0)!=1){i[114610]=0;J(427,e+56|0,e+96|0,e+112|1,e+112|0);g=i[114610];i[114610]=0;if((g|0)==1){break o}mb(a+1304460|0,e+56|0);eb(e+56|0);ob(e+96|0);eb(d);i[a+1304496>>2]=4;p=uLa(e+96|0,j[f|0]);if(k[a+480190>>1]){f=1;d=1;while(1){i[114610]=0;C(428,b|0,e+56|0)|0;g=i[114610];i[114610]=0;if((g|0)==1){break k}i[114610]=0;D(429,e+56|0,(o(f,104)+a|0)+484380|0);g=i[114610];i[114610]=0;if((g|0)==1){break k}g=j[e+72|0];Ld(e+40|0,p,f+ -1|0);Od(e+40|0,(g&3)!=0);d=d+1|0;f=d&65535;if(f>>>0<=k[a+480190>>1]){continue}break}}i[114610]=0;I(430,b|0,a+1304400|0,-1)|0;f=i[114610];i[114610]=0;d=1;if((f|0)!=1){if(k[a+480190>>1]){while(1){i[114610]=0;I(431,b|0,(((d&65535)<<5)+a|0)+946300|0,-1)|0;f=i[114610];i[114610]=0;if((f|0)==1){break m}d=d+1|0;if((d&65535)>>>0<=k[a+480190>>1]){continue}break}}if(k[a+480188>>1]){d=0;while(1){i[114610]=0;f=(d<<5)+a|0;L(432,f+480280|0);g=i[114610];i[114610]=0;if((g|0)==1){break e}i[114610]=0;I(433,b|0,f+480289|0,-1)|0;f=i[114610];i[114610]=0;if((f|0)==1){break e}d=d+1|0;if(d>>>0<k[a+480188>>1]){continue}break}}f=e+112|4;d=j[f|0]|j[f+1|0]<<8;i[114610]=0;n=a+484344|0;D(401,n|0,d|0);d=i[114610];i[114610]=0;if((d|0)!=1){break l}}b=B()|0;A()|0;break d}b=B()|0;A()|0;break n}b=B()|0;A()|0;ob(e+96|0)}eb(d);break c}b=B()|0;A()|0;break d}if(j[f|0]|j[f+1|0]<<8){d=0;while(1){i[114610]=0;I(434,b|0,e+56|0,-1)|0;g=i[114610];i[114610]=0;p:{q:{if((g|0)==1){break q}i[114610]=0;g=I(402,n|0,d&65535,64)|0;l=i[114610];i[114610]=0;if((l|0)==1){break q}if(!g){break p}g=Fb(n,d);i[114610]=0;C(435,g|0,e+56|0)|0;g=i[114610];i[114610]=0;if((g|0)!=1){break p}}b=B()|0;A()|0;break d}d=d+1|0;if(d>>>0<(j[f|0]|j[f+1|0]<<8)>>>0){continue}break}}i[114610]=0;l=F(357,b|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break f}r:{if(!l){break r}i[114610]=0;d=C(258,b|0,l|0)|0;g=i[114610];i[114610]=0;if((g|0)==1){break f}if(!d){break r}g=Mt(e+56|0);i[114610]=0;I(436,b|0,g|0,l|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break h}d=Ab(e+40|0);i[114610]=0;D(111,d|0,l|0);l=i[114610];i[114610]=0;if((l|0)==1){break i}q=e,r=Jb(g),i[q>>2]=r;q=e,r=Kb(g),i[q+32>>2]=r;if(pb(e,e+32|0)){while(1){s:{l=j[i[e>>2]];if(l&128){q=e,r=Ye(d),i[q+16>>2]=r;Ad(e+24|0,e+16|0);i[114610]=0;N(437,d|0,i[e+24>>2],l&127,32)|0;l=i[114610];i[114610]=0;if((l|0)!=1){break s}break i}i[114610]=0;D(110,d|0,l<<24>>24);l=i[114610];i[114610]=0;if((l|0)!=1){break s}break i}Tf(e);if(pb(e,e+32|0)){continue}break}}i[114610]=0;J(438,e|0,4,5,d|0);l=i[114610];i[114610]=0;if((l|0)==1){break i}mb(d,e);eb(e);l=xb(d);i[114610]=0;l=F(439,l|0)|0;m=i[114610];i[114610]=0;if((m|0)==1){break i}m=lb(d);i[114610]=0;S(440,a+1304424|0,l|0,m|0,76,0)|0;l=i[114610];i[114610]=0;if((l|0)==1){break i}eb(d);Md(g)}d=Db(a+484360|0);g=e+112|6;g=j[g|0]|j[g+1|0]<<8;i[114610]=0;S(441,d|0,b|0,g|0,65535,65535)|0;d=i[114610];i[114610]=0;if((d|0)==1){break f}t:{u:{v:{w:{if(!(j[f|0]|j[f+1|0]<<8)){break w}g=c&1;d=0;while(1){i[114610]=0;l=C(258,b|0,4)|0;m=i[114610];i[114610]=0;x:{if((m|0)!=1){if(l){break x}break w}b=B()|0;A()|0;break d}i[114610]=0;l=F(390,b|0)|0;m=i[114610];i[114610]=0;if((m|0)==1){break u}i[114610]=0;G(341,e+56|0,b|0,l|0);l=i[114610];i[114610]=0;if((l|0)==1){break t}y:{if(!g){break y}i[114610]=0;l=C(442,n|0,d&65535)|0;m=i[114610];i[114610]=0;if((m|0)==1){break v}if(!l){break y}l=Fb(n,d);i[114610]=0;G(443,l|0,0,e+56|0);l=i[114610];i[114610]=0;if((l|0)==1){break v}}hb(e+56|0);d=d+1|0;if(d>>>0<(j[f|0]|j[f+1|0]<<8)>>>0){continue}break}}if(!(!(c&2)|!k[a+480190>>1])){f=1;d=1;while(1){c=o(f,104)+a|0;g=k[c+484414>>1];Ld(e+56|0,p,f+ -1|0);f=Ic(e+40|0,g&1?16:8,1,0,ib(e+56|0)?6:0);i[114610]=0;I(400,f|0,c+484380|0,b|0)|0;c=i[114610];i[114610]=0;if((c|0)==1){break j}d=d+1|0;f=d&65535;if(f>>>0<=k[a+480190>>1]){continue}break}}Td(p);break b}b=B()|0;A()|0;hb(e+56|0);break d}b=B()|0;A()|0;break d}b=B()|0;A()|0;break d}b=B()|0;A()|0;break d}b=B()|0;A()|0;break d}b=B()|0;A()|0;eb(d);break g}b=B()|0;A()|0}Md(g);break d}b=B()|0;A()|0;break d}b=B()|0;A()|0}Td(p)}E(b|0);x()}f=1}Xa=e+128|0;return f|0}function Jna(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,l=0,m=0,n=0,p=0,q=0;f=Xa-208|0;Xa=f;h[a+480212>>1]=0;i[a+480240>>2]=65536;i[a+480244>>2]=65536;TJ(a+900380|0);SJ(a+946300|0);d=VJ(f+48|0);i[114610]=0;e=a+906300|0;G(1408,e|0,e+4e4|0,d|0);e=i[114610];i[114610]=0;a:{b:{c:{d:{if((e|0)!=1){wm(d);e:{if(Op(b)){e=0;m=f+48|0;Ena(m);f:{g:{h:{if(c&16){break h}i[114610]=0;g=(c|0)!=0;l=I(1409,m|0,b|0,g|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break g}d=4;i:{if(l){break i}i[114610]=0;l=I(1410,m|0,b|0,g|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break g}d=5;if(l){break i}i[114610]=0;l=I(1411,m|0,b|0,g|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break g}d=6;if(l){break i}l=0;i[114610]=0;g=I(1412,m|0,b|0,g|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break g}d=3;if(!g){break h}}if(!c){e=1;break b}if(!Uc(m)){xO(b,_z(m,0)+12|0)}l=d}if(c&32){break b}d=77888;j:{k:{while(1){g=i[d+8>>2];n=(g>>1)+a|0;e=i[d+4>>2];e=g&1?i[i[n>>2]+e>>2]:e;i[114610]=0;e=I(e|0,n|0,b|0,c|0)|0;g=i[114610];i[114610]=0;if((g|0)!=1){if(e){break j}d=d+12|0;if((d|0)==78344){break k}continue}break}a=H(71348)|0;break f}i[a+480180>>2]=0;i[a+480184>>2]=0}if(!c){break b}if(!(i[a+480184>>2]|!l)){i[a+480184>>2]=l}bx(m);break e}a=H(71348)|0}b=A()|0;bx(m);if((U(71348)|0)!=(b|0)){break c}M(a|0)|0;i[114610]=0;K(81);a=i[114610];i[114610]=0;if((a|0)==1){a=B()|0;A()|0;i[114610]=0;K(20);b=i[114610];i[114610]=0;if((b|0)!=1){break c}a=H(0)|0;A()|0;gb(a)}x()}md(a,0);i[a+1074300>>2]=19465472}d=0;while(1){b=(d<<5)+a|0;Ag(b+480286|0,64);b=b+480284|0;if(k[b>>1]>=257){h[b>>1]=128}Pm((o(d,896)+a|0)+1074984|0,a,d&65535);d=d+1|0;if((d|0)!=127){continue}break}if(k[a+480190>>1]){l=a+1304392|0;d=1;while(1){g=o(d&65535,104)+a|0;n=g+484380|0;l:{if(ie(n)){Mx(n,a,0);break l}e=g+484414|0;b=k[e>>1];if(b&16384){break l}i[n>>2]=0;i[n+4>>2]=0;i[n+16>>2]=0;i[n+8>>2]=0;i[n+12>>2]=0;h[e>>1]=b&65505}b=g+484412|0;if(k[b>>1]>=65){h[b>>1]=64}m:{if(!(j[g+484415|0]&2)){break m}if(!Si(l)){break m}Hna(a)}d=d+1|0;if((d&65535)>>>0<=k[a+480190>>1]){continue}break}}d=0;e=0;while(1){b=i[(((d&65535)<<2)+a|0)+900380>>2];if(b){Zta(b,i[a+480180>>2]);e=d}d=d+1|0;if((d&65535)>>>0<=k[a+480192>>1]){continue}break}h[a+480192>>1]=e;d=i[a+480204>>2];if(d>>>0<1e4){i[a+480204>>2]=125e4;d=125e4}l=i[a+480196>>2];if(!l){i[a+480196>>2]=6;l=6}e=i[a+480220>>2];b=i[a+480216>>2];if(e>>>0<b>>>0){i[a+480220>>2]=b;e=b}i[a+1074420>>2]=d;d=a+1074416|0;i[d>>2]=l;i[a+1074412>>2]=e;i[a+1074408>>2]=b;i[a+1074444>>2]=i[a+480200>>2];qx(a+1074376|0);i[a+1074440>>2]=-65536;b=a+1074384|0;i[b>>2]=0;i[b+4>>2]=0;i[a+1074380>>2]=0;b=a+1074424|0;i[b>>2]=0;i[b+4>>2]=0;b=a+1074432|0;i[b>>2]=0;i[b+4>>2]=0;b=a+1074396|0;i[b>>2]=0;i[b+4>>2]=0;h[a+480276>>1]=0;i[a+1074392>>2]=i[d>>2];oo(a);Ri(a+1304360|0,1);b=a+484360|0;p=f,q=Jb(b),i[p+48>>2]=q;p=f,q=Kb(b),i[p+32>>2]=q;if(!pb(f+48|0,f+32|0)){break d}while(1){e=i[f+48>>2];Zf(e,Ti(e));b=k[e+28>>1];if(Wb(e)>>>0<=b>>>0){Fe(e,0)}Kx(f+48|0);if(pb(f+48|0,f+32|0)){continue}break}break d}a=B()|0;A()|0;wm(d);break c}g=f+48|0;Cna(g);n:{o:{p:{q:{r:{s:{t:{u:{v:{if((c&12)==12){d=0;while(1){c=o(d,160)+a|0;l=c+906300|0;b=l+16|0;e=j[b|0]|j[b+1|0]<<8|(j[b+2|0]<<16|j[b+3|0]<<24);b=l+20|0;w:{if(!(e|(j[b|0]|j[b+1|0]<<8|(j[b+2|0]<<16|j[b+3|0]<<24)))){break w}i[114610]=0;C(1413,l|0,a|0)|0;b=i[114610];i[114610]=0;x:{if((b|0)!=1){e=i[l>>2];if(!e){break x}c=i[c+906448>>2];b=i[i[e>>2]+56>>2];i[114610]=0;D(b|0,e|0,c|0);b=i[114610];i[114610]=0;if((b|0)!=1){break w}}a=B()|0;A()|0;break n}p=f,q=Gna(Jb(g),Kb(g),l),i[p+32>>2]=q;p=f,q=Kb(g),i[p+16>>2]=q;if(pb(f+32|0,f+16|0)){break w}i[114610]=0;i[f+32>>2]=c+906316;D(1414,g|0,f+32|0);b=i[114610];i[114610]=0;if((b|0)==1){break o}i[114610]=0;c=C(2,f+16|0,20510)|0;b=i[114610];i[114610]=0;if((b|0)==1){break v}b=KJ(l);i[114610]=0;D(1415,f|0,b|0);b=i[114610];i[114610]=0;if((b|0)==1){break u}i[114610]=0;G(3,f+32|0,c|0,f|0);b=i[114610];i[114610]=0;if((b|0)==1){break t}i[114610]=0;G(650,a|0,2,f+32|0);b=i[114610];i[114610]=0;if((b|0)==1){break s}eb(f+32|0);eb(f);eb(c)}d=d+1|0;if((d|0)!=250){continue}break}}b=i[a+1074368>>2];i[114610]=0;D(1416,a|0,b|0);b=i[114610];i[114610]=0;if((b|0)==1){break p}b=i[a+480180>>2];y:{if(!b){break y}Fr(a+8|0,ro(a));if(!i[a+1074304>>2]){break y}i[114610]=0;L(1417,a|0);a=i[114610];i[114610]=0;if((a|0)==1){break p}}IJ(g);e=(b|0)!=0;break a}a=B()|0;A()|0;break n}a=B()|0;A()|0;break q}a=B()|0;A()|0;break r}a=B()|0;A()|0;eb(f+32|0)}eb(f)}eb(c);break n}a=B()|0;A()|0;break n}a=B()|0;A()|0}IJ(g)}E(a|0);x()}bx(m)}Xa=f+208|0;return e|0}function A5(a,b,c,d,e,f,l){var n=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=p(0),D=0,E=0,F=0,G=p(0),H=0,I=0,J=0,K=0,L=p(0),M=0,N=0,O=0,P=0;u=Xa-2368|0;Xa=u;A=i[a+404>>2];D=j[c+1|0];H=A+o(D,40)|0;I=i[((j[c|0]<<2)+a|0)+104>>2];a:{t=i[a+4>>2];b:{if((t|0)>=1){while(1){n=j[(i[H+4>>2]+o(B,3)|0)+2|0];K=(u+1344|0)+(B<<2)|0;i[K>>2]=0;n=j[(n+H|0)+9|0];if(!k[((n<<1)+a|0)+132>>1]){Lb(a,21);a=0;break b}q=i[a+260>>2];c:{d:{if(Rb(a,1)){s=2;v=i[((B<<2)+a|0)+996>>2];t=q+o(n,1596)|0;J=i[(j[t+1588|0]<<2)+50620>>2];n=Pk(J)+ -1|0;O=v,P=Rb(a,n),h[O>>1]=P;O=v,P=Rb(a,n),h[O+2>>1]=P;w=0;if(j[t|0]){while(1){M=j[(t+w|0)+1|0];n=t+M|0;z=j[n+33|0];q=0;E=j[n+49|0];e:{if(!E){break e}n=i[a+124>>2]+o(j[n+65|0],2096)|0;if(i[a+1396>>2]<=9){Bj(a)}r=i[a+1392>>2];q=h[(n+((r&1023)<<1)|0)+36>>1];f:{if((q|0)>=0){y=r;r=j[q+i[n+8>>2]|0];i[a+1392>>2]=y>>>r;y=i[a+1396>>2]-r|0;r=(y|0)<0;i[a+1396>>2]=r?0:y;q=r?-1:q;break f}q=Nk(a,n)}if(!j[n+23|0]){break e}q=i[i[n+2088>>2]+(q<<2)>>2]}if(z){N=-1<<E^-1;z=s+z|0;while(1){n=0;r=h[((t+(M<<4)|0)+((q&N)<<1)|0)+82>>1];g:{if((r|0)<0){break g}r=i[a+124>>2]+o(r&65535,2096)|0;if(i[a+1396>>2]<=9){Bj(a)}y=i[a+1392>>2];n=h[(r+((y&1023)<<1)|0)+36>>1];h:{if((n|0)>=0){F=y;y=j[n+i[r+8>>2]|0];i[a+1392>>2]=F>>>y;F=i[a+1396>>2]-y|0;y=(F|0)<0;i[a+1396>>2]=y?0:F;n=y?-1:n;break h}n=Nk(a,r)}if(!j[r+23|0]){break g}n=i[i[r+2088>>2]+(n<<2)>>2]}q=q>>E;h[v+(s<<1)>>1]=n;s=s+1|0;if((z|0)!=(s|0)){continue}break}s=z}w=w+1|0;if(w>>>0<j[t|0]){continue}break}}if(i[a+1396>>2]!=-1){break d}}i[K>>2]=1;break c}h[u+320>>1]=257;z=t+1592|0;s=i[t+1592>>2];if((s|0)>=3){q=2;while(1){s=q<<1;w=s+t|0;E=j[w+1088|0];n=E<<1;r=t+338|0;F=k[s+r>>1];K=k[n+r>>1];y=r;w=j[w+1089|0];r=w<<1;n=l5(F,K,k[y+r>>1],h[n+v>>1],h[r+v>>1]);y=s+v|0;r=k[y>>1];i:{j:{if(r){g[w+(u+320|0)|0]=1;g[E+(u+320|0)|0]=1;g[(u+320|0)+q|0]=1;w=J-n|0;s=r<<16>>16;if(((w|0)<(n|0)?w:n)<<1<=(s|0)){if((w|0)>(n|0)){break i}n=(r^-1)+J|0;break j}if(s&1){n=n-(s+1>>>1|0)|0;break j}n=(s>>1)+n|0;break j}g[(u+320|0)+q|0]=0}h[y>>1]=n}q=q+1|0;s=i[z>>2];if((q|0)<(s|0)){continue}break}}n=0;if((s|0)<=0){break c}while(1){if(!j[(u+320|0)+n|0]){h[v+(n<<1)>>1]=65535;s=i[z>>2]}n=n+1|0;if((n|0)<(s|0)){continue}break}}B=B+1|0;t=i[a+4>>2];if((B|0)<(t|0)){continue}break}}k:{l:{q=i[a+80>>2];if(!(i[a+84>>2]!=i[a+92>>2]?q:0)){Tb(u+320|0,u+1344|0,t<<2);n=k[H>>1];if(n){z=n>>>0>1?n:1;v=i[(A+o(D,40)|0)+4>>2];n=0;while(1){r=v+o(n,3)|0;s=j[r+1|0];r=(u+1344|0)+(j[r|0]<<2)|0;if(!(i[(u+1344|0)+(s<<2)>>2]?i[r>>2]:0)){i[(u+1344|0)+(s<<2)>>2]=0;i[r>>2]=0}n=n+1|0;if((z|0)!=(n|0)){continue}break}}z=I>>1;v=A+o(D,40)|0;if(j[v+8|0]){s=0;while(1){q=0;if((t|0)>=1){w=i[v+4>>2];n=0;while(1){if(j[(w+o(n,3)|0)+2|0]==(s|0)){J=q+u|0;r=n<<2;m:{if(i[r+(u+1344|0)>>2]){B=1;r=0;break m}B=0;r=i[(a+r|0)+800>>2]}g[J|0]=B;i[(u+256|0)+(q<<2)>>2]=r;q=q+1|0}n=n+1|0;if((n|0)<(t|0)){continue}break}}k5(a,u+256|0,q,z,j[(s+v|0)+24|0],u);s=s+1|0;if(s>>>0<j[v+8|0]){t=i[a+4>>2];continue}break}q=i[a+80>>2]}if(!(i[a+84>>2]!=i[a+92>>2]?q:0)){q=k[H>>1];if(q){v=(z|0)>1?z:1;r=A+o(D,40)|0;t=a+800|0;while(1){s=q;q=q+ -1|0;if((I|0)>=2){n=i[r+4>>2]+o(q,3)|0;B=i[t+(j[n+1|0]<<2)>>2];D=i[t+(j[n|0]<<2)>>2];n=0;while(1){A=n<<2;w=A+B|0;G=m[w>>2];A=A+D|0;C=m[A>>2];n:{if(!(C<=p(0))){if(!(G<=p(0))){L=p(C-G);break n}L=C;C=p(G+C);break n}if(!(G<=p(0))){L=p(G+C);break n}L=C;C=p(C-G)}m[A>>2]=C;m[w>>2]=L;n=n+1|0;if((v|0)!=(n|0)){continue}break}}if((s|0)>1){continue}break}}if(i[a+4>>2]<1){break k}s=z<<2;n=0;while(1){t=n<<2;v=t+a|0;q=v;o:{if(i[t+(u+320|0)>>2]){yb(i[q+800>>2],0,s);break o}j5(a,H,n,I,i[q+800>>2],i[v+996>>2])}n=n+1|0;q=i[a+4>>2];if((n|0)<(q|0)){continue}break}break l}V(50392,50448,3319,50640);x()}V(50392,50448,3286,50640);x()}n=0;if((q|0)<=0){break k}while(1){i5(i[((n<<2)+a|0)+800>>2],I,a,j[c|0]);n=n+1|0;if((n|0)<i[a+4>>2]){continue}break}}WE(a);p:{if(j[a+1377|0]){i[a+1060>>2]=0-z;g[a+1377|0]=0;i[a+1064>>2]=1;i[a+1412>>2]=I-f;break p}c=i[a+1412>>2];if(!c){break p}n=e-d|0;if((c|0)>=(n|0)){i[a+1412>>2]=c-n;i[l>>2]=e;d=e;break p}d=c+d|0;i[l>>2]=d;i[a+1412>>2]=0}c=i[a+1064>>2];q:{r:{s:{if(i[a+1388>>2]==i[a+1404>>2]){t:{if(!c|!(j[a+1375|0]&4)){break t}c=i[a+1408>>2];l=i[a+1060>>2];if(c>>>0>=l+(f-d|0)>>>0){break t}e=b;b=c-l|0;b=(b>>>0>c>>>0?0:b)+d|0;b=(b|0)>(f|0)?f:b;i[e>>2]=b;i[a+1060>>2]=b+i[a+1060>>2];break q}i[a+1064>>2]=1;i[a+1060>>2]=i[a+1408>>2]+(d-z|0);break s}if(!c){break r}}i[a+1060>>2]=i[a+1060>>2]+(e-d|0)}if(i[a+84>>2]!=i[a+92>>2]?i[a+80>>2]:0){break a}i[b>>2]=f}a=1}Xa=u+2368|0;return a}V(50392,50448,3435,50640);x()}function gAa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,l=0,m=0,n=0,p=0,q=0,r=0,s=0,t=0,u=0;e=Xa-80|0;Xa=e;pc(b);a:{b:{c:{d:{e:{if($N(b,16612)){g=gp(e- -64|0);l=gp(e+48|0);q=ws(e+32|0);i[114610]=0;D(447,a|0,32768);d=i[114610];i[114610]=0;if((d|0)==1){break b}i[114610]=0;d=C(2,e+8|0,16621)|0;m=i[114610];i[114610]=0;if((m|0)==1){break c}mb(a+1304436|0,d);eb(d);i[114610]=0;d=C(2,e+8|0,16631)|0;m=i[114610];i[114610]=0;if((m|0)==1){break d}mb(a+1304448|0,d);eb(d);i[a+1304496>>2]=2;n=a+484360|0;m=e+24|4;f:{g:{h:{i:{j:{while(1){i[114610]=0;d=C(258,b|0,8)|0;f=i[114610];i[114610]=0;if((f|0)==1){break i}k:{l:{m:{n:{if(!d){break n}i[114610]=0;d=C(928,b|0,e+24|0)|0;f=i[114610];i[114610]=0;if((f|0)==1){break m}if(!d){break n}d=m;d=j[d|0]|j[d+1|0]<<8|(j[d+2|0]<<16|j[d+3|0]<<24);i[114610]=0;G(341,e+8|0,b|0,d<<8&16711680|d<<24|(d>>>8&65280|d>>>24));d=i[114610];i[114610]=0;if((d|0)==1){break l}i[114610]=0;d=F(337,e+8|0)|0;f=i[114610];i[114610]=0;if((f|0)==1){break e}if(d){break k}hb(e+8|0)}if(k[a+480188>>1]){break j}d=0;break f}a=B()|0;A()|0;break a}a=B()|0;A()|0;break a}o:{p:{q:{r:{s:{t:{d=e+24|0;d=j[d|0]|j[d+1|0]<<8|(j[d+2|0]<<16|j[d+3|0]<<24);d=d<<24|d<<8&16711680|(d>>>8&65280|d>>>24);if((d|0)<=1347175757){if((d|0)==1129140036){break t}if((d|0)==1346458708){break r}if((d|0)!=1346522948){break p}if(Wc(g)>>>0>255){break p}i[114610]=0;D(604,g|0,e+8|0);d=i[114610];i[114610]=0;if((d|0)==1){break e}break p}if((d|0)<=1396854595){if((d|0)==1347175758){break s}if(k[a+480190>>1]|(d|0)!=1396788560){break p}i[114610]=0;G(929,e+8|0,q|0,a|0);d=i[114610];i[114610]=0;if((d|0)==1){break e}break p}if((d|0)==1396854596){break q}if((d|0)!=1397769541){break p}i[114610]=0;d=F(255,e+8|0)|0;f=i[114610];i[114610]=0;if((f|0)==1){break e}if(d>>>0<2){break p}i[114610]=0;d=F(484,e+8|0)|0;f=i[114610];i[114610]=0;if((f|0)==1){break e}t=a,u=hd(d,1,255),i[t+480196>>2]=u;break p}if(k[a+480188>>1]){break p}i[114610]=0;d=F(255,e+8|0)|0;f=i[114610];i[114610]=0;if((f|0)==1){break e}f=0;if(d>>>0<8){break p}while(1){i[114610]=0;p=F(387,e+8|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break o}i[114610]=0;r=F(387,e+8|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break e}d=k[a+480188>>1];if(p|r){i[114610]=0;L(432,((d<<5)+a|0)+480280|0);d=i[114610];i[114610]=0;if((d|0)==1){break e}p=k[a+480188>>1];d=p+1|0;h[a+480188>>1]=d;h[((p<<5)+a|0)+480284>>1]=f+ -1>>>0<2?192:64}i[114610]=0;L(432,(((d&65535)<<5)+a|0)+480280|0);d=i[114610];i[114610]=0;if((d|0)==1){break e}d=k[a+480188>>1];h[a+480188>>1]=d+1;h[((d<<5)+a|0)+480284>>1]=f+ -1>>>0<2?192:64;f=f+1|0;if((f|0)!=4){continue}break}if(c){break p}hb(e+8|0);break g}i[114610]=0;d=F(255,e+8|0)|0;f=i[114610];i[114610]=0;if((f|0)==1){break e}if(d>>>0<2){break p}i[114610]=0;s=F(484,e+8|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break e}break p}d=Db(n);i[114610]=0;f=F(255,e+8|0)|0;p=i[114610];i[114610]=0;if((p|0)==1){break e}i[114610]=0;S(584,d|0,e+8|0,f|0,255,254)|0;d=i[114610];i[114610]=0;if((d|0)!=1){break p}break e}if(Wc(l)>>>0>3998){break p}i[114610]=0;d=F(255,e+8|0)|0;f=i[114610];i[114610]=0;if((f|0)==1){break e}if(!d){break p}i[114610]=0;D(604,l|0,e+8|0);d=i[114610];i[114610]=0;if((d|0)==1){break e}}hb(e+8|0);continue}break}break e}i[a+480200>>2]=256;i[a+480204>>2]=125e4;i[a+480260>>2]=452;i[a+480264>>2]=3424;i[a+480228>>2]=48;i[a+480232>>2]=48;b=Db(n);i[114610]=0;D(930,b|0,s&65535);b=i[114610];i[114610]=0;if((b|0)==1){break b}u:{if(!(c&1)){break u}d=0;b=Wc(g);i[114610]=0;D(401,a+484344|0,b&65535);b=i[114610];i[114610]=0;if((b|0)==1){break b}if(!Wc(g)){break u}b=0;while(1){d=_b(g,d);i[114610]=0;G(931,d|0,b&65535,a|0);d=i[114610];i[114610]=0;if((d|0)==1){break h}b=b+1|0;d=b&65535;if(Wc(g)>>>0>d>>>0){continue}break}}d=1;if(k[a+480190>>1]<2){break f}m=c&2;f=1;b=0;v:{while(1){if(!m|b>>>0>=Wc(l)>>>0){break g}w:{c=(o(f,104)+a|0)+484380|0;if(i[c>>2]){d=_b(l,b);i[114610]=0;d=F(255,d|0)|0;n=i[114610];i[114610]=0;if((n|0)==1){break w}kc(c,d);Ld(e+8|0,q,f+ -1|0);d=Ic(e+24|0,8,1,1,ib(e+8|0)?10:0);n=_b(l,b);i[114610]=0;I(400,d|0,c|0,n|0)|0;c=i[114610];i[114610]=0;if((c|0)==1){break v}b=b+1|0}d=1;f=f+1|0;if(f>>>0<k[a+480190>>1]){continue}break f}break}a=B()|0;A()|0;break a}a=B()|0;A()|0;break a}a=B()|0;A()|0;break a}a=B()|0;A()|0;break a}d=1}Td(q);Qc(l);Qc(g)}Xa=e+80|0;return d|0}a=B()|0;A()|0;hb(e+8|0);break a}a=B()|0;A()|0;break a}a=B()|0;A()|0;break a}a=B()|0;A()|0}Td(q);Qc(l);Qc(g);E(a|0);x()}function sW(a,b){var c=0,d=0,e=0,f=0;c=Xa-176|0;Xa=c;f=uv(c+160|0);a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{d=i[b>>2];if(d&1){i[114610]=0;i[c+144>>2]=19465472;D(242,c+96|0,c+144|0);d=i[114610];i[114610]=0;if((d|0)==1){break o}i[114610]=0;D(201,f|0,c+96|0);d=i[114610];i[114610]=0;if((d|0)==1){break n}eb(c+96|0);d=i[b>>2]}if(!(d&4)){break l}i[114610]=0;d=R(243)|0;e=i[114610];i[114610]=0;if((e|0)==1){break k}if(!d){break m}break l}b=B()|0;A()|0;break a}b=B()|0;A()|0;eb(c+96|0);break a}i[114610]=0;L(244,c+96|0);d=i[114610];i[114610]=0;p:{if((d|0)!=1){i[114610]=0;D(201,f|0,c+96|0);d=i[114610];i[114610]=0;if((d|0)==1){break p}eb(c+96|0);break l}b=B()|0;A()|0;break a}b=B()|0;A()|0;eb(c+96|0);break a}q:{d=i[b>>2];if(!(d&8)){break q}i[114610]=0;d=C(2,c+128|0,7142)|0;e=i[114610];i[114610]=0;r:{s:{t:{u:{v:{if((e|0)!=1){i[114610]=0;D(219,c+144|0,d|0);e=i[114610];i[114610]=0;if((e|0)==1){break v}i[114610]=0;G(245,c+96|0,c+144|0,7152);e=i[114610];i[114610]=0;if((e|0)==1){break u}i[114610]=0;D(201,f|0,c+96|0);e=i[114610];i[114610]=0;if((e|0)==1){break t}eb(c+96|0);ob(c+144|0);eb(d);d=i[b>>2];break q}b=B()|0;A()|0;break a}b=B()|0;A()|0;break r}b=B()|0;A()|0;break s}b=B()|0;A()|0;eb(c+96|0)}ob(c+144|0)}eb(d);break a}w:{if(!(d&16)){break w}i[114610]=0;L(236,c+96|0);d=i[114610];i[114610]=0;x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{I:{J:{K:{L:{M:{N:{O:{P:{Q:{R:{S:{T:{U:{V:{if((d|0)!=1){i[114610]=0;D(246,c+144|0,c+96|0);d=i[114610];i[114610]=0;if((d|0)==1){break y}d=Cc(c+144|0);eb(c+144|0);if(!d){i[114610]=0;d=C(2,c- -64|0,7156)|0;e=i[114610];i[114610]=0;if((e|0)==1){break V}i[114610]=0;D(219,c+80|0,d|0);e=i[114610];i[114610]=0;if((e|0)==1){break U}i[114610]=0;D(246,c+48|0,c+96|0);e=i[114610];i[114610]=0;if((e|0)==1){break T}i[114610]=0;G(247,c+144|0,c+80|0,c+48|0);e=i[114610];i[114610]=0;if((e|0)==1){break S}i[114610]=0;D(201,f|0,c+144|0);e=i[114610];i[114610]=0;if((e|0)==1){break R}eb(c+144|0);eb(c+48|0);ob(c+80|0);eb(d)}if(!Cc(xg(c+96|0))){i[114610]=0;d=C(2,c+32|0,7160)|0;e=i[114610];i[114610]=0;if((e|0)==1){break N}i[114610]=0;D(219,c+80|0,d|0);e=i[114610];i[114610]=0;if((e|0)==1){break M}e=xg(c+96|0);i[114610]=0;G(247,c+144|0,c+80|0,e|0);e=i[114610];i[114610]=0;if((e|0)==1){break L}i[114610]=0;D(201,f|0,c+144|0);e=i[114610];i[114610]=0;if((e|0)==1){break K}eb(c+144|0);ob(c+80|0);eb(d)}i[114610]=0;D(248,c+144|0,c+96|0);d=i[114610];i[114610]=0;if((d|0)==1){break H}d=Cc(c+144|0);eb(c+144|0);if(!d){i[114610]=0;d=C(2,c+16|0,7156)|0;e=i[114610];i[114610]=0;if((e|0)==1){break G}i[114610]=0;D(219,c+80|0,d|0);e=i[114610];i[114610]=0;if((e|0)==1){break F}i[114610]=0;D(248,c+48|0,c+96|0);e=i[114610];i[114610]=0;if((e|0)==1){break E}i[114610]=0;G(247,c+144|0,c+80|0,c+48|0);e=i[114610];i[114610]=0;if((e|0)==1){break D}i[114610]=0;D(201,f|0,c+144|0);e=i[114610];i[114610]=0;if((e|0)==1){break C}eb(c+144|0);eb(c+48|0);ob(c+80|0);eb(d)}Ie(c+96|0);d=i[b>>2];break w}b=B()|0;A()|0;break a}b=B()|0;A()|0;break x}b=B()|0;A()|0;break O}b=B()|0;A()|0;break P}b=B()|0;A()|0;break Q}b=B()|0;A()|0;eb(c+144|0)}eb(c+48|0)}ob(c+80|0)}eb(d);break x}b=B()|0;A()|0;break x}b=B()|0;A()|0;break I}b=B()|0;A()|0;break J}b=B()|0;A()|0;eb(c+144|0)}ob(c+80|0)}eb(d);break x}b=B()|0;A()|0;break x}b=B()|0;A()|0;break x}b=B()|0;A()|0;break z}b=B()|0;A()|0;break A}b=B()|0;A()|0;break B}b=B()|0;A()|0;eb(c+144|0)}eb(c+48|0)}ob(c+80|0)}eb(d);break x}b=B()|0;A()|0}Ie(c+96|0);break a}W:{if(!(d&32)){break W}i[114610]=0;d=R(243)|0;e=i[114610];i[114610]=0;if((e|0)==1){break k}if(d){break W}Oc(c+96|0);i[114610]=0;D(201,f|0,c+96|0);d=i[114610];i[114610]=0;if((d|0)==1){break b}eb(c+96|0)}if(j[b|0]&64){i[114610]=0;L(249,c+96|0);b=i[114610];i[114610]=0;if((b|0)==1){break j}i[114610]=0;D(201,f|0,c+96|0);b=i[114610];i[114610]=0;if((b|0)==1){break i}eb(c+96|0)}i[114610]=0;d=C(2,c+96|0,7166)|0;b=i[114610];i[114610]=0;if((b|0)==1){break h}i[114610]=0;G(250,c|0,f|0,d|0);b=i[114610];i[114610]=0;if((b|0)==1){break g}i[114610]=0;e=C(2,c+144|0,10991)|0;b=i[114610];i[114610]=0;if((b|0)==1){break f}i[114610]=0;G(251,a|0,c|0,e|0);a=i[114610];i[114610]=0;if((a|0)==1){break e}eb(e);eb(c);eb(d);Ok(f);Xa=c+176|0;return}b=B()|0;A()|0;break a}b=B()|0;A()|0;break a}b=B()|0;A()|0;eb(c+96|0);break a}b=B()|0;A()|0;break a}b=B()|0;A()|0;break c}b=B()|0;A()|0;break d}b=B()|0;A()|0;eb(e)}eb(c)}eb(d);break a}b=B()|0;A()|0;eb(c+96|0)}Ok(f);E(b|0);x()}function T2(a,b,c,d,e,f){var g=0,h=0,k=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;g=Xa-432|0;Xa=g;h=i[b+4>>2];a:{if(h>>>0<l[b+104>>2]){i[b+4>>2]=h+1;k=j[h|0];break a}k=Hc(b)}b:{c:{while(1){if((k|0)!=48){d:{if((k|0)!=46){break b}h=i[b+4>>2];if(h>>>0>=l[b+104>>2]){break d}i[b+4>>2]=h+1;k=j[h|0];break c}}else{h=i[b+4>>2];if(h>>>0<l[b+104>>2]){z=1;i[b+4>>2]=h+1;k=j[h|0]}else{z=1;k=Hc(b)}continue}break}k=Hc(b)}y=1;if((k|0)!=48){break b}while(1){r=r+ -1|0;h=v+ -1|0;if((h|0)!=-1){r=r+1|0}v=h;h=i[b+4>>2];e:{if(h>>>0<l[b+104>>2]){i[b+4>>2]=h+1;k=j[h|0];break e}k=Hc(b)}if((k|0)==48){continue}break}z=1}h=1073676288;while(1){f:{A=k|32;g:{h:{B=k+ -48|0;if(B>>>0<10){break h}if(A+ -97>>>0>5?(k|0)!=46:0){break f}if((k|0)!=46){break h}if(y){break f}y=1;v=p;r=m;break g}k=(k|0)>57?A+ -87|0:B;i:{if((m|0)<0?1:(m|0)<=0?p>>>0<=7:0){s=k+(s<<4)|0;break i}if((m|0)<0?1:(m|0)<=0?p>>>0<=28:0){Qf(g+48|0,k);_c(g+32|0,w,x,q,h,0,0,0,1073414144);w=i[g+32>>2];x=i[g+36>>2];q=i[g+40>>2];h=i[g+44>>2];_c(g+16|0,w,x,q,h,i[g+48>>2],i[g+52>>2],i[g+56>>2],i[g+60>>2]);Ff(g,n,o,t,u,i[g+16>>2],i[g+20>>2],i[g+24>>2],i[g+28>>2]);t=i[g+8>>2];u=i[g+12>>2];n=i[g>>2];o=i[g+4>>2];break i}if(!k|E){break i}_c(g+80|0,w,x,q,h,0,0,0,1073610752);Ff(g- -64|0,n,o,t,u,i[g+80>>2],i[g+84>>2],i[g+88>>2],i[g+92>>2]);t=i[g+72>>2];u=i[g+76>>2];E=1;n=i[g+64>>2];o=i[g+68>>2]}p=p+1|0;if(p>>>0<1){m=m+1|0}z=1}k=i[b+4>>2];if(k>>>0<l[b+104>>2]){i[b+4>>2]=k+1;k=j[k|0]}else{k=Hc(b)}continue}break}j:{k:{l:{if(!z){if(!i[b+104>>2]){if(f){break k}break l}c=i[b+4>>2];i[b+4>>2]=c+ -1;if(!f){break l}i[b+4>>2]=c+ -2;if(!y){break k}i[b+4>>2]=c+ -3;break k}if((m|0)<0?1:(m|0)<=0?p>>>0<=7:0){q=p;h=m;while(1){s=s<<4;q=q+1|0;if(q>>>0<1){h=h+1|0}if((q|0)!=8|h){continue}break}}m:{if((k&-33)==80){q=FD(b,f);k=_a;h=k;if(q|(h|0)!=-2147483648){break m}if(f){q=0;h=0;if(!i[b+104>>2]){break m}i[b+4>>2]=i[b+4>>2]+ -1;break m}n=0;o=0;Gg(b,0,0);c=0;b=0;break j}q=0;h=0;if(!i[b+104>>2]){break m}i[b+4>>2]=i[b+4>>2]+ -1}if(!s){Fh(g+112|0,+(e|0)*0);n=i[g+112>>2];o=i[g+116>>2];c=i[g+120>>2];b=i[g+124>>2];break j}f=y?v:p;r=(y?r:m)<<2|f>>>30;b=q+(f<<2)|0;f=h+r|0;f=b>>>0<q>>>0?f+1|0:f;b=b+ -32|0;h=f+ -1|0;p=b;m=b>>>0<4294967264?h+1|0:h;if((m|0)>0?1:(m|0)>=0?b>>>0>0-d>>>0:0){i[114584]=68;Qf(g+160|0,e);_c(g+144|0,i[g+160>>2],i[g+164>>2],i[g+168>>2],i[g+172>>2],-1,-1,-1,2147418111);_c(g+128|0,i[g+144>>2],i[g+148>>2],i[g+152>>2],i[g+156>>2],-1,-1,-1,2147418111);n=i[g+128>>2];o=i[g+132>>2];c=i[g+136>>2];b=i[g+140>>2];break j}b=d+ -226|0;f=p>>>0>=b>>>0;b=b>>31;if((m|0)>(b|0)?1:(m|0)>=(b|0)?f:0){if((s|0)>-1){while(1){Ff(g+416|0,n,o,t,u,0,0,0,-1073807360);h=vE(n,o,t,u,1073610752);f=(h|0)<0;b=f;Ff(g+400|0,n,o,t,u,b?n:i[g+416>>2],b?o:i[g+420>>2],b?t:i[g+424>>2],b?u:i[g+428>>2]);m=m+ -1|0;b=p+ -1|0;if((b|0)!=-1){m=m+1|0}p=b;t=i[g+408>>2];u=i[g+412>>2];n=i[g+400>>2];o=i[g+404>>2];s=s<<1|(h|0)>-1;if((s|0)>-1){continue}break}}f=p;b=d;h=(f-b|0)+32|0;f=m-((b>>31)+(f>>>0<b>>>0)|0)|0;b=h;f=b>>>0<32?f+1|0:f;c=((f|0)<0?1:(f|0)<=0?b>>>0<c>>>0:0)?(b|0)>0?b:0:c;n:{if((c|0)>=113){Qf(g+384|0,e);v=i[g+392>>2];r=i[g+396>>2];w=i[g+384>>2];x=i[g+388>>2];d=0;b=0;break n}Fh(g+352|0,yh(1,144-c|0));Qf(g+336|0,e);w=i[g+336>>2];x=i[g+340>>2];v=i[g+344>>2];r=i[g+348>>2];JD(g+368|0,i[g+352>>2],i[g+356>>2],i[g+360>>2],i[g+364>>2],w,x,v,r);C=i[g+376>>2];D=i[g+380>>2];d=i[g+372>>2];b=i[g+368>>2]}c=!(s&1)&((Lk(n,o,t,u,0,0,0,0)|0)!=0&(c|0)<32);Xl(g+320|0,c+s|0);_c(g+304|0,w,x,v,r,i[g+320>>2],i[g+324>>2],i[g+328>>2],i[g+332>>2]);Ff(g+272|0,i[g+304>>2],i[g+308>>2],i[g+312>>2],i[g+316>>2],b,d,C,D);_c(g+288|0,c?0:n,c?0:o,c?0:t,c?0:u,w,x,v,r);Ff(g+256|0,i[g+288>>2],i[g+292>>2],i[g+296>>2],i[g+300>>2],i[g+272>>2],i[g+276>>2],i[g+280>>2],i[g+284>>2]);Xu(g+240|0,i[g+256>>2],i[g+260>>2],i[g+264>>2],i[g+268>>2],b,d,C,D);e=i[g+240>>2];d=i[g+244>>2];c=i[g+248>>2];b=i[g+252>>2];if(!Lk(e,d,c,b,0,0,0,0)){i[114584]=68}ID(g+224|0,e,d,c,b,p);n=i[g+224>>2];o=i[g+228>>2];c=i[g+232>>2];b=i[g+236>>2];break j}i[114584]=68;Qf(g+208|0,e);_c(g+192|0,i[g+208>>2],i[g+212>>2],i[g+216>>2],i[g+220>>2],0,0,0,65536);_c(g+176|0,i[g+192>>2],i[g+196>>2],i[g+200>>2],i[g+204>>2],0,0,0,65536);n=i[g+176>>2];o=i[g+180>>2];c=i[g+184>>2];b=i[g+188>>2];break j}Gg(b,0,0)}Fh(g+96|0,+(e|0)*0);n=i[g+96>>2];o=i[g+100>>2];c=i[g+104>>2];b=i[g+108>>2]}i[a>>2]=n;i[a+4>>2]=o;i[a+8>>2]=c;i[a+12>>2]=b;Xa=g+432|0}function EKa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,k=0,l=0,m=0,n=0,p=0,q=0,r=0,s=0,t=0,u=0;e=Xa-3040|0;Xa=e;pc(b);l=e+1080|0;f=BKa(b,l);if(!f){_R(l)}a:{if(!f){break a}if(!cS(e+1080|0)){break a}if(!c){d=1;break a}if(!wb(b,Vc(1024,0))){break a}bS(b,e+560|0);bS(b,e+48|0);while(1){l=k<<2;f=l+(e+560|0)|0;if((j[f|0]|j[f+1|0]<<8|(j[f+2|0]<<16|j[f+3|0]<<24))>>>0>16777215){break a}l=l+(e+48|0)|0;if((j[l|0]|j[l+1|0]<<8|(j[l+2|0]<<16|j[l+3|0]<<24))>>>0<3|(j[l|0]|j[l+1|0]<<8|(j[l+2|0]<<16|j[l+3|0]<<24))>>>0>4096){break a}if(!aS(b,((j[f|0]|j[f+1|0]<<8|(j[f+2|0]<<16|j[f+3|0]<<24))+(j[l|0]|j[l+1|0]<<8|(j[l+2|0]<<16|j[l+3|0]<<24))|0)+2978|0)){break a}k=k+1|0;if((k|0)!=128){continue}break}md(a,2);Vh(a);d=Bb(e+16|0,12301);mb(a+1304436|0,d);eb(d);d=Bb(e+16|0,12306);mb(a+1304448|0,d);eb(d);d=Bb(e+16|0,12310);mb(a+1304460|0,d);eb(d);i[a+1304496>>2]=4;d=j[e+1080|0];i[a+480204>>2]=143e4;i[a+480196>>2]=d;m=a+484360|0;Fe(Db(m),j[e+1081|0]);i[a+480188>>2]=4194317;tb(a+1074308|0,95,1);d=0;while(1){h[((d<<5)+a|0)+480284>>1]=d&1?192:64;d=d+1|0;if((d|0)!=4){continue}break}d=0;b:{c:{d:{e:{while(1){k=d+1|0;l=o(k,104)+a|0;f=l+484380|0;kd(f,2);oi(e+32|0,1,(o(d,13)+e|0)+1082|0);oc(e+16|0,e+32|0);i[114610]=0;C(369,((k<<5)+a|0)+946300|0,e+16|0)|0;p=i[114610];i[114610]=0;if((p|0)==1){break e}eb(e+16|0);r=f;d=(e+1080|0)+(d<<4)|0;f=d+422|0;i[r>>2]=j[f|0]|j[f+1|0]<<8|(j[f+2|0]<<16|j[f+3|0]<<24);if((j[d+430|0]|j[d+431|0]<<8|(j[d+432|0]<<16|j[d+433|0]<<24))>>>0<=(j[d+422|0]|j[d+423|0]<<8|(j[d+424|0]<<16|j[d+425|0]<<24))>>>0){i[l+484384>>2]=j[d+426|0]|j[d+427|0]<<8|(j[d+428|0]<<16|j[d+429|0]<<24);d=j[d+430|0]|j[d+431|0]<<8|(j[d+432|0]<<16|j[d+433|0]<<24);h[l+484414>>1]=2;i[l+484388>>2]=d}i[l+484404>>2]=8287;d=k;if((d|0)!=32){continue}break}k=0;while(1){d=k+33|0;l=(o(d,104)+a|0)+484380|0;kd(l,2);oi(e+32|0,1,(o(k,13)+e|0)+2010|0);oc(e+16|0,e+32|0);i[114610]=0;C(369,((d<<5)+a|0)+946300|0,e+16|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break d}eb(e+16|0);i[e+24>>2]=0;i[e+16>>2]=0;i[e+20>>2]=0;d=(e+1080|0)+o(k,11)|0;f=j[d+1347|0];t=Nb(e+16|0,0),u=f,g[t|0]=u;f=j[d+1352|0];t=Nb(e+16|0,1),u=f,g[t|0]=u;f=j[d+1348|0];t=Nb(e+16|0,2),u=f,g[t|0]=u;f=j[d+1353|0];t=Nb(e+16|0,3),u=f,g[t|0]=u;f=j[d+1349|0];t=Nb(e+16|0,4),u=f,g[t|0]=u;f=j[d+1354|0];t=Nb(e+16|0,5),u=f,g[t|0]=u;f=j[d+1350|0];t=Nb(e+16|0,6),u=f,g[t|0]=u;f=j[d+1355|0];t=Nb(e+16|0,7),u=f,g[t|0]=u;f=j[d+1351|0];t=Nb(e+16|0,8),u=f,g[t|0]=u;f=j[d+1356|0];t=Nb(e+16|0,9),u=f,g[t|0]=u;d=j[d+1346|0];t=Nb(e+16|0,10),u=d,g[t|0]=u;i[e+8>>2]=i[e+24>>2];d=i[e+20>>2];i[e>>2]=i[e+16>>2];i[e+4>>2]=d;No(l,1,e);k=k+1|0;if((k|0)!=32){continue}break}st(Db(m),e+2778|0,256,255,65535);p=a+484344|0;Gf(p,128);r=c&1;l=0;f:{while(1){k=l<<2;d=k+(e+560|0)|0;vc(b,(j[d|0]|j[d+1|0]<<8|(j[d+2|0]<<16|j[d+3|0]<<24))+2978|0);d=k+(e+48|0)|0;ad(e+16|0,b,j[d|0]|j[d+1|0]<<8|(j[d+2|0]<<16|j[d+3|0]<<24));g:{if(!r){break g}i[114610]=0;d=I(402,p|0,l&65535,64)|0;k=i[114610];i[114610]=0;if((k|0)==1){break c}if(!d){break g}d=0;f=Fb(p,l);while(1){i[114610]=0;k=C(258,e+16|0,1)|0;m=i[114610];i[114610]=0;h:{i:{if((m|0)!=1){if(!k){break g}i[114610]=0;k=F(387,e+16|0)|0;m=i[114610];i[114610]=0;if((m|0)==1){break c}if(k>>>0>12){break i}i[114610]=0;m=I(471,f|0,d|0,k|0)|0;n=i[114610];i[114610]=0;if((n|0)==1){break c}i[114610]=0;D(472,e+32|0,e+16|0);n=i[114610];i[114610]=0;if((n|0)==1){break c}n=Nc(e+32|0);q=e+32|0;s=j[q|0];k=k>>>0>3;g[m|0]=((s&15)+(k?13:37)|0)+o(s>>>4&7,12);g[m+1|0]=((j[n|0]>>>4|0)+(k?33:1)|0)+(j[q|0]>>>3&16);$R(m,j[n|0],k);break h}break c}m=k+ -32|0;if((m&255)>>>0<=12){i[114610]=0;m=I(471,f|0,d|0,m&65535)|0;n=i[114610];i[114610]=0;if((n|0)==1){break c}i[114610]=0;n=F(387,e+16|0)|0;q=i[114610];i[114610]=0;if((q|0)==1){break c}$R(m,n,k>>>0>35);break h}if((k|0)!=64){if((k|0)!=96){break f}if(!d){break g}i[114610]=0;d=I(471,f|0,d+ -1|0,0)|0;k=i[114610];i[114610]=0;if((k|0)==1){break c}g[d+3|0]=14;break g}i[114610]=0;k=F(387,e+16|0)|0;m=i[114610];i[114610]=0;if((m|0)==1){break c}d=d+k|0}if(d>>>0<64){continue}break}}hb(e+16|0);l=l+1|0;if((l|0)!=128){continue}break}d=1;if(!(c&2)){break a}k=1;while(1){Xf(Ic(e+16|0,8,1,0,1),(o(k,104)+a|0)+484380|0,b);k=k+1|0;if((k|0)!=33){continue}break}break a}hb(e+16|0);d=0;break a}d=B()|0;A()|0;eb(e+16|0);break b}d=B()|0;A()|0;eb(e+16|0);break b}d=B()|0;A()|0;hb(e+16|0)}E(d|0);x()}Xa=e+3040|0;return d|0}function vG(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,h=0;e=Xa-416|0;Xa=e;g[e+415|0]=c;a:{if(Oi(b)){break a}f=j[Dj(b)|0];c=1;b:{if((f|0)==33){break b}if((f|0)!=63){break a}c=0}d=c;Oj(e+160|0,b,i[b+4>>2]+ -1|0);c=i[e+164>>2];i[b>>2]=i[e+160>>2];i[b+4>>2]=c}jd(e+160|0);c=i[e+160>>2];jd(e+376|0);h=Cj(c,i[e+380>>2],b);jd(e+160|0);c=i[b>>2];f=i[b+4>>2];c:{d:{e:{f:{if((h|0)==i[e+164>>2]){i[e+400>>2]=c;i[e+404>>2]=f;a=Zb(e+392|0,38187);c=i[e+404>>2];i[e+8>>2]=i[e+400>>2];i[e+12>>2]=c;c=i[a+4>>2];i[e>>2]=i[a>>2];i[e+4>>2]=c;if(mc(e+8|0,e)){a=P(8)|0;i[114610]=0;D(2141,e+376|0,e+415|0);b=i[114610];i[114610]=0;g:{h:{i:{if((b|0)!=1){i[114610]=0;G(2119,e+160|0,39252,e+376|0);b=i[114610];i[114610]=0;if((b|0)==1){break i}Ub(a,e+160|0);d=0;i[114610]=0;G(2009,a|0,83568,2017);b=i[114610];i[114610]=0;if((b|0)!=1){break e}b=B()|0;A()|0;eb(e+160|0);break h}b=B()|0;A()|0;break g}b=B()|0;d=1;A()|0}eb(e+376|0);if(!d){break f}}Q(a|0);break f}if(!d){break c}a=P(8)|0;i[114610]=0;d=C(2142,e+344|0,b|0)|0;b=i[114610];i[114610]=0;c=1;j:{k:{l:{m:{n:{o:{p:{q:{r:{if((b|0)!=1){i[114610]=0;G(2119,e+360|0,39131,d|0);b=i[114610];i[114610]=0;if((b|0)==1){break r}i[114610]=0;G(2137,e+376|0,e+360|0,39267);b=i[114610];i[114610]=0;if((b|0)==1){break q}i[114610]=0;D(2141,e+328|0,e+415|0);b=i[114610];i[114610]=0;if((b|0)==1){break p}i[114610]=0;G(138,e+160|0,e+376|0,e+328|0);b=i[114610];i[114610]=0;if((b|0)==1){break o}Ub(a,e+160|0);i[114610]=0;G(2009,a|0,83568,2017);b=i[114610];i[114610]=0;if((b|0)!=1){break e}b=B()|0;A()|0;eb(e+160|0);c=0;break n}b=B()|0;A()|0;break j}b=B()|0;A()|0;break k}b=B()|0;A()|0;break l}b=B()|0;A()|0;break m}b=B()|0;A()|0}eb(e+328|0)}eb(e+376|0)}eb(e+360|0)}eb(d)}if(!c){break f}Q(a|0);break f}i[e+320>>2]=c;i[e+324>>2]=f;c=Zb(e+312|0,38187);d=i[e+324>>2];i[e+152>>2]=i[e+320>>2];i[e+156>>2]=d;d=i[c+4>>2];i[e+144>>2]=i[c>>2];i[e+148>>2]=d;if(!mc(e+152|0,e+144|0)){break d}a=P(8)|0;i[114610]=0;D(2141,e+376|0,e+415|0);b=i[114610];i[114610]=0;s:{t:{u:{if((b|0)!=1){i[114610]=0;G(2119,e+160|0,39252,e+376|0);b=i[114610];i[114610]=0;if((b|0)==1){break u}Ub(a,e+160|0);d=0;i[114610]=0;G(2009,a|0,83568,2017);b=i[114610];i[114610]=0;if((b|0)!=1){break e}b=B()|0;A()|0;eb(e+160|0);break t}b=B()|0;A()|0;break s}b=B()|0;d=1;A()|0}eb(e+376|0);if(!d){break f}}Q(a|0)}E(b|0)}x()}c=i[b+4>>2];i[e+304>>2]=i[b>>2];i[e+308>>2]=c;c=Zb(e+296|0,38869);d=i[e+308>>2];i[e+136>>2]=i[e+304>>2];i[e+140>>2]=d;d=i[c+4>>2];i[e+128>>2]=i[c>>2];i[e+132>>2]=d;v:{if(!mc(e+136|0,e+128|0)){c=i[b+4>>2];i[e+288>>2]=i[b>>2];i[e+292>>2]=c;c=Zb(e+280|0,39166);d=i[e+292>>2];i[e+120>>2]=i[e+288>>2];i[e+124>>2]=d;d=i[c+4>>2];i[e+112>>2]=i[c>>2];i[e+116>>2]=d;if(!mc(e+120|0,e+112|0)){break v}}g[a+60|0]=j[e+415|0];break c}c=i[b+4>>2];i[e+272>>2]=i[b>>2];i[e+276>>2]=c;c=Zb(e+264|0,38887);d=i[e+276>>2];i[e+104>>2]=i[e+272>>2];i[e+108>>2]=d;d=i[c+4>>2];i[e+96>>2]=i[c>>2];i[e+100>>2]=d;w:{if(!mc(e+104|0,e+96|0)){c=i[b+4>>2];i[e+256>>2]=i[b>>2];i[e+260>>2]=c;c=Zb(e+248|0,39184);d=i[e+260>>2];i[e+88>>2]=i[e+256>>2];i[e+92>>2]=d;d=i[c+4>>2];i[e+80>>2]=i[c>>2];i[e+84>>2]=d;if(!mc(e+88|0,e+80|0)){break w}}g[a+61|0]=j[e+415|0];break c}c=i[b+4>>2];i[e+240>>2]=i[b>>2];i[e+244>>2]=c;c=Zb(e+232|0,38906);d=i[e+244>>2];i[e+72>>2]=i[e+240>>2];i[e+76>>2]=d;d=i[c+4>>2];i[e+64>>2]=i[c>>2];i[e+68>>2]=d;if(mc(e+72|0,e- -64|0)){g[a+62|0]=j[e+415|0];break c}c=i[b+4>>2];i[e+224>>2]=i[b>>2];i[e+228>>2]=c;c=Zb(e+216|0,38924);d=i[e+228>>2];i[e+56>>2]=i[e+224>>2];i[e+60>>2]=d;d=i[c+4>>2];i[e+48>>2]=i[c>>2];i[e+52>>2]=d;if(mc(e+56|0,e+48|0)){g[a+63|0]=j[e+415|0];break c}c=i[b+4>>2];i[e+208>>2]=i[b>>2];i[e+212>>2]=c;c=Zb(e+200|0,38948);d=i[e+212>>2];i[e+40>>2]=i[e+208>>2];i[e+44>>2]=d;d=i[c+4>>2];i[e+32>>2]=i[c>>2];i[e+36>>2]=d;if(mc(e+40|0,e+32|0)){g[a+64|0]=j[e+415|0];break c}c=i[b+4>>2];i[e+192>>2]=i[b>>2];i[e+196>>2]=c;b=Zb(e+184|0,39022);c=i[e+196>>2];i[e+24>>2]=i[e+192>>2];i[e+28>>2]=c;c=i[b+4>>2];i[e+16>>2]=i[b>>2];i[e+20>>2]=c;if(!mc(e+24|0,e+16|0)){break c}c=a+24|0;b=i[c>>2];d=b+24664|0;f=i[d+4>>2];i[e+176>>2]=i[d>>2];i[e+180>>2]=f;d=b+24656|0;f=i[d+4>>2];i[e+168>>2]=i[d>>2];i[e+172>>2]=f;d=i[b+24652>>2];i[e+160>>2]=i[b+24648>>2];i[e+164>>2]=d;b=e;if(j[e+415|0]){a=ZF(i[a+56>>2])}else{a=0}i[b+180>>2]=a;if(!Yv(e+160|0,i[c>>2]+24648|0)){break c}Vw(i[c>>2],e+160|0)}Xa=e+416|0}function C9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=Xa-48|0;Xa=d;e=Bb(d+32|0,38671);f=Xe(c,e);eb(e);a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{if(f){Li(a,0,i[b+24>>2]+1304448|0);break k}e=Bb(d+32|0,38676);f=Xe(c,e);eb(e);if(f){Li(a,0,i[b+24>>2]+1304436|0);break k}e=Bb(d+32|0,38686);f=Xe(c,e);eb(e);if(f){Li(a,0,i[b+24>>2]+1304484|0);break k}e=Bb(d+32|0,38699);f=Xe(c,e);eb(e);if(f){Li(a,0,i[b+24>>2]+1304472|0);break k}e=Bb(d+32|0,38717);f=Xe(c,e);eb(e);if(f){ama(d+32|0,i[i[b+24>>2]+480184>>2]);i[114610]=0;G(9,a|0,0,d+32|0);a=i[114610];i[114610]=0;if((a|0)==1){break j}eb(d+32|0);break k}e=Bb(d+32|0,38727);f=Xe(c,e);eb(e);if(f){$la(d+32|0,i[i[b+24>>2]+480184>>2]);i[114610]=0;G(9,a|0,0,d+32|0);a=i[114610];i[114610]=0;if((a|0)!=1){eb(d+32|0);break k}c=B()|0;A()|0;eb(d+32|0);break a}e=Bb(d+32|0,38742);f=Xe(c,e);eb(e);if(f){Li(a,0,i[b+24>>2]+1304460|0);break k}e=Bb(d+32|0,38750);f=Xe(c,e);eb(e);if(f){Li(a,0,i[b+24>>2]+1304412|0);break k}e=Bb(d+32|0,38757);f=Xe(c,e);eb(e);if(f){Kf(d+32|0,i[b+24>>2]+1304400|0);i[114610]=0;G(2185,a|0,b|0,d+32|0);a=i[114610];i[114610]=0;if((a|0)!=1){eb(d+32|0);break k}c=B()|0;A()|0;eb(d+32|0);break a}e=Bb(d+32|0,38763);f=Xe(c,e);eb(e);if(f){l:{b=b+24|0;if(!Uc(Qv(i[b>>2]))){if(i[eG(Qv(i[b>>2]))+12>>2]){break l}}Ab(a);break k}eoa(d+32|0,eG(Qv(i[b>>2])));i[114610]=0;G(9,a|0,0,d+32|0);a=i[114610];i[114610]=0;if((a|0)!=1){eb(d+32|0);break k}c=B()|0;A()|0;eb(d+32|0);break a}e=Bb(d+32|0,38768);f=Xe(c,e);eb(e);if(f){c=b+24|0;DM(d+32|0,i[c>>2]+1304424|0);m:{n:{o:{if(!Cc(d+32|0)){break o}c=i[c>>2];i[114610]=0;c=F(2186,c|0)|0;e=i[114610];i[114610]=0;if((e|0)==1){break m}p:{switch(c|0){case 0:i[114610]=0;D(2187,d+16|0,b|0);c=i[114610];i[114610]=0;if((c|0)!=1){mb(d+32|0,d+16|0);eb(d+16|0);break o}c=B()|0;A()|0;break b;case 1:i[114610]=0;D(2188,d+16|0,b|0);c=i[114610];i[114610]=0;if((c|0)!=1){mb(d+32|0,d+16|0);eb(d+16|0);break o}c=B()|0;A()|0;break b;case 2:if(Cc(d+32|0)){i[114610]=0;D(2187,d+16|0,b|0);c=i[114610];i[114610]=0;if((c|0)==1){break i}mb(d+32|0,d+16|0);eb(d+16|0)}if(!Cc(d+32|0)){break o}i[114610]=0;D(2188,d+16|0,b|0);c=i[114610];i[114610]=0;if((c|0)!=1){mb(d+32|0,d+16|0);eb(d+16|0);break o}c=B()|0;A()|0;break b;case 3:if(Cc(d+32|0)){i[114610]=0;D(2188,d+16|0,b|0);c=i[114610];i[114610]=0;if((c|0)==1){break h}mb(d+32|0,d+16|0);eb(d+16|0)}if(!Cc(d+32|0)){break o}i[114610]=0;D(2187,d+16|0,b|0);c=i[114610];i[114610]=0;if((c|0)!=1){mb(d+32|0,d+16|0);eb(d+16|0);break o}c=B()|0;A()|0;break b;case 4:i[114610]=0;D(2187,d+16|0,b|0);c=i[114610];i[114610]=0;q:{r:{if((c|0)!=1){i[114610]=0;D(2188,d|0,b|0);c=i[114610];i[114610]=0;if((c|0)==1){break q}if(Cc(d+16|0)){break r}i[114610]=0;C(1251,d+32|0,d+16|0)|0;c=i[114610];i[114610]=0;if((c|0)!=1){break r}break d}c=B()|0;A()|0;break b}if(!Cc(d)){i[114610]=0;C(1251,d+32|0,d|0)|0;c=i[114610];i[114610]=0;if((c|0)==1){break d}}eb(d);eb(d+16|0);break o}c=B()|0;A()|0;break c;case 5:break p;default:break o}}i[114610]=0;D(2187,d+16|0,b|0);c=i[114610];i[114610]=0;s:{if((c|0)!=1){i[114610]=0;D(2188,d|0,b|0);c=i[114610];i[114610]=0;if((c|0)==1){break n}if(Cc(d)){break s}i[114610]=0;C(1251,d+32|0,d|0)|0;c=i[114610];i[114610]=0;if((c|0)!=1){break s}break f}c=B()|0;A()|0;break b}if(!Cc(d+16|0)){i[114610]=0;C(1251,d+32|0,d+16|0)|0;c=i[114610];i[114610]=0;if((c|0)==1){break f}}eb(d);eb(d+16|0)}i[114610]=0;G(2185,a|0,b|0,d+32|0);a=i[114610];i[114610]=0;if((a|0)==1){break m}eb(d+32|0);break k}c=B()|0;A()|0;break e}c=B()|0;A()|0;break b}e=Bb(d+32|0,38776);f=Xe(c,e);eb(e);if(f){DM(d+32|0,i[b+24>>2]+1304424|0);i[114610]=0;G(2185,a|0,b|0,d+32|0);a=i[114610];i[114610]=0;if((a|0)!=1){eb(d+32|0);break k}c=B()|0;A()|0;eb(d+32|0);break a}e=c;c=Bb(d+32|0,38788);e=Xe(e,c);eb(c);if(e){a=Ab(a);b=b+68|0;g=d,h=Jb(b),i[g+32>>2]=h;g=d,h=Kb(b),i[g+16>>2]=h;if(!pb(d+32|0,d+16|0)){break k}c=1;while(1){b=i[d+32>>2];if(!(c&1)){i[114610]=0;C(1995,a|0,38797)|0;c=i[114610];i[114610]=0;if((c|0)==1){break g}}i[114610]=0;C(1251,a|0,b|0)|0;b=i[114610];i[114610]=0;if((b|0)==1){break g}_m(d+32|0);c=0;if(pb(d+32|0,d+16|0)){continue}break}break k}Bb(a,38187)}Xa=d+48|0;return}c=B()|0;A()|0;eb(d+32|0);break a}c=B()|0;A()|0;break b}c=B()|0;A()|0;break b}c=B()|0;A()|0;eb(a);break a}c=B()|0;A()|0;eb(d)}eb(d+16|0);break b}c=B()|0;A()|0;eb(d)}eb(d+16|0)}eb(d+32|0)}E(c|0);x()}function vIa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,l=0,m=0,n=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;d=Xa-336|0;Xa=d;pc(b);a:{if(!Xs(b,d+320|0)){break a}if(!$Q(d+320|0)){break a}if(i[d+320>>2]==1179472708){Ib(b,4)}if(!Se(b,d+312|0)|i[d+312>>2]!=1196314451){break a}if(!c){e=1;break a}n=d+312|4;l=n;lS(b,d+120|0,j[l|0]|j[l+1|0]<<8|(j[l+2|0]<<16|j[l+3|0]<<24));if((j[d+156|0]|j[d+157|0]<<8)>>>0>128|(j[d+162|0]|j[d+163|0]<<8)>>>0>16|((j[d+160|0]|j[d+161|0]<<8)>>>0>256|(j[d+154|0]|j[d+155|0]<<8)>>>0>128)){break a}md(a,8192);e=Bb(d+40|0,12774);mb(a+1304436|0,e);eb(e);e=Bb(d+40|0,12786);mb(a+1304448|0,e);eb(e);i[a+1304496>>2]=4;Ws(d+104|0,2,d+120|0);oc(d+40|0,d+104|0);mb(a+1304400|0,d+40|0);eb(d+40|0);h[d+40>>1]=j[d+162|0]|j[d+163|0]<<8;h[d+104>>1]=1;v=a,w=k[ri(d+40|0,d+104|0)>>1],h[v+480188>>1]=w;i[a+480196>>2]=j[d+166|0];i[a+480204>>2]=o(j[d+167|0],1e4);g[d+40|0]=j[d+164|0];g[d+104|0]=64;e=j[Xb(d+40|0,d+104|0)|0];i[a+480200>>2]=e<<2;if(!e){i[a+480200>>2]=256}e=a;b:{if(j[d+165|0]==128){i[d+40>>2]=256/k[a+480188>>1];i[d+104>>2]=128;l=i[rb(d+40|0,d+104|0)>>2];break b}l=j[d+165|0]&127}i[e+480228>>2]=l;e=0;while(1){l=(e<<5)+a|0;sg(l+480280|0);f=d+e|0;if(j[f+168|0]<=128){h[l+480284>>1]=j[f+168|0]<<1}e=e+1|0;if((e|0)!=16){continue}break}e=a+484360|0;fn(Db(e),d+184|0,j[d+156|0]|j[d+157|0]<<8,255,254);if((j[d+154|0]|j[d+155|0]<<8)>>>0<(j[d+156|0]|j[d+157|0]<<8)>>>0){Fe(Db(e),j[d+154|0]|j[d+155|0]<<8)}e=1;if(!Se(b,d+312|0)){break a}s=c&2;p=a+484344|0;t=c&1;u=d+76|0;while(1){c=n;ad(d+104|0,b,j[c|0]|j[c+1|0]<<8|(j[c+2|0]<<16|j[c+3|0]<<24));c:{d:{e:{if(!(!t|i[d+312>>2]!=1414807888)){i[114610]=0;r=q&65535;c=I(402,p|0,r|0,64)|0;e=i[114610];i[114610]=0;if((e|0)==1){break e}if(!c){break c}i[114610]=0;C(338,d+104|0,2)|0;c=i[114610];i[114610]=0;if((c|0)==1){break e}Tg(d+40|0);l=0;f:{while(1){i[114610]=0;c=C(258,d+104|0,1)|0;e=i[114610];i[114610]=0;g:{h:{if((e|0)!=1){if(c^1|l>>>0>63){break f}i[114610]=0;e=F(387,d+104|0)|0;c=i[114610];i[114610]=0;if((c|0)==1){break h}if(e){break g}l=l+1|0;continue}b=B()|0;A()|0;break d}b=B()|0;A()|0;break d}c=d+40|0;i:{j:{k:{f=e&15;l:{if(k[a+480188>>1]>f>>>0){c=Fb(p,r);i[114610]=0;c=I(471,c|0,l|0,f|0)|0;f=i[114610];i[114610]=0;if((f|0)==1){break l}}m:{if(!(e&128)){break m}i[114610]=0;f=F(387,d+104|0)|0;m=i[114610];i[114610]=0;if((m|0)==1){break k}if(!f){break m}g[c|0]=f>>>0<109?f+12|0:f}if(!(e&64)){break i}i[114610]=0;f=F(387,d+104|0)|0;m=i[114610];i[114610]=0;if((m|0)!=1){break j}}b=B()|0;A()|0;break d}b=B()|0;A()|0;break d}g[c+1|0]=f}n:{o:{p:{q:{r:{s:{t:{u:{if(e&32){g[c+2|0]=1;i[114610]=0;f=F(387,d+104|0)|0;m=i[114610];i[114610]=0;if((m|0)==1){break u}i[114610]=0;g[d+24|0]=f;g[d+8|0]=64;f=C(391,d+24|0,d+8|0)|0;m=i[114610];i[114610]=0;if((m|0)==1){break t}g[c+4|0]=j[f|0]}if(!(e&16)){continue}i[114610]=0;D(472,d+24|0,d+104|0);e=i[114610];i[114610]=0;if((e|0)==1){break s}m=Nc(d+24|0);f=d+24|0;e=j[f|0];switch(e+ -17|0){case 2:break q;case 0:case 1:break r;default:break p}}b=B()|0;A()|0;break d}b=B()|0;A()|0;break d}b=B()|0;A()|0;break d}e=e&15;break o}g[f|0]=33;g[m|0]=145;e=j[f|0];break n}if(e>>>0<17){break n}e=(e&240)==32?9:-1}g[f|0]=e}g[c+3|0]=e;g[c+5|0]=j[m|0];i[114610]=0;L(577,c|0);c=i[114610];i[114610]=0;if((c|0)!=1){continue}break}b=B()|0;A()|0;break d}q=q+1|0;break c}if(i[d+312>>2]!=1414745673){break c}if(!bn(a)){break c}c=k[a+480190>>1]+1|0;h[a+480190>>1]=c;i[114610]=0;C(578,d+104|0,d+40|0)|0;e=i[114610];i[114610]=0;v:{w:{x:{if((e|0)==1){break x}i[114610]=0;c=(o(c&65535,104)+a|0)+484380|0;D(579,d+40|0,c|0);e=i[114610];i[114610]=0;if((e|0)==1){break x}i[114610]=0;G(580,d+8|0,2,u|0);e=i[114610];i[114610]=0;if((e|0)==1){break w}i[114610]=0;D(415,d+24|0,d+8|0);e=i[114610];i[114610]=0;if((e|0)==1){break w}e=k[a+480190>>1];i[114610]=0;C(369,((e<<5)+a|0)+946300|0,d+24|0)|0;e=i[114610];i[114610]=0;if((e|0)==1){break v}eb(d+24|0);if(!s){break c}i[114610]=0;D(581,d+24|0,d+40|0);e=i[114610];i[114610]=0;if((e|0)!=1){i[114610]=0;I(400,d+24|0,c|0,d+104|0)|0;c=i[114610];i[114610]=0;if((c|0)!=1){break c}}b=B()|0;A()|0;break d}b=B()|0;A()|0;break d}b=B()|0;A()|0;break d}b=B()|0;A()|0;eb(d+24|0);break d}b=B()|0;A()|0}hb(d+104|0);E(b|0);x()}hb(d+104|0);e=1;if(Se(b,d+312|0)){continue}break}}Xa=d+336|0;return e|0}function Xia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,l=0,n=0;e=Xa-144|0;Xa=e;d=-1;a:{b:{c:{if(!kt(i[i[b>>2]+ -12>>2]+b|0)){b=Ek(e+40|0,b);i[114610]=0;d=C(686,e+24|0,32396)|0;f=i[114610];i[114610]=0;d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{if((f|0)!=1){i[114610]=0;i[e+16>>2]=83886084;i[e+20>>2]=0;G(687,b|0,d|0,e+16|0);f=i[114610];i[114610]=0;if((f|0)==1){break F}ob(d);i[114610]=0;g[e+15|0]=0;d=C(686,e+24|0,32406)|0;f=i[114610];i[114610]=0;if((f|0)==1){break E}i[114610]=0;I(688,b|0,e+15|0,d|0)|0;f=i[114610];i[114610]=0;if((f|0)==1){break D}ob(d);i[114610]=0;f=j[e+15|0];d=C(686,e+24|0,32411)|0;l=i[114610];i[114610]=0;if((l|0)==1){break C}i[114610]=0;f=f?0:c;J(1605,b|0,a+40|0,d|0,f|0);c=i[114610];i[114610]=0;if((c|0)==1){break B}ob(d);i[114610]=0;h[e+12>>1]=65535;c=C(686,e+24|0,32413)|0;d=i[114610];i[114610]=0;if((d|0)==1){break A}i[114610]=0;I(1184,b|0,e+12|0,c|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break z}ob(c);i[114610]=0;h[e+10>>1]=0;c=C(686,e+24|0,32415)|0;d=i[114610];i[114610]=0;if((d|0)==1){break y}i[114610]=0;I(1184,b|0,e+10|0,c|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break x}ob(c);h[a>>1]=k[e+10>>1];i[114610]=0;c=C(686,e+24|0,32417)|0;d=i[114610];i[114610]=0;if((d|0)==1){break w}i[114610]=0;J(1606,b|0,a+52|0,c|0,f|0);d=i[114610];i[114610]=0;if((d|0)==1){break v}ob(c);i[114610]=0;c=C(686,e+24|0,32419)|0;d=i[114610];i[114610]=0;if((d|0)==1){break u}i[114610]=0;I(1571,b|0,a+36|0,c|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break t}ob(c);i[114610]=0;c=C(686,e+24|0,32421)|0;d=i[114610];i[114610]=0;if((d|0)==1){break s}i[114610]=0;f=a+4|0;N(1607,b|0,f|0,c|0,1608)|0;d=i[114610];i[114610]=0;if((d|0)==1){break r}ob(c);i[114610]=0;c=C(686,e+24|0,32426)|0;d=i[114610];i[114610]=0;if((d|0)==1){break q}i[114610]=0;l=a+28|0;I(1609,b|0,l|0,c|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break p}ob(c);i[114610]=0;c=C(686,e+24|0,32431)|0;d=i[114610];i[114610]=0;if((d|0)==1){break o}i[114610]=0;I(1609,b|0,a+30|0,c|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break n}ob(c);i[114610]=0;c=C(686,e+24|0,32436)|0;d=i[114610];i[114610]=0;if((d|0)==1){break m}i[114610]=0;I(1610,b|0,a+32|0,c|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break l}ob(c);i[114610]=0;h[e+8>>1]=0;c=C(686,e+24|0,32441)|0;d=i[114610];i[114610]=0;if((d|0)==1){break c}i[114610]=0;I(1184,b|0,e+8|0,c|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break k}ob(c);d=-1;if(i[b>>2]&1073741824|(k[l>>1]+300&65535)>>>0>=601){break d}c=k[a>>1];if(c>>>0>3|(c|0)==2|h[a+30>>1]<0){break d}c=i[a+36>>2];i[114610]=0;c=F(864,c|0)|0;n=i[114610];i[114610]=0;if((n|0)==1){break j}i[114610]=0;i[e+24>>2]=c;i[e+16>>2]=0;c=I(1241,e+24|0,e+16|0,32392)|0;n=i[114610];i[114610]=0;if((n|0)==1){break i}i[a+36>>2]=i[c>>2];if(qb(f)>>>0>32767){break d}switch(k[a>>1]+ -1|0){case 0:break g;case 2:break h;default:break f}}a=B()|0;A()|0;break a}a=B()|0;A()|0;ob(d);break a}a=B()|0;A()|0;break a}a=B()|0;A()|0;ob(d);break a}a=B()|0;A()|0;break a}a=B()|0;A()|0;ob(d);break a}a=B()|0;A()|0;break a}a=B()|0;A()|0;ob(c);break a}a=B()|0;A()|0;break a}a=B()|0;A()|0;ob(c);break a}a=B()|0;A()|0;break a}a=B()|0;A()|0;ob(c);break a}a=B()|0;A()|0;break a}a=B()|0;A()|0;ob(c);break a}a=B()|0;A()|0;break a}a=B()|0;A()|0;ob(c);break a}a=B()|0;A()|0;break a}a=B()|0;A()|0;ob(c);break a}a=B()|0;A()|0;break a}a=B()|0;A()|0;ob(c);break a}a=B()|0;A()|0;break a}a=B()|0;A()|0;ob(c);break a}a=B()|0;A()|0;ob(c);break a}a=B()|0;A()|0;break a}a=B()|0;A()|0;break a}if(h[e+8>>1]<1){break d}h[e+6>>1]=k[a+30>>1];m[e+24>>2]=m[a+32>>2];c=k[a+28>>1];i[114610]=0;h[e+16>>1]=c;h[e+18>>1]=(c+k[e+8>>1]|0)+ -1;a=N(1611,a|0,e+6|0,e+24|0,e+16|0)|0;c=i[114610];i[114610]=0;if((c|0)!=1){if(a){break e}break d}a=B()|0;A()|0;break a}if(h[e+8>>1]<1){break d}m[e+24>>2]=m[a+32>>2];c=k[a+28>>1];i[114610]=0;h[e+16>>1]=c;h[e+18>>1]=(c+k[e+8>>1]|0)+ -1;a=S(1612,a|0,f|0,e+24|0,e+16|0,l|0)|0;c=i[114610];i[114610]=0;if((c|0)!=1){if(a){break e}break d}a=B()|0;A()|0;break a}i[114610]=0;L(1613,a|0);a=i[114610];i[114610]=0;if((a|0)==1){break b}}d=1}Yf(b)}Xa=e+144|0;return d|0}a=B()|0;A()|0;break a}a=B()|0;A()|0}Yf(b);E(a|0);x()}function CK(a,b,c,d,e){var f=0,l=0,m=0,n=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;m=Xa-16|0;Xa=m;a:{if(!Jd(d&255)){break a}p=(o(b,896)+a|0)+1074984|0;b:{c:{if(e?0:!(!(i[a+480180>>2]&17825824)|!k[a+480192>>1])){break c}if(Pi(p)){break c}d=o(b,896)+a|0;e=d+1075060|0;if(!i[e>>2]|j[d+1075073|0]&4){break a}c=o(b,896)+a|0;l=c+1075004|0;f=c+1075008|0;if(!(i[l>>2]|i[f>>2])){break a}c=EK(a,b);if((c|0)==65535){break a}n=a+1074984|0;c=n+o(c,896)|0;Mr(c,p);g[c+851|0]=0;g[c+827|0]=0;h[c+808>>1]=b+1;i[c+88>>2]=i[c+88>>2]&-918529;vs(c+810|0);i[c+696>>2]=0;i[c+88>>2]=i[c+88>>2]|2101248;i[e>>2]=0;i[p>>2]=0;i[p+4>>2]=0;c=n+o(b,896)|0;i[c+92>>2]=0;i[c+96>>2]=0;i[l>>2]=0;i[f>>2]=0;if(!(j[d+1075073|0]&2)){break b}a=a+1304392|0;if(!$c(a)){break b}Zh(i[a>>2],b,1);break b}e=o(b,896)+a|0;q=i[e+1075088>>2];c=k[a+480192>>1]<c>>>0?0:c;l=i[(c?((c<<2)+a|0)+900380|0:e+1075640|0)>>2];d:{if(!l){break d}n=d+ -1|0;c=k[Mc(l+236|0,n)>>1];f=a+1074308|0;kb(m+8|0,f,104);e:{if(ib(m+8|0)){kb(m,f,34);if(ib(m)){break e}}d=j[Nb(l+108|0,n)|0]}if((c+ -1&65535)>>>0<=3998){q=(o(c,104)+a|0)+484380|0;break d}kb(m+8|0,f,43);if(!ib(m+8|0)){break d}if(!Xh(l)){break a}}if(j[e+1075073|0]&4){break a}if(b>>>0<=255){n=a+1304392|0;t=a+1074308|0;w=b+1|0;c=b;while(1){f=(b|0)==(c|0);f:{if(c>>>0<k[a+480188>>1]?!f:0){break f}e=o(c,896)+a|0;if(k[e+1075792>>1]!=(w|0)?!f:0){break f}v=e+1075640|0;f=i[v>>2];if(!f){break f}r=e+1074984|0;g:{h:{i:{j:{k:{l:{m:{switch(j[f+17|0]+ -1|0){case 0:if(!d){break f}s=(f|0)==(l|0)&j[e+1075803|0]==(d|0);u=s;if(!l){break l}if(s){break i}break f;case 1:if(!q|i[e+1075088>>2]!=(q|0)){break f}if((f|0)==(l|0)){break g}kb(m+8|0,t,104);if(!ib(m+8|0)){break g}break f;case 3:break k;case 2:break m;default:break f}}if(l){break j}u=(f|0)==(l|0)}if(u){break g}break f}if(!l){break f}s=j[l+34|0];if(!s){break f}if((s|0)==j[f+34|0]){break h}break f}if((f|0)!=(l|0)){break f}}if(!j[l+34|0]){break g}}if(!j[e+1075803|0]|j[f+18|0]>2){break g}kb(m+8|0,t,34);Kj(a,c&65535,wM(r,ib(m+8|0))+255|0,0);g[e+1075806|0]=0}n:{o:{switch(j[i[v>>2]+18|0]){case 0:Bm(a,r);i[e+1075672>>2]=0;if(!(j[e+1075073|0]&2)){break n}if(!$c(n)){break n}Zh(i[n>>2],c&65535,1);break n;case 1:Bm(a,r);if(!(j[e+1075073|0]&2)){break n}if(!$c(n)){break n}Rj(i[n>>2],c&65535);break n;case 2:break o;default:break n}}r=e+1075072|0;f=i[r>>2];i[r>>2]=f|4096;if(!(f&512)){break n}if(!$c(n)){break n}kb(m+8|0,t,105);if(ib(m+8|0)){break n}Rj(i[n>>2],c&65535)}if(i[e+1075672>>2]){break f}i[e+1075680>>2]=0;e=e+1075072|0;i[e>>2]=i[e>>2]|2101248}c=c+1|0;if((c&65535)!=256){continue}break}}e=0;l=0;p:{if(!Pi(p)){break p}if(!Jd(j[(o(b,896)+a|0)+1075803|0])){break p}q:{c=ym(a,b,2,1);if(c+ -251>>>0<5){break q}if(!c){break p}l=i[(o(c,160)+a|0)+906140>>2];if(!l){break q}kb(m+8|0,a+1074308|0,34);e=(y=l,z=wM(p,ib(m+8|0)),A=b,x=i[i[l>>2]+96>>2],$a[x](y|0,z|0,A|0)|0);break p}l=0}if(nh(p)?0:!e){break a}d=EK(a,b);if((d|0)==65535){break a}f=o(d,896)+a|0;c=f+1075072|0;n=f+1074984|0;r:{if(!(j[f+1075073|0]&2)){break r}q=a+1304392|0;if(!$c(q)){break r}Zh(i[q>>2],d,1)}Mr(n,p);i[c>>2]=i[c>>2]&-917505;g[f+1075835|0]=0;q=k[a+480188>>1];g[f+1075811|0]=0;h[f+1075792>>1]=q>>>0>b>>>0?b+1|0:0;s:{if(!l|e^1){break s}e=j[(o(b,896)+a|0)+1075804|0];if(e>>>0>3|(e|0)==1){break s}Kj(a,b,255,0);g[(o(b,896)+a|0)+1075806|0]=0}t:{u:{switch(j[(o(b,896)+a|0)+1075804|0]){case 2:Bm(a,n);if(!(j[c+1|0]&2)){break t}e=a+1304392|0;if(!$c(e)){break t}Rj(i[e>>2],b);kb(m+8|0,a+1074308|0,105);if(!ib(m+8|0)){break t}Gx(i[e>>2],b,d);break t;case 0:i[(o(d,896)+a|0)+1075680>>2]=0;e=i[c>>2];i[c>>2]=e|4096;if(!(e&512)){break t}e=a+1304392|0;if(!$c(e)){break t}Zh(i[e>>2],b,1);break t;case 3:e=i[c>>2];i[c>>2]=e|4096;if(!(e&512)){break t}e=a+1304392|0;if(!$c(e)){break t}kb(m+8|0,a+1074308|0,105);l=ib(m+8|0);e=i[e>>2];if(l){Gx(e,b,d);break t}Rj(e,b);break t;case 1:break u;default:break t}}if(!(j[c+1|0]&2)){break t}e=a+1304392|0;if(!$c(e)){break t}Gx(i[e>>2],b,d)}if(!i[(o(d,896)+a|0)+1075672>>2]){i[(o(d,896)+a|0)+1075680>>2]=0;i[c>>2]=i[c>>2]|2101248}a=o(b,896)+a|0;i[a+1075060>>2]=0;i[p>>2]=0;i[p+4>>2]=0;a=a+1075076|0;i[a>>2]=0;i[a+4>>2]=0}}Xa=m+16|0}function KE(a,b,c,d,e){var f=0,g=0,h=0,j=0,k=0,l=0,m=0,p=0,r=0,s=0,t=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;h=Xa-560|0;Xa=h;g=c;c=(c+ -3|0)/24|0;x=(c|0)>0?c:0;m=g+o(x,-24)|0;r=i[(e<<2)+52240>>2];k=d+ -1|0;if((r+k|0)>=0){g=d+r|0;c=x-k|0;while(1){n[(h+320|0)+(j<<3)>>3]=(c|0)<0?0:+i[(c<<2)+52256>>2];c=c+1|0;j=j+1|0;if((g|0)!=(j|0)){continue}break}}t=m+ -24|0;g=0;j=(r|0)>0?r:0;p=(d|0)<1;while(1){a:{if(p){f=0;break a}l=g+k|0;c=0;f=0;while(1){f=f+n[(c<<3)+a>>3]*n[(h+320|0)+(l-c<<3)>>3];c=c+1|0;if((d|0)!=(c|0)){continue}break}}n[(g<<3)+h>>3]=f;c=(g|0)==(j|0);g=g+1|0;if(!c){continue}break}C=47-m|0;y=48-m|0;D=m+ -25|0;g=r;b:{while(1){f=n[(g<<3)+h>>3];c=0;j=g;l=(g|0)<1;if(!l){while(1){p=(h+480|0)+(c<<2)|0;s=f;f=f*5.960464477539063e-8;c:{if(q(f)<2147483648){k=~~f;break c}k=-2147483648}f=+(k|0);s=s+f*-16777216;d:{if(q(s)<2147483648){k=~~s;break d}k=-2147483648}i[p>>2]=k;j=j+ -1|0;f=n[(j<<3)+h>>3]+f;c=c+1|0;if((g|0)!=(c|0)){continue}break}}f=yh(f,t);f=f+u(f*.125)*-8;e:{if(q(f)<2147483648){p=~~f;break e}p=-2147483648}f=f- +(p|0);f:{g:{h:{z=(t|0)<1;i:{if(!z){j=(g<<2)+h|0;k=i[j+476>>2];c=k>>y;w=j;j=k-(c<<y)|0;i[w+476>>2]=j;p=c+p|0;k=j>>C;break i}if(t){break h}k=i[((g<<2)+h|0)+476>>2]>>23}if((k|0)<1){break f}break g}k=2;if(!(f>=.5^1)){break g}k=0;break f}c=0;j=0;if(!l){while(1){w=(h+480|0)+(c<<2)|0;A=i[w>>2];l=16777215;j:{k:{if(j){break k}l=16777216;if(A){break k}j=0;break j}i[w>>2]=l-A;j=1}c=c+1|0;if((g|0)!=(c|0)){continue}break}}l:{if(z){break l}m:{switch(D|0){case 0:c=(g<<2)+h|0;i[c+476>>2]=i[c+476>>2]&8388607;break l;case 1:break m;default:break l}}c=(g<<2)+h|0;i[c+476>>2]=i[c+476>>2]&4194303}p=p+1|0;if((k|0)!=2){break f}f=1-f;k=2;if(!j){break f}f=f-yh(1,t)}if(f==0){j=0;n:{c=g;if((c|0)<=(r|0)){break n}while(1){c=c+ -1|0;j=i[(h+480|0)+(c<<2)>>2]|j;if((c|0)>(r|0)){continue}break}if(!j){break n}m=t;while(1){m=m+ -24|0;g=g+ -1|0;if(!i[(h+480|0)+(g<<2)>>2]){continue}break}break b}c=1;while(1){j=c;c=c+1|0;if(!i[(h+480|0)+(r-j<<2)>>2]){continue}break}j=g+j|0;while(1){k=d+g|0;g=g+1|0;n[(h+320|0)+(k<<3)>>3]=i[(x+g<<2)+52256>>2];c=0;f=0;if((d|0)>=1){while(1){f=f+n[(c<<3)+a>>3]*n[(h+320|0)+(k-c<<3)>>3];c=c+1|0;if((d|0)!=(c|0)){continue}break}}n[(g<<3)+h>>3]=f;if((g|0)<(j|0)){continue}break}g=j;continue}break}f=yh(f,0-t|0);o:{if(!(f>=16777216^1)){d=(h+480|0)+(g<<2)|0;s=f;f=f*5.960464477539063e-8;p:{if(q(f)<2147483648){c=~~f;break p}c=-2147483648}f=s+ +(c|0)*-16777216;q:{if(q(f)<2147483648){a=~~f;break q}a=-2147483648}i[d>>2]=a;g=g+1|0;break o}if(q(f)<2147483648){c=~~f}else{c=-2147483648}m=t}i[(h+480|0)+(g<<2)>>2]=c}f=yh(1,m);r:{if((g|0)<=-1){break r}c=g;while(1){n[(c<<3)+h>>3]=f*+i[(h+480|0)+(c<<2)>>2];f=f*5.960464477539063e-8;a=(c|0)>0;c=c+ -1|0;if(a){continue}break}l=0;if((g|0)<0){break r}a=(r|0)>0?r:0;j=g;while(1){d=a>>>0<l>>>0?a:l;m=g-j|0;c=0;f=0;while(1){f=f+n[(c<<3)+55024>>3]*n[(c+j<<3)+h>>3];t=(c|0)!=(d|0);c=c+1|0;if(t){continue}break}n[(h+160|0)+(m<<3)>>3]=f;j=j+ -1|0;c=(g|0)!=(l|0);l=l+1|0;if(c){continue}break}}s:{t:{u:{switch(e|0){case 3:v:{if((g|0)<1){break v}f=n[(h+160|0)+(g<<3)>>3];c=g;while(1){s=f;a=c+ -1|0;d=(h+160|0)+(a<<3)|0;B=n[d>>3];f=B+f;n[(h+160|0)+(c<<3)>>3]=s+(B-f);n[d>>3]=f;d=(c|0)>1;c=a;if(d){continue}break}if((g|0)<2){break v}f=n[(h+160|0)+(g<<3)>>3];c=g;while(1){s=f;a=c+ -1|0;d=(h+160|0)+(a<<3)|0;v=n[d>>3];f=v+f;n[(h+160|0)+(c<<3)>>3]=s+(v-f);n[d>>3]=f;d=(c|0)>2;c=a;if(d){continue}break}v=0;if((g|0)<=1){break v}while(1){v=v+n[(h+160|0)+(g<<3)>>3];a=(g|0)>2;g=g+ -1|0;if(a){continue}break}}f=n[h+160>>3];if(k){break t}n[b>>3]=f;f=n[h+168>>3];n[b+16>>3]=v;n[b+8>>3]=f;break s;case 0:f=0;if((g|0)>=0){while(1){f=f+n[(h+160|0)+(g<<3)>>3];a=(g|0)>0;g=g+ -1|0;if(a){continue}break}}n[b>>3]=k?-f:f;break s;case 1:case 2:break u;default:break s}}f=0;if((g|0)>=0){c=g;while(1){f=f+n[(h+160|0)+(c<<3)>>3];a=(c|0)>0;c=c+ -1|0;if(a){continue}break}}n[b>>3]=k?-f:f;f=n[h+160>>3]-f;c=1;if((g|0)>=1){while(1){f=f+n[(h+160|0)+(c<<3)>>3];a=(c|0)!=(g|0);c=c+1|0;if(a){continue}break}}n[b+8>>3]=k?-f:f;break s}n[b>>3]=-f;f=n[h+168>>3];n[b+16>>3]=-v;n[b+8>>3]=-f}Xa=h+560|0;return p&7}function Qia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,l=0,n=0,o=0,q=p(0),r=0,s=0;d=Xa-128|0;Xa=d;l=-1;a:{b:{c:{d:{if(!hf(i[i[b>>2]+ -12>>2]+b|0)){break d}Ue(d+112|0,b);e=i[d+120>>2];f=i[d+124>>2];yl(d+104|0);yj(b,d+104|0,8);if((j[d+104|0]|j[d+105|0]<<8|(j[d+106|0]<<16|j[d+107|0]<<24))!=1414681667|(j[d+108|0]|j[d+109|0]<<8|(j[d+110|0]<<16|j[d+111|0]<<24))!=776101705){a=og(d+88|0,e,f);c=i[a+12>>2];i[d+16>>2]=i[a+8>>2];i[d+20>>2]=c;c=i[a+4>>2];i[d+8>>2]=i[a>>2];i[d+12>>2]=c;Di(b,d+8|0);break d}h[d+86>>1]=0;af(b,d+86|0);if((k[d+86>>1]&65534)!=2){break d}yl(d+78|0);yj(b,d+78|0,8);if((j[d+78|0]|j[d+79|0]<<8|(j[d+80|0]<<16|j[d+81|0]<<24))!=1933333571|(j[d+82|0]|j[d+83|0]<<8|(j[d+84|0]<<16|j[d+85|0]<<24))!=1111389030){break d}h[d+76>>1]=0;af(b,d+76|0);e=h[d+76>>1];if((e+ -3&65535)>>>0>1){break d}e:{f:{g:{h:{i:{j:{k:{if((e|0)<=3){e=Ab(d+112|0);i[114610]=0;f=I(724,b|0,e|0,65535)|0;n=i[114610];i[114610]=0;if((n|0)==1){break b}if(!f){break j}i[114610]=0;G(13,d- -64|0,c|0,e|0);f=i[114610];i[114610]=0;if((f|0)!=1){break k}break b}e=Ab(d+112|0);i[114610]=0;f=I(726,b|0,e|0,255)|0;n=i[114610];i[114610]=0;if((n|0)==1){break c}if(!f){break i}i[114610]=0;G(13,d- -64|0,c|0,e|0);f=i[114610];i[114610]=0;if((f|0)==1){break c}}mb(a+40|0,d- -64|0);eb(d- -64|0);eb(e);h[d+62>>1]=0;af(b,d+62|0);h[d+60>>1]=0;af(b,d+60|0);h[a>>1]=k[d+60>>1];h[d+58>>1]=0;l:{if(h[d+76>>1]<=3){i[d+112>>2]=0;di(b,d+112|0);e=i[d+112>>2];if(e>>>0>65535){break d}e=sz(e);h[d+58>>1]=e;break l}af(b,d+58|0);e=k[d+58>>1]}m:{n:{o:{p:{if(e&65535){n=a+52|0;f=0;while(1){e=Ab(d+112|0);i[114610]=0;h[d+40>>1]=0;C(1616,b|0,d+40|0)|0;g=i[114610];i[114610]=0;if((g|0)==1){break g}q:{if(h[d+76>>1]<=3){i[114610]=0;g=I(724,b|0,e|0,65535)|0;o=i[114610];i[114610]=0;if((o|0)==1){break g}if(g){break q}break e}i[114610]=0;g=I(726,b|0,e|0,255)|0;o=i[114610];i[114610]=0;if((o|0)==1){break g}if(!g){break e}}i[114610]=0;G(13,d- -64|0,c|0,e|0);g=i[114610];i[114610]=0;if((g|0)==1){break p}i[114610]=0;g=C(1617,n|0,d+40|0)|0;o=i[114610];i[114610]=0;if((o|0)==1){break o}mb(g,d- -64|0);eb(d- -64|0);eb(e);f=f+1|0;if((f&65535)>>>0<k[d+58>>1]){continue}break}}yl(d- -64|0);yj(b,d- -64|0,8);if((j[d+64|0]|j[d+65|0]<<8|(j[d+66|0]<<16|j[d+67|0]<<24))!=1933333571|(j[d+68|0]|j[d+69|0]<<8|(j[d+70|0]<<16|j[d+71|0]<<24))!=1161720678){break d}c=k[a>>1];if(c>>>0>3|(c|0)==2){break d}c=a+4|0;if(h[d+86>>1]>2){break n}if(fI(b,c)){break m}break d}b=B()|0;A()|0;break f}b=B()|0;A()|0;eb(d- -64|0);break f}if(!eI(b,c)){break d}}c=a+16|0;r:{if(h[d+86>>1]<=2){if(fI(b,c)){break r}break d}if(!eI(b,c)){break d}}r=a,s=qb(a+16|0),i[r+36>>2]=s;h[d+56>>1]=0;af(b,d+56|0);c=k[d+56>>1];h[a+28>>1]=c;if((c+200&65535)>>>0>400){break d}h[d+54>>1]=0;af(b,d+54|0);c=h[d+54>>1];h[a+30>>1]=c;if((c|0)<0){break d}i[d+48>>2]=0;fo(b,d+48|0);q=m[d+48>>2];m[a+32>>2]=q;if(q<p(0)){break d}yl(d+40|0);yj(b,d+40|0,8);if((j[d+40|0]|j[d+41|0]<<8|(j[d+42|0]<<16|j[d+43|0]<<24))!=1414681667|(j[d+44|0]|j[d+45|0]<<8|(j[d+46|0]<<16|j[d+47|0]<<24))!=776298313){break d}c=a+4|0;if(qb(c)>>>0>32767){break d}f=a+32|0;s:{if(!(m[f>>2]>p(0)?h[a+30>>1]>=1:0)){if(!k[a>>1]){break s}break d}t:{switch(k[a>>1]+ -1|0){case 0:case 2:break t;default:break s}}if(qb(c)>>>0<h[a+30>>1]>>>0){break d}}b=0;e=i[a+36>>2];if(e){b=e+ -1|0;i[a+36>>2]=b}r=d,s=Cs(b),i[r+112>>2]=s;i[d+32>>2]=0;r=a,s=i[_r(d+112|0,d+32|0,32392)>>2],i[r+36>>2]=s;go(a);l=1;if(k[a>>1]!=3){break d}b=kI(qb(c));if((h[a+30>>1]-h[a+28>>1]|0)>(b|0)){break d}e=Gj(d+112|0);l=0;if(h[a+30>>1]>0){while(1){b=vb(c,l-h[a+28>>1]|0);i[114610]=0;D(1618,e|0,b|0);b=i[114610];i[114610]=0;if((b|0)==1){break h}l=l+1|0;if((l|0)<h[a+30>>1]){continue}break}}b=k[a+28>>1];h[d+32>>1]=b;c=qb(c);i[114610]=0;h[d+34>>1]=(b+c|0)+ -1;h[d+30>>1]=0;S(1612,a|0,e|0,f|0,d+32|0,d+30|0)|0;a=i[114610];i[114610]=0;l=1;if((a|0)!=1){uf(e);break d}break h}eb(e);break d}eb(e);break d}b=B()|0;A()|0;uf(e);break a}b=B()|0;A()|0}eb(e);break a}eb(e)}Xa=d+128|0;return l|0}b=B()|0;A()|0;eb(e);break a}b=B()|0;A()|0;eb(e)}E(b|0);x()}function $F(a,b,c,d,e,f){var h=0,l=0,m=0,n=0;h=Xa-48|0;Xa=h;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{if($q(c)){l=b+24|0;if(pg(i[l>>2]+484344|0,c&65535)){break j}}c=a;a=Ab(h+32|0);b=Ab(h+16|0);hh(c,a,b);eb(b);eb(a);break i}b=Fb(i[l>>2]+484344|0,c);if(!(i[b+12>>2]>(d|0)?(d|0)>=0:0)){c=a;a=Ab(h+32|0);b=Ab(h+16|0);hh(c,a,b);eb(b);eb(a);break i}if(!(k[i[l>>2]+480188>>1]>(e|0)?(e|0)>=0:0)){c=a;a=Ab(h+32|0);b=Ab(h+16|0);hh(c,a,b);eb(b);eb(a);break i}if(f>>>0>=6){c=a;a=Ab(h+32|0);b=Ab(h+16|0);hh(c,a,b);eb(b);eb(a);break i}b=Qe(b,d,e&65535);k:{switch(f|0){case 0:l:{m:{n:{if(!Jf(b)){if(!zr(b)){break n}}BJ(h+16|0,i[l>>2],j[b|0],j[b+1|0]);i[114610]=0;G(9,h+32|0,0,h+16|0);c=i[114610];i[114610]=0;d=1;if((c|0)!=1){break m}c=B()|0;A()|0;break b}d=0;i[114610]=0;C(85,h+32|0,38821)|0;c=i[114610];i[114610]=0;if((c|0)==1){break l}}i[114610]=0;c=F(556,b|0)|0;e=i[114610];i[114610]=0;if((e|0)==1){break c}o:{if(c){i[114610]=0;C(85,h|0,38825)|0;b=i[114610];i[114610]=0;if((b|0)==1){break c}break o}if(zr(b)){i[114610]=0;C(85,h|0,38829)|0;b=i[114610];i[114610]=0;if((b|0)!=1){break o}break c}i[114610]=0;C(85,h|0,38821)|0;b=i[114610];i[114610]=0;if((b|0)==1){break c}}hh(a,h+32|0,h);eb(h);eb(h+32|0);if(!d){break i}eb(h+16|0);break i}c=B()|0;A()|0;break a;case 1:c=b+1|0;p:{if(j[b+1|0]){Ds(h+32|0,c);break p}Bb(h+32|0,38833)}q:{if(j[c|0]){i[114610]=0;C(85,h+16|0,38836)|0;b=i[114610];i[114610]=0;if((b|0)!=1){break q}break d}i[114610]=0;C(85,h+16|0,38833)|0;b=i[114610];i[114610]=0;if((b|0)==1){break d}}hh(a,h+32|0,h+16|0);eb(h+16|0);eb(h+32|0);break i;case 2:r:{if(Dm(b)){Bb(h+32|0,38839);break r}if(j[b+2|0]){ej(h+32|0,1,HI(i[i[l>>2]+8>>2],j[b+2|0]));break r}Bb(h+32|0,38839)}i[114610]=0;c=F(1342,b|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break e}s:{if(c){i[114610]=0;C(85,h+16|0,38839)|0;b=i[114610];i[114610]=0;if((b|0)==1){break e}break s}if(j[b+2|0]){i[114610]=0;C(85,h+16|0,38841)|0;b=i[114610];i[114610]=0;if((b|0)!=1){break s}break e}i[114610]=0;C(85,h+16|0,38839)|0;b=i[114610];i[114610]=0;if((b|0)==1){break e}}hh(a,h+32|0,h+16|0);eb(h+16|0);eb(h+32|0);break i;case 4:t:{if(Dm(b)){m=h,n=sx(b)&255,i[m>>2]=n;Ay(h+32|0,h);break t}if(j[b+2|0]){Ds(h+32|0,b+4|0);break t}Bb(h+32|0,38833)}i[114610]=0;c=F(1342,b|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break f}u:{if(c){i[114610]=0;C(85,h+16|0,38843)|0;b=i[114610];i[114610]=0;if((b|0)==1){break f}break u}if(j[b+2|0]){i[114610]=0;C(85,h+16|0,38843)|0;b=i[114610];i[114610]=0;if((b|0)!=1){break u}break f}i[114610]=0;C(85,h+16|0,38833)|0;b=i[114610];i[114610]=0;if((b|0)==1){break f}}hh(a,h+32|0,h+16|0);eb(h+16|0);eb(h+32|0);break i;case 3:v:{if(Dm(b)){m=h,n=(Sr(b)&3840)!=0,g[m|0]=n;c9(h+32|0,h);break v}if(j[b+3|0]){ej(h+32|0,1,GI(i[i[l>>2]+8>>2],j[b+3|0]));break v}Bb(h+32|0,38846)}i[114610]=0;c=F(1342,b|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break g}w:{if(c){i[114610]=0;C(85,h+16|0,38848)|0;b=i[114610];i[114610]=0;if((b|0)==1){break g}break w}if(j[b+3|0]){i[114610]=0;C(85,h+16|0,38848)|0;b=i[114610];i[114610]=0;if((b|0)!=1){break w}break g}i[114610]=0;C(85,h+16|0,38846)|0;b=i[114610];i[114610]=0;if((b|0)==1){break g}}hh(a,h+32|0,h+16|0);eb(h+16|0);eb(h+32|0);break i;case 5:x:{if(Dm(b)){m=h,n=Sr(b)&255,i[m>>2]=n;Ay(h+32|0,h);break x}if(j[b+3|0]){Ds(h+32|0,b+5|0);break x}Bb(h+32|0,38833)}i[114610]=0;c=F(1342,b|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break h}y:{if(c){i[114610]=0;C(85,h+16|0,38850)|0;b=i[114610];i[114610]=0;if((b|0)==1){break h}break y}if(j[b+3|0]){i[114610]=0;C(85,h+16|0,38850)|0;b=i[114610];i[114610]=0;if((b|0)!=1){break y}break h}i[114610]=0;C(85,h+16|0,38833)|0;b=i[114610];i[114610]=0;if((b|0)==1){break h}}hh(a,h+32|0,h+16|0);eb(h+16|0);eb(h+32|0);break i;default:break k}}c=a;a=Ab(h+32|0);b=Ab(h+16|0);hh(c,a,b);eb(b);eb(a)}Xa=h+48|0;return}c=B()|0;A()|0;eb(h+32|0);break a}c=B()|0;A()|0;eb(h+32|0);break a}c=B()|0;A()|0;eb(h+32|0);break a}c=B()|0;A()|0;eb(h+32|0);break a}c=B()|0;A()|0;eb(h+32|0);break a}c=B()|0;A()|0;eb(h+32|0);if(!d){break a}}eb(h+16|0)}E(c|0);x()}function iya(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,l=0,m=0,n=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;d=Xa-192|0;Xa=d;pc(b);a:{if(!gz(b,d+144|0)){break a}if(!fN(d+144|0)){break a}if(!wb(b,Vc(eN(d+144|0),_a))){break a}b:{if(!c){break b}md(a,256);en(d+16|0,2,d+144|0);oc(d+48|0,d+16|0);mb(a+1304400|0,d+48|0);eb(d+48|0);e=Bb(d+48|0,17279);mb(a+1304436|0,e);eb(e);e=Bb(d+48|0,17296);mb(a+1304448|0,e);eb(e);l=Bb(d+128|0,17300);i[114610]=0;D(219,d+16|0,l|0);e=i[114610];i[114610]=0;c:{d:{e:{f:{g:{h:{i:{if((e|0)!=1){i[114610]=0;D(450,d+112|0,d+175|0);e=i[114610];i[114610]=0;if((e|0)==1){break i}i[114610]=0;J(451,d+48|0,d+16|0,d+174|0,d+112|0);e=i[114610];i[114610]=0;if((e|0)==1){break h}mb(a+1304460|0,d+48|0);eb(d+48|0);eb(d+112|0);ob(d+16|0);eb(l);i[a+1304496>>2]=4;i[a+480260>>2]=64;i[a+480264>>2]=32767;i[a+480188>>2]=2031620;f=j[d+176|0];if(j[d+175|0]<=20){e=((f&255)>>>0)/10|0;f=e<<4|f-o(e,10)}l=(f&255?f:96)&255;e=HK(l);i[a+480196>>2]=l>>>4;i[a+480204>>2]=e;if(j[d+175|0]>10){break e}break d}f=B()|0;A()|0;break f}f=B()|0;A()|0;break g}f=B()|0;A()|0;eb(d+112|0)}ob(d+16|0)}eb(l);break c}g[d+48|0]=64;v=a,w=j[Xb(d+178|0,d+48|0)|0]<<2,i[v+480200>>2]=w}f=0;while(1){e=(f<<5)+a|0;sg(e+480280|0);h[e+480284>>1]=f&1?64:192;f=f+1|0;if((f|0)!=4){continue}break}f=1;j:{k:{while(1){ys(b,d+16|0);if(j[d+28|0]!=46?j[d+28|0]:0){break k}gya(d+16|0,(o(f,104)+a|0)+484380|0);bk(d,2,d+16|0);oc(d+112|0,d);i[114610]=0;C(369,((f<<5)+a|0)+946300|0,d+112|0)|0;e=i[114610];i[114610]=0;if((e|0)==1){break j}eb(d+112|0);h[((f<<1)+d|0)+46>>1]=j[d+30|0]|j[d+31|0]<<8;f=f+1|0;if((f|0)!=32){continue}break}e=a+484360|0;hp(Db(e),b,j[d+175|0]?128:64,65535,65535);e=Db(e);v=d,w=Jb(e),i[v+16>>2]=w;v=d,w=Kb(e),i[v+112>>2]=w;if(pb(d+16|0,d+112|0)){while(1){e=i[d+16>>2];l=k[e>>1];l:{if(!((l|0)!=99?(l|0)!=255:0)){h[e>>1]=65535;break l}if(l>>>0>63){break k}}he(d+16|0);if(pb(d+16|0,d+112|0)){continue}break}}t=c&1;if(t){Gf(a+484344|0,j[d+177|0])}if(j[d+177|0]){r=a+484344|0;while(1){m:{n:{if(t){if(Sf(r,p&65535,64)){break n}}f=0;while(1){if((id(b)+5&255)>>>0>=3){Ib(b,3)}f=f+1|0;if((f|0)!=256){continue}break}break m}v=d,w=Jb(Fb(r,p)),i[v+112>>2]=w;i[d>>2]=63;n=65535;q=0;while(1){f=0;while(1){l=f;m=0;f=0;s=0;u=0;o:{p:{q:{r:{s:{t:{e=id(b);switch(e+ -251|0){case 1:break o;case 0:break r;case 2:break t;default:break s}}g[i[d+112>>2]]=254;break o}wt(d+16|0,b);f=j[Nb(d+16|0,0)|0];s=j[Nb(d+16|0,1)|0];u=j[Nb(d+16|0,2)|0];m=254;if((e|0)==254){break q}m=e;if(e>>>0>95){break p}}m=(o(m>>>4|0,12)+(m&15)|0)+37|0}e=m;g[i[d+112>>2]]=e}g[i[d+112>>2]+1|0]=(f&248)>>>3;if(j[i[d+112>>2]+1|0]>=32){g[i[d+112>>2]+1|0]=0}e=s>>>1&120|f&7;if(e>>>0<=64){g[i[d+112>>2]+2|0]=1;g[i[d+112>>2]+4|0]=e}g[i[d+112>>2]+3|0]=j[(s&15)+17328|0];g[i[d+112>>2]+5|0]=u;u:{switch(j[i[d+112>>2]+3|0]+ -11|0){case 0:m=i[d+112>>2];e=j[m+5|0];if(j[i[d+112>>2]+5|0]&15){g[m+5|0]=e&15;break o}g[m+5|0]=e&240;break o;case 3:g[i[d+112>>2]+5|0]=o(j[i[d+112>>2]+5|0]&240,10)|j[i[d+112>>2]+5|0]&15;v:{if((n|0)!=65535){if(j[i[d+112>>2]+5|0]){break v}g[i[d+112>>2]+3|0]=12;g[i[d+112>>2]+5|0]=n}n=65535}kc(d,q);break o;case 1:n=j[i[d+112>>2]+5|0];i[d>>2]=63;g[i[d+112>>2]+3|0]=0;break o;case 5:if(j[d+175|0]<=20){g[i[d+112>>2]+5|0]=j[i[d+112>>2]+5|0]%10|j[i[d+112>>2]+5|0]/10<<4}if(j[i[d+112>>2]+5|0]){break o}g[i[d+112>>2]+3|0]=0;break o;case 7:break o;default:break u}}if(j[i[d+112>>2]+5|0]){break o}g[i[d+112>>2]+3|0]=0}jk(d+112|0);f=l+1|0;if((l&65535)>>>0<3){continue}break}q=q+1|0;if((q|0)!=64){continue}break}if((n|0)==65535){break m}Vk(Fb(r,p),dn(Ee(yp(d+16|0,12,n&255),i[d>>2])))}p=p+1|0;if(p>>>0<j[d+177|0]){continue}break}}f=1;if(!(c&2)){break a}l=Ic(d+16|0,8,1,0,0);while(1){c=o(f,104)+a|0;e=c+484380|0;w:{if(!i[e>>2]|!k[c+484410>>1]){break w}c=k[((f<<1)+d|0)+46>>1];if(c>>>0<4){break w}if(!vc(b,c<<4)){break w}Xf(l,e,b)}f=f+1|0;if((f|0)!=32){continue}break}break b}f=0;break a}f=B()|0;A()|0;eb(d+112|0)}E(f|0);x()}f=1}Xa=d+192|0;return f|0}function z$(){var a=0,b=0,c=0,d=0,e=0;rd(463392);i[115848]=62416;i[114610]=0;b=C(2515,463408,28)|0;a=i[114610];i[114610]=0;a:{b:{c:{d:{if((a|0)!=1){i[114610]=0;c=C(85,463568,62405)|0;a=i[114610];i[114610]=0;if((a|0)==1){break d}qb(b);HC(b);GC(b);rd(463072);i[115768]=64032;i[114610]=0;D(2516,463392,463072);a=i[114610];i[114610]=0;if((a|0)==1){break c}rd(463080);i[115770]=64064;i[114610]=0;D(2517,463392,463080);a=i[114610];i[114610]=0;if((a|0)==1){break c}rd(463088);g[463100]=0;i[115774]=0;i[115772]=62436;d=463096,e=Mn(),i[d>>2]=e;i[114610]=0;D(2518,463392,463088);a=i[114610];i[114610]=0;if((a|0)==1){break c}rd(463104);i[115776]=63020;i[114610]=0;D(2519,463392,463104);a=i[114610];i[114610]=0;if((a|0)==1){break c}rd(463112);i[115778]=63168;i[114610]=0;D(2520,463392,463112);a=i[114610];i[114610]=0;if((a|0)==1){break c}i[114610]=0;K(2521);a=i[114610];i[114610]=0;if((a|0)==1){break c}i[114610]=0;D(2522,463392,463120);a=i[114610];i[114610]=0;if((a|0)==1){break c}rd(463136);i[115784]=63316;i[114610]=0;D(2523,463392,463136);a=i[114610];i[114610]=0;if((a|0)==1){break c}i[114610]=0;lq(463144);a=i[114610];i[114610]=0;if((a|0)==1){break c}i[114610]=0;D(2525,463392,463144);a=i[114610];i[114610]=0;if((a|0)==1){break c}rd(463152);h[231580]=11310;i[115788]=62536;Ab(463164);i[114610]=0;D(2526,463392,463152);a=i[114610];i[114610]=0;if((a|0)==1){break c}rd(463184);i[115798]=46;i[115799]=44;i[115796]=62576;Ab(463200);i[114610]=0;D(2527,463392,463184);a=i[114610];i[114610]=0;if((a|0)==1){break c}rd(463216);i[115804]=64096;i[114610]=0;D(2528,463392,463216);a=i[114610];i[114610]=0;if((a|0)==1){break c}rd(463224);i[115806]=64340;i[114610]=0;D(2529,463392,463224);a=i[114610];i[114610]=0;if((a|0)==1){break c}rd(463232);i[115808]=64552;i[114610]=0;D(2530,463392,463232);a=i[114610];i[114610]=0;if((a|0)==1){break c}rd(463240);i[115810]=64784;i[114610]=0;D(2531,463392,463240);a=i[114610];i[114610]=0;if((a|0)==1){break c}i[114610]=0;FC();a=i[114610];i[114610]=0;if((a|0)==1){break c}i[114610]=0;D(2533,463392,463248);a=i[114610];i[114610]=0;if((a|0)==1){break c}rd(463256);i[115814]=65916;i[114610]=0;D(2534,463392,463256);a=i[114610];i[114610]=0;if((a|0)==1){break c}rd(463264);i[115816]=66032;i[114610]=0;D(2535,463392,463264);a=i[114610];i[114610]=0;if((a|0)==1){break c}rd(463272);i[115818]=66148;i[114610]=0;D(2536,463392,463272);a=i[114610];i[114610]=0;if((a|0)==1){break c}i[114610]=0;EC();a=i[114610];i[114610]=0;if((a|0)==1){break c}i[114610]=0;D(2538,463392,463280);a=i[114610];i[114610]=0;if((a|0)==1){break c}i[114610]=0;DC();a=i[114610];i[114610]=0;if((a|0)==1){break c}i[114610]=0;D(2540,463392,463288);a=i[114610];i[114610]=0;if((a|0)==1){break c}i[114610]=0;CC();a=i[114610];i[114610]=0;if((a|0)==1){break c}i[114610]=0;D(2542,463392,463296);a=i[114610];i[114610]=0;if((a|0)==1){break c}i[114610]=0;BC();a=i[114610];i[114610]=0;if((a|0)==1){break c}i[114610]=0;D(2544,463392,463304);a=i[114610];i[114610]=0;if((a|0)==1){break c}rd(463312);i[115830]=68308;i[115828]=64984;i[115830]=65032;i[114610]=0;D(2545,463392,463312);a=i[114610];i[114610]=0;if((a|0)==1){break c}rd(463328);i[115834]=68344;i[115832]=65248;i[115834]=65296;i[114610]=0;D(2546,463392,463328);a=i[114610];i[114610]=0;if((a|0)==1){break c}i[114610]=0;K(2547);a=i[114610];i[114610]=0;if((a|0)==1){break c}i[114610]=0;D(2548,463392,463344);a=i[114610];i[114610]=0;if((a|0)==1){break c}i[114610]=0;K(2549);a=i[114610];i[114610]=0;if((a|0)==1){break c}i[114610]=0;D(2550,463392,463360);a=i[114610];i[114610]=0;if((a|0)==1){break c}i[114610]=0;AC();a=i[114610];i[114610]=0;if((a|0)==1){break c}i[114610]=0;D(2552,463392,463376);a=i[114610];i[114610]=0;if((a|0)==1){break c}rd(463384);i[115846]=67040;i[114610]=0;D(2553,463392,463384);a=i[114610];i[114610]=0;if((a|0)==1){break c}return}a=B()|0;A()|0;break a}a=B()|0;A()|0;break b}a=B()|0;A()|0;eb(c)}KC(b)}E(a|0);x()}function HU(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,k=0,l=0,m=0;d=Xa-160|0;Xa=d;pc(b);Yp(a);a:{if(!Qt(b,d+120|0)){break a}if(!TI(d+120|0)){break a}if(!Gla(b,d+120|0)){break a}if(!c){f=1;break a}Cla(d+104|0,b,d+120|0);c=d+152|0;c=j[c|0]|j[c+1|0]<<8|(j[c+2|0]<<16|j[c+3|0]<<24);i[114610]=0;c=C(256,b|0,c|0)|0;g=i[114610];i[114610]=0;b:{c:{d:{e:{f:{g:{h:{i:{if((g|0)!=1){if(!c){break b}g=d+88|0;BU(g);c=d+148|0;f=j[c|0]|j[c+1|0]<<8|(j[c+2|0]<<16|j[c+3|0]<<24);i[114610]=0;D(332,g|0,f|0);f=i[114610];i[114610]=0;if((f|0)==1){break h}if(!(j[c|0]|j[c+1|0]<<8|(j[c+2|0]<<16|j[c+3|0]<<24))){break i}f=d+120|4;while(1){j:{i[114610]=0;e=C(258,b|0,4)|0;m=i[114610];i[114610]=0;if((m|0)==1){break j}if(!e){break i}e=j[f|0]|j[f+1|0]<<8;i[114610]=0;e=C(333,b|0,e|0)|0;m=i[114610];i[114610]=0;k:{if((m|0)!=1){i[d+24>>2]=e;if(e>>>0>=cc(d+104|0)>>>0){break k}i[114610]=0;D(334,g|0,d+24|0);e=i[114610];i[114610]=0;if((e|0)!=1){break k}}b=B()|0;A()|0;break f}k=k+1|0;if(k>>>0<(j[c|0]|j[c+1|0]<<8|(j[c+2|0]<<16|j[c+3|0]<<24))>>>0){continue}break i}break}b=B()|0;A()|0;break f}b=B()|0;A()|0;break e}c=d+144|0;c=j[c|0]|j[c+1|0]<<8|(j[c+2|0]<<16|j[c+3|0]<<24);f=0;i[114610]=0;c=C(256,b|0,c|0)|0;k=i[114610];i[114610]=0;if((k|0)!=1){break g}}b=B()|0;A()|0;break f}if(!c){break c}f=d+140|0;if(!(j[f|0]|j[f+1|0]<<8|(j[f+2|0]<<16|j[f+3|0]<<24))){break d}m=d+36|0;c=d+120|4;k=0;l:{m:{n:{o:{p:{q:{while(1){i[114610]=0;e=C(258,b|0,4)|0;h=i[114610];i[114610]=0;r:{if((h|0)!=1){if(e){break r}break d}b=B()|0;A()|0;break f}e=j[c|0]|j[c+1|0]<<8;i[114610]=0;_(335,b|0,d+84|0,d+80|0,d+76|0,d+72|0,e|0);e=i[114610];i[114610]=0;if((e|0)==1){break o}s:{t:{if(i[d+76>>2]<1){break t}e=i[d+84>>2];if((e|0)>-1){break t}e=e^-1;i[d+84>>2]=e;if(qb(g)>>>0<=e>>>0){break t}if(!Bd(Yc(d+104|0,i[vb(g,i[d+84>>2])>>2]),11555)){break t}i[114610]=0;J(336,d+56|0,b|0,i[d+80>>2],i[d+76>>2]);e=i[114610];i[114610]=0;if((e|0)==1){break n}i[114610]=0;e=F(337,d+56|0)|0;h=i[114610];i[114610]=0;if((h|0)==1){break m}if(e){if((j[c|0]|j[c+1|0]<<8)>>>0<=39){i[114610]=0;C(338,d+56|0,8)|0;e=i[114610];i[114610]=0;if((e|0)==1){break m}}if((j[c|0]|j[c+1|0]<<8)>>>0<=59){i[114610]=0;C(338,d+56|0,16)|0;e=i[114610];i[114610]=0;if((e|0)==1){break m}}i[114610]=0;F(339,d+56|0)|0;e=i[114610];i[114610]=0;if((e|0)==1){break m}u:{if((j[c|0]|j[c+1|0]<<8)>>>0>=120){i[114610]=0;F(339,d+56|0)|0;e=i[114610];i[114610]=0;if((e|0)==1){break m}i[114610]=0;C(338,d+56|0,8)|0;break u}if((j[c|0]|j[c+1|0]<<8)>>>0>=100){i[114610]=0;C(338,d+56|0,4)|0;e=i[114610];i[114610]=0;if((e|0)==1){break m}i[114610]=0;F(339,d+56|0)|0;e=i[114610];i[114610]=0;if((e|0)==1){break m}i[114610]=0;C(338,d+56|0,4)|0;break u}if((j[c|0]|j[c+1|0]<<8)>>>0>=62){i[114610]=0;F(339,d+56|0)|0;e=i[114610];i[114610]=0;if((e|0)==1){break m}i[114610]=0;C(338,d+56|0,4)|0;break u}i[114610]=0;F(339,d+56|0)|0}e=i[114610];i[114610]=0;if((e|0)==1){break m}i[114610]=0;h=F(339,d+56|0)|0;e=i[114610];i[114610]=0;if((e|0)==1){break p}i[114610]=0;e=F(340,d+24|0)|0;l=i[114610];i[114610]=0;if((l|0)==1){break s}l=i[d+72>>2];v:{if((l|0)<0){break v}if(l>>>0>=cc(d+104|0)>>>0){break v}l=Yc(d+104|0,i[d+72>>2]);i[114610]=0;G(13,d+8|0,2,l|0);l=i[114610];i[114610]=0;if((l|0)==1){break q}mb(d+24|0,d+8|0);eb(d+8|0)}i[114610]=0;G(341,d+8|0,d+56|0,h|0);h=i[114610];i[114610]=0;if((h|0)==1){break q}Cd(m,d+8|0);hb(d+8|0);i[114610]=0;D(342,a|0,e|0);h=i[114610];i[114610]=0;if((h|0)==1){break q}Zt(e)}hb(d+56|0)}k=k+1|0;if(k>>>0<(j[f|0]|j[f+1|0]<<8|(j[f+2|0]<<16|j[f+3|0]<<24))>>>0){continue}break d}break}b=B()|0;A()|0;break l}b=B()|0;A()|0;Zt(e);break l}b=B()|0;A()|0;break l}b=B()|0;A()|0;break f}b=B()|0;A()|0;break f}b=B()|0;A()|0}hb(d+56|0)}KA(g)}Sc(d+104|0);E(b|0);x()}f=Uc(a)^1}KA(g)}Sc(d+104|0)}Xa=d+160|0;return f|0}function V4(a,b){var c=p(0),d=0,e=0,f=0,g=p(0),h=0,i=0,j=p(0),k=p(0),l=p(0),n=0,o=p(0),r=0,s=p(0),t=p(0),u=p(0),v=p(0);g=p(1);a:{b:{h=(hNa(a),dNa(2));c:{if((h|0)==1065353216){break c}i=(hNa(b),dNa(2));d=i&2147483647;if(!d){break c}e=h&2147483647;if(!(d>>>0<2139095041?e>>>0<=2139095040:0)){return p(a+b)}d:{e:{if((h|0)>-1){break e}n=2;if(d>>>0>1266679807){break d}if(d>>>0<1065353216){break e}f=150-(d>>>23|0)|0;r=d>>>f|0;n=0;if((d|0)!=r<<f){break d}n=2-(r&1)|0;break d}n=0}f=n;f:{if((d|0)!=1065353216){if((d|0)!=2139095040){break f}if((e|0)==1065353216){break c}if(e>>>0>=1065353217){return(i|0)>-1?b:p(0)}return(i|0)>-1?p(0):p(-b)}return(i|0)>-1?a:p(p(1)/a)}if((i|0)==1073741824){return p(a*a)}if(!((i|0)!=1056964608|(h|0)<0)){return p(w(a))}c=p(q(a));if(!(e?(h&1073741823)!=1065353216:0)){g=(i|0)<0?p(p(1)/c):c;if((h|0)>-1){break c}if(!(f|e+ -1065353216)){a=p(g-g);return p(a/a)}return(f|0)==1?p(-g):g}g:{if((h|0)>-1){break g}h:{switch(f|0){case 0:a=p(a-a);return p(a/a);case 1:break h;default:break g}}g=p(-1)}i:{if(d>>>0>=1291845633){if(e>>>0<=1065353207){return(i|0)<0?p(p(g*p(1.0000000150474662e+30))*p(1.0000000150474662e+30)):p(p(g*p(1.0000000031710769e-30))*p(1.0000000031710769e-30))}if(e>>>0>=1065353224){return(i|0)>0?p(p(g*p(1.0000000150474662e+30))*p(1.0000000150474662e+30)):p(p(g*p(1.0000000031710769e-30))*p(1.0000000031710769e-30))}a=p(c+p(-1));c=p(a*p(1.44268798828125));j=p(p(a*p(7052607543300837e-21))+p(p(p(a*a)*p(p(.5)-p(a*p(p(a*p(-.25))+p(.3333333432674408)))))*p(-1.4426950216293335)));a=(eNa(2,(hNa(p(c+j)),dNa(2))&-4096),iNa());o=p(a-c);break i}d=e>>>0<8388608;e=d?(hNa(p(c*p(16777216))),dNa(2)):e;h=e&8388607;f=h|1065353216;d=(e>>23)+(d?-151:-127)|0;e=0;j:{if(h>>>0<1885298){break j}if(h>>>0<6140887){e=1;break j}f=f+ -8388608|0;d=d+1|0}h=e<<2;o=m[h+52192>>2];j=(eNa(2,f),iNa());k=m[h+52176>>2];l=p(j-k);s=p(p(1)/p(k+j));c=p(l*s);a=(eNa(2,(hNa(c),dNa(2))&-4096),iNa());t=p(a*a);u=a;v=l;l=(eNa(2,((f>>1&-536875008|536870912)+(e<<21)|0)+4194304|0),iNa());j=p(s*p(p(v-p(a*l))-p(a*p(j-p(l-k)))));l=p(p(c+a)*j);a=p(c*c);k=p(l+p(p(a*a)*p(p(a*p(p(a*p(p(a*p(p(a*p(p(a*p(.20697501301765442))+p(.23066075146198273)))+p(.2727281153202057)))+p(.3333333432674408)))+p(.4285714328289032)))+p(.6000000238418579))));a=(eNa(2,(hNa(p(p(t+p(3))+k)),dNa(2))&-4096),iNa());l=p(u*a);c=p(p(j*a)+p(c*p(k-p(p(a+p(-3))-t))));a=(eNa(2,(hNa(p(l+c)),dNa(2))&-4096),iNa());k=p(a*p(.9619140625));j=p(m[h+52184>>2]+p(p(p(c-p(a-l))*p(.9617967009544373))+p(a*p(-.00011736857413779944))));c=p(d|0);a=(eNa(2,(hNa(p(p(o+p(k+j))+c)),dNa(2))&-4096),iNa());o=p(p(p(a-c)-o)-k)}k=(eNa(2,i&-4096),iNa());c=p(a*k);a=p(p(p(j-o)*b)+p(p(b-k)*a));b=p(c+a);f=(hNa(b),dNa(2));if((f|0)>=1124073473){break b}e=1124073472;k:{l:{if((f|0)==1124073472){if(p(a+p(4.299566569443414e-8))>p(b-c)^1){break l}break b}e=f&2147483647;if(!(a<=p(b-c)^1|(f|0)!=-1021968384)|e>>>0>=1125515265){break a}d=0;if(e>>>0<1056964609){break k}}i=(8388608>>>(e>>>23|0)+ -126|0)+f|0;e=i>>>23&255;d=(i&8388607|8388608)>>>150-e|0;d=(f|0)<0?0-d|0:d;c=p(c-(eNa(2,i&-8388608>>e+ -127),iNa()));f=(hNa(p(a+c)),dNa(2))}b=(eNa(2,f&-32768),iNa());j=p(b*p(.693145751953125));c=p(p(b*p(14286065379565116e-22))+p(p(a-p(b-c))*p(.6931471824645996)));a=p(j+c);b=p(a*a);b=p(a-p(b*p(p(b*p(p(b*p(p(b*p(p(b*p(4.138136944220605e-8))+p(-16533901998627698e-22)))+p(661375597701408e-19)))+p(-.0027777778450399637)))+p(.1666666716337204))));l=p(p(a*b)/p(b+p(-2)));b=p(c-p(a-j));a=p(p(a-p(l-p(b+p(a*b))))+p(1));f=(hNa(a),dNa(2))+(d<<23)|0;m:{if((f|0)<=8388607){a=ME(a,d);break m}a=(eNa(2,f),iNa())}g=p(g*a)}return g}return p(p(g*p(1.0000000150474662e+30))*p(1.0000000150474662e+30))}return p(p(g*p(1.0000000031710769e-30))*p(1.0000000031710769e-30))}function i5(a,b,c,d){var e=0,f=0,g=0,h=p(0),j=0,l=p(0),n=0,q=p(0),r=p(0),s=0,t=p(0),u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=p(0),C=p(0),D=p(0),E=p(0),F=0,G=0,H=0,I=0,J=0,K=0;v=b>>1;f=v<<2;J=i[c+92>>2];a:{if(i[c+80>>2]){u=fm(c,f);break a}u=Zc(f)}f=v<<2;w=f+a|0;f=(f+u|0)+ -8|0;j=i[((d<<2)+c|0)+1068>>2];b:{if(!v){e=j;break b}g=a;e=j;while(1){m[f+4>>2]=p(m[e>>2]*m[g>>2])-p(m[e+4>>2]*m[g+8>>2]);m[f>>2]=p(m[e>>2]*m[g+8>>2])+p(m[e+4>>2]*m[g>>2]);e=e+8|0;f=f+ -8|0;g=g+16|0;if((w|0)!=(g|0)){continue}break}}if(f>>>0>=u>>>0){g=((v<<2)+a|0)+ -12|0;while(1){m[f+4>>2]=p(m[e+4>>2]*m[g>>2])-p(m[e>>2]*m[g+8>>2]);m[f>>2]=p(m[e>>2]*p(-m[g>>2]))-p(m[e+4>>2]*m[g+8>>2]);g=g+ -16|0;e=e+8|0;f=f+ -8|0;if(f>>>0>=u>>>0){continue}break}}H=b>>2;if((b|0)>=16){g=H<<2;f=g+u|0;n=a+g|0;e=(j+(v<<2)|0)+ -32|0;s=a;g=u;while(1){r=m[g>>2];q=m[f>>2];l=m[g+4>>2];h=m[f+4>>2];m[n+4>>2]=l+h;m[n>>2]=m[g>>2]+m[f>>2];l=p(h-l);h=p(q-r);m[s+4>>2]=p(m[e+16>>2]*l)-p(m[e+20>>2]*h);m[s>>2]=p(m[e+20>>2]*l)+p(m[e+16>>2]*h);r=m[g+8>>2];q=m[f+8>>2];l=m[g+12>>2];h=m[f+12>>2];m[n+12>>2]=l+h;m[n+8>>2]=m[g+8>>2]+m[f+8>>2];l=p(h-l);h=p(q-r);m[s+12>>2]=p(m[e>>2]*l)-p(m[e+4>>2]*h);m[s+8>>2]=p(m[e+4>>2]*l)+p(m[e>>2]*h);g=g+16|0;f=f+16|0;s=s+16|0;n=n+16|0;e=e+ -32|0;if(e>>>0>=j>>>0){continue}break}}y=Pk(b);g=b>>4;n=v+ -1|0;e=b>>3;f=0-e|0;RE(g,a,n,f,j);RE(g,a,n-H|0,f,j);A=b>>5;f=0-g|0;Zn(A,a,n,f,j,16);Zn(A,a,n-e|0,f,j,16);Zn(A,a,n-(e<<1)|0,f,j,16);Zn(A,a,n+o(e,-3)|0,f,j,16);s=2;if((y|0)>=10){f=y+ -4>>1;s=(f|0)>3?f:3;f=2;while(1){g=f;f=f+1|0;F=2<<g;if((F|0)>=1){G=8<<g;e=0;x=b>>g+2;z=0-(x>>1)|0;g=b>>g+4;while(1){Zn(g,a,n-o(e,x)|0,z,j,G);e=e+1|0;if((F|0)!=(e|0)){continue}break}}if((f|0)!=(s|0)){continue}break}}I=y+ -7|0;if((s|0)<(I|0)){while(1){f=s;s=f+1|0;e=b>>f+6;if((e|0)>=1){K=2<<f;y=8<<f;F=y<<2;G=b>>f+2;x=0-(G>>1)|0;f=j;g=n;while(1){d5(K,a,g,x,f,y,G);g=g+ -8|0;f=(F<<2)+f|0;z=(e|0)>1;e=e+ -1|0;if(z){continue}break}}if((s|0)!=(I|0)){continue}break}}c5(A,a,n,j,b);x=v+ -4|0;e=((H<<2)+u|0)+ -16|0;if(e>>>0>=u>>>0){f=(x<<2)+u|0;g=i[((d<<2)+c|0)+1100>>2];while(1){j=(k[g>>1]<<2)+a|0;m[f+12>>2]=m[j>>2];m[f+8>>2]=m[j+4>>2];m[e+12>>2]=m[j+8>>2];m[e+8>>2]=m[j+12>>2];j=(k[g+2>>1]<<2)+a|0;m[f+4>>2]=m[j>>2];m[f>>2]=m[j+4>>2];m[e+4>>2]=m[j+8>>2];m[e>>2]=m[j+12>>2];g=g+4|0;f=f+ -16|0;e=e+ -16|0;if(e>>>0>=u>>>0){continue}break}}f=(v<<2)+u|0;j=f+ -16|0;if(j>>>0>u>>>0){g=i[((d<<2)+c|0)+1084>>2];n=f;e=u;while(1){B=m[g+4>>2];z=n+ -4|0;C=m[z>>2];q=m[e+4>>2];D=p(C+q);l=m[g>>2];E=m[e>>2];s=n+ -8|0;t=m[s>>2];h=p(E-t);r=p(p(B*D)-p(l*h));q=p(q-C);m[e+4>>2]=r+q;l=p(p(l*D)+p(B*h));h=p(t+E);m[e>>2]=l+h;m[z>>2]=r-q;m[s>>2]=h-l;B=m[g+12>>2];s=n+ -12|0;C=m[s>>2];q=m[e+12>>2];D=p(C+q);l=m[g+8>>2];E=m[e+8>>2];t=m[j>>2];h=p(E-t);r=p(p(B*D)-p(l*h));q=p(q-C);m[e+12>>2]=r+q;l=p(p(l*D)+p(B*h));h=p(t+E);m[e+8>>2]=l+h;m[j>>2]=h-l;m[s>>2]=r-q;g=g+16|0;e=e+16|0;n=j;j=j+ -16|0;if(e>>>0<j>>>0){continue}break}}j=f+ -32|0;if(j>>>0>=u>>>0){e=i[((d<<2)+c|0)+1076>>2]+(v<<2)|0;g=(x<<2)+a|0;n=((b<<2)+a|0)+ -16|0;while(1){t=m[e+ -4>>2];r=m[f+ -8>>2];q=m[e+ -8>>2];l=m[f+ -4>>2];h=p(p(t*r)-p(q*l));m[a>>2]=h;m[g+12>>2]=-h;h=p(p(q*p(-r))-p(l*t));m[w>>2]=h;m[n+12>>2]=h;t=m[e+ -12>>2];r=m[f+ -16>>2];q=m[e+ -16>>2];l=m[f+ -12>>2];h=p(p(t*r)-p(q*l));m[a+4>>2]=h;m[g+8>>2]=-h;h=p(p(q*p(-r))-p(l*t));m[w+4>>2]=h;m[n+8>>2]=h;t=m[e+ -20>>2];r=m[f+ -24>>2];q=m[e+ -24>>2];l=m[f+ -20>>2];h=p(p(t*r)-p(q*l));m[a+8>>2]=h;m[g+4>>2]=-h;h=p(p(q*p(-r))-p(l*t));m[w+8>>2]=h;m[n+4>>2]=h;t=m[e+ -28>>2];r=m[j>>2];e=e+ -32|0;q=m[e>>2];l=m[f+ -28>>2];h=p(p(t*r)-p(q*l));m[a+12>>2]=h;m[g>>2]=-h;h=p(p(q*p(-r))-p(l*t));m[w+12>>2]=h;m[n>>2]=h;n=n+ -16|0;g=g+ -16|0;w=w+16|0;a=a+16|0;f=j;j=f+ -32|0;if(j>>>0>=u>>>0){continue}break}}if(!i[c+80>>2]){Cb(u)}i[c+92>>2]=J}function tG(a,b,c,d){a=a|0;b=b|0;c=+c;d=d|0;var e=0,f=0,g=0,h=0;e=Xa-256|0;Xa=e;n[e+248>>3]=c;a:{if(Oi(b)){break a}g=j[Dj(b)|0];f=1;b:{if((g|0)==33){break b}if((g|0)!=63){break a}f=0}d=f;Oj(e+216|0,b,i[b+4>>2]+ -1|0);f=i[e+220>>2];i[b>>2]=i[e+216>>2];i[b+4>>2]=f}jd(e+216|0);f=i[e+216>>2];jd(e+200|0);h=Cj(f,i[e+204>>2],b);jd(e+216|0);f=i[b>>2];g=i[b+4>>2];c:{d:{e:{f:{if((h|0)==i[e+220>>2]){i[e+240>>2]=f;i[e+244>>2]=g;a=Zb(e+232|0,38187);f=i[e+244>>2];i[e+16>>2]=i[e+240>>2];i[e+20>>2]=f;f=i[a+4>>2];i[e+8>>2]=i[a>>2];i[e+12>>2]=f;if(mc(e+16|0,e+8|0)){d=P(8)|0;i[114610]=0;D(2144,e+200|0,e+248|0);a=i[114610];i[114610]=0;g:{h:{i:{if((a|0)!=1){i[114610]=0;G(2119,e+216|0,39252,e+200|0);a=i[114610];i[114610]=0;if((a|0)==1){break i}Ub(d,e+216|0);a=0;i[114610]=0;G(2009,d|0,83568,2017);b=i[114610];i[114610]=0;if((b|0)!=1){break c}b=B()|0;A()|0;eb(e+216|0);break h}b=B()|0;A()|0;break g}b=B()|0;a=1;A()|0}eb(e+200|0);if(!a){break d}}Q(d|0);break d}if(!d){break f}d=P(8)|0;i[114610]=0;f=C(2142,e+168|0,b|0)|0;b=i[114610];i[114610]=0;a=1;j:{k:{l:{m:{n:{o:{p:{q:{r:{if((b|0)!=1){i[114610]=0;G(2119,e+184|0,39131,f|0);a=i[114610];i[114610]=0;if((a|0)==1){break r}i[114610]=0;G(2137,e+200|0,e+184|0,39267);b=i[114610];i[114610]=0;a=1;if((b|0)==1){break q}i[114610]=0;D(2144,e+152|0,e+248|0);a=i[114610];i[114610]=0;if((a|0)==1){break p}i[114610]=0;G(138,e+216|0,e+200|0,e+152|0);b=i[114610];i[114610]=0;a=1;if((b|0)==1){break o}Ub(d,e+216|0);i[114610]=0;G(2009,d|0,83568,2017);a=i[114610];i[114610]=0;if((a|0)!=1){break c}b=B()|0;A()|0;eb(e+216|0);a=0;break n}b=B()|0;A()|0;break j}b=B()|0;a=1;A()|0;break k}b=B()|0;A()|0;break l}b=B()|0;a=1;A()|0;break m}b=B()|0;A()|0}eb(e+152|0)}eb(e+200|0)}eb(e+184|0)}eb(f)}if(!a){break d}Q(d|0);break d}i[e+144>>2]=f;i[e+148>>2]=g;d=Zb(e+136|0,38187);f=i[e+148>>2];i[e+80>>2]=i[e+144>>2];i[e+84>>2]=f;f=i[d+4>>2];i[e+72>>2]=i[d>>2];i[e+76>>2]=f;if(mc(e+80|0,e+72|0)){d=P(8)|0;i[114610]=0;D(2144,e+200|0,e+248|0);a=i[114610];i[114610]=0;s:{t:{u:{if((a|0)!=1){i[114610]=0;G(2119,e+216|0,39252,e+200|0);a=i[114610];i[114610]=0;if((a|0)==1){break u}Ub(d,e+216|0);a=0;i[114610]=0;G(2009,d|0,83568,2017);b=i[114610];i[114610]=0;if((b|0)!=1){break c}b=B()|0;A()|0;eb(e+216|0);break t}b=B()|0;A()|0;break s}b=B()|0;a=1;A()|0}eb(e+200|0);if(!a){break d}}Q(d|0);break d}d=i[b+4>>2];i[e+128>>2]=i[b>>2];i[e+132>>2]=d;d=Zb(e+120|0,38974);f=i[e+132>>2];i[e+64>>2]=i[e+128>>2];i[e+68>>2]=f;f=i[d+4>>2];i[e+56>>2]=i[d>>2];i[e+60>>2]=f;if(mc(e- -64|0,e+56|0)){if(!j[a+28|0]){break f}c=n[e+248>>3];if(!(c<=4?!(c<=0):0)){a=P(8)|0;i[114610]=0;d=C(85,e+216|0,39272)|0;b=i[114610];i[114610]=0;if((b|0)==1){break e}Ub(a,d);i[114610]=0;G(2009,a|0,83568,2017);a=i[114610];i[114610]=0;if((a|0)!=1){break c}b=B()|0;A()|0;eb(d);break d}b=Wj(65536/c);a=a+24|0;i[i[a>>2]+480244>>2]=b;oo(i[a>>2]);break f}d=i[b+4>>2];i[e+112>>2]=i[b>>2];i[e+116>>2]=d;d=Zb(e+104|0,38992);f=i[e+116>>2];i[e+48>>2]=i[e+112>>2];i[e+52>>2]=f;f=i[d+4>>2];i[e+40>>2]=i[d>>2];i[e+44>>2]=f;if(mc(e+48|0,e+40|0)){if(!j[a+28|0]){break f}c=n[e+248>>3];if(!(c<=4?!(c<=0):0)){a=P(8)|0;i[114610]=0;d=C(85,e+216|0,39293)|0;b=i[114610];i[114610]=0;if((b|0)!=1){Ub(a,d);i[114610]=0;G(2009,a|0,83568,2017);a=i[114610];i[114610]=0;if((a|0)!=1){break c}b=B()|0;A()|0;eb(d);break d}b=B()|0;A()|0;Q(a|0);break d}b=Wj(c*65536);a=a+24|0;i[i[a>>2]+480240>>2]=b;oo(i[a>>2]);break f}d=i[b+4>>2];i[e+96>>2]=i[b>>2];i[e+100>>2]=d;b=Zb(e+88|0,39089);d=i[e+100>>2];i[e+32>>2]=i[e+96>>2];i[e+36>>2]=d;d=i[b+4>>2];i[e+24>>2]=i[b>>2];i[e+28>>2]=d;if(!mc(e+32|0,e+24|0)){break f}a=a+24|0;a;b=Mm(n[e+248>>3]*65536);i[i[a>>2]+480236>>2]=b}Xa=e+256|0;return}b=B()|0;A()|0;Q(a|0)}E(b|0)}x()}function k5(a,b,c,d,e,f){var g=0,m=0,n=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;s=Xa-16|0;Xa=s;p=i[a+4>>2];m=i[a+396>>2];r=m+o(e,24)|0;q=i[r+4>>2];x=k[((e<<1)+a|0)+268>>1];g=d<<((x|0)==2);n=q>>>0<g>>>0?q:g;q=i[r>>2];q=(n-(q>>>0<g>>>0?q:g)>>>0)/l[r+8>>2]|0;t=q<<2;g=o(p,t+4|0);y=i[i[a+124>>2]+o(j[r+13|0],2096)>>2];C=i[a+92>>2];a:{if(i[a+80>>2]){g=fm(a,g);p=i[a+4>>2];break a}g=Zc(g)}t=g5(g,p,t);b:{c:{d:{if((c|0)>=1){p=d<<2;g=0;while(1){if(!j[f+g|0]){yb(i[(g<<2)+b>>2],0,p)}g=g+1|0;if((g|0)!=(c|0)){continue}break}if((c|0)==1|(x|0)!=2){break d}g=0;if((c|0)<1){break c}while(1){if(!j[f+g|0]){break c}g=g+1|0;if((g|0)!=(c|0)){continue}break}break b}g=0;if((x|0)==2){break c}}z=m+o(e,24)|0;A=z;B=(q|0)<1;d=0;while(1){if(!B){v=0;w=(c|0)<1;D=w|(d|0)!=0;p=0;while(1){g=0;if(!D){while(1){if(!j[f+g|0]){m=i[a+124>>2]+o(j[r+13|0],2096)|0;if(i[a+1396>>2]<=9){Bj(a)}n=i[a+1392>>2];e=h[(m+((n&1023)<<1)|0)+36>>1];e:{if((e|0)>=0){u=n;n=j[e+i[m+8>>2]|0];i[a+1392>>2]=u>>>n;u=i[a+1396>>2]-n|0;n=(u|0)<0;i[a+1396>>2]=n?0:u;e=n?-1:e;break e}e=Nk(a,m)}e=j[m+23|0]?i[i[m+2088>>2]+(e<<2)>>2]:e;if((e|0)==-1){break b}i[i[t+(g<<2)>>2]+(v<<2)>>2]=i[i[z+16>>2]+(e<<2)>>2]}g=g+1|0;if((g|0)!=(c|0)){continue}break}}f:{if((p|0)>=(q|0)){break f}e=0;if((y|0)<1){break f}while(1){g=0;if(!w){while(1){g:{if(j[f+g|0]){break g}m=g<<2;n=h[(i[A+20>>2]+(j[i[i[m+t>>2]+(v<<2)>>2]+e|0]<<4)|0)+(d<<1)>>1];if((n|0)<0){break g}u=i[b+m>>2];m=i[r+8>>2];if(!f5(a,i[a+124>>2]+o(n&65535,2096)|0,u,i[r>>2]+o(m,p)|0,m,x)){break b}}g=g+1|0;if((g|0)!=(c|0)){continue}break}}p=p+1|0;if((p|0)>=(q|0)){break f}e=e+1|0;if((e|0)<(y|0)){continue}break}}v=v+1|0;if((p|0)<(q|0)){continue}break}}d=d+1|0;if((d|0)!=8){continue}break}break b}if((c|0)==(g|0)){break b}z=(q|0)<1;A=z|(c|0)<3;v=m+o(e,24)|0;x=v;B=(c|0)!=2;e=0;while(1){h:{if(!B){if(z){break h}f=0;p=0;while(1){g=i[r>>2]+o(i[r+8>>2],f)|0;i[s+12>>2]=g&1;i[s+8>>2]=g>>1;if(!e){m=i[a+124>>2]+o(j[r+13|0],2096)|0;if(i[a+1396>>2]<=9){Bj(a)}n=i[a+1392>>2];g=h[(m+((n&1023)<<1)|0)+36>>1];i:{if((g|0)>=0){u=n;n=j[g+i[m+8>>2]|0];i[a+1392>>2]=u>>>n;w=i[a+1396>>2]-n|0;n=(w|0)<0;i[a+1396>>2]=n?0:w;g=n?-1:g;break i}g=Nk(a,m)}g=j[m+23|0]?i[i[m+2088>>2]+(g<<2)>>2]:g;if((g|0)==-1){break b}i[i[t>>2]+(p<<2)>>2]=i[i[v+16>>2]+(g<<2)>>2]}j:{if((f|0)>=(q|0)){break j}g=0;if((y|0)<1){break j}while(1){m=i[r+8>>2];n=h[(i[x+20>>2]+(j[i[i[t>>2]+(p<<2)>>2]+g|0]<<4)|0)+(e<<1)>>1];k:{if((n|0)>=0){if(SE(a,i[a+124>>2]+o(n&65535,2096)|0,b,2,s+12|0,s+8|0,d,m)){break k}break b}m=i[r>>2]+(m+o(f,m)|0)|0;i[s+8>>2]=m>>1;i[s+12>>2]=m&1}f=f+1|0;if((f|0)>=(q|0)){break j}g=g+1|0;if((g|0)<(y|0)){continue}break}}p=p+1|0;if((f|0)<(q|0)){continue}break}break h}if(A){break h}f=0;p=0;while(1){m=i[r>>2]+o(i[r+8>>2],f)|0;g=(m|0)/(c|0)|0;i[s+12>>2]=m-o(c,g);i[s+8>>2]=g;if(!e){m=i[a+124>>2]+o(j[r+13|0],2096)|0;if(i[a+1396>>2]<=9){Bj(a)}n=i[a+1392>>2];g=h[(m+((n&1023)<<1)|0)+36>>1];l:{if((g|0)>=0){u=n;n=j[g+i[m+8>>2]|0];i[a+1392>>2]=u>>>n;w=i[a+1396>>2]-n|0;n=(w|0)<0;i[a+1396>>2]=n?0:w;g=n?-1:g;break l}g=Nk(a,m)}g=j[m+23|0]?i[i[m+2088>>2]+(g<<2)>>2]:g;if((g|0)==-1){break b}i[i[t>>2]+(p<<2)>>2]=i[i[v+16>>2]+(g<<2)>>2]}m:{if((f|0)>=(q|0)){break m}g=0;if((y|0)<1){break m}while(1){m=i[r+8>>2];n=h[(i[x+20>>2]+(j[i[i[t>>2]+(p<<2)>>2]+g|0]<<4)|0)+(e<<1)>>1];n:{if((n|0)>=0){if(SE(a,i[a+124>>2]+o(n&65535,2096)|0,b,c,s+12|0,s+8|0,d,m)){break n}break b}m=i[r>>2]+(m+o(f,m)|0)|0;n=(m|0)/(c|0)|0;i[s+8>>2]=n;i[s+12>>2]=m-o(c,n)}f=f+1|0;if((f|0)>=(q|0)){break m}g=g+1|0;if((g|0)<(y|0)){continue}break}}p=p+1|0;if((f|0)<(q|0)){continue}break}}e=e+1|0;if((e|0)!=8){continue}break}}if(!i[a+80>>2]){Cb(t)}i[a+92>>2]=C;Xa=s+16|0}function dra(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,l=0,m=0,n=0,p=0,q=0,r=0,s=0,t=0,u=0;f=Xa-11360|0;Xa=f;pc(c);a:{b:{if(!wb(c,4)){break b}c:{while(1){d:{YS(c,f+16|0);e:{if(!Xc(f+16|0,20233,3)){bra(c,f+4648|0);l=3;d=0;while(1){g=j[(f+4648|0)+l|0];if(g&128){break c}d=g|d<<7;l=l+1|0;if((l|0)!=7){continue}break}Ib(c,d);break e}f:{if(Xc(f+16|0,20237,3)){break f}if(!GO(c,20241)){break f}Ib(c,Cf(c)+16|0);break e}if(!Xc(f+16|0,20247,3)){break e}if(!Xc(f+16|0,20251,3)){break e}if(j[f+16|0]){break d}tg(c,2)}if(wb(c,4)){continue}break b}break}if(FM(f+16|0)){break b}}l=0;break a}pc(c);Wy(f+11336|0,c);l=i[f+11336>>2];i[114610]=0;c=F(412,f+11336|0)|0;d=i[114610];i[114610]=0;g:{h:{if((d|0)!=1){i[114610]=0;c=F(859,c|0)|0;d=i[114610];i[114610]=0;if((d|0)!=1){break h}}l=B()|0;A()|0;break g}n=f+11320|0;dU(n);yb(f+4648|0,0,6668);i[114610]=0;L(1239,f+4648|0);d=i[114610];i[114610]=0;i:{j:{k:{if((d|0)!=1){d=f+4640|0;i[d>>2]=0;i[d+4>>2]=0;d=f+4632|0;i[d>>2]=0;i[d+4>>2]=0;i[f+4624>>2]=0;i[f+4628>>2]=0;g=0;d=0;l:{m:{n:{while(1){i[114610]=0;m=eg(458,l,q);p=i[114610];i[114610]=0;if((p|0)==1){break l}i[114610]=0;r=S(1240,f+4648|0,c|0,m|0,f+16|0,f+4624|0)|0;m=i[114610];i[114610]=0;if((m|0)==1){break l}if((r|0)<0){break j}m=i[f+4624>>2];if((m|0)<0|!m&(r|0)>0|!(m|r)){break j}o:{if((m|0)>=1){p=i[f+4636>>2];if((p|0)!=(g|0)?g:0){break j}m=i[f+4632>>2];if((m|0)!=(d|0)?d:0){break j}if((p|0)<1|m+ -1>>>0>1){break k}i[114610]=0;i[f+8>>2]=0;d=eg(458,l,q);g=i[114610];i[114610]=0;if((g|0)==1){break o}i[114610]=0;i[f+4>>2]=d;d=I(1241,f+4624|0,f+8|0,f+4|0)|0;g=i[114610];i[114610]=0;if((g|0)==1){break o}d=i[d>>2];i[114610]=0;i[f+8>>2]=0;g=eg(458,l,q);s=i[114610];i[114610]=0;if((s|0)==1){break n}i[114610]=0;i[f+4>>2]=g;g=I(1241,f+4624|0,f+8|0,f+4|0)|0;s=i[114610];i[114610]=0;if((s|0)==1){break n}c=c+d|0;d=l;g=i[g>>2];l=d-g|0;q=q-((g>>31)+(d>>>0<g>>>0)|0)|0;if((r|0)>=1){t=f,u=Kb(n),i[t+8>>2]=u;Ad(f,f+8|0);i[114610]=0;N(1242,n|0,i[f>>2],f+16|0,(f+16|0)+(o(m,r)<<1)|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break m}}g=p;d=m}m=Wb(n);if((q|0)<0?1:(q|0)<=0?l>>>0<1:0){break j}if((m>>>0)/(d>>>0)>>>0<268435457){continue}break j}break}l=B()|0;A()|0;break i}l=B()|0;A()|0;break i}l=H(71348)|0;if((A()|0)!=(U(71348)|0)){break i}M(l|0)|0;i[114610]=0;K(20);c=i[114610];i[114610]=0;g=p;d=m;if((c|0)!=1){break j}l=B()|0;A()|0;break i}l=B()|0;A()|0;break i}l=B()|0;A()|0;break i}g=p;d=m}l=0;p:{q:{r:{s:{t:{if(!d|!g){break t}if(Uc(n)){break t}if((Wb(n)>>>0)/(d>>>0)>>>0>268435456){break t}i[114610]=0;C(1243,a|0,b|0)|0;c=i[114610];i[114610]=0;if((c|0)==1){break p}if(!e){i[114610]=0;c=C(85,f+16|0,20255)|0;m=i[114610];i[114610]=0;if((m|0)==1){break s}i[114610]=0;C(369,((b<<5)+a|0)+946300|0,c|0)|0;m=i[114610];i[114610]=0;if((m|0)==1){break r}eb(c);i[114610]=0;c=o(b,104)+a|0;D(386,c+484380|0,0);m=i[114610];i[114610]=0;if((m|0)==1){break p}i[c+484404>>2]=g}g=o(b,104)+a|0;c=g+484380|0;t=c,u=(Wb(n)>>>0)/(d>>>0)|0,i[t>>2]=u;m=g+484414|0;g=k[m>>1];h[m>>1]=(d|0)==2?g|65:g&65470|1;i[114610]=0;F(465,c|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break p}if(ie(c)){d=Jb(n);g=Kb(n);b=i[(o(b,104)+a|0)+484400>>2];i[114610]=0;I(1244,d|0,g|0,b|0)|0;b=i[114610];i[114610]=0;if((b|0)==1){break p}}if(!e){b=i[a+480180>>2];i[114610]=0;G(1245,c|0,32,b|0);b=i[114610];i[114610]=0;if((b|0)==1){break q}i[114610]=0;G(1246,c|0,a|0,0);a=i[114610];i[114610]=0;if((a|0)==1){break p}}l=ie(c)}DA(n);jc(f+11336|0);break a}l=B()|0;A()|0;break i}l=B()|0;A()|0;eb(c);break i}l=B()|0;A()|0;break i}l=B()|0;A()|0}DA(n)}jc(f+11336|0);E(l|0);x()}Xa=f+11360|0;return l|0}function U8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=Xa-352|0;Xa=d;a:{if(Oi(b)){break a}e=j[Dj(b)|0];f=1;b:{if((e|0)==33){break b}if((e|0)!=63){break a}f=0}c=f;Oj(d+320|0,b,i[b+4>>2]+ -1|0);e=i[d+324>>2];i[b>>2]=i[d+320>>2];i[b+4>>2]=e}jd(d+320|0);e=i[d+320>>2];jd(d+304|0);e=Cj(e,i[d+308>>2],b);jd(d+320|0);c:{d:{e:{f:{if((e|0)==i[d+324>>2]){a=i[b+4>>2];i[d+344>>2]=i[b>>2];i[d+348>>2]=a;a=Zb(d+336|0,38187);e=i[d+348>>2];i[d+8>>2]=i[d+344>>2];i[d+12>>2]=e;e=i[a+4>>2];i[d>>2]=i[a>>2];i[d+4>>2]=e;if(mc(d+8|0,d)){a=P(8)|0;i[114610]=0;c=C(85,d+320|0,39121)|0;b=i[114610];i[114610]=0;if((b|0)==1){break e}Ub(a,c);i[114610]=0;G(2009,a|0,83568,2017);a=i[114610];i[114610]=0;if((a|0)!=1){break c}b=B()|0;A()|0;eb(c);break d}e=0;if(!c){break f}a=P(8)|0;i[114610]=0;c=C(2142,d+304|0,b|0)|0;b=i[114610];i[114610]=0;g:{h:{i:{if((b|0)!=1){i[114610]=0;G(2119,d+320|0,39131,c|0);b=i[114610];i[114610]=0;if((b|0)==1){break i}Ub(a,d+320|0);e=0;i[114610]=0;G(2009,a|0,83568,2017);b=i[114610];i[114610]=0;if((b|0)!=1){break c}b=B()|0;A()|0;eb(d+320|0);break h}b=B()|0;A()|0;break g}b=B()|0;e=1;A()|0}eb(c);if(!e){break d}}Q(a|0);break d}if(i[e+4>>2]){a=P(8)|0;i[114610]=0;c=C(85,d+320|0,39145)|0;b=i[114610];i[114610]=0;if((b|0)!=1){Ub(a,c);i[114610]=0;G(2009,a|0,83568,2017);a=i[114610];i[114610]=0;if((a|0)!=1){break c}b=B()|0;A()|0;eb(c);break d}b=B()|0;A()|0;Q(a|0);break d}c=i[b+4>>2];i[d+296>>2]=i[b>>2];i[d+300>>2]=c;c=Zb(d+288|0,38187);e=i[d+300>>2];i[d+152>>2]=i[d+296>>2];i[d+156>>2]=e;e=i[c+4>>2];i[d+144>>2]=i[c>>2];i[d+148>>2]=e;if(mc(d+152|0,d+144|0)){a=P(8)|0;i[114610]=0;c=C(85,d+320|0,39121)|0;b=i[114610];i[114610]=0;if((b|0)!=1){Ub(a,c);i[114610]=0;G(2009,a|0,83568,2017);a=i[114610];i[114610]=0;if((a|0)!=1){break c}b=B()|0;A()|0;eb(c);break d}b=B()|0;A()|0;Q(a|0);break d}c=i[b+4>>2];i[d+280>>2]=i[b>>2];i[d+284>>2]=c;c=Zb(d+272|0,38869);e=i[d+284>>2];i[d+136>>2]=i[d+280>>2];i[d+140>>2]=e;e=i[c+4>>2];i[d+128>>2]=i[c>>2];i[d+132>>2]=e;j:{if(!mc(d+136|0,d+128|0)){c=i[b+4>>2];i[d+264>>2]=i[b>>2];i[d+268>>2]=c;c=Zb(d+256|0,39166);e=i[d+268>>2];i[d+120>>2]=i[d+264>>2];i[d+124>>2]=e;e=i[c+4>>2];i[d+112>>2]=i[c>>2];i[d+116>>2]=e;if(!mc(d+120|0,d+112|0)){break j}}e=j[a+60|0]!=0;break f}c=i[b+4>>2];i[d+248>>2]=i[b>>2];i[d+252>>2]=c;c=Zb(d+240|0,38887);e=i[d+252>>2];i[d+104>>2]=i[d+248>>2];i[d+108>>2]=e;e=i[c+4>>2];i[d+96>>2]=i[c>>2];i[d+100>>2]=e;k:{if(!mc(d+104|0,d+96|0)){c=i[b+4>>2];i[d+232>>2]=i[b>>2];i[d+236>>2]=c;c=Zb(d+224|0,39184);e=i[d+236>>2];i[d+88>>2]=i[d+232>>2];i[d+92>>2]=e;e=i[c+4>>2];i[d+80>>2]=i[c>>2];i[d+84>>2]=e;if(!mc(d+88|0,d+80|0)){break k}}e=j[a+61|0]!=0;break f}c=i[b+4>>2];i[d+216>>2]=i[b>>2];i[d+220>>2]=c;c=Zb(d+208|0,38906);e=i[d+220>>2];i[d+72>>2]=i[d+216>>2];i[d+76>>2]=e;e=i[c+4>>2];i[d+64>>2]=i[c>>2];i[d+68>>2]=e;if(mc(d+72|0,d- -64|0)){e=j[a+62|0]!=0;break f}c=i[b+4>>2];i[d+200>>2]=i[b>>2];i[d+204>>2]=c;c=Zb(d+192|0,38924);e=i[d+204>>2];i[d+56>>2]=i[d+200>>2];i[d+60>>2]=e;e=i[c+4>>2];i[d+48>>2]=i[c>>2];i[d+52>>2]=e;if(mc(d+56|0,d+48|0)){e=j[a+63|0]!=0;break f}c=i[b+4>>2];i[d+184>>2]=i[b>>2];i[d+188>>2]=c;c=Zb(d+176|0,38948);e=i[d+188>>2];i[d+40>>2]=i[d+184>>2];i[d+44>>2]=e;e=i[c+4>>2];i[d+32>>2]=i[c>>2];i[d+36>>2]=e;if(mc(d+40|0,d+32|0)){e=j[a+64|0]!=0;break f}c=i[b+4>>2];i[d+168>>2]=i[b>>2];i[d+172>>2]=c;b=Zb(d+160|0,39022);c=i[d+172>>2];i[d+24>>2]=i[d+168>>2];i[d+28>>2]=c;c=i[b+4>>2];i[d+16>>2]=i[b>>2];i[d+20>>2]=c;e=0;if(!mc(d+24|0,d+16|0)){break f}e=i[i[a+24>>2]+24668>>2]!=0}Xa=d+352|0;return e|0}b=B()|0;A()|0;Q(a|0)}E(b|0)}x()}function A6(a,b){var c=0,d=0,e=0,f=0,g=0;c=Xa-112|0;Xa=c;f=Oc(c+96|0);i[114610]=0;g=C(2,c+80|0,6848)|0;d=i[114610];i[114610]=0;a:{b:{c:{if((d|0)!=1){d=i[b+20>>2];if(d){break c}Lc(a,f);break a}a=B()|0;A()|0;break b}i[114610]=0;i[c+48>>2]=d+1900;D(191,c- -64|0,c+48|0);d=i[114610];i[114610]=0;d:{e:{if((d|0)!=1){i[114610]=0;C(192,f|0,c- -64|0)|0;d=i[114610];i[114610]=0;f:{if((d|0)!=1){eb(c- -64|0);if(l[b+16>>2]<12){break f}Lc(a,f);break a}a=B()|0;A()|0;eb(c- -64|0);break d}i[114610]=0;d=C(2,c+48|0,6850)|0;e=i[114610];i[114610]=0;g:{h:{i:{j:{k:{l:{if((e|0)!=1){e=i[b+16>>2];i[114610]=0;i[c+16>>2]=e+1;D(193,c+32|0,c+16|0);e=i[114610];i[114610]=0;if((e|0)==1){break l}i[114610]=0;G(3,c- -64|0,d|0,c+32|0);e=i[114610];i[114610]=0;if((e|0)==1){break k}i[114610]=0;C(192,f|0,c- -64|0)|0;e=i[114610];i[114610]=0;if((e|0)==1){break j}eb(c- -64|0);eb(c+32|0);eb(d);if(i[b+12>>2]+ -1>>>0<31){break g}Lc(a,f);break a}a=B()|0;A()|0;break d}a=B()|0;A()|0;break h}a=B()|0;A()|0;break i}a=B()|0;A()|0;eb(c- -64|0)}eb(c+32|0)}eb(d);break d}i[114610]=0;d=C(2,c+48|0,6850)|0;e=i[114610];i[114610]=0;m:{n:{o:{p:{q:{r:{s:{if((e|0)!=1){i[114610]=0;D(193,c+32|0,b+12|0);e=i[114610];i[114610]=0;if((e|0)==1){break s}i[114610]=0;G(3,c- -64|0,d|0,c+32|0);e=i[114610];i[114610]=0;if((e|0)==1){break r}i[114610]=0;C(192,f|0,c- -64|0)|0;e=i[114610];i[114610]=0;if((e|0)==1){break q}eb(c- -64|0);eb(c+32|0);eb(d);d=i[b+8>>2];if(d){break n}if(i[b+4>>2]|i[b>>2]){break m}Lc(a,f);break a}a=B()|0;A()|0;break d}a=B()|0;A()|0;break o}a=B()|0;A()|0;break p}a=B()|0;A()|0;eb(c- -64|0)}eb(c+32|0)}eb(d);break d}if(d>>>0<24){break m}Lc(a,f);break a}if(l[b+4>>2]>=60){Lc(a,f);break a}i[114610]=0;d=C(2,c- -64|0,6852)|0;e=i[114610];i[114610]=0;t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{if((e|0)!=1){i[114610]=0;C(192,f|0,d|0)|0;e=i[114610];i[114610]=0;if((e|0)==1){break F}eb(d);if(i[b+32>>2]>=1){i[114610]=0;d=C(2,c- -64|0,6854)|0;e=i[114610];i[114610]=0;if((e|0)==1){break E}mb(g,d);eb(d)}i[114610]=0;D(193,c+32|0,b+8|0);d=i[114610];i[114610]=0;if((d|0)==1){break D}i[114610]=0;d=C(2,c+16|0,6861)|0;e=i[114610];i[114610]=0;if((e|0)==1){break C}i[114610]=0;G(3,c+48|0,c+32|0,d|0);e=i[114610];i[114610]=0;if((e|0)==1){break B}i[114610]=0;D(193,c|0,b+4|0);e=i[114610];i[114610]=0;if((e|0)==1){break A}i[114610]=0;G(3,c- -64|0,c+48|0,c|0);e=i[114610];i[114610]=0;if((e|0)==1){break z}i[114610]=0;C(192,f|0,c- -64|0)|0;e=i[114610];i[114610]=0;if((e|0)==1){break y}eb(c- -64|0);eb(c);eb(c+48|0);eb(d);eb(c+32|0);if(l[b>>2]<62){break t}i[114610]=0;G(194,a|0,f|0,g|0);a=i[114610];i[114610]=0;if((a|0)!=1){break a}break e}a=B()|0;A()|0;break d}a=B()|0;A()|0;eb(d);break d}a=B()|0;A()|0;break d}a=B()|0;A()|0;break d}a=B()|0;A()|0;break u}a=B()|0;A()|0;break v}a=B()|0;A()|0;break w}a=B()|0;A()|0;break x}a=B()|0;A()|0;eb(c- -64|0)}eb(c)}eb(c+48|0)}eb(d)}eb(c+32|0);break d}i[114610]=0;d=C(2,c+48|0,6861)|0;e=i[114610];i[114610]=0;G:{H:{I:{J:{K:{if((e|0)!=1){i[114610]=0;D(193,c+32|0,b|0);b=i[114610];i[114610]=0;if((b|0)==1){break K}i[114610]=0;G(3,c- -64|0,d|0,c+32|0);b=i[114610];i[114610]=0;if((b|0)==1){break J}i[114610]=0;C(192,f|0,c- -64|0)|0;b=i[114610];i[114610]=0;if((b|0)==1){break I}eb(c- -64|0);eb(c+32|0);eb(d);i[114610]=0;C(192,f|0,g|0)|0;b=i[114610];i[114610]=0;if((b|0)==1){break e}Lc(a,f);break a}a=B()|0;A()|0;break d}a=B()|0;A()|0;break G}a=B()|0;A()|0;break H}a=B()|0;A()|0;eb(c- -64|0)}eb(c+32|0)}eb(d);break d}a=B()|0;A()|0;break d}a=B()|0;A()|0}eb(g)}eb(f);E(a|0);x()}eb(g);eb(f);Xa=c+112|0}function Ff(a,b,c,d,e,f,g,h,j){var k=0,l=0,m=0,n=0,o=0,p=0,q=0,s=0,t=0,u=0;m=Xa-112|0;Xa=m;o=h;n=j&2147483647;l=c+ -1|0;k=b+ -1|0;if((k|0)!=-1){l=l+1|0}p=k;s=(k|0)==-1&(l|0)==-1;q=e&2147483647;k=q;t=d;l=(c|0)==(l|0)&p>>>0<b>>>0|l>>>0<c>>>0;p=d+l|0;if(p>>>0<l>>>0){k=k+1|0}l=p+ -1|0;k=k+ -1|0;k=(l|0)!=-1?k+1|0:k;a:{b:{if(!((l|0)==-1&(k|0)==2147418111?s:k>>>0>2147418111)){l=g+ -1|0;k=f+ -1|0;if((k|0)!=-1){l=l+1|0}p=k;s=(k|0)!=-1|(l|0)!=-1;k=n;l=(g|0)==(l|0)&p>>>0<f>>>0|l>>>0<g>>>0;p=l+o|0;if(p>>>0<l>>>0){k=k+1|0}l=p+ -1|0;k=k+ -1|0;k=(l|0)!=-1?k+1|0:k;if((l|0)==-1&(k|0)==2147418111?s:(k|0)==2147418111&(l|0)!=-1|k>>>0<2147418111){break b}}if(!(!t&(q|0)==2147418112?!(b|c):(q|0)==2147418112&t>>>0<0|q>>>0<2147418112)){h=d;j=e|32768;f=b;g=c;break a}if(!(!o&(n|0)==2147418112?!(f|g):(n|0)==2147418112&o>>>0<0|n>>>0<2147418112)){j=j|32768;break a}if(!(b|t|(q^2147418112|c))){k=d;d=!(b^f|d^h|(c^g|e^j^-2147483648));h=d?0:k;j=d?2147450880:e;f=d?0:b;g=d?0:c;break a}if(!(f|o|(n^2147418112|g))){break a}if(!(b|t|(c|q))){if(f|o|(g|n)){break a}f=b&f;g=c&g;h=d&h;j=e&j;break a}if(f|o|(g|n)){break b}f=b;g=c;h=d;j=e;break a}k=(o|0)==(t|0)&(n|0)==(q|0)?(c|0)==(g|0)&f>>>0>b>>>0|g>>>0>c>>>0:(n|0)==(q|0)&o>>>0>t>>>0|n>>>0>q>>>0;q=k?f:b;l=k?g:c;o=k?j:e;t=o;p=k?h:d;o=o&65535;j=k?e:j;e=j;h=k?d:h;s=j>>>16&32767;n=t>>>16&32767;if(!n){d=!(o|p);j=d<<6;n=r(d?q:p)+32|0;d=r(d?l:o);d=j+((d|0)==32?n:d)|0;kf(m+96|0,q,l,p,o,d+ -15|0);p=i[m+104>>2];o=i[m+108>>2];q=i[m+96>>2];n=16-d|0;l=i[m+100>>2]}f=k?b:f;g=k?c:g;j=e&65535;if(!s){b=!(h|j);c=b<<6;d=r(b?f:h)+32|0;b=r(b?g:j);b=c+((b|0)==32?d:b)|0;kf(m+80|0,f,g,h,j,b+ -15|0);s=16-b|0;h=i[m+88>>2];j=i[m+92>>2];g=i[m+84>>2];f=i[m+80>>2]}b=h;k=j<<3|b>>>29;h=b<<3|g>>>29;j=k|524288;b=p;d=o<<3|b>>>29;o=b<<3|l>>>29;u=d;p=e^t;b=f;k=g<<3|b>>>29;b=b<<3;c=k;d=n-s|0;e=b;c:{if(!d){break c}if(d>>>0>127){h=0;j=0;k=0;e=1;break c}kf(m- -64|0,b,c,h,j,128-d|0);cm(m+48|0,b,c,h,j,d);h=i[m+56>>2];j=i[m+60>>2];k=i[m+52>>2];e=i[m+48>>2]|((i[m+64>>2]|i[m+72>>2])!=0|(i[m+68>>2]|i[m+76>>2])!=0)}f=k;d=o;s=u|524288;b=q;k=l<<3|b>>>29;c=b<<3;d:{if((p|0)<-1?1:(p|0)<=-1){l=e;b=c-l|0;o=h;q=d-h|0;e=(f|0)==(k|0)&c>>>0<l>>>0|k>>>0<f>>>0;h=q-e|0;c=k-((c>>>0<l>>>0)+f|0)|0;j=(s-((d>>>0<o>>>0)+j|0)|0)-(q>>>0<e>>>0)|0;if(!(b|h|(c|j))){f=0;g=0;h=0;j=0;break a}if(j>>>0>524287){break d}f=b;d=!(h|j);e=d<<6;g=r(d?b:h)+32|0;b=r(d?c:j);b=e+((b|0)==32?g:b)|0;b=b+ -12|0;kf(m+32|0,f,c,h,j,b);n=n-b|0;h=i[m+40>>2];j=i[m+44>>2];b=i[m+32>>2];c=i[m+36>>2];break d}k=f+k|0;b=c+e|0;if(b>>>0<c>>>0){k=k+1|0}c=k;g=(f|0)==(k|0)&b>>>0<e>>>0|k>>>0<f>>>0;l=j+s|0;e=d+h|0;if(e>>>0<d>>>0){l=l+1|0}f=e;e=g+f|0;d=l;h=e;j=h>>>0<f>>>0?d+1|0:d;if(!(j&1048576)){break d}b=b&1|((c&1)<<31|b>>>1);c=h<<31|c>>>1;n=n+1|0;h=(j&1)<<31|h>>>1;j=j>>>1|0}l=0;o=t&-2147483648;if((n|0)>=32767){h=l;j=o|2147418112;f=0;g=0;break a}e=0;e:{if((n|0)>0){e=n;break e}kf(m+16|0,b,c,h,j,n+127|0);cm(m,b,c,h,j,1-n|0);b=i[m>>2]|((i[m+16>>2]|i[m+24>>2])!=0|(i[m+20>>2]|i[m+28>>2])!=0);c=i[m+4>>2];h=i[m+8>>2];j=i[m+12>>2]}n=b&7;g=n>>>0>4;b=(c&7)<<29|b>>>3;d=h<<29|c>>>3;k=d;f=b+g|0;if(f>>>0<b>>>0){k=k+1|0}c=f;g=k;b=(d|0)==(k|0)&c>>>0<b>>>0|k>>>0<d>>>0;k=o|j>>>3&65535|e<<16;c=(j&7)<<29|h>>>3|l;b=c+b|0;if(b>>>0<c>>>0){k=k+1|0}h=b;j=k;f:{if((n|0)==4){b=0;d=b+g|0;c=f&1;f=c+f|0;if(f>>>0<c>>>0){d=d+1|0}g=d;b=(b|0)==(d|0)&f>>>0<c>>>0|d>>>0<b>>>0;c=b+h|0;if(c>>>0<b>>>0){k=k+1|0}h=c;j=k;break f}if(!n){break a}}}i[a>>2]=f;i[a+4>>2]=g;i[a+8>>2]=h;i[a+12>>2]=j;Xa=m+112|0}function lAa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,l=0,m=0,n=0,p=0,q=0,r=0,s=0,t=0,u=0;d=Xa-256|0;Xa=d;pc(b);a:{if(!xz(b,d+184|0)){break a}if(!cO(d+184|0)){break a}if(!wb(b,Vc(bO(d+184|0),_a))){break a}b:{if(!c){break b}md(a,16);en(d,2,d+184|4);oc(d+16|0,d);mb(a+1304400|0,d+16|0);eb(d+16|0);h[a+480190>>1]=j[d+214|0];h[a+480188>>1]=j[d+217|0];e=Bb(d+16|0,16572);mb(a+1304436|0,e);eb(e);e=Bb(d+16|0,16585);mb(a+1304448|0,e);eb(e);f=Bb(d+168|0,16589);i[114610]=0;D(219,d|0,f|0);e=i[114610];i[114610]=0;c:{d:{e:{f:{g:{h:{i:{if((e|0)!=1){e=d+184|3;i[d+152>>2]=j[e|0]>>>4;e=j[e|0];i[114610]=0;i[d+164>>2]=e&15;J(534,d+16|0,d|0,d+152|0,d+164|0);e=i[114610];i[114610]=0;if((e|0)==1){break i}mb(a+1304460|0,d+16|0);eb(d+16|0);ob(d);eb(f);i[a+1304496>>2]=4;if(k[a+480190>>1]){e=1;l=1;while(1){cT(b,d+16|0);kAa(d+16|0,(o(e,104)+a|0)+484380|0);on(d+152|0,2,d+16|0);oc(d,d+152|0);i[114610]=0;C(369,((e<<5)+a|0)+946300|0,d|0)|0;e=i[114610];i[114610]=0;if((e|0)==1){break e}eb(d);l=l+1|0;e=l&65535;if(e>>>0<=k[a+480190>>1]){continue}break}}if(k[a+480188>>1]){e=0;while(1){f=(e<<5)+a|0;sg(f+480280|0);h[f+480284>>1]=(j[(d+e|0)+218|0]<<4|8)&248;e=e+1|0;if(e>>>0<k[a+480188>>1]){continue}break}}jAa(b,d+16|0);mT(Db(a+484360|0),d+16|0,j[d+211|0]+1|0);if(j[d+216|0]){break g}p=64;break f}e=B()|0;A()|0;break h}e=B()|0;A()|0;ob(d)}eb(f);break c}p=j[d+216|0]}ad(d,b,o(j[d+208|0]|j[d+209|0]<<8,192));j:{k:{if(!(c&1)){break k}e=j[d+210|0];i[114610]=0;s=a+484344|0;D(401,s|0,e+1|0);e=i[114610];i[114610]=0;if((e|0)==1){break d}while(1){i[114610]=0;f=I(402,s|0,q&65535,p|0)|0;e=i[114610];i[114610]=0;if((e|0)==1){break j}e=0;if(!f){break k}while(1){i[114610]=0;f=F(357,b|0)|0;m=i[114610];i[114610]=0;if((m|0)==1){break d}t=e;l:{if(!f|f>>>0>(j[d+208|0]|j[d+209|0]<<8)>>>0){break l}e=t&65535;if(e>>>0>=k[a+480188>>1]){break l}i[114610]=0;C(256,d|0,o(f,192)+ -192|0)|0;f=i[114610];i[114610]=0;if((f|0)==1){break d}f=Fb(s,q);i[114610]=0;e=I(471,f|0,0,e|0)|0;f=i[114610];i[114610]=0;if((f|0)==1){break d}u=0;if(!p){break l}while(1){i[114610]=0;D(810,d+152|0,d|0);f=i[114610];i[114610]=0;if((f|0)==1){break d}l=Nc(d+152|0);r=yf(d+152|0);m=e;n=d+152|0;f=j[n|0];if(f>>>0>=4){g[e|0]=(f>>>2|0)+37;f=j[n|0]}g[m+1|0]=f<<4&48|j[l|0]>>>4;f=j[r|0];m=0;r=0;m:{n:{o:{p:{q:{r:{l=j[l|0]&15;switch(l+ -8|0){case 0:break o;case 6:break q;case 2:break r;default:break p}}f=f&240?f&-16:f&15;l=10;break n}l=14;n=(f+16&240)>>>4|0;if(n>>>0>8){break n}if(1<<n&435){break o}break n}m=l;r=f}f=r;l=m;if(!((f|l)&255)){break m}}g[e+5|0]=f;g[e+3|0]=l;i[114610]=0;L(577,e|0);f=i[114610];i[114610]=0;if((f|0)!=1){break m}break d}e=o(k[a+480188>>1],6)+e|0;u=u+1|0;if((u|0)!=(p|0)){continue}break}}e=t+1|0;if((t&65535)>>>0<31){continue}break}e=q>>>0<j[d+210|0];q=q+1|0;if(e){continue}break}}if(j[d+212|0]|j[d+213|0]<<8){e=j[d+212|0]|j[d+213|0]<<8;i[114610]=0;S(549,a+1304424|0,b|0,e|0,39,1)|0;e=i[114610];i[114610]=0;if((e|0)==1){break d}}if(!(!(c&2)|!k[a+480190>>1])){f=1;while(1){c=o(f&65535,104)+a|0;e=Ic(d+152|0,h[c+484414>>1]&1?16:8,1,0,1);i[114610]=0;I(400,e|0,c+484380|0,b|0)|0;c=i[114610];i[114610]=0;if((c|0)==1){break d}f=f+1|0;if((f&65535)>>>0<=k[a+480190>>1]){continue}break}}i[a+480260>>2]=64;i[a+480264>>2]=32767;hb(d);break b}break d}e=B()|0;A()|0;eb(d);break c}e=B()|0;A()|0;hb(d)}E(e|0);x()}e=1}Xa=d+256|0;return e|0}function vK(a,b,c){var d=0,e=0,f=0,h=0,m=0,n=0,p=0,q=0,r=0;f=Xa-16|0;Xa=f;d=c&15;h=o(b,896)+a|0;e=h+1074984|0;a:{b:{switch((c&240)+ -16>>>4|0){case 0:a=h+1075072|0;i[a>>2]=i[a>>2]&-1048577|((d|0)!=0)<<20;break a;case 1:if(!(j[a+480209|0]&16)){break a}if(i[a+480180>>2]!=64){b=o(b,896)+a|0;c=d<<28>>24;i[b+1075752>>2]=c;d=k[(d<<1)+21440>>1];i[b+1075688>>2]=d;e=b+1075684|0;if(!i[e>>2]){break a}q=e,r=Vf(a,j[b+1075803|0],c,d),i[q>>2]=r;break a}a=o(b,896)+a|0;b=i[a+1075088>>2];if(!b){break a}i[a+1075688>>2]=i[b+24>>2]+o(d,80);break a;case 2:if(i[a+480180>>2]==2){g[(o(b,896)+a|0)+1075826|0]=c&3;break a}kb(f+8|0,a+1074308|0,21);if(ib(f+8|0)){g[(o(b,896)+a|0)+1075826|0]=d>>>0<4?d:0;break a}g[(o(b,896)+a|0)+1075826|0]=c&7;break a;case 3:if(i[a+480180>>2]==2){g[(o(b,896)+a|0)+1075829|0]=c&3;break a}kb(f+8|0,a+1074308|0,21);if(ib(f+8|0)){g[(o(b,896)+a|0)+1075829|0]=d>>>0<4?d:0;break a}g[(o(b,896)+a|0)+1075829|0]=c&7;break a;case 4:kb(f+8|0,a+1074308|0,21);if(ib(f+8|0)){a=o(b,896)+a|0;g[a+1075825|0]=0;g[a+1075832|0]=d>>>0<4?d:0;break a}g[(o(b,896)+a|0)+1075832|0]=c&7;break a;case 5:if(i[a+1074392>>2]|!(j[a+480209|0]&16)){break a}a=a+1074400|0;i[a>>2]=i[a>>2]+d;break a;case 6:if(!(j[a+480209|0]&16)){break a}c:{switch(d|0){case 0:case 1:case 2:d=k[a+480188>>1];if(d>>>0>255){break a}e=a+1304392|0;n=b+1|0;p=(c&15)+ -1|0;while(1){c=o(d,896)+a|0;d:{if(k[c+1075792>>1]!=(n|0)){break d}e:{f:{switch(p|0){case 0:Bm(a,c+1074984|0);if(!(j[c+1075073|0]&2)){break e}if(!$c(e)){break e}Rj(i[e>>2],d&65535);break e;case 1:m=c+1075072|0;h=i[m>>2];i[m>>2]=h|4096;if(!(h&512)){break e}if(!$c(e)){break e}Rj(i[e>>2],d&65535);break e;default:break f}}i[c+1075680>>2]=0;m=c+1075072|0;h=i[m>>2];i[m>>2]=h|4096;if(!(h&512)){break e}if(!$c(e)){break e}Zh(i[e>>2],d&65535,1)}h=i[c+1075640>>2];if(!h){break d}m=j[h+34|0];if(!m){break d}m=i[(o(m,160)+a|0)+906140>>2];if(!m){break d}$a[i[i[m>>2]+88>>2]](m,h,j[c+1075803|0]+255|0,0,b)}d=d+1|0;if((d&65535)!=256){continue}break}break a;case 3:g[(o(b,896)+a|0)+1075804|0]=0;break a;case 4:g[(o(b,896)+a|0)+1075804|0]=1;break a;case 5:g[(o(b,896)+a|0)+1075804|0]=2;break a;case 6:g[(o(b,896)+a|0)+1075804|0]=3;break a;case 7:a=(o(b,896)+a|0)+1075708|0;g[a|0]=j[a|0]&254;break a;case 8:a=(o(b,896)+a|0)+1075708|0;g[a|0]=j[a|0]|1;break a;case 9:a=(o(b,896)+a|0)+1075720|0;g[a|0]=j[a|0]&254;break a;case 10:a=(o(b,896)+a|0)+1075720|0;g[a|0]=j[a|0]|1;break a;case 11:a=(o(b,896)+a|0)+1075732|0;g[a|0]=j[a|0]&254;break a;case 12:a=(o(b,896)+a|0)+1075732|0;g[a|0]=j[a|0]|1;break a;case 13:case 14:break c;default:break a}}if(i[a+480180>>2]!=16777216){break a}b=(o(b,896)+a|0)+1075732|0;a=j[b|0];g[b|0]=(d|0)==13?a&238|1:a|17;break a;case 7:if(!(j[a+480209|0]&16)){break a}$k(a,e,d,4);break a;case 8:Ooa(a,e,d);break a;case 9:if(!(j[a+480209|0]&16)){break a}c=o(b,896)+a|0;g[c+1075840|0]=d;kb(f+8|0,a+1074308|0,35);if(ib(f+8|0)){break a}if(!Jf(c+1075794|0)){break a}c=d<<16;if(c>>>0>=l[(o(b,896)+a|0)+1075060>>2]){break a}i[e+4>>2]=c;break a;case 11:g:{if(d){break g}d=1;if(i[a+480180>>2]&16777248){break g}d=0;if(i[a+480180>>2]==2){break a}}kb(f+8|0,a+1074308|0,30);c=a;if(ib(f+8|0)){a=1}else{a=i[a+480180>>2]==2}ox(c,b,d,a);break a;case 14:break b;default:break a}}if(i[a+480180>>2]==2){break a}g[(o(b,896)+a|0)+1075848|0]=d}Xa=f+16|0}function rma(a,b,c,d){var e=0,f=0,m=0,n=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;n=Xa-16|0;Xa=n;q=o(b,896)+a|0;e=i[q+1075640>>2];a:{if(!e){break a}f=j[e+34|0];if(!f|j[e+15|0]&2|(!i[(o(f,160)+a|0)+906140>>2]|i[(o(b,896)+a|0)+1075072>>2]&134218752)){break a}f=o(b,896)+a|0;r=f+1075797|0;s=j[r|0];p=f+1075805|0;if(Jd(j[p|0])){m=j[Nb(e+108|0,j[p|0]+ -1|0)|0]}p=f+1075794|0;b:{c:{if((s|0)==1){e=0;d:{e:{switch((l[a+1074392>>2]%3|0)+ -1|0){case 0:e=j[(o(b,896)+a|0)+1075812|0]>>>4|0;break d;case 1:break e;default:break d}}e=j[(o(b,896)+a|0)+1075812|0]&15}f=o(b,896)+a|0;g[f+1075807|0]=m;if(j[f+1075806|0]==(e+m|0)){break b}if(!(j[a+480209|0]&16)){break c}if(!Jf(p)){break c}break b}e=0;if(j[p|0]|!j[(o(b,896)+a|0)+1075806|0]){break b}}f=o(b,896)+a|0;Kj(a,b,j[f+1075807|0]+e|0,k[f+1075672>>1])}f=(o(b,896)+a|0)+1075806|0;t=j[f|0];f:{if(t){Kj(a,b,t+255|0,0);break f}if(!(j[a+480209|0]&16)|(s|0)!=1){break f}if(Jf(p)){break f}if(!Jd(m)){break f}Kj(a,b,m+255|0,0)}g[f|0]=j[r|0]==1?j[(o(b,896)+a|0)+1075807|0]+e|0:0}g:{if(j[q+1075811|0]!=1){break g}if(Vi(q+1074984|0)){m=0;h:{i:{j:{switch(l[a+1074392>>2]%3|0){case 1:m=j[(o(b,896)+a|0)+1075812|0]>>>4|0;break i;case 0:break i;case 2:break j;default:break h}}m=j[(o(b,896)+a|0)+1075812|0]&15}h[d>>1]=m}a=(o(b,896)+a|0)+1075856|0;g[a|0]=j[a|0]|12;break g}if(!(!(j[a+480209|0]&16)|i[a+480180>>2]!=1048576)){d=o(b,896)+a|0;e=Vf(a,j[d+1075803|0],i[d+1075752>>2],i[d+1075688>>2]);i[c>>2]=e;i[d+1075684>>2]=e}m=a+1074308|0;kb(n+8|0,m,13);if(ib(n+8|0)){m=j[(o(b,896)+a|0)+1075812|0];if(!m){break g}b=65536;k:{switch(((l[a+1074392>>2]%(i[a+1074400>>2]+i[a+1074416>>2]>>>0)>>>0)%3|0)+ -1|0){case 1:m=m<<4;case 0:b=i[((m&240)<<2)+25296>>2];break;default:break k}}e=wo(a);a=i[c>>2];d=a;a=a>>31;l:{if(e){b=XMa(d,a,b,b>>31)+32768|0;a=_a;a=YMa(b,b>>>0<32768?a+1|0:a,65536,0);b=_a;break l}a=a<<16|d>>>16;e=(b|0)/2|0;f=d<<16;d=e+f|0;a=a+(e>>31)|0;a=YMa(d,d>>>0<f>>>0?a+1|0:a,b,b>>31);b=_a}u=c,v=gc(a,b),i[u>>2]=v;break g}kb(n+8|0,m,51);if(ib(n+8|0)){if(j[a+480209|0]&16){break g}m:{n:{d=i[a+1074416>>2];d=d-(l[a+1074392>>2]%(d>>>0)|0)|0;if((d|0)>16){break n}if((d|0)==16){break g}e=0;o:{switch((d|0)%3|0){case 0:break g;case 2:break n;case 1:break o;default:break m}}e=j[(o(b,896)+a|0)+1075812|0]>>>4|0;break m}e=j[(o(b,896)+a|0)+1075812|0]&15}b=o(b,896)+a|0;d=b+1075752|0;b=b+1075688|0;e=Lr(a,i[c>>2],i[d>>2],i[b>>2])+e|0;d=Vf(a,e,i[d>>2],i[b>>2]);i[c>>2]=d;if(e>>>0<109){break g}i[n+8>>2]=d;u=n,v=Vf(a,109,0,i[b>>2]),i[u+4>>2]=v;u=c,v=i[Jc(n+8|0,n+4|0)>>2],i[u>>2]=v;break g}d=i[a+1074392>>2];if(i[a+480180>>2]!=1){e=j[(o(b,896)+a|0)+1075803|0]}else{e=o(b,896)+a|0;e=Lr(a,i[c>>2],i[e+1075752>>2],i[e+1075688>>2])}p:{q:{switch((((i[a+480180>>2]&67633152?d+2|0:d)>>>0)%3|0)+ -1|0){case 0:e=(j[(o(b,896)+a|0)+1075812|0]>>>4|0)+e|0;break p;case 1:break q;default:break p}}e=(j[(o(b,896)+a|0)+1075812|0]&15)+e|0}if(!(i[a+480180>>2]&67633408|j[(o(b,896)+a|0)+1075803|0]!=(e&255))){kb(n+8|0,m,82);if(!ib(n+8|0)){break g}}f=c;q=a;if(j[a+480210|0]&32){p=e&255;if((p|0)==85){i[c>>2]=2147483647;break g}e=p>>>0>85?e+ -37|0:e}d=o(b,896)+a|0;u=f,v=Vf(q,e&255,i[d+1075752>>2],i[d+1075688>>2]),i[u>>2]=v;if(i[a+480180>>2]&71827712){i[d+1075684>>2]=i[c>>2];break g}kb(n+8|0,m,82);if(!ib(n+8|0)){break g}g[(o(b,896)+a|0)+1075806|0]=e}Xa=n+16|0}function ED(a,b,c,d,e){var f=0,h=0,k=0,m=0,n=0,p=0,q=0,r=0,s=0;q=Xa-16|0;Xa=q;a:{b:{c:{d:{e:{f:{if(b>>>0<=36){while(1){f=i[a+4>>2];g:{if(f>>>0<l[a+104>>2]){i[a+4>>2]=f+1;f=j[f|0];break g}f=Hc(a)}if(Yl(f)){continue}break}h:{i:{switch(f+ -43|0){case 0:case 2:break i;default:break h}}r=(f|0)==45?-1:0;f=i[a+4>>2];if(f>>>0<l[a+104>>2]){i[a+4>>2]=f+1;f=j[f|0];break h}f=Hc(a)}j:{if(!(b&-17|(f|0)!=48)){f=i[a+4>>2];k:{if(f>>>0<l[a+104>>2]){i[a+4>>2]=f+1;f=j[f|0];break k}f=Hc(a)}if((f&-33)==88){b=16;f=i[a+4>>2];l:{if(f>>>0<l[a+104>>2]){i[a+4>>2]=f+1;f=j[f|0];break l}f=Hc(a)}if(j[f+57393|0]<16){break e}if(!i[a+104>>2]){d=0;e=0;if(c){break a}break b}b=i[a+4>>2];i[a+4>>2]=b+ -1;if(!c){break b}i[a+4>>2]=b+ -2;d=0;e=0;break a}if(b){break j}b=8;break e}b=b?b:10;if(b>>>0>j[f+57393|0]){break j}if(i[a+104>>2]){i[a+4>>2]=i[a+4>>2]+ -1}d=0;e=0;Gg(a,0,0);i[114584]=28;break a}if((b|0)!=10){break e}c=f+ -48|0;if(c>>>0<=9){b=0;while(1){b=o(b,10)+c|0;c=i[a+4>>2];m:{if(c>>>0<l[a+104>>2]){i[a+4>>2]=c+1;f=j[c|0];break m}f=Hc(a)}c=f+ -48|0;if(b>>>0<429496729?c>>>0<=9:0){continue}break}h=b}if(c>>>0>9){break f}m=XMa(h,0,10,0);n=_a;b=c;while(1){c=i[a+4>>2];n:{if(c>>>0<l[a+104>>2]){i[a+4>>2]=c+1;f=j[c|0];break n}f=Hc(a)}c=f+ -48|0;p=c>>>0>9;k=n;h=b+m|0;if(h>>>0<b>>>0){k=k+1|0}if((k|0)==429496729&h>>>0>=2576980378|k>>>0>429496729|p){break f}m=XMa(h,k,10,0);n=_a;b=c;if((n|0)==-1&m>>>0<=(c^-1)>>>0|(n|0)!=-1){continue}break}b=10;break d}i[114584]=28;d=0;e=0;break a}b=10;if(c>>>0<=9){break d}break c}if(b+ -1&b){c=j[f+57393|0];if(b>>>0>c>>>0){while(1){n=o(b,n)+c|0;m=n>>>0<=119304646;h=b;f=i[a+4>>2];o:{if(f>>>0<l[a+104>>2]){i[a+4>>2]=f+1;f=j[f|0];break o}f=Hc(a)}c=j[f+57393|0];if(h>>>0>c>>>0?m:0){continue}break}h=n}if(b>>>0<=c>>>0){break d}n=b;while(1){p=XMa(h,k,n,0);m=_a;c=c&255;if((m|0)==-1&p>>>0>(c^-1)>>>0){break d}k=m;f=c+p|0;if(f>>>0<c>>>0){k=k+1|0}h=f;m=b;f=i[a+4>>2];p:{if(f>>>0<l[a+104>>2]){i[a+4>>2]=f+1;f=j[f|0];break p}f=Hc(a)}c=j[f+57393|0];if(m>>>0<=c>>>0){break d}ch(q,n,0,h,k);if(!(i[q+8>>2]|i[q+12>>2])){continue}break}break d}m=g[(o(b,23)>>>5&7)+57649|0];c=j[f+57393|0];if(b>>>0>c>>>0){while(1){n=n<<m|c;p=n>>>0<=134217727;h=b;f=i[a+4>>2];q:{if(f>>>0<l[a+104>>2]){i[a+4>>2]=f+1;f=j[f|0];break q}f=Hc(a)}c=j[f+57393|0];if(h>>>0>c>>>0?p:0){continue}break}h=n}n=m;p=n&31;if(32<=(n&63)>>>0){m=0;p=-1>>>p|0}else{m=-1>>>p|0;p=(1<<p)-1<<32-p|-1>>>p}if(!m&p>>>0<h>>>0|m>>>0<0|b>>>0<=c>>>0){break d}while(1){s=c&255;c=n;f=c&31;if(32<=(c&63)>>>0){k=h<<f;c=0}else{k=(1<<f)-1&h>>>32-f|k<<f;c=h<<f}h=s|c;c=i[a+4>>2];r:{if(c>>>0<l[a+104>>2]){i[a+4>>2]=c+1;f=j[c|0];break r}f=Hc(a)}if((k|0)==(m|0)&h>>>0>p>>>0|k>>>0>m>>>0){break d}c=j[f+57393|0];if(b>>>0>c>>>0){continue}break}}if(b>>>0<=j[f+57393|0]){break c}while(1){c=b;f=i[a+4>>2];s:{if(f>>>0<l[a+104>>2]){i[a+4>>2]=f+1;f=j[f|0];break s}f=Hc(a)}if(c>>>0>j[f+57393|0]){continue}break}i[114584]=68;r=d&1?0:r;h=d;k=e}if(i[a+104>>2]){i[a+4>>2]=i[a+4>>2]+ -1}t:{if((e|0)==(k|0)&h>>>0<d>>>0|k>>>0<e>>>0){break t}if(!(d&1|r)){i[114584]=68;e=e+ -1|0;a=d+ -1|0;if((a|0)!=-1){e=e+1|0}d=a;break a}if((e|0)==(k|0)&h>>>0<=d>>>0|k>>>0<e>>>0){break t}i[114584]=68;break a}a=r;b=a^h;d=b-a|0;c=a>>31;e=(c^k)-(c+(b>>>0<a>>>0)|0)|0;break a}d=0;e=0;Gg(a,0,0)}Xa=q+16|0;_a=e;return d}function Cb(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0;a:{if(!a){break a}d=a+ -8|0;b=i[a+ -4>>2];a=b&-8;f=d+a|0;b:{if(b&1){break b}if(!(b&3)){break a}b=i[d>>2];d=d-b|0;if(d>>>0<l[115924]){break a}a=a+b|0;if(i[115925]!=(d|0)){if(b>>>0<=255){e=i[d+8>>2];b=b>>>3|0;c=i[d+12>>2];if((c|0)==(e|0)){j=463680,k=i[115920]&aNa(-2,b),i[j>>2]=k;break b}i[e+12>>2]=c;i[c+8>>2]=e;break b}h=i[d+24>>2];b=i[d+12>>2];c:{if((d|0)!=(b|0)){c=i[d+8>>2];i[c+12>>2]=b;i[b+8>>2]=c;break c}d:{e=d+20|0;c=i[e>>2];if(c){break d}e=d+16|0;c=i[e>>2];if(c){break d}b=0;break c}while(1){g=e;b=c;e=b+20|0;c=i[e>>2];if(c){continue}e=b+16|0;c=i[b+16>>2];if(c){continue}break}i[g>>2]=0}if(!h){break b}e=i[d+28>>2];c=(e<<2)+463984|0;e:{if(i[c>>2]==(d|0)){i[c>>2]=b;if(b){break e}j=463684,k=i[115921]&aNa(-2,e),i[j>>2]=k;break b}i[h+(i[h+16>>2]==(d|0)?16:20)>>2]=b;if(!b){break b}}i[b+24>>2]=h;c=i[d+16>>2];if(c){i[b+16>>2]=c;i[c+24>>2]=b}c=i[d+20>>2];if(!c){break b}i[b+20>>2]=c;i[c+24>>2]=b;break b}b=i[f+4>>2];if((b&3)!=3){break b}i[115922]=a;i[f+4>>2]=b&-2;i[d+4>>2]=a|1;i[a+d>>2]=a;return}if(f>>>0<=d>>>0){break a}b=i[f+4>>2];if(!(b&1)){break a}f:{if(!(b&2)){if(i[115926]==(f|0)){i[115926]=d;a=i[115923]+a|0;i[115923]=a;i[d+4>>2]=a|1;if(i[115925]!=(d|0)){break a}i[115922]=0;i[115925]=0;return}if(i[115925]==(f|0)){i[115925]=d;a=i[115922]+a|0;i[115922]=a;i[d+4>>2]=a|1;i[a+d>>2]=a;return}a=(b&-8)+a|0;g:{if(b>>>0<=255){c=i[f+8>>2];b=b>>>3|0;e=i[f+12>>2];if((c|0)==(e|0)){j=463680,k=i[115920]&aNa(-2,b),i[j>>2]=k;break g}i[c+12>>2]=e;i[e+8>>2]=c;break g}h=i[f+24>>2];b=i[f+12>>2];h:{if((f|0)!=(b|0)){c=i[f+8>>2];i[c+12>>2]=b;i[b+8>>2]=c;break h}i:{e=f+20|0;c=i[e>>2];if(c){break i}e=f+16|0;c=i[e>>2];if(c){break i}b=0;break h}while(1){g=e;b=c;e=b+20|0;c=i[e>>2];if(c){continue}e=b+16|0;c=i[b+16>>2];if(c){continue}break}i[g>>2]=0}if(!h){break g}e=i[f+28>>2];c=(e<<2)+463984|0;j:{if(i[c>>2]==(f|0)){i[c>>2]=b;if(b){break j}j=463684,k=i[115921]&aNa(-2,e),i[j>>2]=k;break g}i[h+(i[h+16>>2]==(f|0)?16:20)>>2]=b;if(!b){break g}}i[b+24>>2]=h;c=i[f+16>>2];if(c){i[b+16>>2]=c;i[c+24>>2]=b}c=i[f+20>>2];if(!c){break g}i[b+20>>2]=c;i[c+24>>2]=b}i[d+4>>2]=a|1;i[a+d>>2]=a;if(i[115925]!=(d|0)){break f}i[115922]=a;return}i[f+4>>2]=b&-2;i[d+4>>2]=a|1;i[a+d>>2]=a}if(a>>>0<=255){a=a>>>3|0;b=(a<<3)+463720|0;c=i[115920];a=1<<a;k:{if(!(c&a)){i[115920]=a|c;a=b;break k}a=i[b+8>>2]}i[b+8>>2]=d;i[a+12>>2]=d;i[d+12>>2]=b;i[d+8>>2]=a;return}e=31;i[d+16>>2]=0;i[d+20>>2]=0;if(a>>>0<=16777215){b=a>>>8|0;g=b+1048320>>>16&8;b=b<<g;e=b+520192>>>16&4;b=b<<e;c=b+245760>>>16&2;b=(b<<c>>>15|0)-(c|(e|g))|0;e=(b<<1|a>>>b+21&1)+28|0}i[d+28>>2]=e;g=(e<<2)+463984|0;l:{m:{c=i[115921];b=1<<e;n:{if(!(c&b)){i[115921]=b|c;i[g>>2]=d;i[d+24>>2]=g;break n}e=a<<((e|0)==31?0:25-(e>>>1|0)|0);b=i[g>>2];while(1){c=b;if((i[b+4>>2]&-8)==(a|0)){break m}b=e>>>29|0;e=e<<1;g=c+(b&4)|0;b=i[g+16>>2];if(b){continue}break}i[g+16>>2]=d;i[d+24>>2]=c}i[d+12>>2]=d;i[d+8>>2]=d;break l}a=i[c+8>>2];i[a+12>>2]=d;i[c+8>>2]=d;i[d+24>>2]=0;i[d+12>>2]=c;i[d+8>>2]=a}a=i[115928]+ -1|0;i[115928]=a;if(a){break a}d=464136;while(1){a=i[d>>2];d=a+8|0;if(a){continue}break}i[115928]=-1}}function CGa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,h=0,k=0;e=Xa-272|0;Xa=e;oGa(e+24|0,b);i[114610]=0;h=I(677,e+128|0,e+24|0,8)|0;b=i[114610];i[114610]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{if((b|0)!=1){eb(e+24|0);if(c>>>0<2189){break g}i[114610]=0;b=C(685,e+24|0,h|0)|0;c=i[114610];i[114610]=0;if((c|0)==1){break c}i[114610]=0;c=C(686,e+8|0,14349)|0;d=i[114610];i[114610]=0;if((d|0)==1){break z}i[114610]=0;i[e>>2]=19465472;i[e+4>>2]=0;G(687,b|0,c|0,e|0);d=i[114610];i[114610]=0;if((d|0)==1){break y}ob(c);i[114610]=0;g[e|0]=0;c=C(686,e+8|0,14357)|0;d=i[114610];i[114610]=0;if((d|0)==1){break i}d=0;i[114610]=0;I(688,b|0,e|0,c|0)|0;f=i[114610];i[114610]=0;if((f|0)==1){break x}ob(c);if(!j[e|0]){i[114610]=0;d=F(689,a|0)|0;c=i[114610];i[114610]=0;if((c|0)==1){break w}}f=i[a+4>>2];i[114610]=0;c=C(686,e+8|0,14368)|0;k=i[114610];i[114610]=0;if((k|0)==1){break v}i[114610]=0;J(690,b|0,f|0,c|0,d|0);f=i[114610];i[114610]=0;if((f|0)==1){break u}ob(c);i[114610]=0;c=C(686,e+8|0,14370)|0;f=i[114610];i[114610]=0;if((f|0)==1){break t}i[114610]=0;J(691,b|0,a|0,c|0,d|0);d=i[114610];i[114610]=0;if((d|0)==1){break s}ob(c);i[114610]=0;c=C(686,e+8|0,14372)|0;d=i[114610];i[114610]=0;if((d|0)==1){break r}i[114610]=0;d=a+484360|0;N(692,b|0,d|0,c|0,693)|0;f=i[114610];i[114610]=0;if((f|0)==1){break q}ob(c);i[114610]=0;c=C(686,e+8|0,14374)|0;f=i[114610];i[114610]=0;if((f|0)==1){break p}i[114610]=0;N(694,b|0,a+484344|0,c|0,695)|0;f=i[114610];i[114610]=0;if((f|0)==1){break o}ob(c);i[114610]=0;f=F(689,a|0)|0;c=i[114610];i[114610]=0;if((c|0)==1){break n}i[114610]=0;c=C(686,e+8|0,14380)|0;k=i[114610];i[114610]=0;if((k|0)==1){break m}i[114610]=0;J(696,b|0,d|0,c|0,f|0);d=i[114610];i[114610]=0;if((d|0)==1){break l}ob(c);if(i[b>>2]&1073741824){i[114610]=0;c=C(2,e+8|0,14388)|0;d=i[114610];i[114610]=0;if((d|0)==1){break k}i[114610]=0;G(650,a|0,1,c|0);a=i[114610];i[114610]=0;if((a|0)==1){break j}eb(c)}Yf(b);break f}a=B()|0;A()|0;eb(e+24|0);break a}a=B()|0;A()|0;break h}a=B()|0;A()|0;ob(c);break h}a=B()|0;A()|0;ob(c);break h}a=B()|0;A()|0;break h}a=B()|0;A()|0;break h}a=B()|0;A()|0;ob(c);break h}a=B()|0;A()|0;break h}a=B()|0;A()|0;ob(c);break h}a=B()|0;A()|0;break h}a=B()|0;A()|0;ob(c);break h}a=B()|0;A()|0;break h}a=B()|0;A()|0;ob(c);break h}a=B()|0;A()|0;break h}a=B()|0;A()|0;break h}a=B()|0;A()|0;ob(c);break h}a=B()|0;A()|0;break h}a=B()|0;A()|0;eb(c);break h}a=B()|0;A()|0}Yf(b);break b}b=Oc(e+24|0);d=i[a+4>>2];i[114610]=0;f=F(689,a|0)|0;k=i[114610];i[114610]=0;if((k|0)==1){break e}i[114610]=0;d=N(697,d|0,h|0,b|0,f|0)|0;f=i[114610];i[114610]=0;if((f|0)==1){break e}A:{if((d|0)!=1){i[114610]=0;c=C(2,e+8|0,14437)|0;d=i[114610];i[114610]=0;B:{if((d|0)!=1){i[114610]=0;G(650,a|0,1,c|0);a=i[114610];i[114610]=0;if((a|0)==1){break B}eb(c);break A}a=B()|0;A()|0;break d}a=B()|0;A()|0;eb(c);break d}i[114610]=0;d=F(689,a|0)|0;f=i[114610];i[114610]=0;if((f|0)==1){break e}i[114610]=0;J(698,h|0,a|0,d|0,c>>>0<2188|0);a=i[114610];i[114610]=0;if((a|0)==1){break e}}eb(b)}Ve(h);Xa=e+272|0;return}a=B()|0;A()|0}eb(b);break b}a=B()|0;A()|0}Ve(h)}E(a|0);x()}function zJa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,l=0,m=0,n=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;e=Xa-720|0;Xa=e;pc(b);f=e+104|0;l=tJa(b,f);if(!l){zR(f)}a:{if(!l){break a}if(!AR(e+104|0)){break a}b:{if(!c){break b}md(a,67108864);Vh(a);d=j[e+129|0];h[a+480190>>1]=31;h[a+480188>>1]=d;i[a+480228>>2]=256/(d>>>0);d=Bb(e,12631);mb(a+1304436|0,d);eb(d);d=Bb(e,12643);mb(a+1304448|0,d);eb(d);f=Bb(e+88|0,12648);i[114610]=0;D(219,e- -64|0,f|0);d=i[114610];i[114610]=0;c:{d:{if((d|0)!=1){i[e+84>>2]=j[e+128|0]>>>4;d=j[e+128|0];i[114610]=0;i[e+80>>2]=d&15;J(534,e|0,e- -64|0,e+84|0,e+80|0);d=i[114610];i[114610]=0;if((d|0)!=1){mb(a+1304460|0,e);eb(e);ob(e- -64|0);eb(f);i[a+1304496>>2]=2;fn(Db(a+484360|0),e+152|0,j[e+151|0]+1|0,65535,65535);f=0;while(1){d=f+1|0;n=o(d,104)+a|0;p=n+484380|0;kd(p,1);l=(e+104|0)+(f<<2)|0;m=j[l+176|0]|j[l+177|0]<<8|(j[l+178|0]<<16|j[l+179|0]<<24);i[p>>2]=m<<24|m<<8&16711680|(m>>>8&65280|m>>>24);m=j[l+300|0]|j[l+301|0]<<8|(j[l+302|0]<<16|j[l+303|0]<<24);q=m<<24|m<<8&16711680|(m>>>8&65280|m>>>24);i[n+484384>>2]=q;m=j[l+424|0]|j[l+425|0]<<8|(j[l+426|0]<<16|j[l+427|0]<<24);i[n+484388>>2]=q+(m<<24|m<<8&16711680|(m>>>8&65280|m>>>24));if(j[l+424|0]|j[l+425|0]<<8|(j[l+426|0]<<16|j[l+427|0]<<24)){l=n+484414|0;h[l>>1]=k[l>>1]|2}Nm(p);f=(e+104|0)+f|0;g[e|0]=j[f+548|0];g[e+64|0]=64;u=n+484410|0,v=j[Xb(e,e- -64|0)|0]<<2,h[u>>1]=v;g[n+484417|0]=j[f+579|0]<<4;f=d;if((d|0)!=31){continue}break}Ez(b,a+1304400|0,32);d=1;while(1){ZS(b,((d<<5)+a|0)+946300|0,30);d=d+1|0;if((d|0)!=32){continue}break}q=c&1;if(q){Gf(a+484344|0,j[e+150|0]+1|0)}p=a+484344|0;d=0;e:{while(1){n=wh(e- -64|0);f:{if(j[e+130|0]){i[114610]=0;f=F(484,b|0)|0;l=i[114610];i[114610]=0;if((l|0)==1){break e}i[114610]=0;G(341,e|0,b|0,f|0);break f}f=k[a+480188>>1];i[114610]=0;G(341,e|0,b|0,f<<8)}f=i[114610];i[114610]=0;if((f|0)==1){break e}l=d;Cd(n,e);hb(e);g:{if(!q){break g}i[114610]=0;d=I(402,p|0,l&65535,64)|0;f=i[114610];i[114610]=0;if((f|0)==1){break e}if(!d){break g}if(!j[e+130|0]){d=0;if(!k[a+480188>>1]){break g}while(1){f=0;while(1){m=Fb(p,l);i[114610]=0;m=I(471,m|0,f|0,d&65535)|0;r=i[114610];i[114610]=0;if((r|0)==1){break e}i[114610]=0;D(535,n|0,m|0);m=i[114610];i[114610]=0;if((m|0)==1){break e}f=f+1|0;if((f|0)!=64){continue}break}d=d+1|0;if((d&65535)>>>0<k[a+480188>>1]){continue}break}break g}m=0;i[114610]=0;C(536,n|0,e|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break e}while(1){d=Fb(p,l);i[114610]=0;r=C(497,d|0,m|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break e}if(k[a+480188>>1]){s=e+m|0;d=128;f=0;while(1){h:{if(!(j[s|0]&d)){break h}i[114610]=0;D(535,n|0,r+o(f,6)|0);t=i[114610];i[114610]=0;if((t|0)!=1){break h}break e}d=d>>>1|0;f=f+1|0;if(f>>>0<k[a+480188>>1]){continue}break}}m=m+1|0;if((m|0)!=64){continue}break}}hb(n);d=l+1|0;if(l>>>0<j[e+150|0]){continue}break}d=1;if(!(c&2)){break a}c=Ic(e,8,1,1,0);while(1){Xf(c,(o(d,104)+a|0)+484380|0,b);d=d+1|0;if((d|0)!=32){continue}break}break b}d=B()|0;A()|0;hb(n);break c}d=B()|0;A()|0;ob(e- -64|0);break d}d=B()|0;A()|0}eb(f)}E(d|0);x()}d=1}Xa=e+720|0;return d|0}function DHa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,l=0,m=0,n=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,G=0;e=Xa-976|0;Xa=e;pc(b);l=e+872|0;f=zHa(b,l);if(!f){OQ(l)}a:{if(!f){break a}if(!RQ(e+872|0)){break a}if(!wb(b,Vc(QQ(e+872|0),_a))){break a}b:{if(!c){break b}md(a,512);i[a+480228>>2]=32;h[a+480188>>1]=16;i[a+480196>>2]=j[e+947|0];i[a+480200>>2]=256;i[a+480204>>2]=8e5;d=Bb(e+96|0,12920);mb(a+1304436|0,d);eb(d);d=Bb(e+96|0,12939);mb(a+1304448|0,d);eb(d);i[a+1304496>>2]=4;PQ(e+24|0,2,e+872|4);oc(e+96|0,e+24|0);mb(a+1304400|0,e+96|0);eb(e+96|0);d=0;while(1){l=(d<<5)+a|0;f=l+480280|0;sg(f);m=f;f=(e+872|0)+d|0;i[m>>2]=!j[f+50|0]<<10;h[l+480284>>1]=(j[f+76|0]<<4|8)&248;d=d+1|0;if((d|0)!=16){continue}break}if(j[e+968|0]|j[e+969|0]<<8){Rx(a+1304424|0,b,j[e+968|0]|j[e+969|0]<<8,132,0)}d=0;if(!BHa(b,e+96|0)){break a}d=a+484360|0;hz(Db(d),e+96|0,j[e+353|0],255,254);Fe(Db(d),j[e+354|0]);vc(b,j[e+919|0]|j[e+920|0]<<8);s=a+484344|0;u=c&1;l=0;c:{d:{while(1){d=(l<<1)+e|0;f=d+355|0;if(j[f|0]|j[f+1|0]<<8){ad(e+24|0,b,j[d+355|0]|j[d+356|0]<<8);d=j[d+355|0]|j[d+356|0]<<8;q=(d+ -2|0)/64|0;e:{if(!u){break e}i[114610]=0;f=I(402,s|0,l&65535,q|0)|0;p=i[114610];i[114610]=0;if((p|0)==1){break d}if(!f){break e}i[114610]=0;p=F(387,e+24|0)|0;f=i[114610];i[114610]=0;if((f|0)==1){break d}i[114610]=0;C(338,e+24|0,1)|0;f=i[114610];i[114610]=0;if((f|0)==1){break d}if(d>>>0>=66){v=q>>>0>1?q:1;m=0;while(1){d=Fb(s,l);i[114610]=0;w=C(497,d|0,m|0)|0;d=i[114610];i[114610]=0;r=0;if((d|0)==1){break d}while(1){i[114610]=0;D(598,e+80|0,e+24|0);d=i[114610];i[114610]=0;f:{g:{if((d|0)!=1){d=o(r,6)+w|0;y=Nc(e+80|0);f=yf(e+80|0);t=li(e+80|0);n=j[e+80|0];if((n+ -1&255)>>>0<72){break g}n=j[d|0];break f}break d}n=n+36|0;g[d|0]=n;g[d+1|0]=j[y|0]+1}if(j[f|0]|n&255){g[d+2|0]=1;z=d,G=(hd(j[f|0],1,16)<<2)+ -4|0,g[z+4|0]=G}f=j[t|0]&15;g[d+5|0]=f;h:{i:{switch((j[t|0]>>>4|0)+ -3|0){case 0:g[d+5|0]=f<<2;break h;case 1:g[d+5|0]=(6/(f+1>>>0)|0)+1;break h;case 3:case 4:g[d+5|0]=f<<3;break h;case 7:g[d+4|0]=(f<<2)+4;g[d+2|0]=1;break h;case 8:g[d+5|0]=f|128;break h;case 9:break i;default:break h}}g[d+5|0]=(6/(f+1>>>0)|0)+1|13}g[d+3|0]=j[(j[t|0]>>>4|0)+12944|0];r=r+1|0;if((r|0)!=16){continue}break}m=m+1|0;if((v|0)!=(m|0)){continue}break}}d=Fb(s,l);i[114610]=0;f=I(498,e+80|0,14,0)|0;m=i[114610];i[114610]=0;if((m|0)==1){break d}f=mi(Ee(f,p?q+ -2>>>0>p>>>0?p+1|0:-1:-1));i[114610]=0;C(499,d|0,f|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break d}}hb(e+24|0)}l=l+1|0;if((l|0)!=256){continue}break}d=1;if(!(c&2)){break a}OR(b,e+72|0);d=0;while(1){j:{k:{if(!(j[e+72+(d>>>3)|0]>>>(d&7)&1)){d=d+1|0;break k}if(!gz(b,e+24|0)){break b}d=d+1|0;h[a+480190>>1]=d;rg(e+8|0,1,e+24|0);oc(e+80|0,e+8|0);c=k[a+480190>>1];i[114610]=0;C(369,((c<<5)+a|0)+946300|0,e+80|0)|0;c=i[114610];i[114610]=0;if((c|0)==1){break j}eb(e+80|0);c=(o(d,104)+a|0)+484380|0;CHa(e+24|0,c);Ic(e+80|0,g[e+70|0]&1?16:8,1,0,0);Xf(e+80|0,c,b)}if((d|0)!=64){continue}break b}break}d=B()|0;A()|0;eb(e+80|0);break c}d=B()|0;A()|0;hb(e+24|0)}E(d|0);x()}d=1}Xa=e+976|0;return d|0}function vba(a){var b=0,c=0,d=0,e=0;b=Xa-96|0;Xa=b;e=Ab(a);i[114610]=0;L(236,b- -64|0);a=i[114610];i[114610]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{if((a|0)!=1){i[114610]=0;i[b+32>>2]=0;D(2118,b+48|0,b+32|0);a=i[114610];i[114610]=0;if((a|0)==1){break k}i[114610]=0;C(1251,e|0,b+48|0)|0;a=i[114610];i[114610]=0;if((a|0)==1){break j}eb(b+48|0);i[114610]=0;C(1995,e|0,38846)|0;a=i[114610];i[114610]=0;l:{if((a|0)==1){break l}i[114610]=0;i[b+32>>2]=5;D(2118,b+48|0,b+32|0);a=i[114610];i[114610]=0;if((a|0)==1){break i}i[114610]=0;C(1251,e|0,b+48|0)|0;a=i[114610];i[114610]=0;if((a|0)==1){break h}eb(b+48|0);i[114610]=0;C(1995,e|0,38846)|0;a=i[114610];i[114610]=0;if((a|0)==1){break l}i[114610]=0;i[b+32>>2]=3;D(2118,b+48|0,b+32|0);a=i[114610];i[114610]=0;if((a|0)==1){break g}i[114610]=0;C(1251,e|0,b+48|0)|0;a=i[114610];i[114610]=0;if((a|0)==1){break f}eb(b+48|0);i[114610]=0;a=C(85,b+48|0,38187)|0;d=i[114610];i[114610]=0;if((d|0)==1){break e}d=lb(a);eb(a);if(!d){break d}i[114610]=0;C(1995,e|0,38187)|0;a=i[114610];i[114610]=0;if((a|0)!=1){break d}}a=B()|0;A()|0;break c}a=B()|0;A()|0;break b}a=B()|0;A()|0;break c}a=B()|0;A()|0;eb(b+48|0);break c}a=B()|0;A()|0;break c}a=B()|0;A()|0;eb(b+48|0);break c}a=B()|0;A()|0;break c}a=B()|0;A()|0;eb(b+48|0);break c}a=B()|0;A()|0;break c}d=Mg(b+48|0);m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{if(i[(b- -64|0)+12>>2]){a=i[(b- -64|0)+12>>2];i[114610]=0;i[b+12>>2]=a;D(2118,b+16|0,b+12|0);a=i[114610];i[114610]=0;if((a|0)==1){break y}i[114610]=0;G(2119,b+32|0,39430,b+16|0);a=i[114610];i[114610]=0;if((a|0)==1){break x}i[114610]=0;D(1534,d|0,b+32|0);a=i[114610];i[114610]=0;if((a|0)==1){break w}eb(b+32|0);eb(b+16|0)}if(!j[(b- -64|0)+16|0]){break s}i[114610]=0;c=C(85,b+32|0,39432)|0;a=i[114610];i[114610]=0;if((a|0)==1){break u}i[114610]=0;D(1534,d|0,c|0);a=i[114610];i[114610]=0;if((a|0)==1){break t}eb(c);break r}a=B()|0;A()|0;break m}a=B()|0;A()|0;break v}a=B()|0;A()|0;eb(b+32|0)}eb(b+16|0);break m}a=B()|0;A()|0;break m}a=B()|0;A()|0;eb(c);break m}if(!j[(b- -64|0)+17|0]){break r}i[114610]=0;c=C(85,b+32|0,39441)|0;a=i[114610];i[114610]=0;if((a|0)==1){break q}i[114610]=0;D(1534,d|0,c|0);a=i[114610];i[114610]=0;if((a|0)==1){break p}eb(c)}if(j[(b- -64|0)+18|0]){break o}break n}a=B()|0;A()|0;break m}a=B()|0;A()|0;eb(c);break m}i[114610]=0;c=C(85,b+32|0,39447)|0;a=i[114610];i[114610]=0;z:{if((a|0)!=1){i[114610]=0;D(1534,d|0,c|0);a=i[114610];i[114610]=0;if((a|0)==1){break z}eb(c);break n}a=B()|0;A()|0;break m}a=B()|0;A()|0;eb(c);break m}if(Uc(d)){break a}i[114610]=0;C(1995,e|0,39451)|0;a=i[114610];i[114610]=0;if((a|0)!=1){i[114610]=0;c=C(85,b+16|0,38846)|0;a=i[114610];i[114610]=0;A:{B:{C:{if((a|0)!=1){i[114610]=0;G(2120,b+32|0,d|0,c|0);a=i[114610];i[114610]=0;if((a|0)==1){break C}i[114610]=0;C(1251,e|0,b+32|0)|0;a=i[114610];i[114610]=0;if((a|0)==1){break B}eb(b+32|0);eb(c);break a}a=B()|0;A()|0;break m}a=B()|0;A()|0;break A}a=B()|0;A()|0;eb(b+32|0)}eb(c);break m}a=B()|0;A()|0}Sc(d)}Ie(b- -64|0)}eb(e);E(a|0);x()}Sc(d);Ie(b- -64|0);Xa=b+96|0}function mx(a,b,c,d){var e=0,f=0,m=0,n=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;m=Xa-16|0;Xa=m;p=o(b,896)+a|0;t=p+1075782|0;n=k[t>>1];s=a+1074308|0;kb(m+8|0,s,23);e=c&15;a:{b:{if(ib(m+8|0)){if(!(i[a+1074392>>2]|!j[(o(b,896)+a|0)+1075794|0])){h[t>>1]=e;break b}f=k[t>>1];if(f){q=f+ -1|0;h[t>>1]=q;f=0;if(q&65535){break b}}h[t>>1]=e;f=1;break b}kb(m+8|0,s,52);q=c&256;if(!(!q|!ib(m+8|0))){c:{if(!(j[a+480209|0]&16)){break c}f=o(b,896)+a|0;if(j[f+1075795|0]){n=EQ(f+1075794|0)?1:n}if(!j[(o(b,896)+a|0)+1075798|0]|j[f+1075796|0]!=1){break c}h[t>>1]=n;break a}f=0;if((e|0)>n<<16>>16){break b}if(j[a+480209|0]&16){if(Jf((o(b,896)+a|0)+1075794|0)){break b}}n=0;f=1;break b}if(i[a+480180>>2]&16777250){f=n&65535?!((n<<16>>16)%((e?e:1)|0)&65535):0;n=n+1|0;break b}if(i[a+480180>>2]==16){f=i[a+1074392>>2]==(e|0)&(e|0)!=0;break b}d:{e:{f:{g:{h:{if(q){f=o(b,896)+a|0;if(j[f+1075796|0]==1){e=(j[f+1075799|0]>15)+e|0}e=e?e:1;break h}if(i[a+480208>>2]&4096?!q:0){break e}e=e?e:1;if(i[a+1074416>>2]){break g}}f=0;break f}f=!(l[a+1074392>>2]%(e>>>0)|0)}n=n+1|0;break d}n=i[a+480180>>2]&1048580?0:n}if(!((e|0)>n<<16>>16|(j[(o(b,896)+a|0)+1075794|0]|!q?!i[a+1074392>>2]:0))){f=1}kb(m+8|0,s,52);if(!ib(m+8|0)|c){break b}f=!i[a+1074392>>2]}q=p+1074984|0;r=(o(b,896)+a|0)+1075060|0;i:{if(i[r>>2]){break i}kb(m+8|0,s,38);if(!ib(m+8|0)){break i}if(!Pi(q)){break a}}kb(m+8|0,s,106);if(A=0,B=ib(m+8|0),C=i[(o(b,896)+a|0)+1075680>>2],C?A:B){break a}if(f){e=o(b,896)+a|0;v=e+1075672|0;i[m+4>>2]=i[v>>2];f=c>>>4&15;j:{if(!f){e=i[e+1075072>>2];break j}kb(m+8|0,s,52);k:{if(A=ib(m+8|0),B=0,C=j[(o(b,896)+a|0)+1075796|0]==1,C?A:B){break k}e=g[f+21856|0];if(e){i[m+4>>2]=o(e,i[m+4>>2])>>4;break k}i[m+4>>2]=i[m+4>>2]+(g[f+21872|0]<<2)}Kd(m+4|0,0,256);f=(o(b,896)+a|0)+1075072|0;e=i[f>>2]|2097152;i[f>>2]=e}u=o(b,896)+a|0;w=u+1075684|0;x=i[w>>2];f=j[u+1075808|0];p=0;if(e&512){kb(m+8|0,s,108);p=ib(m+8|0)}if(!(!i[r>>2]|p^1|(f+ -1&255)>>>0>119)){CK(a,b,0,f,1)}l:{if(!(i[a+480180>>2]&1048580)){e=0;break l}e=(c|0)<256;if((c|0)>255){break l}r=j[(o(b,896)+a|0)+1075795|0];if(!r){break l}e=1;Co(a,q,r,0,0,1)}u=u+1075072|0;m:{if(!p){break m}r=(o(b,896)+a|0)+1075088|0;if(!i[r>>2]){break m}p=a+1304392|0;if(!$c(p)){break m}Zh(i[p>>2],b,1);Fx(i[p>>2],b,i[r>>2]+68|0)}p=o(b,896)+a|0;r=p+1075644|0;y=i[r>>2];z=i[u>>2];i[r>>2]=0;kb(m+8|0,s,23);Rr(a,q,f,ib(m+8|0),e,0,b);if(!j[p+1075795|0]){i[r>>2]=y}if(!(!(z&4096)|i[a+480180>>2]!=4)){i[u>>2]=i[u>>2]|4096}e=p+1075794|0;i[v>>2]=i[m+4>>2];if(k[a+480192>>1]){g[e|0]=f;gJ(a,b)}if(!(j[e|0]|(!(i[a+480180>>2]&16777248)|!x))){i[w>>2]=x}f=i[a+480180>>2];kb(m+8|0,s,23);if(ib(m+8|0)){i[q>>2]=0;i[q+4>>2]=0}f=f&16777250;n:{if(d+ -1>>>0>9){break n}e=i[(o(b,896)+a|0)+1075088>>2];if(!e){break n}o:{if((d|0)==1){b=i[(o(b,896)+a|0)+1075648>>2];break o}p=(o(b,896)+a|0)+1075648|0;b=i[(e+(d<<2)|0)+60>>2];i[p>>2]=b}Bo(a,q,b)}n=f?n:0}kb(m+8|0,s,52);a=ib(m+8|0);kb(m+8|0,s,23);if(ib(m+8|0)){break a}h[t>>1]=(a&c>>>8)+n}Xa=m+16|0}function S5(a,b,c,d){var e=0,f=0,g=0,i=0,j=p(0),k=p(0),l=p(0),n=p(0),q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;i=Xa-32|0;Xa=i;m[d+4080>>2]=m[a+1152>>2];u=c+ -1|0;v=o(u,2304)+a|0;m[d+4084>>2]=m[v+1152>>2];m[d+4088>>2]=m[a>>2];m[d+4092>>2]=m[v>>2];m[d+4336>>2]=m[a+1156>>2];m[d+4340>>2]=m[v+1156>>2];m[d+4344>>2]=m[a+4>>2];m[d+4348>>2]=m[v+4>>2];w=(u<<1)+b|0;Tq(w,c,d+244|0);u=c<<6;Tq(u+w|0,c,d+500|0);Tq(b,c,d+240|0);Tq(b+u|0,c,d+496|0);s=49088;x=d+3840|0;f=14;while(1){q=f<<4;g=q+x|0;u=f;e=o(31-f|0,72);j=m[e+a>>2];m[g>>2]=j;m[(q|4)+x>>2]=m[e+v>>2];e=e|4;m[(q|8)+x>>2]=m[e+a>>2];m[(q|12)+x>>2]=m[e+v>>2];r=o(f,72);e=r+76|0;m[g+256>>2]=m[e+a>>2];m[g+260>>2]=m[e+v>>2];e=r+72|0;m[g+ -248>>2]=m[e+a>>2];m[g+ -244>>2]=m[e+v>>2];l=m[s>>2];r=d+q|0;k=m[r>>2];n=m[s+4>>2];m[i+16>>2]=p(j*l)-p(k*n);m[i>>2]=p(k*l)+p(j*n);e=f<<2;f=1;while(1){q=f<<2;j=m[q+g>>2];k=m[q+r>>2];m[q+(i+16|0)>>2]=p(j*l)-p(k*n);m[i+q>>2]=p(k*l)+p(j*n);f=f+1|0;if((f|0)!=4){continue}break}t=(e<<2)+x|0;q=t+ -3584|0;r=t+ -256|0;l=m[s+12>>2];n=m[s+8>>2];f=0;while(1){g=f<<2;e=g+i|0;j=m[g+q>>2];k=m[g+r>>2];m[e>>2]=p(p(j*n)+p(k*l))+m[e>>2];e=g+(i+16|0)|0;m[e>>2]=p(p(j*l)-p(k*n))+m[e>>2];f=f+1|0;if((f|0)!=4){continue}break}q=t+ -3328|0;r=t+ -512|0;l=m[s+20>>2];n=m[s+16>>2];f=0;while(1){g=f<<2;e=g+i|0;j=m[g+q>>2];k=m[g+r>>2];m[e>>2]=p(p(j*n)+p(k*l))+m[e>>2];e=g+(i+16|0)|0;m[e>>2]=p(p(k*n)-p(j*l))+m[e>>2];f=f+1|0;if((f|0)!=4){continue}break}q=t+ -3072|0;r=t+ -768|0;l=m[s+28>>2];n=m[s+24>>2];f=0;while(1){g=f<<2;e=g+i|0;j=m[g+q>>2];k=m[g+r>>2];m[e>>2]=p(p(j*n)+p(k*l))+m[e>>2];e=g+(i+16|0)|0;m[e>>2]=p(p(j*l)-p(k*n))+m[e>>2];f=f+1|0;if((f|0)!=4){continue}break}q=t+ -2816|0;r=t+ -1024|0;l=m[s+36>>2];n=m[s+32>>2];f=0;while(1){g=f<<2;e=g+i|0;j=m[g+q>>2];k=m[g+r>>2];m[e>>2]=p(p(j*n)+p(k*l))+m[e>>2];e=g+(i+16|0)|0;m[e>>2]=p(p(k*n)-p(j*l))+m[e>>2];f=f+1|0;if((f|0)!=4){continue}break}q=t+ -2560|0;r=t+ -1280|0;l=m[s+44>>2];n=m[s+40>>2];f=0;while(1){g=f<<2;e=g+i|0;j=m[g+q>>2];k=m[g+r>>2];m[e>>2]=p(p(j*n)+p(k*l))+m[e>>2];e=g+(i+16|0)|0;m[e>>2]=p(p(j*l)-p(k*n))+m[e>>2];f=f+1|0;if((f|0)!=4){continue}break}q=t+ -2304|0;r=t+ -1536|0;l=m[s+52>>2];n=m[s+48>>2];f=0;while(1){g=f<<2;e=g+i|0;j=m[g+q>>2];k=m[g+r>>2];m[e>>2]=p(p(j*n)+p(k*l))+m[e>>2];e=g+(i+16|0)|0;m[e>>2]=p(p(k*n)-p(j*l))+m[e>>2];f=f+1|0;if((f|0)!=4){continue}break}q=t+ -2048|0;r=t+ -1792|0;l=m[s+60>>2];n=m[s+56>>2];f=0;while(1){g=f<<2;e=g+i|0;j=m[g+q>>2];k=m[g+r>>2];m[e>>2]=p(p(j*n)+p(k*l))+m[e>>2];e=g+(i+16|0)|0;m[e>>2]=p(p(j*l)-p(k*n))+m[e>>2];f=f+1|0;if((f|0)!=4){continue}break}e=o(15-u|0,c)<<1;y=e+w|0,z=Lh(m[i+20>>2]),h[y>>1]=z;f=o(u+17|0,c)<<1;y=f+w|0,z=Lh(m[i+4>>2]),h[y>>1]=z;y=b+e|0,z=Lh(m[i+16>>2]),h[y>>1]=z;y=b+f|0,z=Lh(m[i>>2]),h[y>>1]=z;e=o(47-u|0,c)<<1;y=e+w|0,z=Lh(m[i+28>>2]),h[y>>1]=z;f=o(u+49|0,c)<<1;y=f+w|0,z=Lh(m[i+12>>2]),h[y>>1]=z;y=b+e|0,z=Lh(m[i+24>>2]),h[y>>1]=z;y=b+f|0,z=Lh(m[i+8>>2]),h[y>>1]=z;f=u+ -1|0;s=s- -64|0;if(u){continue}break}Xa=i+32|0}function cq(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0;f=a+b|0;a:{b:{c=i[a+4>>2];if(c&1){break b}if(!(c&3)){break a}c=i[a>>2];b=c+b|0;a=a-c|0;if((a|0)!=i[115925]){if(c>>>0<=255){e=c>>>3|0;c=i[a+8>>2];d=i[a+12>>2];if((d|0)==(c|0)){j=463680,k=i[115920]&aNa(-2,e),i[j>>2]=k;break b}i[c+12>>2]=d;i[d+8>>2]=c;break b}h=i[a+24>>2];c=i[a+12>>2];c:{if((c|0)!=(a|0)){d=i[a+8>>2];i[d+12>>2]=c;i[c+8>>2]=d;break c}d:{d=a+20|0;e=i[d>>2];if(e){break d}d=a+16|0;e=i[d>>2];if(e){break d}c=0;break c}while(1){g=d;c=e;d=c+20|0;e=i[d>>2];if(e){continue}d=c+16|0;e=i[c+16>>2];if(e){continue}break}i[g>>2]=0}if(!h){break b}d=i[a+28>>2];e=(d<<2)+463984|0;e:{if(i[e>>2]==(a|0)){i[e>>2]=c;if(c){break e}j=463684,k=i[115921]&aNa(-2,d),i[j>>2]=k;break b}i[h+(i[h+16>>2]==(a|0)?16:20)>>2]=c;if(!c){break b}}i[c+24>>2]=h;d=i[a+16>>2];if(d){i[c+16>>2]=d;i[d+24>>2]=c}d=i[a+20>>2];if(!d){break b}i[c+20>>2]=d;i[d+24>>2]=c;break b}c=i[f+4>>2];if((c&3)!=3){break b}i[115922]=b;i[f+4>>2]=c&-2;i[a+4>>2]=b|1;i[f>>2]=b;return}c=i[f+4>>2];f:{if(!(c&2)){if(i[115926]==(f|0)){i[115926]=a;b=i[115923]+b|0;i[115923]=b;i[a+4>>2]=b|1;if(i[115925]!=(a|0)){break a}i[115922]=0;i[115925]=0;return}if(i[115925]==(f|0)){i[115925]=a;b=i[115922]+b|0;i[115922]=b;i[a+4>>2]=b|1;i[a+b>>2]=b;return}b=(c&-8)+b|0;g:{if(c>>>0<=255){e=c>>>3|0;c=i[f+8>>2];d=i[f+12>>2];if((d|0)==(c|0)){j=463680,k=i[115920]&aNa(-2,e),i[j>>2]=k;break g}i[c+12>>2]=d;i[d+8>>2]=c;break g}h=i[f+24>>2];c=i[f+12>>2];h:{if((f|0)!=(c|0)){d=i[f+8>>2];i[d+12>>2]=c;i[c+8>>2]=d;break h}i:{d=f+20|0;e=i[d>>2];if(e){break i}d=f+16|0;e=i[d>>2];if(e){break i}c=0;break h}while(1){g=d;c=e;d=c+20|0;e=i[d>>2];if(e){continue}d=c+16|0;e=i[c+16>>2];if(e){continue}break}i[g>>2]=0}if(!h){break g}d=i[f+28>>2];e=(d<<2)+463984|0;j:{if(i[e>>2]==(f|0)){i[e>>2]=c;if(c){break j}j=463684,k=i[115921]&aNa(-2,d),i[j>>2]=k;break g}i[h+(i[h+16>>2]==(f|0)?16:20)>>2]=c;if(!c){break g}}i[c+24>>2]=h;d=i[f+16>>2];if(d){i[c+16>>2]=d;i[d+24>>2]=c}d=i[f+20>>2];if(!d){break g}i[c+20>>2]=d;i[d+24>>2]=c}i[a+4>>2]=b|1;i[a+b>>2]=b;if(i[115925]!=(a|0)){break f}i[115922]=b;return}i[f+4>>2]=c&-2;i[a+4>>2]=b|1;i[a+b>>2]=b}if(b>>>0<=255){c=b>>>3|0;b=(c<<3)+463720|0;d=i[115920];c=1<<c;k:{if(!(d&c)){i[115920]=c|d;c=b;break k}c=i[b+8>>2]}i[b+8>>2]=a;i[c+12>>2]=a;i[a+12>>2]=b;i[a+8>>2]=c;return}d=31;i[a+16>>2]=0;i[a+20>>2]=0;if(b>>>0<=16777215){d=b>>>8|0;c=d+1048320>>>16&8;e=d<<c;d=e+520192>>>16&4;g=e<<d;e=g+245760>>>16&2;c=(g<<e>>>15|0)-(e|(c|d))|0;d=(c<<1|b>>>c+21&1)+28|0}i[a+28>>2]=d;c=(d<<2)+463984|0;l:{e=i[115921];g=1<<d;m:{if(!(e&g)){i[115921]=e|g;i[c>>2]=a;i[a+24>>2]=c;break m}d=b<<((d|0)==31?0:25-(d>>>1|0)|0);c=i[c>>2];while(1){e=c;if((i[c+4>>2]&-8)==(b|0)){break l}c=d>>>29|0;d=d<<1;g=e+(c&4)|0;c=i[g+16>>2];if(c){continue}break}i[g+16>>2]=a;i[a+24>>2]=e}i[a+12>>2]=a;i[a+8>>2]=a;return}b=i[e+8>>2];i[b+12>>2]=a;i[e+8>>2]=a;i[a+24>>2]=0;i[a+12>>2]=e;i[a+8>>2]=b}}function wB(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;a=Xa-144|0;Xa=a;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{if(i[19092]>=(c|0)){_t(a+96|0,c);i[114610]=0;c=C(2,a+80|0,1024)|0;d=i[114610];i[114610]=0;if((d|0)==1){break E}i[114610]=0;G(3,a+112|0,a+96|0,c|0);d=i[114610];i[114610]=0;if((d|0)==1){break D}i[114610]=0;d=C(4,a+48|0,e|0)|0;e=i[114610];i[114610]=0;if((e|0)==1){break C}i[114610]=0;e=C(2,a+32|0,1027)|0;f=i[114610];i[114610]=0;if((f|0)==1){break B}i[114610]=0;G(5,a- -64|0,d|0,e|0);f=i[114610];i[114610]=0;if((f|0)==1){break A}i[114610]=0;G(3,a+128|0,a+112|0,a- -64|0);f=i[114610];i[114610]=0;if((f|0)==1){break z}eb(a- -64|0);eb(e);eb(d);eb(a+112|0);eb(c);eb(a+96|0);if(i[b>>2]){c=i[b>>2]}else{c=1030}i[114610]=0;D(6,a+112|0,c|0);c=i[114610];i[114610]=0;if((c|0)==1){break t}if(i[b+4>>2]){c=i[b+4>>2]}else{c=1030}i[114610]=0;D(6,a+96|0,c|0);c=i[114610];i[114610]=0;if((c|0)==1){break s}b=i[b+8>>2];i[114610]=0;i[a+64>>2]=b;D(7,a+80|0,a- -64|0);b=i[114610];i[114610]=0;if((b|0)==1){break r}i[114610]=0;b=C(8,461048,1031)|0;c=i[114610];i[114610]=0;if((c|0)==1){break q}i[114610]=0;G(9,a- -64|0,0,a+112|0);c=i[114610];i[114610]=0;if((c|0)==1){break p}i[114610]=0;b=C(10,b|0,a- -64|0)|0;c=i[114610];i[114610]=0;if((c|0)==1){break o}i[114610]=0;b=C(8,b|0,1044)|0;c=i[114610];i[114610]=0;if((c|0)==1){break o}i[114610]=0;G(9,a+32|0,0,a+80|0);c=i[114610];i[114610]=0;if((c|0)==1){break n}i[114610]=0;b=C(10,b|0,a+32|0)|0;c=i[114610];i[114610]=0;if((c|0)==1){break m}i[114610]=0;b=C(8,b|0,1046)|0;c=i[114610];i[114610]=0;if((c|0)==1){break m}i[114610]=0;b=C(8,b|0,1024)|0;c=i[114610];i[114610]=0;if((c|0)==1){break m}i[114610]=0;G(9,a+16|0,0,a+128|0);c=i[114610];i[114610]=0;if((c|0)==1){break l}i[114610]=0;b=C(10,b|0,a+16|0)|0;c=i[114610];i[114610]=0;if((c|0)==1){break k}i[114610]=0;b=C(8,b|0,1048)|0;c=i[114610];i[114610]=0;if((c|0)==1){break k}i[114610]=0;G(9,a|0,0,a+96|0);c=i[114610];i[114610]=0;if((c|0)==1){break j}i[114610]=0;b=C(10,b|0,a|0)|0;c=i[114610];i[114610]=0;if((c|0)==1){break i}i[114610]=0;b=C(8,b|0,1051)|0;c=i[114610];i[114610]=0;if((c|0)==1){break i}i[114610]=0;C(11,b|0,12)|0;b=i[114610];i[114610]=0;if((b|0)==1){break i}eb(a);eb(a+16|0);eb(a+32|0);eb(a- -64|0);eb(a+80|0);eb(a+96|0);eb(a+112|0);eb(a+128|0)}Xa=a+144|0;return}b=B()|0;A()|0;break u}b=B()|0;A()|0;break v}b=B()|0;A()|0;break w}b=B()|0;A()|0;break x}b=B()|0;A()|0;break y}b=B()|0;A()|0;eb(a- -64|0)}eb(e)}eb(d)}eb(a+112|0)}eb(c)}eb(a+96|0);break a}b=B()|0;A()|0;break b}b=B()|0;A()|0;break c}b=B()|0;A()|0;break d}b=B()|0;A()|0;break e}b=B()|0;A()|0;break e}b=B()|0;A()|0;break f}b=B()|0;A()|0;break f}b=B()|0;A()|0;break g}b=B()|0;A()|0;break g}b=B()|0;A()|0;break h}b=B()|0;A()|0;break h}b=B()|0;A()|0;eb(a)}eb(a+16|0)}eb(a+32|0)}eb(a- -64|0)}eb(a+80|0)}eb(a+96|0)}eb(a+112|0)}eb(a+128|0)}E(b|0);x()}function nQ(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,j=0,l=0,m=0,n=0,o=0,p=0;e=Xa-144|0;Xa=e;m=gGa(e+128|0);a:{b:{c:{if(d){i[114610]=0;G(713,a|0,m|0,c|0);c=i[114610];i[114610]=0;if((c|0)!=1){break c}break b}i[114610]=0;G(714,a|0,m|0,c|0);c=i[114610];i[114610]=0;if((c|0)==1){break b}}d=uv(e+112|0);d:{e:{if(k[b+480192>>1]){c=1;n=1;while(1){i[114610]=0;h[e+110>>1]=0;C(715,a|0,e+110|0)|0;l=i[114610];i[114610]=0;f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{if((l|0)!=1){i[114610]=0;l=C(716,m|0,e+110|0)|0;f=i[114610];i[114610]=0;if((f|0)==1){break e}i[e+104>>2]=l;l=((c<<2)+b|0)+900380|0;if(!i[l>>2]){break f}c=fi(m);i[114610]=0;i[e+88>>2]=c;c=C(717,e+104|0,e+88|0)|0;f=i[114610];i[114610]=0;if((f|0)==1){break u}if(!c){break g}i[114610]=0;c=F(718,e+104|0)|0;f=i[114610];i[114610]=0;if((f|0)==1){break t}i[114610]=0;c=C(4,e+88|0,c+4|0)|0;f=i[114610];i[114610]=0;if((f|0)==1){break t}i[114610]=0;f=C(2,e+72|0,14549)|0;g=i[114610];i[114610]=0;if((g|0)==1){break i}g=ep(c,f);eb(f);if(!g){break s}i[i[l>>2]+44>>2]=0;break r}b=B()|0;A()|0;break d}b=B()|0;A()|0;break d}b=B()|0;A()|0;break d}f=i[b+4>>2];i[114610]=0;f=C(719,f|0,c|0)|0;g=i[114610];i[114610]=0;v:{w:{x:{y:{z:{A:{if((g|0)!=1){i[i[l>>2]+44>>2]=f;if(i[i[l>>2]+44>>2]){break r}i[114610]=0;f=C(2,e+72|0,14569)|0;g=i[114610];i[114610]=0;if((g|0)==1){break A}B:{C:{if(ep(c,f)){eb(f);break C}i[114610]=0;g=C(2,e+56|0,14595)|0;j=i[114610];i[114610]=0;if((j|0)==1){break z}j=ep(c,g);eb(g);eb(f);if(!j){break B}}i[114610]=0;D(720,e+72|0,c|0);f=i[114610];i[114610]=0;if((f|0)==1){break y}g=i[b+4>>2];f=dp(e+48|0,e+72|0);i[114610]=0;g=C(721,g|0,f|0)|0;j=i[114610];i[114610]=0;if((j|0)==1){break x}Hf(f);Hf(e+72|0);if(g){break r}}o=e,p=cGa(Jb(d),Kb(d),c),i[o+72>>2]=p;o=e,p=Kb(d),i[o+56>>2]=p;if(!al(e+72|0,e+56|0)){break v}i[114610]=0;D(722,d|0,c|0);f=i[114610];i[114610]=0;if((f|0)!=1){break w}}b=B()|0;A()|0;break h}b=B()|0;A()|0;break h}b=B()|0;A()|0;eb(f);break h}b=B()|0;A()|0;break h}b=B()|0;A()|0;Hf(f);Hf(e+72|0);break h}i[114610]=0;f=C(2,e+16|0,14601)|0;g=i[114610];i[114610]=0;if((g|0)==1){break q}i[114610]=0;G(723,e+32|0,f|0,c|0);g=i[114610];i[114610]=0;if((g|0)==1){break p}i[114610]=0;g=C(2,e|0,14610)|0;j=i[114610];i[114610]=0;if((j|0)==1){break o}i[114610]=0;G(3,e+56|0,e+32|0,g|0);j=i[114610];i[114610]=0;if((j|0)==1){break n}j=ny(e+72|0,e+56|0);i[114610]=0;D(627,b|0,j|0);j=i[114610];i[114610]=0;if((j|0)==1){break m}eb(e+72|0);eb(e+56|0);eb(g);eb(e+32|0);eb(f)}i[i[l>>2]+44>>2]=0}eb(c);break f}b=B()|0;A()|0;break h}b=B()|0;A()|0;break j}b=B()|0;A()|0;break k}b=B()|0;A()|0;break l}b=B()|0;A()|0;eb(e+72|0);eb(e+56|0)}eb(g)}eb(e+32|0)}eb(f);break h}b=B()|0;A()|0}eb(c);break d}if(!i[l>>2]){break f}i[i[l>>2]+44>>2]=0}n=n+1|0;c=n&65535;if(c>>>0<=k[b+480192>>1]){continue}break}}Ok(d);hQ(m);Xa=e+144|0;return}b=B()|0;A()|0}Ok(d);break a}b=B()|0;A()|0}hQ(m);E(b|0);x()}function hja(a,b,c){var d=0,e=0,f=0,g=0,l=0,m=0;d=Xa-80|0;Xa=d;g=h[b+28>>1];e=h[c>>1];f=b+4|0;qb(f);a:{b:{if((g|0)<=(e|0)){if((k[b+28>>1]+qb(f)<<16)+ -65536>>16>=(e|0)){break b}}Oc(a);break a}c:{e=h[b+30>>1];if(!e){b=b+52|0;l=d,m=tw(b,c),i[l+56>>2]=m;l=d,m=fi(b),i[l+40>>2]=m;if(!ei(d+56|0,d+40|0)){break c}Kf(a,Qg(d+56|0)+4|0);break a}f=d;g=h[c>>1];d:{if((g|0)>=0){g=(g|0)%(e|0)|0;break d}g=e+((g^-1)%(e|0)^-1)|0}h[f+78>>1]=g;e=Oc(a);i[114610]=0;g=b+52|0;f=C(1599,g|0,d+78|0)|0;a=i[114610];i[114610]=0;e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{if((a|0)==1){break u}i[d+72>>2]=f;a=fi(g);i[114610]=0;i[d+56>>2]=a;f=C(1600,d+72|0,d+56|0)|0;a=i[114610];i[114610]=0;if((a|0)==1){break f}if(f){i[114610]=0;f=F(1601,d+72|0)|0;a=i[114610];i[114610]=0;if((a|0)==1){break u}i[114610]=0;C(237,e|0,f+4|0)|0;a=i[114610];i[114610]=0;if((a|0)==1){break u}b=h[b+30>>1];a=h[c>>1];v:{if((a|0)>=0){a=(a|0)/(b|0)|0;break v}a=((a+1|0)/(b|0)|0)+ -1|0}i[114610]=0;i[d+40>>2]=a+5;D(234,d+56|0,d+40|0);a=i[114610];i[114610]=0;w:{if((a|0)!=1){i[114610]=0;C(192,e|0,d+56|0)|0;a=i[114610];i[114610]=0;if((a|0)==1){break w}eb(d+56|0);break a}b=B()|0;A()|0;break e}b=B()|0;A()|0;eb(d+56|0);break e}if(h[b+30>>1]>26){break r}i[114610]=0;f=I(803,d+40|0,1,(j[d+78|0]<<24)+1090519040>>24)|0;a=i[114610];i[114610]=0;if((a|0)==1){break t}i[114610]=0;G(13,d+56|0,0,f|0);a=i[114610];i[114610]=0;if((a|0)==1){break s}mb(e,d+56|0);eb(d+56|0);eb(f);i[114610]=0;C(235,e|0,32387)|0;a=i[114610];i[114610]=0;if((a|0)!=1){break q}}b=B()|0;A()|0;break e}b=B()|0;A()|0;break e}b=B()|0;A()|0;eb(f);break e}i[114610]=0;i[d+36>>2]=h[d+78>>1]%16<<16>>16;D(1602,d+40|0,d+36|0);a=i[114610];i[114610]=0;if((a|0)==1){break p}i[114610]=0;i[d+20>>2]=(h[d+78>>1]/16<<16>>16)%16<<16>>16;D(1602,d+24|0,d+20|0);a=i[114610];i[114610]=0;if((a|0)==1){break o}i[114610]=0;G(3,d+56|0,d+40|0,d+24|0);a=i[114610];i[114610]=0;if((a|0)==1){break n}mb(e,d+56|0);eb(d+56|0);eb(d+24|0);eb(d+40|0);if(h[d+78>>1]<256){break q}i[114610]=0;G(9,d+8|0,0,e|0);a=i[114610];i[114610]=0;if((a|0)==1){break l}i[114610]=0;D(1603,d+40|0,d+8|0);a=i[114610];i[114610]=0;if((a|0)==1){break k}i[114610]=0;G(13,d+56|0,0,d+40|0);a=i[114610];i[114610]=0;if((a|0)==1){break j}mb(e,d+56|0);eb(d+56|0);eb(d+40|0);eb(d+8|0)}b=h[b+30>>1];a=h[c>>1];if((a|0)<0){break h}a=(a|0)/(b|0)|0;break g}b=B()|0;A()|0;break e}b=B()|0;A()|0;break m}b=B()|0;A()|0;eb(d+24|0)}eb(d+40|0);break e}b=B()|0;A()|0;break e}b=B()|0;A()|0;break i}b=B()|0;A()|0;eb(d+40|0)}eb(d+8|0);break e}a=((a+1|0)/(b|0)|0)+ -1|0}i[114610]=0;i[d+40>>2]=a+5;D(234,d+56|0,d+40|0);a=i[114610];i[114610]=0;x:{if((a|0)!=1){i[114610]=0;C(192,e|0,d+56|0)|0;a=i[114610];i[114610]=0;if((a|0)==1){break x}eb(d+56|0);break a}b=B()|0;A()|0;break e}b=B()|0;A()|0;eb(d+56|0);break e}b=B()|0;A()|0}eb(e);E(b|0);x()}b=Xa-16|0;Xa=b;Aha(a,c);Xa=b+16|0}Xa=d+80|0}function uG(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;f=Xa-224|0;Xa=f;i[f+216>>2]=c;i[f+220>>2]=d;a:{if(Oi(b)){break a}d=j[Dj(b)|0];c=1;b:{if((d|0)==33){break b}if((d|0)!=63){break a}c=0}e=c;Oj(f+184|0,b,i[b+4>>2]+ -1|0);c=i[f+188>>2];i[b>>2]=i[f+184>>2];i[b+4>>2]=c}jd(f+184|0);c=i[f+184>>2];jd(f+168|0);g=Cj(c,i[f+172>>2],b);jd(f+184|0);c=i[b>>2];d=i[b+4>>2];c:{d:{e:{f:{if((g|0)==i[f+188>>2]){i[f+208>>2]=c;i[f+212>>2]=d;a=Zb(f+200|0,38187);c=i[f+212>>2];i[f+16>>2]=i[f+208>>2];i[f+20>>2]=c;c=i[a+4>>2];i[f+8>>2]=i[a>>2];i[f+12>>2]=c;if(mc(f+16|0,f+8|0)){a=P(8)|0;i[114610]=0;D(2143,f+168|0,f+216|0);b=i[114610];i[114610]=0;g:{h:{i:{if((b|0)!=1){i[114610]=0;G(2119,f+184|0,39252,f+168|0);b=i[114610];i[114610]=0;if((b|0)==1){break i}Ub(a,f+184|0);e=0;i[114610]=0;G(2009,a|0,83568,2017);b=i[114610];i[114610]=0;if((b|0)!=1){break e}b=B()|0;A()|0;eb(f+184|0);break h}b=B()|0;A()|0;break g}b=B()|0;e=1;A()|0}eb(f+168|0);if(!e){break f}}Q(a|0);break f}if(!e){break c}c=P(8)|0;i[114610]=0;d=C(2142,f+136|0,b|0)|0;b=i[114610];i[114610]=0;a=1;j:{k:{l:{m:{n:{o:{p:{q:{r:{if((b|0)!=1){i[114610]=0;G(2119,f+152|0,39131,d|0);a=i[114610];i[114610]=0;if((a|0)==1){break r}i[114610]=0;G(2137,f+168|0,f+152|0,39267);b=i[114610];i[114610]=0;a=1;if((b|0)==1){break q}i[114610]=0;D(2143,f+120|0,f+216|0);a=i[114610];i[114610]=0;if((a|0)==1){break p}i[114610]=0;G(138,f+184|0,f+168|0,f+120|0);b=i[114610];i[114610]=0;a=1;if((b|0)==1){break o}Ub(c,f+184|0);i[114610]=0;G(2009,c|0,83568,2017);a=i[114610];i[114610]=0;if((a|0)!=1){break e}b=B()|0;A()|0;eb(f+184|0);a=0;break n}b=B()|0;A()|0;break j}b=B()|0;a=1;A()|0;break k}b=B()|0;A()|0;break l}b=B()|0;a=1;A()|0;break m}b=B()|0;A()|0}eb(f+120|0)}eb(f+168|0)}eb(f+152|0)}eb(d)}if(!a){break f}Q(c|0);break f}i[f+112>>2]=c;i[f+116>>2]=d;c=Zb(f+104|0,38187);d=i[f+116>>2];i[f+64>>2]=i[f+112>>2];i[f+68>>2]=d;d=i[c+4>>2];i[f+56>>2]=i[c>>2];i[f+60>>2]=d;if(!mc(f- -64|0,f+56|0)){break d}a=P(8)|0;i[114610]=0;D(2143,f+168|0,f+216|0);b=i[114610];i[114610]=0;s:{t:{u:{if((b|0)!=1){i[114610]=0;G(2119,f+184|0,39252,f+168|0);b=i[114610];i[114610]=0;if((b|0)==1){break u}Ub(a,f+184|0);e=0;i[114610]=0;G(2009,a|0,83568,2017);b=i[114610];i[114610]=0;if((b|0)!=1){break e}b=B()|0;A()|0;eb(f+184|0);break t}b=B()|0;A()|0;break s}b=B()|0;e=1;A()|0}eb(f+168|0);if(!e){break f}}Q(a|0)}E(b|0)}x()}c=i[b+4>>2];i[f+96>>2]=i[b>>2];i[f+100>>2]=c;c=Zb(f+88|0,38966);d=i[f+100>>2];i[f+48>>2]=i[f+96>>2];i[f+52>>2]=d;d=i[c+4>>2];i[f+40>>2]=i[c>>2];i[f+44>>2]=d;if(mc(f+48|0,f+40|0)){gG(a,gc(i[f+216>>2],i[f+220>>2]));break c}c=i[b+4>>2];i[f+80>>2]=i[b>>2];i[f+84>>2]=c;b=Zb(f+72|0,39114);c=i[f+84>>2];i[f+32>>2]=i[f+80>>2];i[f+36>>2]=c;c=i[b+4>>2];i[f+24>>2]=i[b>>2];i[f+28>>2]=c;if(!mc(f+32|0,f+24|0)){break c}b=gc(i[f+216>>2],i[f+220>>2]);i[i[a+32>>2]+40>>2]=b>>>0>3?1:b}Xa=f+224|0}function iK(a,b,c,d,e){var f=0,l=0,m=0,n=0,q=0,r=0,s=0,t=0,u=0,v=0,w=p(0),x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=p(0),K=p(0),L=0,M=0;l=Xa-48|0;Xa=l;s=k[a+480192>>1]?i[(o(b,896)+a|0)+1075640>>2]:s;x=a+1074308|0;f=o(b,896)+a|0;y=f+1075805|0;B=f+1075672|0;C=f+1075772|0;z=f+1075748|0;A=f+1075744|0;D=f+1075704|0;E=f+1075676|0;F=f+1075668|0;G=f+1075648|0;H=f+1075792|0;I=f+1075072|0;q=e&127;J=p(q>>>0);u=f+1075855|0;K=p(j[u|0]);m=1;while(1){e=j[d+n|0];if(e){a:{b:{c:{d:{f=e+ -48|0;e:{if((f&255)>>>0<10){break e}if((e+ -65&255)>>>0<=5){f=e+ -55|0;break e}f=r;f:{switch(e+ -97|0){case 13:f=0;if(!Jd(j[y|0])){break c}f=j[y|0]+ -1|0;break c;case 21:kb(l+8|0,x,28);g:{if(!ib(l+8|0)){kb(l,x,1);e=0;if(!ib(l)){break g}}e=h[C>>1]}f=o(i[z>>2],i[A>>2]);e=o(i[a+1074444>>2],e+i[B>>2]|0);f=Eb((gc(YMa(XMa(f,f>>31,e,e>>31),_a,1048576,0),_a)|0)/2|0,1,127);break c;case 23:i[l+8>>2]=i[E>>2]/2;i[l>>2]=127;f=i[Nd(l+8|0,l)>>2];break c;case 24:i[l+8>>2]=i[F>>2]/2;i[l>>2]=127;f=i[Nd(l+8|0,l)>>2];break c;case 0:f=0;if(!s){break c}e=k[s+28>>1];if(!e){break c}f=e+ -1>>>7&127;break c;case 1:f=0;if(!s){break c}e=k[s+28>>1];if(!e){break c}f=e+ -1&127;break c;case 14:f=i[G>>2]>>>8|0;break c;case 7:e=b;if(k[a+480188>>1]<=e>>>0){e=j[H|0]+ -1|0}f=e&127;break c;case 12:f=i[I>>2]>>>7&1;break c;case 15:f=0;if(!s){break c}e=j[s+30|0];if(!e){break c}f=e+ -1&127;break c;case 25:v=u;e=q;h:{if(!c){break h}e=q;if(g[u|0]<0){break h}i:{if(r>>>0<3){break i}t=(l+16|0)+r|0;if(j[t+ -3|0]!=240){break i}e=q;if(j[t+ -2|0]>239){break h}}w=vo(a,K,J);if(w<p(4294967296)&w>=p(0)){e=~~w>>>0;break h}e=0}f=e;g[v|0]=f;break c;case 18:while(1){j:{if(!f){f=0;break j}f=f+ -1|0;if(j[f+(l+16|0)|0]!=240){continue}}break}if(j[(l+16|0)+f|0]!=240|r-f>>>0<5){break a}t=0;e=f+5|0;if((r|0)!=(e|0)){while(1){t=j[(l+16|0)+e|0]+t|0;e=e+1|0;if((r|0)!=(e|0)){continue}break}}f=0-t&127;break c;case 2:break f;case 20:break d;default:break a}}f=Moa(a,b)}e=(l+16|0)+r|0;k:{if(m&1){g[e|0]=f;break k}g[e|0]=j[e|0]<<4|f;r=r+1|0}e=(m^-1)&1;break b}e=o(i[z>>2],i[A>>2]);f=e;v=e>>31;e=o(i[a+1074444>>2],i[D>>2]);f=Eb((gc(YMa(XMa(f,v,e,e>>31),_a,67108864,0),_a)|0)/2|0,1,127)}e=((m^-1)&1)+r|0;g[e+(l+16|0)|0]=f;r=e+1|0;e=1}m=(e|0)!=0}n=n+1|0;if((n|0)!=31){continue}}break}e=((m^-1)&1)+r|0;l:{if(!e){break l}f=0;m=0;while(1){d=(l+16|0)+m|0;q=g[d|0];m:{n:{o:{if((q|0)==-16){if(e-m>>>0>=4){n=4;if((j[(l+m|0)+17|0]&254)==240){break n}}n=m;p:{while(1){n=n+1|0;if(n>>>0>=e>>>0){break p}if(j[(l+16|0)+n|0]!=247){continue}break}q=n-m|0;n=q+1|0;if(n>>>0>=q>>>0){break n}}g[(l+16|0)+e|0]=247;e=e+1|0;n=e-m|0;break o}if((q|0)>=0){if(f&255){m=m+ -1|0;g[m+(l+16|0)|0]=f;break m}m=m+1|0;f=0;break m}L=l,M=JM(q&255),i[L+8>>2]=M;i[l>>2]=e-m;n=i[rb(l+8|0,l)>>2]}if(!n){break l}q=j[d|0];f=q>>>0<240?q:f}d=Loa(a,b,c,d,n);m=(d?d:n)+m|0}if(e>>>0>m>>>0){continue}break}}Xa=l+48|0}function Bma(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;m=Xa-16|0;Xa=m;a:{b:{c:{if(!i[a+1074376>>2]){n=a+1074448|0;c=n;i[c>>2]=0;i[c+4>>2]=0;i[a+1074456>>2]=i[a+1074444>>2];break c}h=i[a+1074456>>2];c=i[a+1074444>>2];d:{if((h|0)==(c|0)){c=i[a+1074448>>2];break d}i[a+1074456>>2]=c;e=a+24604|0;d=a+1074448|0;e:{if((c|0)>(h|0)){c=zM(e);break e}c=yM(e)}i[d>>2]=c;i[a+1074452>>2]=c}n=a+1074448|0;if((c|0)>=1){break b}}break a}h=(i[a+1074456>>2]<<12)-i[a+1074460>>2]|0;l=(h|0)/(c|0)|0;if(i[a+1074368>>2]!=2){break a}i[m+12>>2]=50;i[m+8>>2]=1e4/(i[a+1074452>>2]+1|0);c=l>>31;g=i[wf(m+12|0,m+8|0)>>2];if((c+l^c)<=(g|0)){break a}c=i[a+1074448>>2];f=i[a+1074452>>2];while(1){c=c+f|0;l=(h|0)/(c|0)|0;e=l>>31;if((e^e+l)>(g|0)){continue}break}i[n>>2]=c}f:{g:{switch(i[a+24624>>2]+ -1|0){case 0:if((b|0)<1){break f}e=i[a+1074444>>2];f=e<<12;c=a+12|0;h=e;d=e>>31;g=0;while(1){h:{if(i[n>>2]>=1){e=i[a+1074460>>2]+l|0;i[a+1074460>>2]=e;k=i[c>>2];p=c,q=gc(YMa(XMa(k,k>>31,e,e>>31),_a,1048576,0),_a),i[p>>2]=q;i[a+1074448>>2]=i[a+1074448>>2]+ -1;break h}e=i[c>>2];p=c,q=gc(YMa(XMa(e,e>>31,h,d),_a,256,0),_a),i[p>>2]=q;i[a+1074460>>2]=f}c=c+4|0;g=g+1|0;if((g|0)!=(b|0)){continue}break}break f;case 1:if((b|0)<1){break f}e=i[a+1074444>>2];d=e<<12;c=a+12|0;h=e;e=e>>31;g=0;while(1){i:{if(i[n>>2]>=1){f=i[a+1074460>>2]+l|0;i[a+1074460>>2]=f;k=i[c>>2];p=c,q=gc(YMa(XMa(k,k>>31,f,f>>31),_a,1048576,0),_a),i[p>>2]=q;f=i[a+1074460>>2];j=f;k=f>>31;f=i[c+4>>2];p=c,q=gc(YMa(XMa(j,k,f,f>>31),_a,1048576,0),_a),i[p+4>>2]=q;i[a+1074448>>2]=i[a+1074448>>2]+ -1;break i}f=i[c>>2];p=c,q=gc(YMa(XMa(f,f>>31,h,e),_a,256,0),_a),i[p>>2]=q;f=i[c+4>>2];p=c,q=gc(YMa(XMa(f,f>>31,h,e),_a,256,0),_a),i[p+4>>2]=q;i[a+1074460>>2]=d}c=c+8|0;g=g+1|0;if((g|0)!=(b|0)){continue}break}break f;case 3:break g;default:break f}}if((b|0)<1){break f}h=i[a+1074444>>2];k=h<<12;c=a+12|0;g=a+8204|0;e=h;h=e>>31;f=0;while(1){j:{if(i[n>>2]>=1){d=i[a+1074460>>2]+l|0;i[a+1074460>>2]=d;j=i[c>>2];p=c,q=gc(YMa(XMa(j,j>>31,d,d>>31),_a,1048576,0),_a),i[p>>2]=q;d=i[a+1074460>>2];j=d;o=d>>31;d=i[c+4>>2];p=c,q=gc(YMa(XMa(j,o,d,d>>31),_a,1048576,0),_a),i[p+4>>2]=q;d=i[a+1074460>>2];j=d;o=d>>31;d=i[g>>2];p=g,q=gc(YMa(XMa(j,o,d,d>>31),_a,1048576,0),_a),i[p>>2]=q;d=i[a+1074460>>2];j=d;o=d>>31;d=i[g+4>>2];p=g,q=gc(YMa(XMa(j,o,d,d>>31),_a,1048576,0),_a),i[p+4>>2]=q;i[a+1074448>>2]=i[a+1074448>>2]+ -1;break j}d=i[c>>2];p=c,q=gc(YMa(XMa(d,d>>31,e,h),_a,256,0),_a),i[p>>2]=q;d=i[c+4>>2];p=c,q=gc(YMa(XMa(d,d>>31,e,h),_a,256,0),_a),i[p+4>>2]=q;d=i[g>>2];p=g,q=gc(YMa(XMa(d,d>>31,e,h),_a,256,0),_a),i[p>>2]=q;d=i[g+4>>2];p=g,q=gc(YMa(XMa(d,d>>31,e,h),_a,256,0),_a),i[p+4>>2]=q;i[a+1074460>>2]=k}g=g+8|0;c=c+8|0;f=f+1|0;if((f|0)!=(b|0)){continue}break}}Xa=m+16|0}function fU(a,b){var c=0,d=0,e=0,f=0,h=0,n=0,q=0,r=0,s=p(0),t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=p(0),E=0,F=0;n=b<<2;z=k[a+480214>>1]!=0;d=a+1074328|0;s=m[d>>2];D=m[d+4>>2];while(1){f=(o(e,160)+a|0)+906300|0;d=i[f>>2];a:{if(!d|!i[d+24>>2]){break a}if(!Wg(d+44|0)){break a}h=i[f>>2];if(!($a[i[i[h>>2]+108>>2]](h)|0)){$a[i[i[h>>2]+104>>2]](h,1);$a[i[i[h>>2]+116>>2]](h)}d=h+44|0;w=ud(d,0);r=ud(d,1);b:{if(g[h+28|0]&1){Px(i[h+24>>2],w,r,b,s);break b}d=h+40|0;if(!(i[h+36>>2]?0:!i[d>>2])){Rm(i[h+24>>2],b,d,h+36|0);Px(i[h+24>>2],w,r,b,s);break b}yb(w,0,n);yb(r,0,n)}i[h+28>>2]=i[h+28>>2]&-2;if(Nt(f)){break a}z=!(j[h+28|0]&4)|z}e=e+1|0;if((e|0)!=250){continue}break}B=a+12|0;h=a+12300|0;w=a+14348|0;Px(B,h,w,b,s);d=a+1074464|0;E=j[d|0];g[d|0]=0;n=h;d=w;while(1){q=(o(v,160)+a|0)+906300|0;f=i[q>>2];c:{if(!f|!i[f+24>>2]){break c}if(!Wg(f+44|0)){break c}x=i[q>>2];d:{if(Nt(q)){break d}f=i[q>>2];if($a[i[i[f>>2]+140>>2]](f)|j[i[q>>2]+28|0]&2){break d}e=0;if(!v){break c}while(1){if((dj((o(e,160)+a|0)+906300|0)|0)==(v|0)){break d}e=e+1|0;if((v|0)!=(e|0)){continue}break}break c}f=x+44|0;A=ud(f,0);C=ud(f,1);u=i[q>>2];t=(n|0)==(A|0);n=t?h:n;r=n;d=t?w:d;c=q+28|0;f=d;e:{if(!(j[c|0]|j[c+1|0]<<8|(j[c+2|0]<<16|j[c+3|0]<<24))){break e}r=n;c=dj(q);f=d;if(v>>>0>=c>>>0){break e}f=d;if((c|0)==255){break e}c=i[(o(c,160)+a|0)+906300>>2];f=d;if(!c){break e}if(!(j[u+28|0]&4)){$a[i[i[c>>2]+144>>2]](c)}c=c+44|0;f=d;if(!Wg(c)){break e}r=ud(c,0);f=ud(c,1)}f:{if(!Nt(q)){break f}g:{if(t){break g}e=0;if(!b){break g}while(1){y=e<<2;c=y+A|0;t=n+y|0;m[c>>2]=m[c>>2]+m[t>>2];c=y+C|0;F=c;s=m[c>>2];c=d+y|0;m[F>>2]=s+m[c>>2];i[t>>2]=0;i[c>>2]=0;e=e+1|0;if((e|0)!=(b|0)){continue}break}}d=f;n=r;if(!(z&1)){break f}n=i[q>>2];if(n){$a[i[i[n>>2]+144>>2]](n)}n=r;e=dj(q);if(e>>>0>249|v>>>0>=e>>>0){break f}while(1){n=e&255;d=(o(n,160)+a|0)+906300|0;e=dj(d);d=i[d>>2];if(d){$a[i[i[d>>2]+144>>2]](d)}if(e>>>0>n>>>0?e>>>0<=249:0){continue}break}d=f;n=r}h:{i:{if(!((j[q+24|0]&2)>>>1|0)){if(!EA(q)|!(j[u+28|0]&4)){break i}}e=0;if(!b){break h}while(1){t=e<<2;c=t+r|0;m[c>>2]=m[c>>2]+m[t+A>>2];c=f+t|0;m[c>>2]=m[c>>2]+m[t+C>>2];e=e+1|0;if((e|0)!=(b|0)){continue}break}break h}if(E){$a[i[i[x>>2]+124>>2]](x)}$a[i[i[x>>2]+60>>2]](x,r,f,b);i[u+32>>2]=i[u+32>>2]+b;if(!EA(q)){break h}if(($a[i[i[x>>2]+152>>2]](x)|0)<1|l[u+32>>2]<i[a+24620>>2]<<2>>>0){break h}e=0;j:{if(!b){break j}while(1){k:{c=e<<2;s=m[c+r>>2];if(s>=p(1.1920928955078125e-7)|s<=p(-1.1920928955078125e-7)){break k}s=m[c+f>>2];if(s>=p(1.1920928955078125e-7)|!(s>p(-1.1920928955078125e-7))){break k}e=e+1|0;if((e|0)!=(b|0)){continue}break j}break}i[u+32>>2]=0;break h}i[u+28>>2]=i[u+28>>2]|4}i[u+28>>2]=i[u+28>>2]&-3}v=v+1|0;if((v|0)!=250){continue}break}uua(n,d,B,b,D)}function v0(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0;h=Xa+ -64|0;Xa=h;i[h+56>>2]=b;i[e>>2]=0;fc(h,d);i[114610]=0;j=F(2449,h|0)|0;k=i[114610];i[114610]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{if((k|0)!=1){ub(h);switch(g+ -65|0){case 54:break j;case 19:break k;case 18:break l;case 17:break m;case 49:break n;case 47:break o;case 45:case 51:break p;case 12:break q;case 44:break r;case 41:break s;case 8:break t;case 7:break u;case 5:break v;case 3:break w;case 35:case 36:break x;case 34:break y;case 1:case 33:case 39:break z;case 0:case 32:break A;case 2:case 4:case 6:case 9:case 10:case 11:case 13:case 14:case 15:case 16:case 20:case 21:case 22:case 25:case 26:case 27:case 28:case 29:case 30:case 31:case 37:case 38:case 40:case 42:case 43:case 46:case 48:case 50:case 52:case 53:break d;case 24:break f;case 56:break g;case 23:break h;case 55:break i;default:break e}}a=B()|0;A()|0;ub(h);E(a|0);x()}dD(a,f+24|0,h+56|0,c,e,j);break b}cD(a,f+16|0,h+56|0,c,e,j);break b}b=$a[i[i[a+8>>2]+12>>2]](a+8|0)|0;l=h,m=Bi(a,i[h+56>>2],c,d,e,f,xb(b),xb(b)+(lb(b)<<2)|0),i[l+56>>2]=m;break b}u0(f+12|0,h+56|0,c,e,j);break b}g=i[15555];i[h+24>>2]=i[15554];i[h+28>>2]=g;g=i[15553];i[h+16>>2]=i[15552];i[h+20>>2]=g;g=i[15551];i[h+8>>2]=i[15550];i[h+12>>2]=g;g=i[15549];i[h>>2]=i[15548];i[h+4>>2]=g;l=h,m=Bi(a,b,c,d,e,f,h,h+32|0),i[l+56>>2]=m;break b}g=i[15563];i[h+24>>2]=i[15562];i[h+28>>2]=g;g=i[15561];i[h+16>>2]=i[15560];i[h+20>>2]=g;g=i[15559];i[h+8>>2]=i[15558];i[h+12>>2]=g;g=i[15557];i[h>>2]=i[15556];i[h+4>>2]=g;l=h,m=Bi(a,b,c,d,e,f,h,h+32|0),i[l+56>>2]=m;break b}t0(f+8|0,h+56|0,c,e,j);break b}s0(f+8|0,h+56|0,c,e,j);break b}r0(f+28|0,h+56|0,c,e,j);break b}q0(f+16|0,h+56|0,c,e,j);break b}p0(f+4|0,h+56|0,c,e,j);break b}o0(h+56|0,c,e,j);break b}n0(a,f+8|0,h+56|0,c,e,j);break b}g=Tb(h,62256,44);l=g,m=Bi(a,b,c,d,e,f,g,g+44|0),i[l+56>>2]=m;break b}i[h+16>>2]=i[15580];g=i[15579];i[h+8>>2]=i[15578];i[h+12>>2]=g;g=i[15577];i[h>>2]=i[15576];i[h+4>>2]=g;l=h,m=Bi(a,b,c,d,e,f,h,h+20|0),i[l+56>>2]=m;break b}m0(f,h+56|0,c,e,j);break b}g=i[15591];i[h+24>>2]=i[15590];i[h+28>>2]=g;g=i[15589];i[h+16>>2]=i[15588];i[h+20>>2]=g;g=i[15587];i[h+8>>2]=i[15586];i[h+12>>2]=g;g=i[15585];i[h>>2]=i[15584];i[h+4>>2]=g;l=h,m=Bi(a,b,c,d,e,f,h,h+32|0),i[l+56>>2]=m;break b}l0(f+24|0,h+56|0,c,e,j);break b}a=$a[i[i[a>>2]+20>>2]](a,b,c,d,e,f)|0;break a}b=$a[i[i[a+8>>2]+24>>2]](a+8|0)|0;l=h,m=Bi(a,i[h+56>>2],c,d,e,f,xb(b),xb(b)+(lb(b)<<2)|0),i[l+56>>2]=m;break b}bD(f+20|0,h+56|0,c,e,j);break b}k0(f+20|0,h+56|0,c,e,j);break b}if((g|0)==37){break c}}i[e>>2]=i[e>>2]|4;break b}j0(h+56|0,c,e,j)}a=i[h+56>>2]}Xa=h- -64|0;return a|0}function doa(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,j=0,k=0,l=0,m=0,n=0,p=0,q=0,r=0,s=0,t=0;i[a+24588>>2]=0;i[a+24592>>2]=0;i[a+4>>2]=0;i[a>>2]=20752;i[a+8>>2]=i[19851];b=a+24596|0;i[b>>2]=0;i[b+4>>2]=0;Qo(a+24604|0);WJ(a+24648|0,0);tea(a+393352|0);i[a+480224>>2]=0;h[a+480212>>1]=0;i[a+480204>>2]=0;i[a+480208>>2]=0;i[a+480180>>2]=0;i[a+480184>>2]=0;b=a+480186|0;h[b>>1]=0;h[b+2>>1]=0;h[b+4>>1]=0;h[b+6>>1]=0;i[a+480240>>2]=65536;i[a+480244>>2]=65536;n=hx(a+480248|0);i[a+480272>>2]=0;c=a+484344|0;b=a+480280|0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{while(1){i[114610]=0;b=F(1389,b|0)|0;e=i[114610];i[114610]=0;if((e|0)==1){break l}b=b+32|0;if((c|0)!=(b|0)){continue}break}e=a+484344|0;Xma(e);i[e+12>>2]=a;i[114610]=0;p=C(1390,a+484360|0,a|0)|0;b=i[114610];i[114610]=0;if((b|0)==1){break k}c=a+900380|0;b=a+484380|0;while(1){i[114610]=0;b=C(1014,b|0,0)|0;f=i[114610];i[114610]=0;if((f|0)==1){break j}b=b+104|0;if((c|0)!=(b|0)){continue}break}i[114610]=0;F(1391,a+901404|0)|0;b=i[114610];i[114610]=0;if((b|0)==1){break i}f=a+946300|0;k=a+906300|0;c=0;while(1){i[114610]=0;d=(o(c,160)+a|0)+906300|0;F(1392,d|0)|0;b=i[114610];i[114610]=0;if((b|0)==1){break h}c=c+1|0;if((c|0)!=250){continue}break}c=a+1074300|0;d=a+946300|0;b=d;while(1){i[114610]=0;b=F(1163,b|0)|0;j=i[114610];i[114610]=0;if((j|0)==1){break g}b=b+32|0;if((c|0)!=(b|0)){continue}break}i[a+1074300>>2]=0;i[a+1074304>>2]=0;gx(a+1074308|0);i[114610]=0;b=R(1393)|0;c=i[114610];i[114610]=0;if((c|0)==1){break f}i[114610]=0;b=F(1394,b|0)|0;c=i[114610];i[114610]=0;if((c|0)==1){break f}i[a+1074324>>2]=b;i[114610]=0;F(1395,a+1074328|0)|0;b=i[114610];i[114610]=0;if((b|0)==1){break f}i[114610]=0;F(1396,a+1074376|0)|0;b=i[114610];i[114610]=0;if((b|0)==1){break f}i[114610]=0;c=I(1334,a+1304360|0,a|0,255)|0;b=i[114610];i[114610]=0;if((b|0)==1){break f}j=$na(a+1304392|0);q=_na(a+1304396|0);r=Ab(a+1304400|0);s=Oc(a+1304412|0);l=a+1304424|0;Ab(l);t=UJ(a+1304436|0);m=a+1304500|0;Xna(m);g[a+1304512|0]=0;Zna(a+1304520|0);i[a+1304560>>2]=0;so(a+12|0);Ro(a+8204|0);Ro(a+12300|0);b=a+1074408|0;i[b>>2]=4;i[b+4>>2]=16;i[a+480216>>2]=4;i[a+480220>>2]=16;TJ(a+900380|0);i[114610]=0;L(1397,d|0);b=i[114610];i[114610]=0;if((b|0)==1){break e}i[114610]=0;b=F(1398,12)|0;d=i[114610];i[114610]=0;if((d|0)==1){break e}i[b>>2]=0;i[b+4>>2]=0;i[b+8>>2]=0;Vma(b);i[a+4>>2]=b;return a|0}b=B()|0;A()|0;break a}b=B()|0;A()|0;break b}b=B()|0;A()|0;break c}b=B()|0;A()|0;break c}b=B()|0;A()|0;if(!c){break c}while(1){d=wm(d+ -160|0);if((k|0)!=(d|0)){continue}break}break c}b=B()|0;A()|0;break d}b=B()|0;A()|0;break d}b=B()|0;A()|0;fx(m);Ir(t);eb(l);eb(s);eb(r);Hr(q);Gr(j);yo(c)}while(1){f=wm(f+ -160|0);if((k|0)!=(f|0)){continue}break}}es(p)}ex(e)}Sd(n);E(b|0);x()}function P8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=Xa-192|0;Xa=d;a:{if(Oi(b)){break a}e=j[Dj(b)|0];g=1;b:{if((e|0)==33){break b}if((e|0)!=63){break a}g=0}c=g;Oj(d+160|0,b,i[b+4>>2]+ -1|0);e=i[d+164>>2];i[b>>2]=i[d+160>>2];i[b+4>>2]=e}jd(d+160|0);e=i[d+160>>2];jd(d+144|0);e=Cj(e,i[d+148>>2],b);jd(d+160|0);c:{d:{e:{f:{if((e|0)==i[d+164>>2]){a=i[b+4>>2];i[d+184>>2]=i[b>>2];i[d+188>>2]=a;a=Zb(d+176|0,38187);e=i[d+188>>2];i[d+8>>2]=i[d+184>>2];i[d+12>>2]=e;e=i[a+4>>2];i[d>>2]=i[a>>2];i[d+4>>2]=e;if(mc(d+8|0,d)){a=P(8)|0;i[114610]=0;c=C(85,d+160|0,39121)|0;b=i[114610];i[114610]=0;if((b|0)==1){break e}Ub(a,c);i[114610]=0;G(2009,a|0,83568,2017);a=i[114610];i[114610]=0;if((a|0)!=1){break c}b=B()|0;A()|0;eb(c);break d}f=0;if(!c){break f}a=P(8)|0;i[114610]=0;e=C(2142,d+144|0,b|0)|0;b=i[114610];i[114610]=0;g:{h:{i:{if((b|0)!=1){i[114610]=0;G(2119,d+160|0,39131,e|0);b=i[114610];i[114610]=0;if((b|0)==1){break i}Ub(a,d+160|0);c=0;i[114610]=0;G(2009,a|0,83568,2017);b=i[114610];i[114610]=0;if((b|0)!=1){break c}b=B()|0;A()|0;eb(d+160|0);break h}b=B()|0;A()|0;break g}b=B()|0;c=1;A()|0}eb(e);if(!c){break d}}Q(a|0);break d}if(i[e+4>>2]!=2){a=P(8)|0;i[114610]=0;c=C(85,d+160|0,39145)|0;b=i[114610];i[114610]=0;if((b|0)!=1){Ub(a,c);i[114610]=0;G(2009,a|0,83568,2017);a=i[114610];i[114610]=0;if((a|0)!=1){break c}b=B()|0;A()|0;eb(c);break d}b=B()|0;A()|0;Q(a|0);break d}c=i[b+4>>2];i[d+136>>2]=i[b>>2];i[d+140>>2]=c;c=Zb(d+128|0,38187);e=i[d+140>>2];i[d+72>>2]=i[d+136>>2];i[d+76>>2]=e;e=i[c+4>>2];i[d+64>>2]=i[c>>2];i[d+68>>2]=e;if(mc(d+72|0,d- -64|0)){a=P(8)|0;i[114610]=0;c=C(85,d+160|0,39121)|0;b=i[114610];i[114610]=0;if((b|0)!=1){Ub(a,c);i[114610]=0;G(2009,a|0,83568,2017);a=i[114610];i[114610]=0;if((a|0)!=1){break c}b=B()|0;A()|0;eb(c);break d}b=B()|0;A()|0;Q(a|0);break d}c=i[b+4>>2];i[d+120>>2]=i[b>>2];i[d+124>>2]=c;c=Zb(d+112|0,38974);e=i[d+124>>2];i[d+56>>2]=i[d+120>>2];i[d+60>>2]=e;e=i[c+4>>2];i[d+48>>2]=i[c>>2];i[d+52>>2]=e;if(mc(d+56|0,d+48|0)){f=1;if(!j[a+28|0]){break f}f=65536/+l[i[a+24>>2]+480244>>2];break f}c=i[b+4>>2];i[d+104>>2]=i[b>>2];i[d+108>>2]=c;c=Zb(d+96|0,38992);e=i[d+108>>2];i[d+40>>2]=i[d+104>>2];i[d+44>>2]=e;e=i[c+4>>2];i[d+32>>2]=i[c>>2];i[d+36>>2]=e;if(mc(d+40|0,d+32|0)){f=1;if(!j[a+28|0]){break f}f=+l[i[a+24>>2]+480240>>2]*152587890625e-16;break f}c=i[b+4>>2];i[d+88>>2]=i[b>>2];i[d+92>>2]=c;b=Zb(d+80|0,39089);c=i[d+92>>2];i[d+24>>2]=i[d+88>>2];i[d+28>>2]=c;c=i[b+4>>2];i[d+16>>2]=i[b>>2];i[d+20>>2]=c;f=0;if(!mc(d+24|0,d+16|0)){break f}a=a+24|0;a;f=+l[i[a>>2]+480236>>2]*152587890625e-16}Xa=d+192|0;return+f}b=B()|0;A()|0;Q(a|0)}E(b|0)}x()}function KMa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,l=0,m=0,n=0,p=0,q=0,r=0,s=0,t=0;e=Xa-576|0;Xa=e;pc(b);d=e+72|0;l=FMa(b,d);if(!l){kT(d)}a:{if(!l){break a}if(!qT(e+72|0)){break a}b:{if(!c){break b}if(!wb(b,Vc(pT(e+72|0),_a))){break a}md(a,64);i[a+480260>>2]=112;i[a+480264>>2]=13696;i[a+480204>>2]=78e4;i[a+480196>>2]=4;h[a+480188>>1]=8;d=Bb(e+40|0,11897);mb(a+1304436|0,d);eb(d);d=Bb(e+40|0,11910);mb(a+1304448|0,d);eb(d);tc(a+1304460|0,k[e+72>>1]==26217?11897:11914);i[a+1304496>>2]=4;d=j[e+182|0];h[a+480190>>1]=d;c:{d:{e:{f:{if(d){f=1;l=1;while(1){IMa(b,e+40|0);if((j[e+53|0]|j[e+54|0]<<8|(j[e+55|0]<<16|j[e+56|0]<<24))>>>0>67108863){break d}JMa(e+40|0,(o(f,104)+a|0)+484380|0);oi(e+8|0,2,e+40|0);oc(e+24|0,e+8|0);i[114610]=0;C(369,((f<<5)+a|0)+946300|0,e+24|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break f}eb(e+24|0);l=l+1|0;f=l&65535;if(f>>>0<=k[a+480190>>1]){continue}break}}d=e+72|2;nT(e+24|0,3,d,36);oc(e+40|0,e+24|0);mb(a+1304400|0,e+40|0);eb(e+40|0);f=0;EM(a+1304424|0,jb(d),108,36,0);d=a+484360|0;mT(Db(d),e+185|0,128);if(k[$b(Db(d),j[e+184|0])>>1]<j[e+183|0]){break e}break c}a=B()|0;A()|0;eb(e+24|0);E(a|0);x()}Fe(Db(d),j[e+184|0]);break c}f=0;break a}while(1){d=(f<<5)+a|0;sg(d+480280|0);h[d+480284>>1]=f&1?208:48;f=f+1|0;if((f|0)!=8){continue}break}q=a+484344|0;Gf(q,j[e+183|0]);if(j[e+183|0]){s=c&1;while(1){g:{h:{if(s){if(Sf(q,n&65535,64)){break h}}Ib(b,1536);break g}i[e+24>>2]=-1;i[e+28>>2]=-1;r=0;while(1){f=zp(Fb(q,n),r);l=0;while(1){wt(e+40|0,b);d=Nc(e+40|0);t=yf(e+40|0);m=j[d|0];p=e+40|0;d=j[p|0];if(d>>>0<=253){g[f|0]=(d>>>2|0)+37;g[f+1|0]=(d<<4&48|m>>>4)+1;g[(e+24|0)+l|0]=255;d=j[p|0]}if((d|0)!=255){g[f+2|0]=1;g[f+4|0]=(((m&15)<<6|8)>>>0)/15}p=(e+24|0)+l|0;i:{j:{d=j[t|0];k:{if((d|0)!=255){g[p|0]=d;if(d&15|(d|0)==48){break k}break j}d=j[p|0];if((d|0)==255){break i}}m=d&15;g[f+5|0]=m;l:{if(d<<24>>24<0){break l}d=d>>>4|0;g[f+3|0]=j[d+11923|0];m:{switch(d+ -3|0){case 0:g[f+5|0]=m|32;break j;case 1:g[f+5|0]=m|m<<4;break i;case 2:break j;case 3:break m;default:break i}}n:{switch(m|0){case 0:g[f+5|0]=79;break i;case 1:break n;default:break l}}g[f+5|0]=244;break i}g[f+3|0]=0;break i}g[p|0]=255}f=f+6|0;l=l+1|0;if((l|0)!=8){continue}break}r=r+1|0;if((r|0)!=64){continue}break}d=(e+72|0)+n|0;f=d;if(j[d+369|0]<63){Vk(Fb(q,n),mi(Ee(yp(e+40|0,14,0),j[f+369|0])))}Vk(Fb(q,n),mi(yp(e+40|0,16,j[d+241|0])))}n=n+1|0;if(n>>>0<j[e+183|0]){continue}break}}f=1;if(!(c&2)){break a}c=Ic(e+40|0,8,1,0,1);if(!k[a+480190>>1]){break b}while(1){Xf(c,(o(f&65535,104)+a|0)+484380|0,b);f=f+1|0;if((f&65535)>>>0<=k[a+480190>>1]){continue}break}}f=1}Xa=e+576|0;return f|0}function Daa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,h=0,k=0,l=0,m=0,n=0,o=0;d=Xa-160|0;Xa=d;h=d+144|0;qG(h);i[h>>2]=83720;H8(h+4|0);k=a+24|0;km(i[k>>2],h);f=j[a+62|0];e=j[a+61|0];l=j[a+60|0];m=i[k>>2];b=He(d+128|0,b);i[114610]=0;l=l?13:15;e=e?l&14:l;f=I(2145,m|0,b|0,(f?e&3:e)|0)|0;e=i[114610];i[114610]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{if((e|0)!=1){hb(b);if(!f){b=P(8)|0;i[114610]=0;c=C(85,d+112|0,38563)|0;a=i[114610];i[114610]=0;if((a|0)!=1){Ub(b,c);i[114610]=0;G(2009,b|0,83568,2017);a=i[114610];i[114610]=0;if((a|0)!=1){break a}a=B()|0;A()|0;eb(c);break b}a=B()|0;A()|0;Q(b|0);break b}r:{if(j[a+63|0]){break r}i[114610]=0;D(2146,a|0,a+36|0);b=i[114610];i[114610]=0;if((b|0)!=1){break r}a=B()|0;A()|0;break b}g[a+28|0]=1;km(i[k>>2],i[a+4>>2]);i[114610]=0;D(2147,d+112|0,h|0);b=i[114610];i[114610]=0;if((b|0)==1){break q}n=d,o=Jb(d+112|0),i[n+104>>2]=o;n=d,o=Kb(d+112|0),i[n+96>>2]=o;if(pb(d+104|0,d+96|0)){k=a+68|0;while(1){b=i[d+104>>2];f=i[b>>2];i[114610]=0;e=f;f=b+4|0;G(2148,a|0,e|0,f|0);e=i[114610];i[114610]=0;if((e|0)==1){break e}b=i[b>>2];i[114610]=0;D(2149,d+32|0,b|0);b=i[114610];i[114610]=0;if((b|0)==1){break f}i[114610]=0;G(9,d+48|0,0,d+32|0);b=i[114610];i[114610]=0;if((b|0)==1){break h}i[114610]=0;b=C(85,d+16|0,38582)|0;e=i[114610];i[114610]=0;if((e|0)==1){break j}i[114610]=0;G(138,d- -64|0,d+48|0,b|0);e=i[114610];i[114610]=0;if((e|0)==1){break l}i[114610]=0;G(805,d+80|0,d- -64|0,f|0);f=i[114610];i[114610]=0;if((f|0)==1){break n}i[114610]=0;D(1534,k|0,d+80|0);f=i[114610];i[114610]=0;if((f|0)==1){break o}eb(d+80|0);eb(d- -64|0);eb(b);eb(d+48|0);eb(d+32|0);vf(d+104|0);if(pb(d+104|0,d+96|0)){continue}break}}n=d,o=Wm(c),i[n+80>>2]=o;n=d,o=fi(c),i[n+64>>2]=o;s:{while(1){i[114610]=0;b=C(2150,d+80|0,d- -64|0)|0;c=i[114610];i[114610]=0;if((c|0)==1){break d}if(!b){break p}i[114610]=0;c=F(2151,d+80|0)|0;b=i[114610];i[114610]=0;t:{if((b|0)==1){break t}i[114610]=0;b=C(120,d|0,c|0)|0;k=i[114610];i[114610]=0;if((k|0)==1){break t}i[114610]=0;J(2081,a|0,b|0,c+12|0,0);c=i[114610];i[114610]=0;if((c|0)==1){break s}eb(b);i[114610]=0;F(2152,d+80|0)|0;b=i[114610];i[114610]=0;if((b|0)!=1){continue}break d}break}a=B()|0;A()|0;break c}a=B()|0;A()|0;eb(b);break c}a=B()|0;A()|0;hb(b);break b}a=B()|0;A()|0;break b}Vv(d+112|0);cr(h);Xa=d+160|0;return}a=B()|0;A()|0;eb(d+80|0);break m}a=B()|0;A()|0}eb(d- -64|0);break k}a=B()|0;A()|0}eb(b);break i}a=B()|0;A()|0}eb(d+48|0);break g}a=B()|0;A()|0}eb(d+32|0);break c}a=B()|0;A()|0;break c}a=B()|0;A()|0;break c}a=B()|0;A()|0}Vv(d+112|0)}cr(h);E(a|0)}x()}function O0(a,b,c,d,e,f,h,k){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;h=h|0;k=k|0;var l=0,m=0,n=0,o=0;k=Xa-32|0;Xa=k;i[k+24>>2]=b;i[e>>2]=0;fc(k+8|0,d);i[114610]=0;l=F(21,k+8|0)|0;m=i[114610];i[114610]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{if((m|0)!=1){ub(k+8|0);switch(h+ -65|0){case 54:break j;case 19:break k;case 18:break l;case 17:break m;case 49:break n;case 47:break o;case 45:case 51:break p;case 12:break q;case 44:break r;case 41:break s;case 8:break t;case 7:break u;case 5:break v;case 3:break w;case 35:case 36:break x;case 34:break y;case 1:case 33:case 39:break z;case 0:case 32:break A;case 2:case 4:case 6:case 9:case 10:case 11:case 13:case 14:case 15:case 16:case 20:case 21:case 22:case 25:case 26:case 27:case 28:case 29:case 30:case 31:case 37:case 38:case 40:case 42:case 43:case 46:case 48:case 50:case 52:case 53:break d;case 24:break f;case 56:break g;case 23:break h;case 55:break i;default:break e}}a=B()|0;A()|0;ub(k+8|0);E(a|0);x()}hD(a,f+24|0,k+24|0,c,e,l);break b}gD(a,f+16|0,k+24|0,c,e,l);break b}b=$a[i[i[a+8>>2]+12>>2]](a+8|0)|0;n=k,o=Ci(a,i[k+24>>2],c,d,e,f,xb(b),xb(b)+lb(b)|0),i[n+24>>2]=o;break b}N0(f+12|0,k+24|0,c,e,l);break b}i[k+8>>2]=623865125;i[k+12>>2]=2032480100;n=k,o=Ci(a,b,c,d,e,f,k+8|0,k+16|0),i[n+24>>2]=o;break b}i[k+8>>2]=623728933;i[k+12>>2]=1680158061;n=k,o=Ci(a,b,c,d,e,f,k+8|0,k+16|0),i[n+24>>2]=o;break b}M0(f+8|0,k+24|0,c,e,l);break b}L0(f+8|0,k+24|0,c,e,l);break b}K0(f+28|0,k+24|0,c,e,l);break b}J0(f+16|0,k+24|0,c,e,l);break b}I0(f+4|0,k+24|0,c,e,l);break b}H0(k+24|0,c,e,l);break b}G0(a,f+8|0,k+24|0,c,e,l);break b}h=j[62175]|j[62176]<<8|(j[62177]<<16|j[62178]<<24);g[k+15|0]=h;g[k+16|0]=h>>>8;g[k+17|0]=h>>>16;g[k+18|0]=h>>>24;h=j[62172]|j[62173]<<8|(j[62174]<<16|j[62175]<<24);i[k+8>>2]=j[62168]|j[62169]<<8|(j[62170]<<16|j[62171]<<24);i[k+12>>2]=h;n=k,o=Ci(a,b,c,d,e,f,k+8|0,k+19|0),i[n+24>>2]=o;break b}g[k+12|0]=j[62183];i[k+8>>2]=j[62179]|j[62180]<<8|(j[62181]<<16|j[62182]<<24);n=k,o=Ci(a,b,c,d,e,f,k+8|0,k+13|0),i[n+24>>2]=o;break b}F0(f,k+24|0,c,e,l);break b}i[k+8>>2]=624576549;i[k+12>>2]=1394948685;n=k,o=Ci(a,b,c,d,e,f,k+8|0,k+16|0),i[n+24>>2]=o;break b}E0(f+24|0,k+24|0,c,e,l);break b}a=$a[i[i[a>>2]+20>>2]](a,b,c,d,e,f)|0;break a}b=$a[i[i[a+8>>2]+24>>2]](a+8|0)|0;n=k,o=Ci(a,i[k+24>>2],c,d,e,f,xb(b),xb(b)+lb(b)|0),i[n+24>>2]=o;break b}fD(f+20|0,k+24|0,c,e,l);break b}D0(f+20|0,k+24|0,c,e,l);break b}if((h|0)==37){break c}}i[e>>2]=i[e>>2]|4;break b}C0(k+24|0,c,e,l)}a=i[k+24>>2]}Xa=k+32|0;return a|0}function oaa(a,b,c){a=a|0;b=+b;c=c|0;var d=0,e=0,f=0,g=0;d=Xa-96|0;Xa=d;a:{b:{c:{if(!(b<.8)){i[114610]=0;L(2158,d+24|0);e=i[114610];i[114610]=0;d:{e:{f:{g:{h:{if((e|0)!=1){c=i[c>>2];i[114610]=0;D(2159,d+8|0,c|0);c=i[114610];i[114610]=0;if((c|0)==1){break h}km(i[d+24>>2],i[d+8>>2]);e=i[d+24>>2];c=He(d+80|0,a);i[114610]=0;a=I(2145,e|0,c|0,15)|0;e=i[114610];i[114610]=0;if((e|0)==1){break g}hb(c);if(a){a=i[d+24>>2];i[114610]=0;F(1402,a|0)|0;a=i[114610];i[114610]=0;f=1;if((a|0)==1){break f}}Ec(d+8|0);ih(d+24|0);break b}a=H(0)|0;A()|0;break c}a=H(0)|0;A()|0;break d}a=H(0)|0;A()|0;hb(c);break e}a=H(0)|0;A()|0}Ec(d+8|0)}ih(d+24|0);break c}if(!(b<.6)){i[114610]=0;L(2158,d+24|0);e=i[114610];i[114610]=0;i:{j:{k:{l:{m:{if((e|0)!=1){c=i[c>>2];i[114610]=0;D(2159,d+8|0,c|0);c=i[114610];i[114610]=0;if((c|0)==1){break m}km(i[d+24>>2],i[d+8>>2]);e=i[d+24>>2];c=He(d- -64|0,a);i[114610]=0;a=I(2145,e|0,c|0,2)|0;e=i[114610];i[114610]=0;if((e|0)==1){break l}hb(c);if(a){a=i[d+24>>2];i[114610]=0;F(1402,a|0)|0;a=i[114610];i[114610]=0;f=.8;if((a|0)==1){break k}}Ec(d+8|0);ih(d+24|0);break b}a=H(0)|0;A()|0;break c}a=H(0)|0;A()|0;break i}a=H(0)|0;A()|0;hb(c);break j}a=H(0)|0;A()|0}Ec(d+8|0)}ih(d+24|0);break c}f=.2;if(!(b<.2)){i[114610]=0;L(2158,d+24|0);e=i[114610];i[114610]=0;n:{o:{p:{q:{r:{if((e|0)!=1){c=i[c>>2];i[114610]=0;D(2159,d+8|0,c|0);c=i[114610];i[114610]=0;if((c|0)==1){break r}km(i[d+24>>2],i[d+8>>2]);e=i[d+24>>2];c=He(d+48|0,a);i[114610]=0;a=I(2145,e|0,c|0,0)|0;e=i[114610];i[114610]=0;if((e|0)==1){break q}hb(c);f=0;if(a){a=i[d+24>>2];i[114610]=0;F(1402,a|0)|0;a=i[114610];i[114610]=0;f=.6;if((a|0)==1){break p}}Ec(d+8|0);ih(d+24|0);break b}a=H(0)|0;A()|0;break c}a=H(0)|0;A()|0;break n}a=H(0)|0;A()|0;hb(c);break o}a=H(0)|0;A()|0}Ec(d+8|0)}ih(d+24|0);break c}if(b<.1){break b}i[114610]=0;G(858,d+24|0,a|0,2048);c=i[114610];i[114610]=0;s:{t:{u:{if((c|0)!=1){i[114610]=0;c=F(412,d+24|0)|0;e=i[114610];i[114610]=0;if((e|0)==1){break t}e=i[d+24>>2];i[114610]=0;a=F(255,a|0)|0;g=i[114610];i[114610]=0;if((g|0)==1){break t}i[114610]=0;a=KB(2160,3,0,c,e,a,0);c=i[114610];i[114610]=0;if((c|0)==1){break t}a=a+1|0;if(a>>>0>=3){break u}f=n[(a<<3)+40464>>3];jc(d+24|0);break b}a=H(0)|0;A()|0;break c}c=P(8)|0;i[114610]=0;e=C(85,d+8|0,38187)|0;a=i[114610];i[114610]=0;if((a|0)!=1){Ub(c,e);i[114610]=0;G(2009,c|0,83568,2017);a=i[114610];i[114610]=0;if((a|0)!=1){break a}a=H(0)|0;A()|0;eb(e);break s}a=H(0)|0;A()|0;Q(c|0);break s}a=H(0)|0;A()|0}jc(d+24|0)}M(a|0)|0;O();f=0}Xa=d+96|0;return+f}x()}function Z5(a,b,c,d,e){var f=0,g=0,l=0,n=0,o=0,q=0,r=0,s=0,t=p(0),u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=p(0),E=0,F=0;s=i[b+4>>2];l=i[b>>2]+((s|0)/8|0)|0;r=j[l|0]|j[l+1|0]<<8|(j[l+2|0]<<16|j[l+3|0]<<24);g=(r<<24|r<<8&16711680|(r>>>8&65280|r>>>24))<<(s&7);f=s|-8;u=l+4|0;s=i[c>>2];a:{v=k[c+6>>1];if(!v){v=0;break a}while(1){r=c+C|0;l=j[r+15|0];z=(h[(l<<1)+47920>>1]<<1)+43536|0;r=j[r+18|0];b:{if(l>>>0<16){q=s;w=r;while(1){x=j[q|0]>>>1|0;y=(v|0)>(x|0)?x:v;t=m[d>>2];while(1){n=h[(g>>>26&62)+z>>1];if((n|0)<=-1){o=5;while(1){f=f+o|0;g=g<<o;o=n&7;n=h[((g>>>32-o|0)-(n>>3)<<1)+z>>1];if((n|0)<0){continue}break}}l=n>>8;f=l+f|0;g=g<<l;o=1;while(1){l=n&15;m[a>>2]=m[((l|16)+(g>>31<<4)<<2)+48016>>2]*t;n=n>>4;a=a+4|0;l=(l|0)!=0;f=l+f|0;g=g<<l;l=o&1;o=0;if(l){continue}break}if((f|0)>-1){while(1){g=j[u|0]<<f|g;l=(f|0)>7;f=f+ -8|0;u=u+1|0;if(l){continue}break}}y=y+ -1|0;if(y){continue}break}d=d+4|0;q=q+1|0;v=v-x|0;if((v|0)<1){s=q;break a}l=(w|0)>0;w=w+ -1|0;if(l){continue}break}break b}A=j[l+47984|0];E=32-A|0;l=s;x=r;while(1){B=j[l|0]>>>1|0;w=(v|0)>(B|0)?B:v;t=m[d>>2];while(1){o=h[(g>>>26&62)+z>>1];if((o|0)<=-1){n=5;while(1){g=g<<n;f=f+n|0;q=o&7;n=q;o=h[((g>>>32-n|0)-(o>>3)<<1)+z>>1];if((o|0)<0){continue}break}}q=o>>8;f=q+f|0;g=g<<q;y=1;while(1){F=a;q=o&15;c:{if((q|0)==15){n=g<<A;q=(g>>>E|0)+15|0;f=f+A|0;if((f|0)>=0){while(1){n=j[u|0]<<f|n;g=(f|0)>7;f=f+ -8|0;u=u+1|0;if(g){continue}break}}D=p(p(t*p(((n|0)>-1?1:-1)|0))*O5(q));break c}n=g;D=p(m[((q|16)+(g>>31<<4)<<2)+48016>>2]*t)}m[F>>2]=D;o=o>>4;a=a+4|0;q=(q|0)!=0;f=q+f|0;g=n<<q;q=y&1;y=0;if(q){continue}break}if((f|0)>-1){while(1){g=j[u|0]<<f|g;q=(f|0)>7;f=f+ -8|0;u=u+1|0;if(q){continue}break}}w=w+ -1|0;if(w){continue}break}d=d+4|0;l=l+1|0;v=v-B|0;if((v|0)<1){s=l;break a}q=(x|0)>0;x=x+ -1|0;if(q){continue}break}}C=C+1|0;s=(r+s|0)+1|0;continue}}o=1-v|0;while(1){d:{r=j[c+26|0]?47904:47872;n=j[r+(g>>>28|0)|0];if(!(n&8)){n=j[r+((g<<4>>>32-(n&3))+(n>>>3)|0)|0]}l=n&7;f=l+f|0;if(((f+(u-i[b>>2]<<3)|0)+ -24|0)>(e|0)){break d}o=o+ -1|0;r=d;e:{if(o){break e}o=j[s|0]>>>1|0;if(!o){break d}s=s+1|0;t=m[d>>2];r=d+4|0}g=g<<l;if(n&128){m[a>>2]=(g|0)<0?p(-t):t;f=f+1|0;g=g<<1}if(n&64){m[a+4>>2]=(g|0)<0?p(-t):t;f=f+1|0;g=g<<1}o=o+ -1|0;d=r;f:{if(o){break f}o=j[s|0]>>>1|0;if(!o){break d}s=s+1|0;t=m[r>>2];d=r+4|0}if(n&32){m[a+8>>2]=(g|0)<0?p(-t):t;f=f+1|0;g=g<<1}if(n&16){m[a+12>>2]=(g|0)<0?p(-t):t;f=f+1|0;g=g<<1}if((f|0)>=0){while(1){g=j[u|0]<<f|g;r=(f|0)>7;f=f+ -8|0;u=u+1|0;if(r){continue}break}}a=a+16|0;continue}break}i[b+4>>2]=e}function rla(a,b){var c=0,d=0,e=0,f=0,l=0,m=0,n=0,p=0;m=k[a+4>>1];c=m+1|0;h[a+4>>1]=c;if((c&65535)>>>0>=k[i[a>>2]+480188>>1]){h[a+4>>1]=0}a:{if(Dm(b)){break a}l=i[a>>2];c=i[l+1074304>>2];l=i[l+480180>>2];b:{if((l|0)==2){if(j[b+3|0]!=23|c>>>0>=18415616){break b}ze(b+5|0,64);break b}if(l&16777248){c:{if(j[a+6|0]|c>>>0>=18874368?c>>>0>=18285314:0){break c}d:{switch(j[b+3|0]+ -20|0){case 3:ze(b+5|0,128);break c;case 0:break d;default:break c}}e=j[b+5|0];if((e|0)!=208){if((e|0)!=192){break c}g[b|0]=254;g[b+3|0]=0;break c}g[b+3|0]=0}e:{if(c>>>0>=18350080){d=0;if(j[a+6|0]|c>>>0>=18874368){break e}}f=j[b+3|0]+ -6&255;d=0;if(f>>>0>23){break e}d=8388643>>>f&1}e=j[b+3|0];f:{if(((e|0)==24|(e|0)==22)&c>>>0<18874368?0:!d){break f}d=j[b+5|0];f=d&15;if(!f|(f|0)==15){break f}d=d&240;if(!d|(d|0)==240){break f}if((e|0)==24){g[b+5|0]=d;break f}g[b+5|0]=f}if(!k[i[a>>2]+480192>>1]|((c|0)==19005440|c>>>0>=19005700)|(j[a+6|0]|k[i[a>>2]+480192>>1]>=j[b+1|0])){break b}g[b+4|0]=0;g[b+2|0]=1;break b}if((l|0)!=4){break b}g:{if(j[b+3|0]!=23|c>>>0>=19137026|(c>>>0<18874368?!(j[a+6|0]?c>>>0>=18285314:0):0)){break g}if(j[b+5|0]<65){break g}g[b+3|0]=0}if(!(j[b+3|0]!=10|(j[a+6|0]|c>>>0>=18874368?c>>>0>=18415616:0)|j[b+2|0]!=11)){g[b+3|0]=0}h:{if(j[b+2|0]!=11|c>>>0>=18874640|j[b+3|0]!=4){break h}e=j[b+4|0];if(j[a+6|0]?0:!e){break h}f=j[b+5|0];if(!f){break h}g[b+2|0]=0;n=b,p=kP(f+(e<<4)|0),g[n+5|0]=p}if(j[b+5|0]|(j[b+3|0]!=16|c>>>0>=19007241)){break b}g[b+3|0]=0}i:{if(c>>>0>=18874368){break i}e=0;j:{k:{l:{f=j[b+3|0];d=j[b+5|0]&240;if(!((f|0)!=28|(d|0)!=96)){if(!j[a+6|0]|(l|0)!=4){break l}e=c>>>0<18350080}if(!m){break j}if((f|0)==20&(d|0)==96|e){break k}break j}if(!m){break j}}a=o(0-m|0,6)+b|0;while(1){if(!((j[a+3|0]|8)!=28|(j[a+5|0]&240)!=96)){g[a+3|0]=0}a=a+6|0;if(a>>>0<b>>>0){continue}break}}if(!m|(j[b+5|0]&240)!=224|j[b+3|0]!=20){break i}a=o(0-m|0,6)+b|0;while(1){if(!(j[a+3|0]!=20|(j[a+5|0]&240)!=224)){g[a+3|0]=0}a=a+6|0;if(a>>>0<b>>>0){continue}break}}m:{if(j[b+2|0]!=8|c>>>0>=19333175|(c|0)==19333120){break m}n:{o:{p:{q:{a=j[b+3|0];switch(a+ -5|0){case 1:break m;case 0:break o;case 2:break q;default:break p}}if(!j[b+4|0]){break n}g[b+3|0]=11;break m}if((a|0)!=26){break m}}c=j[b+5|0];if(!(c&15)){g[b+2|0]=1280;g[b+3|0]=5;g[b+5|0]=c|j[b+4|0]&15;break m}r:{switch(a+ -5|0){case 1:break m;case 0:case 2:break n;default:break r}}if((a|0)!=26){break m}}g[b+2|0]=0}if(j[b+3|0]|((l|0)==16777216|j[b+2|0]!=15)){break a}g[b+2|0]=2560;g[b+3|0]=10;g[b+5|0]=j[b+4|0]<<3}}function fka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,h=0,k=0,l=0,m=0,n=0,o=0,p=0;c=Xa-48|0;Xa=c;if(rh(b)){h=Hj(b);m=i[b+12>>2];f=hka(c+32|0,h);a:{if(!m){break a}while(1){e=i[i[a>>2]+ -12>>2];i[114610]=0;e=F(1575,a+e|0)|0;d=i[114610];i[114610]=0;b:{if((d|0)!=1){c:{if(!e){break a}i[114610]=0;g[c+31|0]=0;C(1576,a|0,c+31|0)|0;e=i[114610];i[114610]=0;d:{if((e|0)!=1){e=g[c+31|0];if(e){break d}l=l+1|0;break b}break c}g[c+30|0]=0;e:{if((e|0)>-1){break e}i[114610]=0;C(1576,a|0,c+30|0)|0;d=i[114610];i[114610]=0;if((d|0)!=1){break e}break c}g[c+29|0]=0;Tg(c+16|0);f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{e=e&127;e=(e?e+ -1|0:0)&65535;n=e>>>0>=h>>>0;A:{B:{if(!n){i[114610]=0;k=I(471,b|0,l|0,e|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break c}if(g[c+30|0]&1){break B}break y}k=c+16|0;d=j[c+30|0];if(!(d&1)){break A}}i[114610]=0;C(1576,a|0,c+29|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break c}if(e>>>0<h>>>0){break z}d=j[c+30|0]}if(d&2){break x}break w}d=j[c+29|0];o=uc(f,e),p=d,g[o|0]=p}o=k,p=j[uc(f,e)|0],g[o|0]=p;if(!(j[c+30|0]&2)){break u}}i[114610]=0;C(1576,a|0,c+29|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break c}if(e>>>0<h>>>0){break v}d=j[c+30|0]}if(d&4){break t}break s}d=j[c+29|0];o=uc(f,e),p=d,g[o+1|0]=p}o=k,p=j[uc(f,e)+1|0],g[o+1|0]=p;if(!(j[c+30|0]&4)){break q}}i[114610]=0;C(1576,a|0,c+29|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break c}if(e>>>0<h>>>0){break r}d=j[c+30|0]}if(d&8){break p}break o}d=j[c+29|0];o=uc(f,e),p=d,g[o+2|0]=p}o=k,p=j[uc(f,e)+2|0],g[o+2|0]=p;if(!(j[c+30|0]&8)){break m}}i[114610]=0;C(1576,a|0,c+29|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break c}if(e>>>0<h>>>0){break n}d=j[c+30|0]}if(d&16){break l}break k}d=j[c+29|0];o=uc(f,e),p=d,g[o+4|0]=p}o=k,p=j[uc(f,e)+4|0],g[o+4|0]=p;if(!(j[c+30|0]&16)){break i}}i[114610]=0;C(1576,a|0,c+29|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break c}if(e>>>0<h>>>0){break j}d=j[c+30|0]}if(d&32){break h}break f}d=j[c+29|0];o=uc(f,e),p=d,g[o+3|0]=p}o=k,p=j[uc(f,e)+3|0],g[o+3|0]=p;if(!(j[c+30|0]&32)){break g}}i[114610]=0;C(1576,a|0,c+29|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break c}if(n){break f}d=j[c+29|0];o=uc(f,e),p=d,g[o+5|0]=p}o=k,p=j[uc(f,e)+5|0],g[o+5|0]=p}if(!(j[c+30|0]&64)){break b}i[114610]=0;C(1576,a|0,c+15|0)|0;e=i[114610];i[114610]=0;if((e|0)!=1){e=j[c+15|0];i[114610]=0;I(1577,a|0,e|0,-1)|0;e=i[114610];i[114610]=0;if((e|0)!=1){break b}}}}a=B()|0;A()|0;kl(f);E(a|0);x()}if(l>>>0<m>>>0){continue}break}}kl(f)}Xa=c+48|0}function JE(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;g=Xa-48|0;Xa=g;gNa(+a);f=dNa(1)|0;d=dNa(0)|0;a:{b:{e=f;f=e;h=e&2147483647;c:{if(h>>>0<=1074752122){if((f&1048575)==598523){break c}if(h>>>0<=1073928572){if((e|0)>0?1:(e|0)>=0?d>>>0>=0:0){a=a+ -1.5707963267341256;c=a+ -6.077100506506192e-11;n[b>>3]=c;n[b+8>>3]=a-c+ -6.077100506506192e-11;d=1;break a}a=a+1.5707963267341256;c=a+6.077100506506192e-11;n[b>>3]=c;n[b+8>>3]=a-c+6.077100506506192e-11;d=-1;break a}if((e|0)>0?1:(e|0)>=0?d>>>0>=0:0){a=a+ -3.1415926534682512;c=a+ -1.2154201013012384e-10;n[b>>3]=c;n[b+8>>3]=a-c+ -1.2154201013012384e-10;d=2;break a}a=a+3.1415926534682512;c=a+1.2154201013012384e-10;n[b>>3]=c;n[b+8>>3]=a-c+1.2154201013012384e-10;d=-2;break a}if(h>>>0<=1075594811){if(h>>>0<=1075183036){if((h|0)==1074977148){break c}if((e|0)>0?1:(e|0)>=0?d>>>0>=0:0){a=a+ -4.712388980202377;c=a+ -1.8231301519518578e-10;n[b>>3]=c;n[b+8>>3]=a-c+ -1.8231301519518578e-10;d=3;break a}a=a+4.712388980202377;c=a+1.8231301519518578e-10;n[b>>3]=c;n[b+8>>3]=a-c+1.8231301519518578e-10;d=-3;break a}if((h|0)==1075388923){break c}if((e|0)>0?1:(e|0)>=0?d>>>0>=0:0){a=a+ -6.2831853069365025;c=a+ -2.430840202602477e-10;n[b>>3]=c;n[b+8>>3]=a-c+ -2.430840202602477e-10;d=4;break a}a=a+6.2831853069365025;c=a+2.430840202602477e-10;n[b>>3]=c;n[b+8>>3]=a-c+2.430840202602477e-10;d=-4;break a}if(h>>>0>1094263290){break b}}j=a*.6366197723675814+6755399441055744+ -6755399441055744;c=a+j*-1.5707963267341256;i=j*6.077100506506192e-11;a=c-i;n[b>>3]=a;gNa(+a);d=dNa(1)|0;dNa(0)|0;e=h>>>20|0;f=(e-(d>>>20&2047)|0)<17;if(q(j)<2147483648){d=~~j}else{d=-2147483648}d:{if(f){break d}i=c;a=j*6.077100506303966e-11;c=c-a;i=j*2.0222662487959506e-21-(i-c-a);a=c-i;n[b>>3]=a;f=e;gNa(+a);e=dNa(1)|0;dNa(0)|0;if((f-(e>>>20&2047)|0)<50){break d}i=c;a=j*2.0222662487111665e-21;c=c-a;i=j*8.4784276603689e-32-(i-c-a);a=c-i;n[b>>3]=a}n[b+8>>3]=c-a-i;break a}if(h>>>0>=2146435072){a=a-a;n[b>>3]=a;n[b+8>>3]=a;d=0;break a}eNa(0,d|0);eNa(1,e&1048575|1096810496);a=+fNa();d=0;f=1;while(1){k=(g+16|0)+(d<<3)|0;if(q(a)<2147483648){d=~~a}else{d=-2147483648}c=+(d|0);n[k>>3]=c;a=(a-c)*16777216;d=1;k=f&1;f=0;if(k){continue}break}n[g+32>>3]=a;e:{if(a!=0){d=2;break e}f=1;while(1){d=f;f=d+ -1|0;if(n[(g+16|0)+(d<<3)>>3]==0){continue}break}}d=KE(g+16|0,g,(h>>>20|0)+ -1046|0,d+1|0,1);a=n[g>>3];if((e|0)<-1?1:(e|0)<=-1){n[b>>3]=-a;n[b+8>>3]=-n[g+8>>3];d=0-d|0;break a}n[b>>3]=a;n[b+8>>3]=n[g+8>>3]}Xa=g+48|0;return d}function opa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,h=0,l=0,m=0,n=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0;f=Xa-32|0;Xa=f;v=a+4|0;u=i[v>>2];t=a+20|0;y=i[wc(t,b)+16>>2];a:{if(y+1>>>0<2){break a}l=(o(b,896)+u|0)+608|0;if(!nh(l)){if(!j[wc(t,b)+20|0]){break a}}m=o(b,896)+u|0;if(!i[m+712>>2]){break a}D=i[(i[m+696>>2]&2?m+692|0:m+684|0)>>2];h=i[m+688>>2];n=i[m+692>>2];kb(f+24|0,i[a>>2]+1074308|0,31);z=ib(f+24|0);A=m+1356|0;q=j[A|0];B=m+616|0;e=Pt(B,c);r=_a;s=r;i[f+24>>2]=e;i[f+28>>2]=r;if(j[m+696|0]&128){i[f+24>>2]=0-e;i[f+28>>2]=0-((0<e>>>0)+s|0)}r=n-h|0;E=r<<1;e=o(b,896)+u|0;C=e;F=e+1308|0;s=e+1480|0;G=(q&17)!=1;b:{while(1){c:{if(w>>>0<d>>>0){h=(j[A|0]&17)==1;break c}g[s|0]=j[s|0]&254;e=Qe(Fb(i[a>>2]+484344|0,k[i[v>>2]+60>>1]),i[i[v>>2]+48>>2],b);n=j[e+3|0];if(j[e+2|0]==11){rx(f+16|0,i[a>>2],e,0);q=Pb(f+16|0);zm(i[a>>2],l,i[f+16>>2]);h=1;if(j[q|0]){break c}}h=1;d:{switch(n+ -4|0){case 0:zm(i[a>>2],l,j[e+5|0]);break c;case 2:break d;default:break c}}zm(i[a>>2],l,0)}i[f+12>>2]=i[F>>2];if(z){Cr(i[a>>2],l)}if(!G){mJ(i[a>>2],l,f+12|0);h=1}if(!z){Cr(i[a>>2],l)}i[f+8>>2]=0;oJ(l,f+8|0);e:{if(!h){if(!j[wc(t,b)+20|0]){break e}}if(j[s|0]&12){vM(l,p(1),0,i[a>>2]);e=j[s|0];g[s|0]=(e&8?-9:-5)&e}I=C,J=Uw(i[a>>2],l,i[f+12>>2],0),i[I+616>>2]=J;i[C+620>>2]=_a;I=wc(t,b),J=0,g[I+20|0]=J;e=Pt(B,c);h=_a;n=h;i[f+24>>2]=e;i[f+28>>2]=h;if(!(j[m+696|0]&128)){break e}i[f+24>>2]=0-e;i[f+28>>2]=0-((0<e>>>0)+n|0)}zb(l,f+24|0);e=i[l+4>>2];n=e;q=i[l>>2];f:{h=e;g:{if(D>>>0>e>>>0){break g}e=i[m+696>>2];if(!(e&2)){break f}if(e&4){H=q>>>0<0;x=i[m+688>>2];q=x;e=q;if((n|0)<(e|0)?1:(n|0)<=(e|0)?H:0){i[f+16>>2]=0;i[f+20>>2]=q<<1;I=l,J=Mf(f+16|0,l),i[I>>2]=J;i[l+4>>2]=_a;i[m+696>>2]=i[m+696>>2]^128;e=i[f+24>>2];h=0-(i[f+28>>2]+(0<e>>>0)|0)|0;i[f+24>>2]=0-e;i[f+28>>2]=h;x=i[m+688>>2];h=i[l+4>>2]}kb(f+16|0,i[a>>2]+1074308|0,33);e=(h-x>>>0)%(E-ib(f+16|0)>>>0)|0;n=r>>>0>e>>>0;h:{if(!n){i[l+4>>2]=i[m+692>>2]+(r-e|0);h=i[m+696>>2];if(!(n^(h&128)>>>7)){break h}break g}i[l+4>>2]=e+i[m+688>>2];h=i[m+696>>2];if(n^(h&128)>>>7){break g}}i[m+696>>2]=h^128;e=i[f+24>>2];h=0-(i[f+28>>2]+(0<e>>>0)|0)|0;i[f+24>>2]=0-e;i[f+28>>2]=h;break g}n=i[m+692>>2];if(n+r>>>0<=h>>>0){h=n+((h-n>>>0)%(r>>>0)|0)|0}while(1){e=h;h=e-r|0;if(e>>>0>=n>>>0){continue}break}i[l>>2]=q;i[l+4>>2]=e}w=w+1|0;if((y|0)!=(w|0)){continue}break b}break}xM(l);i[(o(b,896)+u|0)+1316>>2]=0}I=wc(t,b),J=0,i[I+16>>2]=J}Xa=f+32|0}function xBa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,k=0,l=0,m=0,n=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;e=Xa-560|0;Xa=e;a:{if(!vc(b,1464)){break a}if(!$m(b,e+556|0)){break a}md(a,1);d=a+1074308|0;ng(d,83);tb(d,84,1);tb(d,85,1);b:{if(Hd(e+556|0,16010)){d=Bb(e+32|0,16020);mb(a+1304436|0,d);eb(d);d=Bb(e+32|0,16043);mb(a+1304448|0,d);eb(d);d=Bb(e+32|0,16048);mb(a+1304460|0,d);break b}if(!Hd(e+556|0,16015)){break a}d=Bb(e+32|0,16065);mb(a+1304436|0,d);eb(d);d=Bb(e+32|0,16077);mb(a+1304448|0,d);eb(d);d=Bb(e+32|0,16081);mb(a+1304460|0,d)}eb(d);i[a+1304496>>2]=2;d=0;vc(b,0);Mz(b,a+1304400|0,20);h[a+480190>>1]=31;f=1;while(1){d=wy(b,e+32|0,(o(f,104)+a|0)+484380|0,((f<<5)+a|0)+946300|0,1)+d|0;f=f+1|0;if((f|0)!=32){continue}break}if(d>>>0>40){break a}rt(e+552|0,b);r=Nc(e+552|0);m=e+552|0;if(j[m|0]>128){break a}wBa(b,e+32|0);d=e+544|0;f=e+32|0;k=j[r|0];c:{while(1){if(j[f|0]<=k>>>0){f=f+1|0;if((d|0)!=(f|0)){continue}break c}break}break a}t=1;if(!c){break a}i[a+480260>>2]=56;i[a+480264>>2]=13696;i[a+480204>>2]=125e4;i[a+480196>>2]=6;h[a+480192>>1]=0;h[a+480188>>1]=4;i[a+480228>>2]=64;i[a+480208>>2]=i[a+480208>>2]|2097152;Ni(a,0);s=a+484360|0;Zf(Db(s),j[m|0]);h[e+30>>1]=0;n=a+484344|0;Gf(n,j[m|0]);if(j[m|0]){k=0;while(1){x=$b(Db(s),k),y=k,h[x>>1]=y;if(Sf(n,k&65535,64)){u=k<<2;l=0;while(1){vc(b,(j[e+32+(l+u)|0]<<8)+1468|0);f=Qe(Fb(n,k),0,l&65535);d=0;while(1){Bs(b,f);d:{e:{q=j[f+3|0];f:{if((q|0)!=14){if(!q){if(j[f+5|0]){break e}break f}if((q+ -5&255)>>>0<5){break f}break e}if(j[f+5|0]<=15){break e}}g[f+3|0]=0;break d}Xi(f)}f=f+24|0;d=d+1|0;if((d|0)!=64){continue}break}l=l+1|0;if((l|0)!=4){continue}break}x=e,y=Jb(Fb(n,k)),i[x+24>>2]=y;l=0;while(1){d=0;while(1){f=d;g:{if(j[i[e+24>>2]+3|0]!=17?j[i[e+24>>2]+3|0]!=16:0){break g}g[i[e+24>>2]+3|0]=16;p=0;if(j[i[e+24>>2]+5|0]<16){break g}if(!(!(j[i[e+24>>2]+5|0]&15)|(j[i[e+24>>2]+5|0]&15)==(j[i[e+24>>2]+5|0]>>>4|0))){v=j[i[e+24>>2]+5|0]>>>4|0;w=j[i[e+24>>2]+5|0]&15;p=1}d=i[e+24>>2];g[d+5|0]=j[d+5|0]>>>4}jk(e+24|0);d=f+1|0;if((f&65535)>>>0<3){continue}break}g[e+31|0]=w;g[e+30|0]=v;d=p&255;f=0;h:{if(!d){break h}Vk(Fb(n,k),Ee(yp(e+8|0,16,j[(e+d|0)+29|0]),l));d=p+1|0;f=(d&255)==3?1:d}p=f;l=l+1|0;if((l|0)!=64){continue}break}}k=k+1|0;if(k>>>0<j[m|0]){continue}break}}if(!(c&2)){break a}vc(b,(j[r|0]<<8)+1468|0);f=1;while(1){c=(o(f,104)+a|0)+484380|0;if(i[c>>2]){Xf(Ic(e+8|0,8,1,0,0),c,b)}f=f+1|0;if((f|0)!=32){continue}break}}Xa=e+560|0;return t|0}function Xwa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,m=0,n=0,p=0,q=0,r=0;e=Xa+ -64|0;Xa=e;a:{if(!wb(c,8)){break a}Ib(c,4);while(1){f=Ms(c);if(f){break a}if(jsa(c)){continue}break}}g[d|0]=j[d|0]!=0|f;pc(c);b:{c:{d:{e:{if(f){d=Cf(c);ad(e+48|0,c,cf(c));h[a+34>>1]=k[a+34>>1]&65534|j[b|0]>15;b=k[a+34>>1]&-65|(j[b+1|0]!=1)<<6;h[a+34>>1]=b;i[a>>2]=d>>>(b&1)>>>(b>>>6&1);i[114610]=0;i[e+44>>2]=0;i[e+40>>2]=0;D(862,e+16|0,e+48|0);b=i[114610];i[114610]=0;if((b|0)==1){break d}i[114610]=0;c=F(412,e+16|0)|0;b=i[114610];i[114610]=0;if((b|0)!=1){d=i[e+16>>2];i[114610]=0;b=F(859,c|0)|0;f=i[114610];i[114610]=0;if((f|0)==1){break c}i[114610]=0;f=F(860,d|0)|0;n=i[114610];i[114610]=0;if((n|0)==1){break c}i[114610]=0;b=S(861,b|0,f|0,e+44|0,e+40|0,0)|0;f=i[114610];i[114610]=0;if((f|0)==1){break c}i[114610]=0;C(338,e+48|0,i[e+44>>2])|0;f=i[114610];i[114610]=0;if((f|0)==1){break c}f:{if(!b){break f}n=i[e+44>>2];i[114610]=0;F(465,a|0)|0;f=i[114610];i[114610]=0;if((f|0)==1){break c}f=d-n|0;n=c+n|0;c=i[e+40>>2];d=0;while(1){g:{if(d>>>0>=l[a>>2]|(!f|(c|0)!=1?c:0)){break g}if(!ie(a)){break g}i[114610]=0;i[e+12>>2]=0;i[e+8>>2]=0;c=F(859,n|0)|0;p=i[114610];i[114610]=0;if((p|0)==1){break c}i[114610]=0;p=F(860,f|0)|0;m=i[114610];i[114610]=0;if((m|0)==1){break c}i[114610]=0;c=Y(863,b|0,c|0,p|0,e+12|0,e+4|0,e+8|0)|0;p=i[114610];i[114610]=0;if((p|0)==1){break c}i[114610]=0;i[e+44>>2]=c;C(338,e+48|0,c|0)|0;c=i[114610];i[114610]=0;if((c|0)==1){break c}c=i[a>>2];i[114610]=0;p=i[e+44>>2];c=F(864,c-d|0)|0;m=i[114610];i[114610]=0;if((m|0)==1){break c}Xj(e+8|0,c);h:{if(i[e+8>>2]<1){break h}if(i[e+12>>2]!=($d(a)|0)){break h}c=0;if(i[e+12>>2]<=0){break h}while(1){i:{if(g[a+34|0]&1){m=i[a+20>>2];q=$d(a);r=i[i[e+4>>2]+(c<<2)>>2];i[114610]=0;T(865,m+(o(d,q)<<1)|0,r|0,i[e+12>>2],i[e+8>>2],c|0);m=i[114610];i[114610]=0;if((m|0)!=1){break i}break c}m=i[a+20>>2];q=$d(a);r=i[i[e+4>>2]+(c<<2)>>2];i[114610]=0;T(866,m+o(d,q)|0,r|0,i[e+12>>2],i[e+8>>2],c|0);m=i[114610];i[114610]=0;if((m|0)==1){break c}}c=c+1|0;if((c|0)<i[e+12>>2]){continue}break}}i[114610]=0;m=i[e+8>>2];c=F(867,b|0)|0;q=i[114610];i[114610]=0;if((q|0)==1){break c}f=f-p|0;n=n+p|0;i[e+40>>2]=c;d=d+m|0;continue}break}i[114610]=0;L(868,b|0);a=i[114610];i[114610]=0;if((a|0)!=1){break f}break c}jc(e+16|0);hb(e+48|0);a=(b|0)!=0;break e}break c}Xf(b,a,c);a=1}Xa=e- -64|0;return a|0}c=B()|0;A()|0;break b}c=B()|0;A()|0;jc(e+16|0)}hb(e+48|0);E(c|0);x()}function mxa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,l=0,m=0,n=0,p=0,q=0,r=0,s=0,t=0,u=0;d=Xa-208|0;Xa=d;pc(b);a:{if(!gz(b,d+160|0)){break a}if(!VM(d+160|0)){break a}if(!c){f=1;break a}if(!wb(b,Vc(UM(d+160|0),_a))){break a}md(a,128);rg(d+144|0,2,d+175|0);oc(d+72|0,d+144|0);mb(a+1304400|0,d+72|0);eb(d+72|0);f=Bb(d+72|0,17457);mb(a+1304436|0,f);eb(f);f=Bb(d+72|0,17470);mb(a+1304448|0,f);eb(f);e=Bb(d+144|0,17474);i[114610]=0;G(1028,d+72|0,e|0,i[(j[d+174|0]<<2)+77292>>2]);f=i[114610];i[114610]=0;b:{if((f|0)!=1){mb(a+1304460|0,d+72|0);eb(d+72|0);eb(e);i[a+480208>>2]=12;i[a+1304496>>2]=4;Rx(a+1304424|0,b,j[d+207|0]<<5,32,0);t=a,u=id(b),h[t+480190>>1]=u;c:{if(k[a+480190>>1]){m=d+136|0;l=d+134|0;f=1;e=1;while(1){d:{if(j[d+174|0]>=52){xz(b,d+72|0);break d}hxa(b,d+72|0);n=j[l|0]|j[l+1|0]<<8;g[m|0]=n;g[m+1|0]=n>>>8;g[l|0]=8363;g[l+1|0]=32}lxa(d+72|0,(o(f,104)+a|0)+484380|0);rg(d+56|0,2,d+72|0);oc(d+144|0,d+56|0);i[114610]=0;C(369,((f<<5)+a|0)+946300|0,d+144|0)|0;f=i[114610];i[114610]=0;if((f|0)==1){break c}eb(d+144|0);e=e+1|0;f=e&65535;if(f>>>0<=k[a+480190>>1]){continue}break}}hp(Db(a+484360|0),b,256,255,254);f=0;e=id(b);if(e>>>0>=127){break a}h[a+480188>>1]=e+1;m=id(b);r=m+1|0;if(k[a+480188>>1]){while(1){e=(f<<5)+a|0;sg(e+480280|0);e=e+480284|0;e:{if(j[d+174|0]>=51){q=(id(b)<<4|8)&248;break e}q=f&1?192:64}h[e>>1]=q;f=f+1|0;if(f>>>0<k[a+480188>>1]){continue}break}}l=a+484344|0;Gf(l,r);f=0;e=0;while(1){n=e&65535;if(!Sf(l,n,64)){break a}e=e+1|0;if(n>>>0<m>>>0){continue}break}if(k[a+480188>>1]){m=0;while(1){s=aj(d+72|0);n=0;while(1){if(wb(b,5)){e=0;f=Qe(Fb(l,n),0,m&65535);while(1){p=kxa(s,b,j[d+174|0]);q=p+e|0;e=q>>>0>64?64-e|0:p;if(e){while(1){p=i[d+72>>2];g[f|0]=p;g[f+1|0]=p>>>8;g[f+2|0]=p>>>16;g[f+3|0]=p>>>24;p=k[d+76>>1];g[f+4|0]=p;g[f+5|0]=p>>>8;f=o(k[a+480188>>1],6)+f|0;e=e+ -1|0;if(e){continue}break}e=q;q=q>>>0<64;e=q?e:64;if(q){continue}}break}n=n+1|0;if((r|0)!=(n|0)){continue}}break}m=m+1|0;if((m&65535)>>>0<k[a+480188>>1]){continue}break}}e=jxa(d+8|0,k[a+480188>>1]);i[114610]=0;G(1029,d+32|0,l|0,e|0);l=i[114610];i[114610]=0;f=1;if((l|0)!=1){Td(d+32|0);Td(e);if(!(c&2)|!k[a+480190>>1]){break a}e=1;while(1){c=o(e&65535,104)+a|0;Xf(Ic(d+72|0,h[c+484414>>1]&1?16:8,1,0,0),c+484380|0,b);e=e+1|0;if((e&65535)>>>0<=k[a+480190>>1]){continue}break}break a}f=B()|0;A()|0;Td(e);break b}f=B()|0;A()|0;eb(d+144|0);break b}f=B()|0;A()|0;eb(e)}E(f|0);x()}Xa=d+208|0;return f|0}function qDa(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,h=0,i=0,k=0;f=Xa-16|0;Xa=f;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{h=j[a+3|0];switch(h+ -4|0){case 22:break j;case 21:break k;case 20:break l;case 18:break m;case 17:break n;case 16:break o;case 14:break p;case 13:break q;case 11:break r;case 10:break s;case 9:break t;case 8:break u;case 5:break v;case 4:break w;case 0:break x;case 42:break c;case 37:break d;case 28:break e;case 27:break f;case 26:break g;case 25:break h;case 23:break i;default:break b}}g[a+3|0]=5;g[f+15|0]=j[a+5|0]>>>3;g[f+14|0]=15;b=j[Xb(f+15|0,f+14|0)|0];g[f+13|0]=j[a+5|0]<<1&30;g[f+12|0]=15;i=a,k=j[Xb(f+13|0,f+12|0)|0]|b<<4,g[i+5|0]=k;break a}g[a+3|0]=0;break a}if((j[a+5|0]+ -1&255)>>>0<=19){g[a+3|0]=16;break a}g[a+3|0]=0;break a}g[a+3|0]=13;b=j[a+5|0];y:{if(!e){if(b>>>0>152){break y}g[a+5|0]=o((b&240)>>>4|0,10)+(b&15);break a}g[a+5|0]=(b&127)+1>>>1;break a}g[a+3|0]=0;break a}g[a+3|0]=11;break a}g[a+3|0]=0;break a}e=j[a+5|0];if(!e){g[a+3|0]=14;break a}if(e>>>0<=240){g[a+3|0]=17;i=a,k=Gs(+(mP(e,b,c,d)>>>0)*1e-4),g[i+5|0]=k;break a}g[a+3|0]=0;break a}g[a+3|0]=19;g[f+11|0]=15;i=a,k=j[Xb(a+5|0,f+11|0)|0]|16,g[i+5|0]=k;break a}g[a+3|0]=19;g[f+10|0]=15;i=a,k=j[Xb(a+5|0,f+10|0)|0]|32,g[i+5|0]=k;break a}g[a+3|0]=5;g[f+9|0]=(j[a+5|0]>>>4|0)+1;g[f+8|0]=15;b=Xb(f+9|0,f+8|0);g[a+5|0]=j[a+5|0]&15|j[b|0]<<4;break a}g[a+3|0]=19;g[a+5|0]=j[a+5|0]&15|80;break a}g[a+3|0]=19;g[f+7|0]=15;i=a,k=j[Xb(a+5|0,f+7|0)|0]|96,g[i+5|0]=k;break a}g[a+3|0]=19;g[f+6|0]=15;i=a,k=j[Xb(a+5|0,f+6|0)|0]|192,g[i+5|0]=k;break a}g[a+3|0]=10;break a}g[a+3|0]=19;g[f+5|0]=15;i=a,k=j[Xb(a+5|0,f+5|0)|0]|160,g[i+5|0]=k;break a}g[a+3|0]=19;g[f+4|0]=15;i=a,k=j[Xb(a+5|0,f+4|0)|0]|176,g[i+5|0]=k;break a}g[a+3|0]=14;break a}g[a+3|0]=19;g[f+3|0]=15;i=a,k=j[Xb(a+5|0,f+3|0)|0]|224,g[i+5|0]=k;break a}b=j[a+5|0];if(b&240){g[a+3|0]=19;g[a+5|0]=b>>>4|208;break a}if(b&15){g[a+3|0]=19;g[a+5|0]=b|144;break a}g[a+3|0]=0;break a}if(!(j[a+5|0]|j[a+4|0])){g[a+5|0]=159;g[a+3|0]=20;break a}g[a+3|0]=0;break a}b=j[a+4|0];if(b){g[a+3|0]=41;i=a,k=Vm(Vc(((j[a+5|0]<<8&65280)>>>0)/(b>>>0)|0,0)),g[i+5|0]=k;break a}g[a+3|0]=0;break a}b=j[a+5|0];if((b+ -17&255)>>>0>=223){g[a+3|0]=9;i=a,k=_i(((b^128)<<3)+ -896|0),g[i+5|0]=k;break a}g[a+3|0]=0;break a}if(h>>>0<=15){Xi(a);break a}g[a+3|0]=0}Xa=f+16|0}function qma(a,b,c,d,e){var f=0,h=0,k=0,l=0,n=0,q=0,r=0,s=0;q=Xa-16|0;Xa=q;h=i[b+104>>2];a:{if(!h|!j[h+40|0]){break a}s=Vi(b);f=wo(a);kb(q+8|0,a+1074308|0,21);n=f?26320:25296;r=f?25296:26320;if(!(!ib(q+8|0)|s|i[a+480180>>2]==1048576)){if(!j[h+41|0]){break a}l=j[b+838|0];i[q+4>>2]=i[b+780>>2]+j[h+39|0];Xj(q+4|0,j[h+40|0]<<8);d=i[q+4>>2];i[b+780>>2]=d;d=(d|0)/256|0;i[q+4>>2]=d;g[b+838|0]=j[b+838|0]+j[h+41|0];b:{c:{switch(j[h+38|0]+ -1|0){case 3:b=iJ(Am(a))+ -64|0;d=i[q+4>>2];break b;case 2:b=64-(l+1>>>1|0)|0;break b;case 1:b=(l+1>>>1|0)+ -64|0;break b;case 0:b=(l>>>1^-1)&64;break b;default:break c}}b=g[l+21600|0]}Xj(c,8388607);a=i[c>>2]<<8;i[c>>2]=a;l=o(b,d);d=(l|0)/64|0;b=d>>31;h=b^b+d;d=h>>>2|0;b=c;d:{if((l|0)<=-64){d=i[(d<<2)+n>>2];d=gc(YMa(XMa(d,d>>31,a,a>>31),_a,65536,0),_a);a=i[c>>2];n=d-a|0;d=n;r=h&3;if(!r){break d}d=i[(r<<2)+(f?25232:25168)>>2];d=gc(YMa(XMa(d,d>>31,a,a>>31),_a,65536,0),_a)+n|0;a=i[c>>2];d=d-a|0;break d}d=i[(d<<2)+r>>2];d=gc(YMa(XMa(d,d>>31,a,a>>31),_a,65536,0),_a);a=i[c>>2];n=d-a|0;d=n;r=h&3;if(!r){break d}d=i[(r<<2)+(f?25168:25232)>>2];d=gc(YMa(XMa(d,d>>31,a,a>>31),_a,65536,0),_a)+n|0;a=i[c>>2];d=d-a|0}i[b>>2]=(a+d|0)/256;i[e>>2]=d&255;break a}e:{if(!(j[h+39|0]|i[a+480180>>2]&16777248)){i[b+780>>2]=j[h+40|0]<<8;break e}f:{g:{if(i[a+480180>>2]&16777248){l=i[b+780>>2];k=b+780|0;f=j[h+39|0]<<1;break g}if(j[b+89|0]&8){break f}l=((j[h+40|0]<<8&65280)>>>0)/j[h+39|0]|0;k=b+780|0;f=i[b+780>>2]}i[k>>2]=f+l}Xj(b+780|0,j[h+40|0]<<8)}f=j[b+838|0]+j[h+41|0]|0;g[b+838|0]=f;f=f<<24>>24;h:{i:{switch(j[h+38|0]+ -1|0){case 3:g[b+838|0]=f+1;k=g[(f&63)+21536|0];break h;case 2:k=(64-(f>>>1|0)&127)+ -64|0;break h;case 1:k=((f>>>1|0)- -64&127)+ -64|0;break h;case 0:k=(f|0)>-1?-64:64;break h;default:break i}}f=j[b+838|0];k=0-g[f+21600|0]|0;if(i[a+480180>>2]!=1048576){break h}k=(64-g[(f+ -64&255)+21600|0]|0)/2<<16>>16}f=k;k=o(f,i[b+780>>2]);l=(k|0)/256|0;if(s){m[d>>2]=p(p(p(f|0)*p(1220703143189894e-20))*p(j[h+40|0]))+m[d>>2];g[b+872|0]=j[b+872|0]|8;break a}if(i[a+480180>>2]!=4){j:{if((k|0)<=-256){l=0-l|0;b=0-k>>>16|0;a=(b<<2)+n|0;break j}n=r;b=(k|0)/65536|0;a=n+(b<<2)|0}d=i[c>>2];a=i[a>>2];a=((o(i[((b<<2)+n|0)+4>>2]-a|0,(l|0)/4&63)|0)/64|0)+a|0;a=gc(YMa(XMa(d,d>>31,a,a>>31),_a,256,0),_a);i[c>>2]=a;i[e>>2]=a&255;i[c>>2]=i[c>>2]/256;break a}i[c>>2]=i[c>>2]+((k|0)/16384|0)}Xa=q+16|0}function Z0(a,b,c,d,e,f,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;h=h|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;n=Xa-16|0;Xa=n;p=ev(h);r=Lu(h);Pf(n,r);i[f>>2]=d;a:{b:{c:{l=a;h=j[l|0];switch(h+ -43|0){case 0:case 2:break c;default:break b}}i[114610]=0;h=C(2475,p|0,h<<24>>24)|0;l=i[114610];i[114610]=0;if((l|0)==1){break a}l=i[f>>2];i[f>>2]=l+4;i[l>>2]=h;l=a+1|0}d:{h=l;if(!((c-h|0)<=1|j[h|0]!=48|(j[h+1|0]|32)!=120)){i[114610]=0;h=C(2475,p|0,48)|0;k=i[114610];i[114610]=0;if((k|0)==1){break a}k=i[f>>2];i[f>>2]=k+4;i[k>>2]=h;h=g[l+1|0];i[114610]=0;h=C(2475,p|0,h|0)|0;k=i[114610];i[114610]=0;if((k|0)==1){break a}k=i[f>>2];i[f>>2]=k+4;i[k>>2]=h;l=l+2|0;h=l;while(1){if(h>>>0>=c>>>0){break d}k=g[h|0];i[114610]=0;m=R(2445)|0;o=i[114610];i[114610]=0;e:{if((o|0)==1){break e}i[114610]=0;k=Vu(k,m);m=i[114610];i[114610]=0;if((m|0)==1){break e}if(!k){break d}h=h+1|0;continue}break}break a}while(1){if(h>>>0>=c>>>0){break d}k=g[h|0];i[114610]=0;R(2445)|0;m=i[114610];i[114610]=0;if((m|0)==1){break a}i[114610]=0;k=Hg(k);m=i[114610];i[114610]=0;if((m|0)==1){break a}if(!k){break d}h=h+1|0;continue}}f:{if(Cc(n)){k=i[f>>2];i[114610]=0;N(2463,p|0,l|0,h|0,k|0)|0;k=i[114610];i[114610]=0;if((k|0)==1){break a}i[f>>2]=i[f>>2]+(h-l<<2);break f}o=0;i[114610]=0;sj(l,h);k=i[114610];i[114610]=0;if((k|0)==1){break a}i[114610]=0;t=F(2460,r|0)|0;k=i[114610];i[114610]=0;if((k|0)==1){break a}m=0;k=l;while(1){if(k>>>0>=h>>>0){k=i[f>>2];i[114610]=0;On((l-a<<2)+d|0,k);l=i[114610];i[114610]=0;if((l|0)!=1){break f}break a}g:{if(g[Sb(n,m)|0]<1){break g}if(g[Sb(n,m)|0]!=(o|0)){break g}o=i[f>>2];i[f>>2]=o+4;i[o>>2]=t;m=(m>>>0<lb(n)+ -1>>>0)+m|0;o=0}s=g[k|0];i[114610]=0;s=C(2475,p|0,s|0)|0;q=i[114610];i[114610]=0;if((q|0)!=1){q=i[f>>2];i[f>>2]=q+4;i[q>>2]=s;k=k+1|0;o=o+1|0;continue}break}break a}h:{while(1){if(h>>>0<c>>>0){l=j[h|0];if((l|0)==46){i[114610]=0;l=F(2464,r|0)|0;k=i[114610];i[114610]=0;if((k|0)==1){break a}m=i[f>>2];k=m+4|0;i[f>>2]=k;i[m>>2]=l;h=h+1|0;break h}i[114610]=0;l=C(2475,p|0,l<<24>>24)|0;k=i[114610];i[114610]=0;if((k|0)==1){break a}k=i[f>>2];i[f>>2]=k+4;i[k>>2]=l;h=h+1|0;continue}break}k=i[f>>2]}i[114610]=0;N(2463,p|0,h|0,c|0,k|0)|0;l=i[114610];i[114610]=0;if((l|0)==1){break a}l=f;f=i[f>>2]+(c-h<<2)|0;i[l>>2]=f;i[e>>2]=(b|0)==(c|0)?f:(b-a<<2)+d|0;eb(n);Xa=n+16|0;return}a=B()|0;A()|0;eb(n);E(a|0);x()}function i1(a,b,c,d,e,f,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;h=h|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;n=Xa-16|0;Xa=n;p=Ot(h);r=Ou(h);Pf(n,r);i[f>>2]=d;a:{b:{c:{l=a;h=j[l|0];switch(h+ -43|0){case 0:case 2:break c;default:break b}}i[114610]=0;h=C(22,p|0,h<<24>>24)|0;l=i[114610];i[114610]=0;if((l|0)==1){break a}l=i[f>>2];i[f>>2]=l+1;g[l|0]=h;l=a+1|0}d:{h=l;if(!((c-h|0)<=1|j[h|0]!=48|(j[h+1|0]|32)!=120)){i[114610]=0;h=C(22,p|0,48)|0;k=i[114610];i[114610]=0;if((k|0)==1){break a}k=i[f>>2];i[f>>2]=k+1;g[k|0]=h;h=g[l+1|0];i[114610]=0;h=C(22,p|0,h|0)|0;k=i[114610];i[114610]=0;if((k|0)==1){break a}k=i[f>>2];i[f>>2]=k+1;g[k|0]=h;l=l+2|0;h=l;while(1){if(h>>>0>=c>>>0){break d}k=g[h|0];i[114610]=0;m=R(2445)|0;o=i[114610];i[114610]=0;e:{if((o|0)==1){break e}i[114610]=0;k=Vu(k,m);m=i[114610];i[114610]=0;if((m|0)==1){break e}if(!k){break d}h=h+1|0;continue}break}break a}while(1){if(h>>>0>=c>>>0){break d}k=g[h|0];i[114610]=0;R(2445)|0;m=i[114610];i[114610]=0;if((m|0)==1){break a}i[114610]=0;k=Hg(k);m=i[114610];i[114610]=0;if((m|0)==1){break a}if(!k){break d}h=h+1|0;continue}}f:{if(Cc(n)){k=i[f>>2];i[114610]=0;N(2440,p|0,l|0,h|0,k|0)|0;k=i[114610];i[114610]=0;if((k|0)==1){break a}i[f>>2]=i[f>>2]+(h-l|0);break f}o=0;i[114610]=0;sj(l,h);k=i[114610];i[114610]=0;if((k|0)==1){break a}i[114610]=0;t=F(2431,r|0)|0;k=i[114610];i[114610]=0;if((k|0)==1){break a}m=0;k=l;while(1){if(k>>>0>=h>>>0){k=i[f>>2];i[114610]=0;sj((l-a|0)+d|0,k);l=i[114610];i[114610]=0;if((l|0)!=1){break f}break a}g:{if(g[Sb(n,m)|0]<1){break g}if(g[Sb(n,m)|0]!=(o|0)){break g}o=i[f>>2];i[f>>2]=o+1;g[o|0]=t;m=(m>>>0<lb(n)+ -1>>>0)+m|0;o=0}s=g[k|0];i[114610]=0;s=C(22,p|0,s|0)|0;q=i[114610];i[114610]=0;if((q|0)!=1){q=i[f>>2];i[f>>2]=q+1;g[q|0]=s;k=k+1|0;o=o+1|0;continue}break}break a}while(1){h:{if(h>>>0<c>>>0){l=j[h|0];if((l|0)!=46){break h}i[114610]=0;l=F(2441,r|0)|0;k=i[114610];i[114610]=0;if((k|0)==1){break a}k=i[f>>2];i[f>>2]=k+1;g[k|0]=l;h=h+1|0}l=i[f>>2];i[114610]=0;N(2440,p|0,h|0,c|0,l|0)|0;l=i[114610];i[114610]=0;if((l|0)==1){break a}l=f;f=i[f>>2]+(c-h|0)|0;i[l>>2]=f;i[e>>2]=(b|0)==(c|0)?f:(b-a|0)+d|0;eb(n);Xa=n+16|0;return}i[114610]=0;l=C(22,p|0,l<<24>>24)|0;k=i[114610];i[114610]=0;if((k|0)==1){break a}k=i[f>>2];i[f>>2]=k+1;g[k|0]=l;h=h+1|0;continue}}a=B()|0;A()|0;eb(n);E(a|0);x()}function R8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=Xa-160|0;Xa=d;a:{if(Oi(b)){break a}f=j[Dj(b)|0];e=1;b:{if((f|0)==33){break b}if((f|0)!=63){break a}e=0}c=e;Oj(d+128|0,b,i[b+4>>2]+ -1|0);e=i[d+132>>2];i[b>>2]=i[d+128>>2];i[b+4>>2]=e}jd(d+128|0);e=i[d+128>>2];jd(d+112|0);e=Cj(e,i[d+116>>2],b);jd(d+128|0);c:{d:{e:{f:{if((e|0)==i[d+132>>2]){a=i[b+4>>2];i[d+152>>2]=i[b>>2];i[d+156>>2]=a;a=Zb(d+144|0,38187);e=i[d+156>>2];i[d+8>>2]=i[d+152>>2];i[d+12>>2]=e;e=i[a+4>>2];i[d>>2]=i[a>>2];i[d+4>>2]=e;if(mc(d+8|0,d)){a=P(8)|0;i[114610]=0;c=C(85,d+128|0,39121)|0;b=i[114610];i[114610]=0;if((b|0)==1){break e}Ub(a,c);i[114610]=0;G(2009,a|0,83568,2017);a=i[114610];i[114610]=0;if((a|0)!=1){break c}b=B()|0;A()|0;eb(c);break d}e=0;f=0;if(!c){break f}a=P(8)|0;i[114610]=0;e=C(2142,d+112|0,b|0)|0;b=i[114610];i[114610]=0;g:{h:{i:{if((b|0)!=1){i[114610]=0;G(2119,d+128|0,39131,e|0);b=i[114610];i[114610]=0;if((b|0)==1){break i}Ub(a,d+128|0);c=0;i[114610]=0;G(2009,a|0,83568,2017);b=i[114610];i[114610]=0;if((b|0)!=1){break c}b=B()|0;A()|0;eb(d+128|0);break h}b=B()|0;A()|0;break g}b=B()|0;c=1;A()|0}eb(e);if(!c){break d}}Q(a|0);break d}if(i[e+4>>2]!=1){a=P(8)|0;i[114610]=0;c=C(85,d+128|0,39145)|0;b=i[114610];i[114610]=0;if((b|0)!=1){Ub(a,c);i[114610]=0;G(2009,a|0,83568,2017);a=i[114610];i[114610]=0;if((a|0)!=1){break c}b=B()|0;A()|0;eb(c);break d}b=B()|0;A()|0;Q(a|0);break d}c=i[b+4>>2];i[d+104>>2]=i[b>>2];i[d+108>>2]=c;c=Zb(d+96|0,38187);e=i[d+108>>2];i[d+56>>2]=i[d+104>>2];i[d+60>>2]=e;e=i[c+4>>2];i[d+48>>2]=i[c>>2];i[d+52>>2]=e;if(mc(d+56|0,d+48|0)){a=P(8)|0;i[114610]=0;c=C(85,d+128|0,39121)|0;b=i[114610];i[114610]=0;if((b|0)!=1){Ub(a,c);i[114610]=0;G(2009,a|0,83568,2017);a=i[114610];i[114610]=0;if((a|0)!=1){break c}b=B()|0;A()|0;eb(c);break d}b=B()|0;A()|0;Q(a|0);break d}c=i[b+4>>2];i[d+88>>2]=i[b>>2];i[d+92>>2]=c;c=Zb(d+80|0,38966);e=i[d+92>>2];i[d+40>>2]=i[d+88>>2];i[d+44>>2]=e;e=i[c+4>>2];i[d+32>>2]=i[c>>2];i[d+36>>2]=e;if(mc(d+40|0,d+32|0)){a=i[a+8>>2];e=a;f=a>>31;break f}c=i[b+4>>2];i[d+72>>2]=i[b>>2];i[d+76>>2]=c;b=Zb(d- -64|0,39114);c=i[d+76>>2];i[d+24>>2]=i[d+72>>2];i[d+28>>2]=c;c=i[b+4>>2];i[d+16>>2]=i[b>>2];i[d+20>>2]=c;e=0;f=0;if(!mc(d+24|0,d+16|0)){break f}a=i[i[a+32>>2]+40>>2];e=a;f=a>>31}Xa=d+160|0;_a=f;return e|0}b=B()|0;A()|0;Q(a|0)}E(b|0)}x()}function Pba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a=Ab(a);i[114610]=0;K(81);c=i[114610];i[114610]=0;a:{b:{if((c|0)==1){c=Na(83568,71348,71324,0)|0;d=A()|0;c:{d:{e:{if((U(83568)|0)==(d|0)){c=M(c|0)|0;i[114610]=0;C(1995,a|0,b|0)|0;b=i[114610];i[114610]=0;if((b|0)==1){break e}i[114610]=0;C(1995,a|0,37606)|0;b=i[114610];i[114610]=0;if((b|0)==1){break e}i[114610]=0;C(1995,a|0,37665)|0;b=i[114610];i[114610]=0;if((b|0)==1){break e}b=$a[i[i[c>>2]+8>>2]](c)|0;i[114610]=0;C(1995,a|0,(b?b:34133)|0)|0;b=i[114610];i[114610]=0;if((b|0)==1){break e}i[114610]=0;K(20);b=i[114610];i[114610]=0;if((b|0)!=1){break b}b=B()|0;A()|0;break a}f:{if((U(71348)|0)==(d|0)){c=M(c|0)|0;i[114610]=0;C(1995,a|0,b|0)|0;b=i[114610];i[114610]=0;if((b|0)==1){break f}i[114610]=0;C(1995,a|0,37606)|0;b=i[114610];i[114610]=0;if((b|0)==1){break f}i[114610]=0;C(1995,a|0,37649)|0;b=i[114610];i[114610]=0;if((b|0)==1){break f}b=$a[i[i[c>>2]+8>>2]](c)|0;i[114610]=0;C(1995,a|0,(b?b:34133)|0)|0;b=i[114610];i[114610]=0;if((b|0)==1){break f}i[114610]=0;K(20);b=i[114610];i[114610]=0;if((b|0)!=1){break b}b=B()|0;A()|0;break a}e=U(71324)|0;c=M(c|0)|0;g:{if((d|0)==(e|0)){i[114610]=0;C(1995,a|0,b|0)|0;b=i[114610];i[114610]=0;if((b|0)==1){break g}i[114610]=0;C(1995,a|0,37606)|0;b=i[114610];i[114610]=0;if((b|0)==1){break g}i[114610]=0;C(1995,a|0,37632)|0;b=i[114610];i[114610]=0;if((b|0)==1){break g}b=$a[i[i[c>>2]+8>>2]](c)|0;i[114610]=0;C(1995,a|0,(b?b:34133)|0)|0;b=i[114610];i[114610]=0;if((b|0)==1){break g}i[114610]=0;K(20);b=i[114610];i[114610]=0;if((b|0)!=1){break b}b=B()|0;A()|0;break a}i[114610]=0;C(1995,a|0,b|0)|0;b=i[114610];i[114610]=0;if((b|0)==1){break d}i[114610]=0;C(1995,a|0,37606)|0;b=i[114610];i[114610]=0;if((b|0)==1){break d}i[114610]=0;C(1995,a|0,37609)|0;b=i[114610];i[114610]=0;if((b|0)==1){break d}i[114610]=0;K(20);b=i[114610];i[114610]=0;if((b|0)!=1){break b}b=B()|0;A()|0;break a}b=B()|0;A()|0;i[114610]=0;K(20);c=i[114610];i[114610]=0;if((c|0)!=1){break a}break c}b=B()|0;A()|0;i[114610]=0;K(20);c=i[114610];i[114610]=0;if((c|0)!=1){break a}break c}b=B()|0;A()|0;i[114610]=0;K(20);c=i[114610];i[114610]=0;if((c|0)==1){break c}break a}b=B()|0;A()|0;i[114610]=0;K(20);c=i[114610];i[114610]=0;if((c|0)!=1){break a}}a=H(0)|0;A()|0;gb(a)}x()}return}eb(a);E(b|0);x()}function N8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=Xa-160|0;Xa=e;a:{if(Oi(c)){break a}g=j[Dj(c)|0];f=1;b:{if((g|0)==33){break b}if((g|0)!=63){break a}f=0}d=f;Oj(e+128|0,c,i[c+4>>2]+ -1|0);f=i[e+132>>2];i[c>>2]=i[e+128>>2];i[c+4>>2]=f}jd(e+128|0);f=i[e+128>>2];jd(e+112|0);h=Cj(f,i[e+116>>2],c);jd(e+128|0);f=i[c>>2];g=i[c+4>>2];c:{d:{e:{f:{if((h|0)==i[e+132>>2]){i[e+152>>2]=f;i[e+156>>2]=g;b=Zb(e+144|0,38187);f=i[e+156>>2];i[e+8>>2]=i[e+152>>2];i[e+12>>2]=f;f=i[b+4>>2];i[e>>2]=i[b>>2];i[e+4>>2]=f;if(mc(e+8|0,e)){a=P(8)|0;i[114610]=0;b=C(85,e+128|0,39121)|0;c=i[114610];i[114610]=0;if((c|0)==1){break e}Ub(a,b);i[114610]=0;G(2009,a|0,83568,2017);a=i[114610];i[114610]=0;if((a|0)!=1){break c}c=B()|0;A()|0;eb(b);break d}if(d){b=P(8)|0;i[114610]=0;d=C(2142,e+112|0,c|0)|0;a=i[114610];i[114610]=0;g:{h:{i:{if((a|0)!=1){i[114610]=0;G(2119,e+128|0,39131,d|0);a=i[114610];i[114610]=0;if((a|0)==1){break i}Ub(b,e+128|0);a=0;i[114610]=0;G(2009,b|0,83568,2017);c=i[114610];i[114610]=0;if((c|0)!=1){break c}c=B()|0;A()|0;eb(e+128|0);break h}c=B()|0;A()|0;break g}c=B()|0;a=1;A()|0}eb(d);if(!a){break d}}Q(b|0);break d}Ab(a);break f}i[e+104>>2]=f;i[e+108>>2]=g;d=Zb(e+96|0,38187);f=i[e+108>>2];i[e+56>>2]=i[e+104>>2];i[e+60>>2]=f;f=i[d+4>>2];i[e+48>>2]=i[d>>2];i[e+52>>2]=f;if(mc(e+56|0,e+48|0)){a=P(8)|0;i[114610]=0;b=C(85,e+128|0,39121)|0;c=i[114610];i[114610]=0;if((c|0)!=1){Ub(a,b);i[114610]=0;G(2009,a|0,83568,2017);a=i[114610];i[114610]=0;if((a|0)!=1){break c}c=B()|0;A()|0;eb(b);break d}c=B()|0;A()|0;Q(a|0);break d}d=i[c+4>>2];i[e+88>>2]=i[c>>2];i[e+92>>2]=d;d=Zb(e+80|0,39010);f=i[e+92>>2];i[e+40>>2]=i[e+88>>2];i[e+44>>2]=f;f=i[d+4>>2];i[e+32>>2]=i[d>>2];i[e+36>>2]=f;if(mc(e+40|0,e+32|0)){j:{switch(i[b+52>>2]){case 0:Bb(a,39203);break f;case 1:Bb(a,39211);break f;case 2:Bb(a,39220);break f;default:break j}}Ab(a);break f}d=i[c+4>>2];i[e+72>>2]=i[c>>2];i[e+76>>2]=d;c=Zb(e- -64|0,39053);d=i[e+76>>2];i[e+24>>2]=i[e+72>>2];i[e+28>>2]=d;d=i[c+4>>2];i[e+16>>2]=i[c>>2];i[e+20>>2]=d;if(mc(e+24|0,e+16|0)){k:{switch(i[b+56>>2]){case 0:Bb(a,39225);break f;case 1:Bb(a,39230);break f;case 2:Bb(a,39236);break f;case 3:Bb(a,39247);break f;default:break k}}Ab(a);break f}Ab(a)}Xa=e+160|0;return}c=B()|0;A()|0;Q(a|0)}E(c|0)}x()}function kLa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,k=0,m=0,n=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0;e=Xa-32|0;Xa=e;p=aj(e+24|0);if(i[a+12>>2]){v=p+3|0;w=p+5|0;x=p+4|0;y=p+2|0;z=p+1|0;A=b^1;B=e+16|5;C=e+16|3;while(1){D=zp(a,s);while(1){a:{if(!wb(c,1)){break a}q=id(c);if((q|0)==255){break a}m=q&31;d=Hj(a)>>>0>m>>>0;m=o(m,6)+D|0;b:{if(!(q&64)){f=id(c);k=f<<24>>24;c:{d:{e:{f=f&127;switch(f|0){case 0:break c;case 1:break e;default:break d}}g[(d?m:e+24|0)|0]=255;break c}if(!(f>>>0>121|A)){g[(d?m:e+24|0)|0]=f+ -1;break c}if((f+ -12&255)>>>0>96|b){break c}g[(d?m:e+24|0)|0]=f+13}F=d?m+1|0:z,G=id(c),g[F|0]=G;if((k|0)>-1){break b}}u=d?m:p;k=d?m+3|0:v;f=d?m+5|0:w;t=d?m+4|0:x;r=d?m+2|0:y;m=d?m:e+24|0;while(1){d=m;i[e+16>>2]=j[d|0]|j[d+1|0]<<8|(j[d+2|0]<<16|j[d+3|0]<<24);h[e+20>>1]=j[d+4|0]|j[d+5|0]<<8;d=id(c);E=d&128;n=d&63;f:{if(d&64){g[r|0]=1;g[t|0]=n;break f}d=id(c);g[f|0]=d;g:{h:{if(n>>>0<=15){g[k|0]=n;Xi(u);i:{j:{k:{d=j[k|0];switch(d+ -9|0){case 1:case 2:case 3:break g;case 4:break j;case 0:break k;default:break i}}g[k|0]=9;g[f|0]=o(j[f|0]&15,17);break g}g[k|0]=0;g[r|0]=1;i[e+12>>2]=j[f|0]+1>>>1;i[e+8>>2]=64;F=t,G=i[Nd(e+12|0,e+8|0)>>2],g[F|0]=G;break g}if((d|0)!=19){break g}if(j[f|0]==128){break h}Fw(u);break g}if(n>>>0>44){break g}n=n+ -16|0;g[k|0]=j[n+12272|0];l:{switch(n|0){case 0:if(d>>>0>1){break h}g[f|0]=d|158;break g;case 1:case 2:g[e+12|0]=15;F=f,G=j[Xb(e+12|0,f)|0]|224,g[F|0]=G;break g;case 5:case 6:i[e+12>>2]=16;i[e+8>>2]=d+1;F=f,G=i[Nd(e+12|0,e+8|0)>>2]/2|240,g[F|0]=G;break g;case 14:m:{n:{o:{p:{q:{n=d>>>4|0;switch(n+ -1|0){case 1:break o;case 0:break p;default:break q}}switch(n+ -10|0){case 1:break m;case 0:break n;default:break h}}g[k|0]=2;g[f|0]=d|240;break g}g[k|0]=3;g[f|0]=d|240;break g}g[k|0]=11;g[f|0]=(d<<3&120)+8|15;break g}g[k|0]=11;g[f|0]=(d&15)+1>>>1|240;break g;case 12:break l;default:break g}}i[e+12>>2]=d+1>>>1;i[e+8>>2]=64;F=f,G=i[Nd(e+12|0,e+8|0)>>2],g[F|0]=G;break g}g[k|0]=0}Dw(k,f,C,B);if(tm(j[e+19|0])>>>0<=tm(j[k|0])>>>0){break f}r:{if(j[r|0]){break r}if(!Ew(k,f,1)){break r}g[r|0]=j[k|0];g[t|0]=j[f|0]}g[k|0]=j[e+19|0];g[f|0]=j[e+21|0]}if(E){continue}break}}if(!(q&128)){continue}}break}s=s+1|0;if(s>>>0<l[a+12>>2]){continue}break}}Xa=e+32|0}function y_(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,m=0;d=Xa-336|0;Xa=d;Q0(a);e=i[a+28>>2];a:{if(!hf(i[i[e>>2]+ -12>>2]+e|0)){ig(a,1073741825);break a}Ue(d- -64|0,i[a+28>>2]);e=d- -64|0;f=i[e+12>>2];i[a+8>>2]=i[e+8>>2];i[a+12>>2]=f;p_(yc(d- -64|0,3),i[a+28>>2],d+24|0);if(Xc(d+24|0,6931,3)){ig(a,1073741827);break a}g[d+335|0]=0;bh(i[a+28>>2],d+335|0);sC(d- -64|0);m=b;f=d+24|0;b=d- -64|0;e=j[d+335|0];if(e){yj(i[a+28>>2],d- -64|0,e);e=j[d+335|0]}else{e=0}b=Ol(f,b,e);e=Eu(m,b);ob(b);if(!e){ig(a,1073741830)}if(j[a+3|0]&64){break a}bh(i[a+28>>2],d+63|0);e=j[d+63|0];b=e&3;h[a+16>>1]=(b|0)==3?4:b;if(zh(e,6)){kj(a,9,1)}i[d+56>>2]=0;pC(i[a+28>>2],d+56|0);b=i[d+56>>2];g[d+55|0]=0;if(b>>>0>=2){bh(i[a+28>>2],d+63|0);f=j[d+63|0];if(!f){bh(i[a+28>>2],d+55|0);f=j[d+63|0]}Hk(i[a+28>>2],b+(f?-1:-2)|0,-1)}i[d+40>>2]=0;i[d+44>>2]=0;b:{if(!zh(e,4)){break b}jj(i[a+28>>2],d+40|0);b=i[d+44>>2];f=i[d+40>>2];i[a+56>>2]=f;i[a+60>>2]=b;m=i[c+4>>2];if((m|0)==(b|0)&f>>>0<=l[c>>2]|b>>>0<m>>>0){break b}ig(a,536871424)}if(zh(e,5)){bh(i[a+28>>2],d+63|0);Hk(i[a+28>>2],j[d+63|0],-1)}c:{if(!zh(j[d+55|0],0)){break c}bh(i[a+28>>2],d+63|0);b=j[d+63|0];b=b&1?-1:b>>>1|0;h[a+16>>1]=b;if(b){break c}ig(a,536871168)}i[a+4>>2]=0;b=1;if(zh(j[d+55|0],1)){pC(i[a+28>>2],a+4|0)}kj(a,6,zh(e,2));kj(a,7,zh(e,3));kj(a,5,k[a+16>>1]!=0);kj(a,8,zh(e,7));d:{if(dd(a,5)){break d}if(dd(a,6)){break d}if(dd(a,7)){break d}b=dd(a,8)}kj(a,11,b);dd(a,11);b=j[d+55|0];if(zh(b,2)){h[d+24>>1]=0;Cu(i[a+28>>2],d+24|0);Hk(i[a+28>>2],o(k[d+24>>1],dd(a,9)?2:1),-1);b=j[d+55|0]}if(zh(b&255,3)){Hk(i[a+28>>2],5,-1)}jj(i[a+28>>2],d+40|0);c=i[d+44>>2];b=i[d+40>>2];if(!c&b>>>0>=16001|c>>>0>0){ig(a,1073741831);break a}i[a+92>>2]=b;if(!b){ig(a,536871040)}e:{if(!dd(a,11)){break e}jj(i[a+28>>2],d+40|0);b=i[d+44>>2];if((b|0)==2147483647|b>>>0<2147483647){break e}ig(a,1073741829);break a}Ue(d+8|0,i[a+28>>2]);LC(d+24|0,d+8|0,i[a+8>>2],i[a+12>>2]);b=i[d+36>>2];e=i[d+32>>2];if(!(!b|b>>>0<0?(b|0)>0?1:(b|0)>=0?e>>>0>=0:0:0)){ig(a,1073741832);break a}i[a+88>>2]=e;b=a;f:{if(dd(a,11)){c=i[d+40>>2];break f}c=i[a+88>>2]}i[b+64>>2]=c;if(!dd(a,11)){c=i[a+12>>2];e=i[a+88>>2];f=e+i[a+8>>2]|0;if(f>>>0<e>>>0){c=c+1|0}i[a+72>>2]=f;i[a+76>>2]=c}kj(a,10,1)}Xa=d+336|0}function mca(a,b,c,d,e,f,g,h,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0;k=Xa-80|0;Xa=k;a:{b:{c:{l=In(1,32);d:{e:{if(!l){a=P(4)|0;zk(a);i[114610]=0;G(2009,a|0,71348,2008);a=i[114610];i[114610]=0;if((a|0)!=1){break a}j=H(0)|0;A()|0;break e}i[l+16>>2]=0;i[l+20>>2]=0;i[l+12>>2]=f;i[l+8>>2]=e;i[l+4>>2]=d;i[l+24>>2]=0;i[l+28>>2]=0;i[l>>2]=c?c:1997;d=Yr(k- -64|0);f:{g:{if(!j){break g}c=i[j>>2];if(!c){break g}while(1){h:{e=i[j+4>>2];if(e){i[114610]=0;c=C(85,k+48|0,c|0)|0;f=i[114610];i[114610]=0;i:{if((f|0)!=1){i[114610]=0;f=C(2010,d|0,c|0)|0;m=i[114610];i[114610]=0;if((m|0)==1){break i}i[114610]=0;C(483,f|0,e|0)|0;e=i[114610];i[114610]=0;if((e|0)==1){break i}break h}j=H(0)|0;A()|0;break f}j=H(0)|0;A()|0;eb(c);break f}i[114610]=0;c=C(85,k+48|0,c|0)|0;e=i[114610];i[114610]=0;j:{if((e|0)!=1){i[114610]=0;C(2011,d|0,c|0)|0;e=i[114610];i[114610]=0;if((e|0)==1){break j}break h}j=H(0)|0;A()|0;break f}j=H(0)|0;A()|0;eb(c);break f}eb(c);c=i[j+8>>2];j=j+8|0;if(c){continue}break}}c=i[a+8>>2];e=i[a+4>>2];f=i[a>>2];i[114610]=0;a=F(1398,96)|0;j=i[114610];i[114610]=0;k:{l:{m:{if((j|0)!=1){i[114610]=0;i[k+44>>2]=c;i[k+40>>2]=e;i[k+36>>2]=f;i[k+32>>2]=b;G(2012,k+48|0,l|0,l+4|0);b=i[114610];i[114610]=0;if((b|0)==1){break m}b=eo(k+24|0,k+48|0);i[114610]=0;c=i[k+44>>2];i[k+16>>2]=i[k+40>>2];i[k+20>>2]=c;c=i[k+36>>2];i[k+8>>2]=i[k+32>>2];i[k+12>>2]=c;N(2086,a|0,k+8|0,b|0,d|0)|0;c=i[114610];i[114610]=0;if((c|0)==1){break l}i[l+28>>2]=a;Ec(b);Ec(k+48|0);a=i[l+28>>2];i[l+24>>2]=a?a+8|0:0;Pj(d);break d}j=H(0)|0;A()|0;break f}j=H(0)|0;A()|0;break k}j=H(0)|0;A()|0;Ec(b);Ec(k+48|0)}Cb(a)}Pj(d);M(j|0)|0;i[114610]=0;J(1989,37181,l|0,g|0,h|0);a=i[114610];i[114610]=0;if((a|0)!=1){i[114610]=0;K(20);a=i[114610];i[114610]=0;if((a|0)!=1){a=i[l+28>>2];if(a){$a[i[i[a>>2]+4>>2]](a)}i[l+24>>2]=0;i[l+28>>2]=0;a=i[l+20>>2];if(a){Cb(a)}Cb(l);l=0;break d}j=H(0)|0;A()|0;break e}j=H(0)|0;A()|0;i[114610]=0;K(20);a=i[114610];i[114610]=0;if((a|0)==1){break b}}M(j|0)|0;l=0;i[114610]=0;J(1989,37181,0,g|0,h|0);a=i[114610];i[114610]=0;if((a|0)==1){break c}O()}Xa=k+80|0;return l|0}a=B()|0;A()|0;i[114610]=0;K(20);b=i[114610];i[114610]=0;if((b|0)==1){break b}E(a|0);x()}a=H(0)|0;A()|0;gb(a)}x()}function ria(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,k=0,l=0,m=0;e=Xa-176|0;Xa=e;Ue(e+160|0,b);a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{k=qia(a,b,c,d);if(!k){jn(i[i[b>>2]+ -12>>2]+b|0,0);k=i[e+172>>2];i[e+8>>2]=i[e+168>>2];i[e+12>>2]=k;k=i[e+164>>2];i[e>>2]=i[e+160>>2];i[e+4>>2]=k;Di(b,e);b=Ek(e+56|0,b);i[114610]=0;k=C(686,e+40|0,32515)|0;f=i[114610];i[114610]=0;if((f|0)==1){break b}i[114610]=0;i[e+32>>2]=3;i[e+36>>2]=0;G(687,b|0,k|0,e+32|0);f=i[114610];i[114610]=0;if((f|0)==1){break c}ob(k);i[114610]=0;g[e+31|0]=0;k=C(686,e+40|0,32518)|0;f=i[114610];i[114610]=0;if((f|0)==1){break d}i[114610]=0;I(688,b|0,e+31|0,k|0)|0;f=i[114610];i[114610]=0;if((f|0)==1){break e}ob(k);i[114610]=0;k=j[e+31|0];f=F(1624,b|0)|0;l=i[114610];i[114610]=0;if((l|0)==1){break f}i[114610]=0;l=F(1625,b|0)|0;m=i[114610];i[114610]=0;if((m|0)==1){break g}i[e+32>>2]=l;i[e+24>>2]=f;if(pb(e+24|0,e+32|0)){k=k?0:d;while(1){i[114610]=0;h[e+22>>1]=65535;d=C(686,e+40|0,32523)|0;f=i[114610];i[114610]=0;if((f|0)==1){break j}i[114610]=0;f=I(1626,b|0,e+24|0,d|0)|0;l=i[114610];i[114610]=0;if((l|0)==1){break i}ob(d);m:{if(!f){i[114610]=0;J(1627,b|0,e+24|0,c|0,k|0);d=i[114610];i[114610]=0;if((d|0)==1){break h}break m}i[114610]=0;d=C(686,e+40|0,32525)|0;f=i[114610];i[114610]=0;n:{o:{if((f|0)!=1){i[114610]=0;f=I(1626,b|0,e+24|0,d|0)|0;l=i[114610];i[114610]=0;if((l|0)==1){break o}ob(d);if(f){break n}i[114610]=0;I(1628,b|0,e+24|0,e+22|0)|0;d=i[114610];i[114610]=0;if((d|0)!=1){break m}break h}a=B()|0;A()|0;break a}a=B()|0;A()|0;ob(d);break a}i[114610]=0;d=C(686,e+40|0,32527)|0;f=i[114610];i[114610]=0;if((f|0)==1){break l}i[114610]=0;f=I(1626,b|0,e+24|0,d|0)|0;l=i[114610];i[114610]=0;if((l|0)==1){break k}ob(d);if(f){break m}i[114610]=0;J(1629,b|0,e+24|0,a|0,k|0);d=i[114610];i[114610]=0;if((d|0)==1){break h}}d=e+24|0;d;vf(d);if(pb(e+24|0,e+32|0)){continue}break}}a=i[b>>2];Yf(b);k=a&1073741824?-1:1}Xa=e+176|0;return k|0}a=B()|0;A()|0;break a}a=B()|0;A()|0;ob(d);break a}a=B()|0;A()|0;break a}a=B()|0;A()|0;ob(d);break a}a=B()|0;A()|0;break a}a=B()|0;A()|0;break a}a=B()|0;A()|0;break a}a=B()|0;A()|0;ob(k);break a}a=B()|0;A()|0;break a}a=B()|0;A()|0;ob(k);break a}a=B()|0;A()|0}Yf(b);E(a|0);x()}function xua(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;e=Xa-80|0;Xa=e;w=i[a+16>>2];j=tf(e+48|0);i[j+8>>2]=a+112;i[j+16>>2]=i[a+128>>2];y=j,z=of(b+327720|0,i[b+20>>2],(i[a+88>>2]&16384)>>>14|0),i[y+12>>2]=z;b=i[j+16>>2];if(b){y=j,z=sf(a+8|0,b),i[y>>2]=z;i[j+4>>2]=_a}f=i[a+44>>2];i[e+32>>2]=f;p=i[a+48>>2];i[e+36>>2]=p;m=i[a+52>>2];i[e+40>>2]=m;n=i[a+56>>2];i[e+44>>2]=n;q=i[a+40>>2];r=i[a+36>>2];k=i[a+4>>2];g=i[a>>2];i[e+24>>2]=g;i[e+28>>2]=k;b=i[a+12>>2];i[e+16>>2]=i[a+8>>2];i[e+20>>2]=b;a:{if(!d){b=q>>12;l=r>>12;break a}while(1){b=0;f=b;l=g;i[e+72>>2]=g;i[e+76>>2]=b;k=((((k&2147483647)<<1|g>>>31)&2147483646)<<1)+w|0;b:{b=i[j+16>>2];if((b|0)<=0){break b}while(1){g=(f&2147483647)<<1|l>>>31;fd(i[j+8>>2],(h[(g<<1|2)+k>>1]+h[k+((g&2147483646)<<1)>>1]|0)/8<<16>>16);ed(i[j+8>>2],4);zb(e+72|0,j);if((b|0)<2){break b}b=b+ -1|0;l=i[e+72>>2];f=i[e+76>>2];continue}}b=i[j+8>>2];zb(b,b+8|0);b=i[j+8>>2];g=i[b+4>>2];if(g){f=b;b=(i[e+76>>2]&2147483647)<<1|i[e+72>>2]>>>31;fd(f,(h[(b<<1|2)+k>>1]+h[k+((b&2147483646)<<1)>>1]|0)/8<<16>>16);ed(i[j+8>>2],g);b=i[j+8>>2];g=i[b>>2];i[b>>2]=g;i[b+4>>2]=0}d=d+ -1|0;f=nf(b,i[j+12>>2]);i[e+12>>2]=f;i[e+8>>2]=f;l=0;p=1;while(1){m=i[a+60>>2];n=m;k=(e+32|0)+(l<<3)|0;s=i[k>>2];b=Eb(s,-16777216,16776704);v=i[a+64>>2];g=Eb(i[k+4>>2],-16777216,16776704);t=i[a+68>>2];x=t;t=t>>31;i[k+4>>2]=s;s=i[a+72>>2];u=m>>31;m=f<<8;f=m;f=XMa(n,u,f,f>>31);n=_a;u=(e+8|0)+(l<<2)|0;l=XMa(v,v>>31,b,b>>31);f=l+f|0;b=_a+n|0;b=f>>>0<l>>>0?b+1|0:b;n=f;f=XMa(x,t,g,g>>31);g=n+f|0;b=_a+b|0;b=g>>>0<f>>>0?b+1|0:b;g=g+8388608|0;if(g>>>0<8388608){b=b+1|0}b=(b&16777215)<<8|g>>>24;i[u>>2]=(b|0)/256;i[k>>2]=b-(m&s);if(p){l=1;p=0;f=i[e+12>>2];continue}break}b=i[a+32>>2];r=i[a+28>>2]+r|0;l=r>>12;i[c>>2]=i[c>>2]+o(l,i[e+8>>2]);q=b+q|0;b=q>>12;i[c+4>>2]=i[c+4>>2]+o(b,i[e+12>>2]);zb(e+24|0,e+16|0);if(d){c=c+8|0;g=i[e+24>>2];k=i[e+28>>2];continue}break}g=i[e+24>>2];k=i[e+28>>2];n=i[e+44>>2];m=i[e+40>>2];p=i[e+36>>2];f=i[e+32>>2]}i[a+40>>2]=q;i[a+20>>2]=l;i[a+36>>2]=r;i[a+56>>2]=n;i[a+52>>2]=m;i[a+48>>2]=p;i[a+44>>2]=f;i[a+24>>2]=b;i[a>>2]=g;i[a+4>>2]=k;Xa=e+80|0}



function Loa(a,b,c,d,e){var f=0,h=0,l=0,n=p(0),q=0,r=0,s=0,t=p(0),u=0,v=0;h=Xa-32|0;Xa=h;i[h+28>>2]=e;a:{if(!e){break a}f=j[d|0];l=f+ -250|0;if(!(l>>>0>5|!(1<<l&37))){if(k[a+480188>>1]){f=0;while(1){l=(o(f,896)+a|0)+1075841|0;g[l|0]=127;g[l+1|0]=0;f=f+1|0;if(f>>>0<k[a+480188>>1]){continue}break}}f=j[d|0]}b:{if((f&255)!=240){break b}f=j[d+1|0];if((f&254)!=240){break b}if(e>>>0<4){break a}l=(o(b,896)+a|0)+1074984|0;e=g[d+3|0];r=(e|0)<0;d=j[d+2|0];if(!(r|(f|0)==241|d)){d=o(b,896)+a|0;f=d+1075841|0;q=f;if(c){e=hK(vo(a,p(j[f|0]),p((e&255)>>>0)))}g[q|0]=e;g[d+1075802|0]=0;q=4;c=d+1075072|0;d=Eo(a,l,!(i[c>>2]&32768),256);if((d|0)<0|!(j[c+1|0]&2)){break a}a=a+1304392|0;if(!$c(a)){break a}Jo(i[a>>2],b,d>>>2&255,1);break a}if(!(r|(f|0)==241|(d|0)!=1)){b=o(b,896)+a|0;d=b+1075842|0;c:{if(!c){break c}n=vo(a,p(j[d|0]),p((e&255)>>>0));if(n<p(4294967296)&n>=p(0)){e=~~n>>>0;break c}e=0}g[d|0]=e;g[b+1075801|0]=0;Eo(a,l,!(i[b+1075072>>2]&32768),256);q=4;break a}r=(f|0)==241;if(!(r|(d|0)!=2)){q=4;if((e&255)>>>0>31){break a}b=o(b,896)+a|0;g[b+1075849|0]=(e&240)>>>4;Eo(a,l,!(i[b+1075072>>2]&32768),256);break a}if(!(r|(d|0)!=3)){q=4;b=ym(a,b,3,0);if((e|0)<0|(b+5&255)>>>0<6){break a}b=(o(b,160)+a|0)+906284|0;n=p(p(((e^127)&255)>>>0)*p(.007874015718698502));if(!c){m[b>>2]=n;break a}s=b,t=vo(a,m[b>>2],n),m[s>>2]=t;break a}if(d&128?0:(f|0)!=241){break a}q=4;b=ym(a,b,3,0);if((e|0)<0|(b+5&255)>>>0<6){break a}b=i[(o(b,160)+a|0)+906140>>2];if(!b){break a}d=(f|0)==241?d+128|0:d&127;n=p(p((e&255)>>>0)*p(.007874015718698502));if(!c){$a[i[i[b>>2]+44>>2]](b,d,n);break a}u=b,v=d,t=vo(a,p($a[i[i[b>>2]+48>>2]](b,d)),n),s=i[i[b>>2]+44>>2],$a[s](u|0,v|0,p(t));break a}d:{e:{if(k[a+480188>>1]>b>>>0){f=b+1|0;break e}f=k[(o(b,896)+a|0)+1075792>>1];if(!f){break d}}if(j[(o(b,896)+a|0)+1075075|0]&4|(f&65535)>>>0>k[a+480188>>1]){break d}b=ym(a,b,3,0);if(!b|b+ -251>>>0<5){break d}a=i[(o(b,160)+a|0)+906140>>2];if(!a){break d}b=j[d|0];if((b|0)==240){Ob(h+16|0,jb(d),e);$a[i[i[a>>2]+72>>2]](a,h+16|0)|0;break d}s=h,v=JM(b),i[s+12>>2]=v;b=i[rb(h+12|0,h+28|0)>>2];i[h+12>>2]=0;Tb(h+12|0,d,b);$a[i[i[a>>2]+68>>2]](a,i[h+12>>2])|0}q=i[h+28>>2]}Xa=h+32|0;return q}function dw(a){a=a|0;var b=0,c=0,d=p(0),e=0;yb(a+4960|0,0,76);g[a+5044|0]=0;i[a+5036>>2]=0;i[a+5040>>2]=0;b=i[a+4292>>2];d=m[a+4268>>2];i[114610]=0;e=a+4504|0;if(d<p(4294967296)&d>=p(0)){c=~~d>>>0}else{c=0}T(1916,e|0,67,5,c|0,b|0);b=i[114610];i[114610]=0;a:{if((b|0)==1){break a}b=i[a+4296>>2];i[114610]=0;T(1916,a+4528|0,62,5,c|0,b|0);b=i[114610];i[114610]=0;if((b|0)==1){break a}b=i[a+4300>>2];i[114610]=0;T(1916,a+4552|0,53,5,c|0,b|0);b=i[114610];i[114610]=0;if((b|0)==1){break a}b=i[a+4304>>2];i[114610]=0;T(1916,a+4576|0,43,5,c|0,b|0);b=i[114610];i[114610]=0;if((b|0)==1){break a}b=i[a+4308>>2];i[114610]=0;T(1916,a+4600|0,32,5,c|0,b|0);b=i[114610];i[114610]=0;if((b|0)==1){break a}b=i[a+4312>>2];i[114610]=0;T(1916,a+4624|0,22,5,c|0,b|0);b=i[114610];i[114610]=0;if((b|0)==1){break a}b=i[a+4316>>2];i[114610]=0;T(1916,a+4648|0,75,5,c|0,b|0);b=i[114610];i[114610]=0;if((b|0)==1){break a}b=i[a+4320>>2];i[114610]=0;T(1916,a+4672|0,69,5,c|0,b|0);b=i[114610];i[114610]=0;if((b|0)==1){break a}b=i[a+4324>>2];i[114610]=0;T(1916,a+4696|0,60,5,c|0,b|0);b=i[114610];i[114610]=0;if((b|0)==1){break a}b=i[a+4328>>2];i[114610]=0;T(1916,a+4720|0,48,5,c|0,b|0);b=i[114610];i[114610]=0;if((b|0)==1){break a}b=i[a+4332>>2];i[114610]=0;T(1916,a+4744|0,36,5,c|0,b|0);b=i[114610];i[114610]=0;if((b|0)==1){break a}b=i[a+4336>>2];i[114610]=0;T(1916,a+4768|0,25,5,c|0,b|0);b=i[114610];i[114610]=0;if((b|0)==1){break a}i[114610]=0;T(1916,a+4792|0,0,0,0,0);b=i[114610];i[114610]=0;if((b|0)==1){break a}b=i[a+4344>>2];i[114610]=0;T(1916,a+4816|0,3,0,c|0,b|0);b=i[114610];i[114610]=0;if((b|0)==1){break a}b=i[a+4348>>2];i[114610]=0;T(1916,a+4840|0,3,0,c|0,b|0);b=i[114610];i[114610]=0;if((b|0)==1){break a}i[114610]=0;T(1916,a+4864|0,407,1,c|0,0);b=i[114610];i[114610]=0;if((b|0)==1){break a}i[114610]=0;T(1916,a+4888|0,400,1,c|0,0);b=i[114610];i[114610]=0;if((b|0)==1){break a}i[114610]=0;T(1916,a+4912|0,10,0,c|0,-1);b=i[114610];i[114610]=0;if((b|0)==1){break a}i[114610]=0;T(1916,a+4936|0,10,0,c|0,-1);c=i[114610];i[114610]=0;if((c|0)==1){break a}g[a+5045|0]=1;return}c=H(71348)|0;if((A()|0)==(U(71348)|0)){M(c|0)|0;g[a+5045|0]=0;O();return}E(c|0);x()}function GD(a,b,c,d){var e=0,f=0,h=0,k=0,m=0,n=0,o=0;f=Xa-48|0;Xa=f;a:{if(c>>>0<=2){c=c<<2;k=i[c+57372>>2];o=i[c+57360>>2];while(1){c=i[b+4>>2];b:{if(c>>>0<l[b+104>>2]){i[b+4>>2]=c+1;c=j[c|0];break b}c=Hc(b)}if(Yl(c)){continue}break}h=1;c:{d:{switch(c+ -43|0){case 0:case 2:break d;default:break c}}h=(c|0)==45?-1:1;c=i[b+4>>2];if(c>>>0<l[b+104>>2]){i[b+4>>2]=c+1;c=j[c|0];break c}c=Hc(b)}e:{f:{while(1){if(g[e+57296|0]==(c|32)){g:{if(e>>>0>6){break g}c=i[b+4>>2];if(c>>>0<l[b+104>>2]){i[b+4>>2]=c+1;c=j[c|0];break g}c=Hc(b)}e=e+1|0;if((e|0)!=8){continue}break f}break}if((e|0)!=3){if((e|0)==8){break f}if(!d|e>>>0<4){break e}if((e|0)==8){break f}}c=i[b+104>>2];if(c){i[b+4>>2]=i[b+4>>2]+ -1}if(!d|e>>>0<4){break f}while(1){if(c){i[b+4>>2]=i[b+4>>2]+ -1}e=e+ -1|0;if(e>>>0>3){continue}break}}V2(f,p(p(h|0)*p(z)));h=i[f+8>>2];k=i[f+12>>2];m=i[f>>2];n=i[f+4>>2];break a}h:{i:{j:{if(e){break j}e=0;while(1){if(g[e+57305|0]!=(c|32)){break j}k:{if(e>>>0>1){break k}c=i[b+4>>2];if(c>>>0<l[b+104>>2]){i[b+4>>2]=c+1;c=j[c|0];break k}c=Hc(b)}e=e+1|0;if((e|0)!=3){continue}break}break i}l:{switch(e|0){case 0:m:{if((c|0)!=48){break m}e=i[b+4>>2];n:{if(e>>>0<l[b+104>>2]){i[b+4>>2]=e+1;e=j[e|0];break n}e=Hc(b)}if((e&-33)==88){T2(f+16|0,b,o,k,h,d);h=i[f+24>>2];k=i[f+28>>2];m=i[f+16>>2];n=i[f+20>>2];break a}if(!i[b+104>>2]){break m}i[b+4>>2]=i[b+4>>2]+ -1}S2(f+32|0,b,c,o,k,h,d);h=i[f+40>>2];k=i[f+44>>2];m=i[f+32>>2];n=i[f+36>>2];break a;case 3:break i;default:break l}}if(i[b+104>>2]){i[b+4>>2]=i[b+4>>2]+ -1}break h}o:{c=i[b+4>>2];p:{if(c>>>0<l[b+104>>2]){i[b+4>>2]=c+1;c=j[c|0];break p}c=Hc(b)}if((c|0)==40){e=1;break o}h=0;k=2147450880;if(!i[b+104>>2]){break a}i[b+4>>2]=i[b+4>>2]+ -1;break a}while(1){c=i[b+4>>2];q:{if(c>>>0<l[b+104>>2]){i[b+4>>2]=c+1;c=j[c|0];break q}c=Hc(b)}if(!(c+ -97>>>0>=26?!(c+ -48>>>0<10|c+ -65>>>0<26|(c|0)==95):0)){e=e+1|0;continue}break}h=0;k=2147450880;if((c|0)==41){break a}c=i[b+104>>2];if(c){i[b+4>>2]=i[b+4>>2]+ -1}if(d){if(!e){break a}while(1){e=e+ -1|0;if(c){i[b+4>>2]=i[b+4>>2]+ -1}if(e){continue}break}break a}}i[114584]=28;Gg(b,0,0)}h=0;k=0}i[a>>2]=m;i[a+4>>2]=n;i[a+8>>2]=h;i[a+12>>2]=k;Xa=f+48|0}function IG(a,b,c,d,e,f,g,h,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0;k=Xa-80|0;Xa=k;a:{b:{c:{d:{e:{f:{l=In(1,28);if(!l){a=P(4)|0;zk(a);i[114610]=0;G(2009,a|0,71348,2008);a=i[114610];i[114610]=0;if((a|0)!=1){break a}break f}i[l+24>>2]=0;i[l+16>>2]=0;i[l+20>>2]=0;i[l+12>>2]=f;i[l+8>>2]=e;i[l+4>>2]=d;i[l>>2]=c?c:1997;d=Yr(k- -64|0);g:{h:{if(!j){break h}c=i[j>>2];if(!c){break h}while(1){i:{e=i[j+4>>2];if(e){i[114610]=0;c=C(85,k+48|0,c|0)|0;f=i[114610];i[114610]=0;j:{if((f|0)!=1){i[114610]=0;f=C(2010,d|0,c|0)|0;m=i[114610];i[114610]=0;if((m|0)==1){break j}i[114610]=0;C(483,f|0,e|0)|0;e=i[114610];i[114610]=0;if((e|0)==1){break j}break i}j=H(0)|0;A()|0;break g}j=H(0)|0;A()|0;eb(c);break g}i[114610]=0;c=C(85,k+48|0,c|0)|0;e=i[114610];i[114610]=0;k:{if((e|0)!=1){i[114610]=0;C(2011,d|0,c|0)|0;e=i[114610];i[114610]=0;if((e|0)==1){break k}break i}j=H(0)|0;A()|0;break g}j=H(0)|0;A()|0;eb(c);break g}eb(c);c=i[j+8>>2];j=j+8|0;if(c){continue}break}}c=i[a+8>>2];e=i[a+4>>2];f=i[a>>2];i[114610]=0;a=F(1398,80)|0;j=i[114610];i[114610]=0;l:{m:{n:{if((j|0)!=1){i[114610]=0;i[k+44>>2]=c;i[k+40>>2]=e;i[k+36>>2]=f;i[k+32>>2]=b;G(2012,k+48|0,l|0,l+4|0);b=i[114610];i[114610]=0;if((b|0)==1){break n}b=eo(k+24|0,k+48|0);i[114610]=0;c=i[k+44>>2];i[k+16>>2]=i[k+40>>2];i[k+20>>2]=c;c=i[k+36>>2];i[k+8>>2]=i[k+32>>2];i[k+12>>2]=c;N(2013,a|0,k+8|0,b|0,d|0)|0;c=i[114610];i[114610]=0;if((c|0)==1){break m}i[l+24>>2]=a;Ec(b);Ec(k+48|0);Pj(d);c=l;break d}j=H(0)|0;A()|0;break g}j=H(0)|0;A()|0;break l}j=H(0)|0;A()|0;Ec(b);Ec(k+48|0)}Cb(a)}Pj(d);M(j|0)|0;i[114610]=0;J(1989,34674,l|0,g|0,h|0);a=i[114610];i[114610]=0;if((a|0)!=1){i[114610]=0;K(20);a=i[114610];i[114610]=0;if((a|0)==1){break f}a=i[l+24>>2];if(a){Cb(br(a))}c=0;i[l+24>>2]=0;a=i[l+20>>2];if(a){Cb(a)}Cb(l);break d}j=H(0)|0;A()|0;i[114610]=0;K(20);a=i[114610];i[114610]=0;if((a|0)!=1){break e}break b}j=H(0)|0;A()|0}M(j|0)|0;c=0;i[114610]=0;J(1989,34674,0,g|0,h|0);a=i[114610];i[114610]=0;if((a|0)==1){break c}O()}Xa=k+80|0;return c|0}a=B()|0;A()|0;i[114610]=0;K(20);b=i[114610];i[114610]=0;if((b|0)==1){break b}E(a|0);x()}a=H(0)|0;A()|0;gb(a)}x()}function Vk(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,h=0,m=0,n=0,p=0,q=0,r=0;m=Xa-16|0;Xa=m;a:{b:{if(Uc(a)|l[b+4>>2]>=l[a+12>>2]){break b}c=k[b+8>>1]>=Hj(a)>>>0;n=k[b+8>>1];if((n|0)!=65535?c:0){break b}h=n;if((h&65535)==65535){n=Hj(a)+ -1|0;h=0}c=Qe(a,i[b+4>>2],h&65535);c:{e=j[b+12|0];d:{if(e&2){break d}q=n&65535;if((h&65535)>>>0>q>>>0){break d}r=e&4;p=j[b+10|0];f=h;d=c;while(1){e:{if(!r){if((p|0)!=j[d+3|0]){break e}break c}if((p|0)==j[d+2|0]){break c}}d=d+6|0;f=f+1|0;if((f&65535)>>>0<=q>>>0){continue}break}}p=n&65535;if((h&65535)>>>0<=p>>>0){q=e&4;f=h;d=c;while(1){f:{if(!q){if(j[d+3|0]){break f}g[d+3|0]=j[b+10|0];g[d+5|0]=j[b+11|0];break c}if(j[d+2|0]){break f}g[d+2|0]=j[b+10|0];g[d+4|0]=j[b+11|0];break c}d=d+6|0;f=f+1|0;if((f&65535)>>>0<=p>>>0){continue}break}}g:{if(!(e&1)){break g}f=i[sm(a)+480180>>2]&2;e=j[b+12|0];h:{if(e&4){break h}n=n&65535;if((h&65535)>>>0>n>>>0){break h}while(1){i:{j:{switch(j[c+3|0]+ -9|0){case 4:if(!II(i[sm(a)+8>>2],1)){break i}d=1;g[c+2|0]=1;g[c+4|0]=j[c+5|0];g[c+3|0]=j[b+10|0];g[c+5|0]=j[b+11|0];break a;case 0:break j;default:break i}}d=c;k:{if(f){e=j[c+5|0];if(e>>>0>128){break i}g[c+2|0]=2;g[c+3|0]=j[b+10|0];a=1;break k}g[c+2|0]=2;g[c+3|0]=j[b+10|0];e=j[c+5|0];a=2}g[d+4|0]=a+e>>>a;g[c+5|0]=j[b+11|0];break c}c=c+6|0;h=h+1|0;if((h&65535)>>>0<=n>>>0){continue}break}e=j[b+12|0]}l:{if(e&4){d=j[b+11|0];c=13;m:{switch(j[b+10|0]+ -1|0){case 1:d=Vm(o(f?2:4,d));e=j[b+12|0];c=9;break;case 0:break m;default:break l}}g[b+11|0]=d;g[b+10|0]=c;e=e&254;g[b+12|0]=e;break l}g[m+15|0]=0;c=j[b+11|0];g[m+14|0]=c;h=j[b+10|0];n:{o:{if(!(!f|(h|0)!=9)){if(c>>>0>128){break n}d=2;g[m+15|0]=2;f=c>>>1|0;g[m+14|0]=f;break o}g[m+15|0]=h;if(!Ew(m+15|0,m+14|0,1)){g[m+15|0]=0;break n}d=j[m+15|0];if(!d){break n}e=j[b+12|0];f=j[m+14|0]}g[b+11|0]=f;g[b+10|0]=d;g[b+12|0]=e&254}e=j[b+12|0]}d=1;if(e&1){break g}g[b+12|0]=e^4;if(Vk(a,b)){break a}}c=i[b>>2];p:{if((c|0)==1){if(i[b+4>>2]+1>>>0<l[a+12>>2]){i[b+4>>2]=i[b+4>>2]+1;break p}c=i[b>>2]}if((c|0)!=2){break b}d=0;c=i[b+4>>2];if(!c){break a}i[b+4>>2]=c+ -1}g[b+12|0]=j[b+12|0]|1;d=Vk(a,b);break a}d=1;break a}d=0}Xa=m+16|0;return d|0}function zm(a,b,c){var d=0,e=0,f=0,h=0,k=0,m=0,n=0,p=0,r=0;f=Xa-16|0;Xa=f;i[b+88>>2]=i[b+88>>2]|524288;a:{b:{if(!(i[a+480208>>2]&8)){kb(f+8|0,a+1074308|0,15);if(ib(f+8|0)){break b}}if(i[a+480180>>2]!=268435456){break a}}c=c?c:j[b+831|0];g[b+832|0]=c;g[b+831|0]=c}c:{if(Vi(b)){e=i[a+1074392>>2];m=i[b+880>>2];d:{if(c){i[b+776>>2]=c;break d}c=i[b+776>>2];if(!c){break c}}d=i[b+708>>2];e:{f:{if((d|0)>=1){if((c|0)<0){break f}break e}if(!d|(c|0)<1){break e}}c=0-c|0;i[b+776>>2]=c}h=b;k=(+(e>>>0)+1)*+(c|0)/+l[a+1074416>>2];g:{if(q(k)<2147483648){c=~~k;break g}c=-2147483648}i[h+880>>2]=c;if(j[b+90|0]&16){c=o(i[i[i[b+656>>2]+44>>2]+36>>2]+1|0,c);i[b+880>>2]=c}a=c-(e?m:0)|0;c=a>>31;e=d>>31;if((e+d^e)<=(c^a+c)){if(!d){break c}i[b+708>>2]=0;i[b+876>>2]=d+i[b+876>>2];g[b+872|0]=j[b+872|0]|8;break c}i[b+708>>2]=d-a;i[b+876>>2]=a+i[b+876>>2];g[b+872|0]=j[b+872|0]|8;break c}d=1;h:{if(!(g[b+872|0]&1)|i[a+480180>>2]&524352){break h}if(i[a+1074416>>2]==1){kb(f+8|0,a+1074308|0,6);if(ib(f+8|0)){break h}}d=0;if(i[a+480180>>2]!=8){break h}d=(j[a+480208|0]&2)>>>1|0}if(!(i[a+480180>>2]!=268435456|c>>>0<240)){d=g[b+872|0]&1;c=c+ -240|0}if(c){i[b+776>>2]=(i[a+480180>>2]==64?o(c,10):c)<<2}e=i[b+708>>2];c=i[b+700>>2];i:{if(!c){c=0;break i}if(!e|d^1){break i}h=b;j:{if((c|0)<(e|0)){d=i[b+776>>2];k:{if(!(j[a+480208|0]&16)){break k}if(i[a+480180>>2]==4){c=i[b+700>>2];break k}c=i[b+776>>2]/4|0;c=i[((c>>>0<255?c:255)<<2)+25296>>2];d=c;e=c>>31;c=i[b+700>>2];d=XMa(d,e,c,c>>31)+32768|0;c=_a;d=gc(YMa(d,d>>>0<32768?c+1|0:c,65536,0),_a);c=i[b+700>>2];d=d-c|0;d=(d|0)>1?d:1}e=i[b+708>>2];c=c+d|0;c=(c|0)>(e|0)?e:c;break j}if((c|0)<=(e|0)){break i}d=0-i[b+776>>2]|0;l:{if(!(j[a+480208|0]&16)){break l}if(i[a+480180>>2]==4){c=i[b+700>>2];break l}c=i[b+776>>2]/4|0;c=i[((c>>>0<255?c:255)<<2)+26320>>2];d=c;e=c>>31;c=i[b+700>>2];d=XMa(d,e,c,c>>31)+32768|0;c=_a;d=gc(YMa(d,d>>>0<32768?c+1|0:c,65536,0),_a);c=i[b+700>>2];d=d-c|0;d=(d|0)<-1?d:-1}e=i[b+708>>2];c=c+d|0;c=(c|0)<(e|0)?e:c}i[h+700>>2]=c}if((c|0)!=(e|0)){break c}kb(f+8|0,a+1074308|0,25);if(n=!ib(f+8|0),p=0,r=i[a+480180>>2]!=1,r?n:p){break c}i[b+708>>2]=0}Xa=f+16|0}function Bu(a){var b=0,c=0,d=0,e=0,f=0,g=0,j=0,m=0,n=0,o=0,p=0;c=Xa-96|0;Xa=c;g=a;m=a;a:{b:{c:{d:{e:{if(!(n=0,o=!dd(a,11),p=i[a+4>>2],p?n:o)){d=i[a+28>>2];b=c+80|0;e=i[a+12>>2];f=i[a+64>>2];j=f+i[a+8>>2]|0;if(j>>>0<f>>>0){e=e+1|0}e=og(b,j,e);f=i[e+12>>2];i[c+32>>2]=i[e+8>>2];i[c+36>>2]=f;b=i[e+4>>2];i[c+24>>2]=i[e>>2];i[c+28>>2]=b;Di(d,c+24|0);b=i[a+28>>2];if(kt(i[i[b>>2]+ -12>>2]+b|0)){ig(a,1073741826);break a}e=a+44|0;PY(e,i[a+92>>2]);f=a+32|0;eD(f,i[a+92>>2]<<2);if(i[a+92>>2]){b=0;while(1){d=i[a+28>>2];if(kt(i[i[d>>2]+ -12>>2]+d|0)){ig(a,1073741828);break a}d=k[a+16>>1];h[c+78>>1]=d;if((d|0)==65535){Cu(i[a+28>>2],c+78|0)}n=c,o=rc(f),i[n+72>>2]=o;f:{if(!k[c+78>>1]){d=0;break f}j=i[c+72>>2];d=k[c+78>>1];if(-1-j>>>0<d>>>0){break f}Kn(f,d+j|0);yj(i[a+28>>2],dc(f,i[c+72>>2]),k[c+78>>1]);d=k[c+78>>1]}n=_b(e,b),o=d,h[n+12>>1]=o;d=i[c+72>>2];n=_b(e,b),o=d,i[n>>2]=o;if(dd(a,6)){jj(i[a+28>>2],c+56|0);if(l[c+60>>2]>2147483647){break e}d=i[c+56>>2];n=_b(e,b),o=d,i[n+4>>2]=o}d=i[a+4>>2];g:{if(d){n=_b(e,b),o=d,i[n+8>>2]=o;break g}if(!dd(a,7)){break g}jj(i[a+28>>2],c+56|0);if(l[c+60>>2]>2147483647){break d}d=i[c+56>>2];n=_b(e,b),o=d,i[n+8>>2]=o}h:{if(i[_b(e,b)+8>>2]==-1){break h}if(dd(a,6)){break h}if(b){d=b+ -1|0;d=i[_b(e,d)+4>>2]+i[_b(e,d)+8>>2]|0}else{d=0}n=_b(e,b),o=d,i[n+4>>2]=o}if(dd(a,8)){h[c+56>>1]=0;Cu(i[a+28>>2],c+56|0);d=dd(a,9);Hk(i[a+28>>2],k[c+56>>1]<<d,-1)}b=b+1|0;if(b>>>0<l[a+92>>2]){continue}break}}Ue(c+56|0,i[a+28>>2]);b=i[c+68>>2];i[a+72>>2]=i[c+64>>2];i[a+76>>2]=b}kj(a,4,1);e=i[a+88>>2];if((e|0)!=i[a+64>>2]){break c}b=i[a+76>>2];d=i[a+72>>2];break b}ig(a,1073741829);break a}ig(a,1073741829);break a}b=i[a+12>>2];d=e+i[a+8>>2]|0;if(d>>>0<e>>>0){b=b+1|0}}e=d;i[m+80>>2]=e;i[g+84>>2]=b;g=i[a+28>>2];b=og(c+40|0,e,b);e=i[b+12>>2];i[c+16>>2]=i[b+8>>2];i[c+20>>2]=e;e=i[b+4>>2];i[c+8>>2]=i[b>>2];i[c+12>>2]=e;Di(g,c+8|0);if(dd(a,6)){break a}if((n=0,o=!dd(a,7),p=i[a+4>>2],p?n:o)|!i[a+92>>2]){break a}b=i[a+80>>2];g=i[a+8>>2];g=b-g|0;e=a+44|0;b=0;while(1){d=_b(e,b);i[d+4>>2]=g+i[d+4>>2];b=b+1|0;if(b>>>0<l[a+92>>2]){continue}break}}Xa=c+96|0}function yua(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,h=0,j=0,k=0,l=0,m=0,n=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;e=Xa-80|0;Xa=e;w=i[a+16>>2];j=tf(e+48|0);i[j+8>>2]=a+112;i[j+16>>2]=i[a+128>>2];y=j,z=of(b+327720|0,i[b+20>>2],(i[a+88>>2]&16384)>>>14|0),i[y+12>>2]=z;b=i[j+16>>2];if(b){y=j,z=sf(a+8|0,b),i[y>>2]=z;i[j+4>>2]=_a}f=i[a+44>>2];i[e+32>>2]=f;p=i[a+48>>2];i[e+36>>2]=p;m=i[a+52>>2];i[e+40>>2]=m;n=i[a+56>>2];i[e+44>>2]=n;q=i[a+40>>2];r=i[a+36>>2];k=i[a+4>>2];h=i[a>>2];i[e+24>>2]=h;i[e+28>>2]=k;b=i[a+12>>2];i[e+16>>2]=i[a+8>>2];i[e+20>>2]=b;a:{if(!d){b=q>>12;l=r>>12;break a}while(1){b=0;f=b;l=h;i[e+72>>2]=h;i[e+76>>2]=b;k=(((k&2147483647)<<1|h>>>31)&-2)+w|0;b:{b=i[j+16>>2];if((b|0)<=0){break b}while(1){h=(f&2147483647)<<1|l>>>31;fd(i[j+8>>2],g[(h|1)+k|0]+g[k+(h&-2)|0]<<5);ed(i[j+8>>2],4);zb(e+72|0,j);if((b|0)<2){break b}b=b+ -1|0;l=i[e+72>>2];f=i[e+76>>2];continue}}b=i[j+8>>2];zb(b,b+8|0);b=i[j+8>>2];h=i[b+4>>2];if(h){f=b;b=(i[e+76>>2]&2147483647)<<1|i[e+72>>2]>>>31;fd(f,g[(b|1)+k|0]+g[k+(b&-2)|0]<<5);ed(i[j+8>>2],h);b=i[j+8>>2];h=i[b>>2];i[b>>2]=h;i[b+4>>2]=0}d=d+ -1|0;f=nf(b,i[j+12>>2]);i[e+12>>2]=f;i[e+8>>2]=f;l=0;p=1;while(1){m=i[a+60>>2];n=m;k=(e+32|0)+(l<<3)|0;s=i[k>>2];b=Eb(s,-16777216,16776704);v=i[a+64>>2];h=Eb(i[k+4>>2],-16777216,16776704);t=i[a+68>>2];x=t;t=t>>31;i[k+4>>2]=s;s=i[a+72>>2];u=m>>31;m=f<<8;f=m;f=XMa(n,u,f,f>>31);n=_a;u=(e+8|0)+(l<<2)|0;l=XMa(v,v>>31,b,b>>31);f=l+f|0;b=_a+n|0;b=f>>>0<l>>>0?b+1|0:b;n=f;f=XMa(x,t,h,h>>31);h=n+f|0;b=_a+b|0;b=h>>>0<f>>>0?b+1|0:b;h=h+8388608|0;if(h>>>0<8388608){b=b+1|0}b=(b&16777215)<<8|h>>>24;i[u>>2]=(b|0)/256;i[k>>2]=b-(m&s);if(p){l=1;p=0;f=i[e+12>>2];continue}break}b=i[a+32>>2];r=i[a+28>>2]+r|0;l=r>>12;i[c>>2]=i[c>>2]+o(l,i[e+8>>2]);q=b+q|0;b=q>>12;i[c+4>>2]=i[c+4>>2]+o(b,i[e+12>>2]);zb(e+24|0,e+16|0);if(d){c=c+8|0;h=i[e+24>>2];k=i[e+28>>2];continue}break}h=i[e+24>>2];k=i[e+28>>2];n=i[e+44>>2];m=i[e+40>>2];p=i[e+36>>2];f=i[e+32>>2]}i[a+40>>2]=q;i[a+20>>2]=l;i[a+36>>2]=r;i[a+56>>2]=n;i[a+52>>2]=m;i[a+48>>2]=p;i[a+44>>2]=f;i[a+24>>2]=b;i[a>>2]=h;i[a+4>>2]=k;Xa=e+80|0}function dva(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;g=Xa-48|0;Xa=g;w=i[a+16>>2];a:{b:{c:{k=i[a+8>>2];f=i[a+12>>2];d:{if((f|0)<1?1:(f|0)<=1?k>>>0<=805306368:0){if((f|0)>-2?1:(f|0)>=-2?k>>>0>=3489660928:0){break c}if((f|0)>-2?1:(f|0)>=-2?k>>>0>2147483647:0){break d}break b}if((f|0)>1?1:(f|0)>=1?k>>>0>2147483648:0){break b}}b=b+196648|0;break a}b=b+131112|0;break a}b=b+262184|0}x=b;j=i[a+44>>2];i[g+32>>2]=j;p=i[a+48>>2];i[g+36>>2]=p;m=i[a+52>>2];i[g+40>>2]=m;n=i[a+56>>2];i[g+44>>2]=n;r=i[a+40>>2];s=i[a+36>>2];e=i[a+4>>2];l=i[a>>2];i[g+24>>2]=l;i[g+28>>2]=e;i[g+16>>2]=k;i[g+20>>2]=f;e:{if(!d){b=r>>12;f=s>>12;break e}while(1){p=1;b=((((e&2147483647)<<1|l>>>31)&2147483646)<<1)+w|0;e=(l>>>16&65520)+x|0;l=h[e+14>>1];k=h[e+12>>1];n=h[e+10>>1];t=h[e+8>>1];y=h[e+6>>1];q=h[e+4>>1];u=h[e+2>>1];v=h[e>>1];j=0;m=1;f=0;while(1){e=f<<1;i[(g+8|0)+(f<<2)>>2]=(((((((o(h[b+(e|-8)>>1],u)+o(h[b+(e|-12)>>1],v)|0)+o(h[b+(e|-4)>>1],q)|0)+o(h[b+e>>1],y)|0)+o(h[b+(e|4)>>1],t)|0)+o(h[b+(e|8)>>1],n)|0)+o(k,h[b+(e|12)>>1])|0)+o(l,h[b+(e|16)>>1])|0)/32768;e=m&1;m=0;f=1;if(e){continue}break}while(1){m=(g+8|0)+(j<<2)|0;l=i[m>>2];k=i[a+60>>2];e=(g+32|0)+(j<<3)|0;j=i[e>>2];b=Eb(j,-16777216,16776704);t=i[a+64>>2];f=Eb(i[e+4>>2],-16777216,16776704);q=i[a+68>>2];u=q;q=q>>31;i[e+4>>2]=j;v=i[a+72>>2];l=l<<8;j=l;j=XMa(k,k>>31,j,j>>31);k=_a;n=m;m=XMa(t,t>>31,b,b>>31);j=m+j|0;b=_a+k|0;b=j>>>0<m>>>0?b+1|0:b;k=j;j=XMa(u,q,f,f>>31);f=k+j|0;b=_a+b|0;b=f>>>0<j>>>0?b+1|0:b;f=f+8388608|0;if(f>>>0<8388608){b=b+1|0}b=(b&16777215)<<8|f>>>24;i[n>>2]=(b|0)/256;i[e>>2]=b-(l&v);j=1;b=p&1;p=0;if(b){continue}break}b=i[a+32>>2];s=i[a+28>>2]+s|0;f=s>>12;i[c>>2]=i[c>>2]+o(f,i[g+8>>2]);r=b+r|0;b=r>>12;i[c+4>>2]=i[c+4>>2]+o(b,i[g+12>>2]);zb(g+24|0,g+16|0);d=d+ -1|0;if(d){c=c+8|0;l=i[g+24>>2];e=i[g+28>>2];continue}break}l=i[g+24>>2];e=i[g+28>>2];n=i[g+44>>2];m=i[g+40>>2];p=i[g+36>>2];j=i[g+32>>2]}i[a+40>>2]=r;i[a+20>>2]=f;i[a+36>>2]=s;i[a+56>>2]=n;i[a+52>>2]=m;i[a+48>>2]=p;i[a+44>>2]=j;i[a+24>>2]=b;i[a>>2]=l;i[a+4>>2]=e;Xa=g+48|0}function lJ(a,b,c,d){var e=0,f=0,h=0,k=0,l=0,n=0,q=0;k=Xa-16|0;Xa=k;e=o(b,896)+a|0;a:{if(j[e+1075074|0]&2){n=1;b:{if(!(j[a+480209|0]&16)){break b}n=0;if(!(i[a+480180>>2]&16777248)){break b}n=!(j[a+480208|0]&4)}if(i[a+480180>>2]==64){a=o(b,896)+a|0;b=a+1075823|0;d=j[b|0];if(d&1){i[c>>2]=i[c>>2]+o(j[a+1075828|0],167)}g[b|0]=d+1;break a}h=e+1074984|0;c:{if(!n){break c}kb(k+8|0,a+1074308|0,21);if(!ib(k+8|0)){break c}e=o(b,896)+a|0;f=e+1075823|0;g[f|0]=j[f|0]+(j[e+1075827|0]<<2)}f=o(b,896)+a|0;l=f+1075826|0;q=f+1075823|0;e=Tw(a,j[l|0],j[q|0]);d:{if(Vi(h)){m[d>>2]=p(p(o(j[f+1075828|0],e)|0)*p(6510417279059766e-21))+m[d>>2];c=f+1075856|0;d=j[c|0];g[c|0]=d&243|8;if(i[a+1074416>>2]!=(i[a+1074392>>2]+1|0)){break d}g[c|0]=d|12;break d}if((i[a+480208>>2]&2101248)==2101248|(j[a+480209|0]&16?i[a+480180>>2]&67633152:0)){break a}e=i[a+480180>>2]&5?(j[l|0]&3)==1?0-e|0:e:e;h=a+1074308|0;kb(k+8|0,h,21);d=ib(k+8|0);f=i[a+480208>>2];e:{if(d){d=f&4;e=d?e:0-e|0;d=d?5:6;break e}d=5;f:{if(f&131072){break f}d=8;if(i[a+480180>>2]==1024){break f}d=7;if(i[a+480180>>2]&524304|(j[a+480208|0]&4?0:i[a+480180>>2]&16777248)){break f}d=6}kb(k+8|0,h,80);if(!ib(k+8|0)){break e}d=j[(o(b,896)+a|0)+1075797|0]==26?d+2|0:d}d=(o(j[(o(b,896)+a|0)+1075828|0],e)|0)/(1<<d)|0;f=0-d|0;g:{if(!(j[a+480208|0]&16)|i[a+480180>>2]==4){break g}e=i[c>>2];if((d|0)<=-1){d=kx(a,f>>>2|0);d=gc(YMa(XMa(d,d>>31,e,e>>31),_a,65536,0),_a);e=i[c>>2];d=d-e|0;h=f&3;if(!h){break g}l=d;d=kK(a,h);d=(l+gc(YMa(XMa(d,d>>31,e,e>>31),_a,65536,0),_a)|0)-i[c>>2]|0;break g}h=d&3;d=jx(a,d>>>2|0);d=gc(YMa(XMa(d,d>>31,e,e>>31),_a,65536,0),_a);e=i[c>>2];d=d-e|0;if(!h){break g}l=d;d=jK(a,h);d=(l+gc(YMa(XMa(d,d>>31,e,e>>31),_a,65536,0),_a)|0)-i[c>>2]|0}i[c>>2]=i[c>>2]+d;c=lx(a,b);if(!c){break d}d=c;e=f<<16>>16;h=i[(o(b,896)+a|0)+1075640>>2];l=2;h:{if(!h){break h}l=j[h+33|0]}$a[i[i[c>>2]+84>>2]](d,e,l<<24>>24,b)}if(!n){break a}kb(k+8|0,a+1074308|0,21);if(ib(k+8|0)){break a}g[q|0]=j[q|0]+j[(o(b,896)+a|0)+1075827|0];break a}if(!(j[e+1075654|0]&2)){break a}a=lx(a,b);if(!a){break a}$a[i[i[a>>2]+84>>2]](a,0,0,b)}Xa=k+16|0}function eva(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,j=0,k=0,l=0,m=0,n=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;e=Xa-48|0;Xa=e;x=i[a+16>>2];a:{b:{c:{l=i[a+8>>2];f=i[a+12>>2];d:{if((f|0)<1?1:(f|0)<=1?l>>>0<=805306368:0){if((f|0)>-2?1:(f|0)>=-2?l>>>0>=3489660928:0){break c}if((f|0)>-2?1:(f|0)>=-2?l>>>0>2147483647:0){break d}break b}if((f|0)>1?1:(f|0)>=1?l>>>0>2147483648:0){break b}}b=b+196648|0;break a}b=b+131112|0;break a}b=b+262184|0}y=b;j=i[a+44>>2];i[e+32>>2]=j;q=i[a+48>>2];i[e+36>>2]=q;n=i[a+52>>2];i[e+40>>2]=n;p=i[a+56>>2];i[e+44>>2]=p;s=i[a+40>>2];t=i[a+36>>2];k=i[a+4>>2];m=i[a>>2];i[e+24>>2]=m;i[e+28>>2]=k;i[e+16>>2]=l;i[e+20>>2]=f;e:{if(!d){b=s>>12;f=t>>12;break e}while(1){k=(((k&2147483647)<<1|m>>>31)&-2)+x|0;b=(m>>>16&65520)+y|0;f=h[b+14>>1];m=h[b+12>>1];l=h[b+10>>1];p=h[b+8>>1];u=h[b+6>>1];z=h[b+4>>1];r=h[b+2>>1];v=h[b>>1];j=0;q=1;n=1;b=0;while(1){i[(e+8|0)+(b<<2)>>2]=(((((((o(g[k+(b|-4)|0],r)+o(g[k+(b|-6)|0],v)|0)+o(g[k+(b|-2)|0],z)|0)+o(g[b+k|0],u)|0)+o(g[k+(b|2)|0],p)|0)+o(g[k+(b|4)|0],l)|0)+o(m,g[k+(b|6)|0])|0)+o(f,g[k+(b|8)|0])<<8)/32768;w=n&1;n=0;b=1;if(w){continue}break}while(1){n=(e+8|0)+(j<<2)|0;m=i[n>>2];l=i[a+60>>2];k=(e+32|0)+(j<<3)|0;j=i[k>>2];b=Eb(j,-16777216,16776704);u=i[a+64>>2];f=Eb(i[k+4>>2],-16777216,16776704);r=i[a+68>>2];v=r;r=r>>31;i[k+4>>2]=j;w=i[a+72>>2];m=m<<8;j=m;j=XMa(l,l>>31,j,j>>31);l=_a;p=n;n=XMa(u,u>>31,b,b>>31);j=n+j|0;b=_a+l|0;b=j>>>0<n>>>0?b+1|0:b;l=j;j=XMa(v,r,f,f>>31);f=l+j|0;b=_a+b|0;b=f>>>0<j>>>0?b+1|0:b;f=f+8388608|0;if(f>>>0<8388608){b=b+1|0}b=(b&16777215)<<8|f>>>24;i[p>>2]=(b|0)/256;i[k>>2]=b-(m&w);j=1;b=q&1;q=0;if(b){continue}break}b=i[a+32>>2];t=i[a+28>>2]+t|0;f=t>>12;i[c>>2]=i[c>>2]+o(f,i[e+8>>2]);s=b+s|0;b=s>>12;i[c+4>>2]=i[c+4>>2]+o(b,i[e+12>>2]);zb(e+24|0,e+16|0);d=d+ -1|0;if(d){c=c+8|0;m=i[e+24>>2];k=i[e+28>>2];continue}break}m=i[e+24>>2];k=i[e+28>>2];p=i[e+44>>2];n=i[e+40>>2];q=i[e+36>>2];j=i[e+32>>2]}i[a+40>>2]=s;i[a+20>>2]=f;i[a+36>>2]=t;i[a+56>>2]=p;i[a+52>>2]=n;i[a+48>>2]=q;i[a+44>>2]=j;i[a+24>>2]=b;i[a>>2]=m;i[a+4>>2]=k;Xa=e+48|0}function LB(a,b,c,d,e,f,g,h,j){var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;k=Xa-128|0;Xa=k;a:{b:{c:{if(!Lk(f,g,h,j,0,0,0,0)){break c}m=nX(f,g,h,j);s=e>>>16|0;p=s&32767;if((p|0)==32767){break c}if(m){break b}}_c(k+16|0,b,c,d,e,f,g,h,j);e=i[k+16>>2];d=i[k+20>>2];c=i[k+24>>2];b=i[k+28>>2];HD(k,e,d,c,b,e,d,c,b);d=i[k+8>>2];e=i[k+12>>2];h=i[k>>2];j=i[k+4>>2];break a}m=p<<16;q=d;r=m|e&65535;n=r;o=h;r=j>>>16&32767;l=j&65535|r<<16;if((Lk(b,c,q,n,f,g,h,l)|0)<=0){if(Lk(b,c,q,n,f,g,o,l)){h=b;j=c;break a}_c(k+112|0,b,c,d,e,0,0,0,0);d=i[k+120>>2];e=i[k+124>>2];h=i[k+112>>2];j=i[k+116>>2];break a}if(p){j=c;h=b}else{_c(k+96|0,b,c,q,n,0,0,0,1081540608);h=i[k+108>>2];n=h;q=i[k+104>>2];p=(h>>>16|0)+ -120|0;j=i[k+100>>2];h=i[k+96>>2]}if(!r){_c(k+80|0,f,g,o,l,0,0,0,1081540608);f=i[k+92>>2];l=f;o=i[k+88>>2];r=(l>>>16|0)+ -120|0;g=i[k+84>>2];f=i[k+80>>2]}t=l&65535|65536;n=n&65535|65536;if((p|0)>(r|0)){while(1){l=q;m=o;u=l-m|0;m=n-((l>>>0<m>>>0)+t|0)|0;l=(g|0)==(j|0)&h>>>0<f>>>0|j>>>0<g>>>0;m=m-(u>>>0<l>>>0)|0;l=u-l|0;d:{if((m|0)>0?1:(m|0)>=0?l>>>0>=0:0){n=h;h=h-f|0;j=j-((n>>>0<f>>>0)+g|0)|0;if(!(h|l|(j|m))){_c(k+32|0,b,c,d,e,0,0,0,0);d=i[k+40>>2];e=i[k+44>>2];h=i[k+32>>2];j=i[k+36>>2];break a}m=m<<1|l>>>31;q=l<<1|j>>>31;break d}m=n<<1|q>>>31;q=q<<1|j>>>31}n=m;m=j<<1|h>>>31;h=h<<1;j=m;p=p+ -1|0;if((p|0)>(r|0)){continue}break}p=r}e:{m=q;r=m-o|0;l=n-((m>>>0<o>>>0)+t|0)|0;m=(g|0)==(j|0)&h>>>0<f>>>0|j>>>0<g>>>0;l=l-(r>>>0<m>>>0)|0;o=r-m|0;if((l|0)<0?1:(l|0)<=0?o>>>0<0:0){o=q;l=n;break e}q=h;h=h-f|0;j=j-((q>>>0<f>>>0)+g|0)|0;if(h|o|(j|l)){break e}_c(k+48|0,b,c,d,e,0,0,0,0);d=i[k+56>>2];e=i[k+60>>2];h=i[k+48>>2];j=i[k+52>>2];break a}if((l|0)==65535|l>>>0<65535){while(1){b=j>>>31|0;p=p+ -1|0;n=j<<1|h>>>31;h=h<<1;j=n;c=b;b=o;l=l<<1|b>>>31;o=c|b<<1;if((l|0)==65536&o>>>0<0|l>>>0<65536){continue}break}}b=s&32768;if((p|0)<=0){_c(k- -64|0,h,j,o,l&65535|(b|p+120)<<16,0,0,0,1065811968);d=i[k+72>>2];e=i[k+76>>2];h=i[k+64>>2];j=i[k+68>>2];break a}d=o;e=l&65535|(b|p)<<16}i[a>>2]=h;i[a+4>>2]=j;i[a+8>>2]=d;i[a+12>>2]=e;Xa=k+128|0}function $wa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,j=0,m=0,n=0,o=0;d=Xa+ -64|0;Xa=d;h[d+62>>1]=c;Ag(d+62|0,32);f=mn(a);i[114610]=0;D(798,f|0,k[d+62>>1]);a=i[114610];i[114610]=0;a:{if((a|0)!=1){b:{c:{if(!k[d+62>>1]){break c}while(1){a=k[b+480190>>1]+1|0;h[d+60>>1]=a;d:{e:{if((a&65535)>>>0<4e3){break e}h[d+24>>1]=1;f:{if(!k[b+480190>>1]){break f}while(1){g:{if(ie(Uo(b,k[d+24>>1]))){break g}n=d,o=sy(Jb(f),Kb(f),d+24|0),i[n+48>>2]=o;n=d,o=Kb(f),i[n+40>>2]=o;if(!al(d+48|0,d+40|0)){break g}h[d+60>>1]=k[d+24>>1];a=1;if(!k[b+480192>>1]){break f}while(1){c=i[(((a&65535)<<2)+b|0)+900380>>2];h:{if(!c){break h}c=c+236|0;e=ms(c);if((c|0)==(e|0)){break h}while(1){if(k[c>>1]==k[d+60>>1]){h[c>>1]=0}c=c+2|0;if((e|0)!=(c|0)){continue}break}}a=a+1|0;if((a&65535)>>>0<=k[b+480192>>1]){continue}break}break f}a=k[d+24>>1]+1|0;h[d+24>>1]=a;if((a&65535)>>>0<=k[b+480190>>1]){continue}break}}if(k[d+60>>1]<4e3){break e}a=ws(d+48|0);i[114610]=0;c=C(1051,b|0,a|0)|0;e=i[114610];i[114610]=0;i:{j:{if((e|0)==1){break j}k:{if(c){i[114610]=0;C(1052,b|0,a|0)|0;c=i[114610];i[114610]=0;if((c|0)==1){break j}e=1;if(!k[b+480192>>1]){break k}while(1){c=i[(((e&65535)<<2)+b|0)+900380>>2];l:{if(!c){break l}c=c+236|0;j=ms(c);if((c|0)==(j|0)){break l}while(1){m:{if(l[a+4>>2]<=k[c>>1]){break m}Ld(d+40|0,a,k[c>>1]);if(ib(d+40|0)){break m}h[c>>1]=0}c=c+2|0;if((j|0)!=(c|0)){continue}break}}e=e+1|0;if((e&65535)>>>0<=k[b+480192>>1]){continue}break}break k}Td(a);break c}Wi(d+24|0,a);i[114610]=0;G(1053,d+32|0,d+24|0,1);c=i[114610];i[114610]=0;if((c|0)!=1){Uj(d+16|0,a);i[114610]=0;g[d+15|0]=0;J(1054,d+40|0,d+32|0,d+16|0,d+15|0);c=i[114610];i[114610]=0;if((c|0)!=1){break i}}}c=B()|0;A()|0;Td(a);break a}Wi(d,a);n=d,o=$h(d+40|0,d),h[n+60>>1]=o;Td(a);if(k[d+60>>1]>=4e3){break d}}i[114610]=0;D(461,f|0,d+60|0);a=i[114610];i[114610]=0;if((a|0)==1){break b}if(k[d+60>>1]<=k[b+480190>>1]){break d}h[b+480190>>1]=k[d+60>>1]}m=m+1|0;if((m&65535)>>>0<k[d+62>>1]){continue}break}}Xa=d- -64|0;return}c=B()|0;A()|0;break a}c=B()|0;A()|0}df(f);E(c|0);x()}function lca(a,b,c,d,e,f,g,h,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0;l=Xa-48|0;Xa=l;a:{b:{c:{k=In(1,32);d:{e:{if(!k){a=P(4)|0;zk(a);i[114610]=0;G(2009,a|0,71348,2008);a=i[114610];i[114610]=0;if((a|0)!=1){break a}j=H(0)|0;A()|0;break e}i[k+16>>2]=0;i[k+20>>2]=0;i[k+12>>2]=f;i[k+8>>2]=e;i[k+4>>2]=d;i[k+24>>2]=0;i[k+28>>2]=0;i[k>>2]=c?c:1997;d=Yr(l+32|0);f:{g:{if(!j){break g}c=i[j>>2];if(!c){break g}while(1){h:{e=i[j+4>>2];if(e){i[114610]=0;c=C(85,l+16|0,c|0)|0;f=i[114610];i[114610]=0;i:{if((f|0)!=1){i[114610]=0;f=C(2010,d|0,c|0)|0;m=i[114610];i[114610]=0;if((m|0)==1){break i}i[114610]=0;C(483,f|0,e|0)|0;e=i[114610];i[114610]=0;if((e|0)==1){break i}break h}j=H(0)|0;A()|0;break f}j=H(0)|0;A()|0;eb(c);break f}i[114610]=0;c=C(85,l+16|0,c|0)|0;e=i[114610];i[114610]=0;j:{if((e|0)!=1){i[114610]=0;C(2011,d|0,c|0)|0;e=i[114610];i[114610]=0;if((e|0)==1){break j}break h}j=H(0)|0;A()|0;break f}j=H(0)|0;A()|0;eb(c);break f}eb(c);c=i[j+8>>2];j=j+8|0;if(c){continue}break}}i[114610]=0;c=F(1398,96)|0;e=i[114610];i[114610]=0;k:{l:{m:{if((e|0)!=1){i[114610]=0;G(2012,l+16|0,k|0,k+4|0);e=i[114610];i[114610]=0;if((e|0)==1){break m}e=eo(l+8|0,l+16|0);i[114610]=0;S(2087,c|0,a|0,b|0,e|0,d|0)|0;a=i[114610];i[114610]=0;if((a|0)==1){break l}i[k+28>>2]=c;Ec(e);Ec(l+16|0);a=i[k+28>>2];i[k+24>>2]=a?a+8|0:0;Pj(d);break d}j=H(0)|0;A()|0;break f}j=H(0)|0;A()|0;break k}j=H(0)|0;A()|0;Ec(e);Ec(l+16|0)}Cb(c)}Pj(d);M(j|0)|0;i[114610]=0;J(1989,37207,k|0,g|0,h|0);a=i[114610];i[114610]=0;if((a|0)!=1){i[114610]=0;K(20);a=i[114610];i[114610]=0;if((a|0)!=1){a=i[k+28>>2];if(a){$a[i[i[a>>2]+4>>2]](a)}i[k+24>>2]=0;i[k+28>>2]=0;a=i[k+20>>2];if(a){Cb(a)}Cb(k);k=0;break d}j=H(0)|0;A()|0;break e}j=H(0)|0;A()|0;i[114610]=0;K(20);a=i[114610];i[114610]=0;if((a|0)==1){break b}}M(j|0)|0;k=0;i[114610]=0;J(1989,37207,0,g|0,h|0);a=i[114610];i[114610]=0;if((a|0)==1){break c}O()}Xa=l+48|0;return k|0}a=B()|0;A()|0;i[114610]=0;K(20);b=i[114610];i[114610]=0;if((b|0)==1){break b}E(a|0);x()}a=H(0)|0;A()|0;gb(a)}x()}function Su(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,h=0,k=0,l=0;e=i[b>>2];a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{if(!d){break l}h=i[d>>2];if(!h){break l}if(!a){d=c;break j}i[d>>2]=0;d=c;break k}m:{if(!i[i[21199]>>2]){if(!a){break m}if(!c){break a}h=c;while(1){d=g[e|0];if(d){i[a>>2]=d&57343;a=a+4|0;e=e+1|0;h=h+ -1|0;if(h){continue}break a}break}i[a>>2]=0;i[b>>2]=0;return c-h|0}d=c;if(!a){break i}break g}return le(e)|0}f=1;break g}f=0;break h}f=1}while(1){if(!f){f=j[e|0]>>>3|0;if((f+ -16|f+(h>>26))>>>0>7){break f}f=e+1|0;n:{if(!(h&33554432)){break n}k=e;if((j[e+1|0]&192)!=128){break f}f=e+2|0;if(!(h&524288)){break n}if((j[k+2|0]&192)!=128){break f}f=e+3|0}e=f;d=d+ -1|0;f=1;continue}while(1){h=j[e|0];o:{if(e&3|h+ -1>>>0>126){break o}h=i[e>>2];if((h|h+ -16843009)&-2139062144){break o}while(1){d=d+ -4|0;h=i[e+4>>2];f=e+4|0;e=f;if(!((h+ -16843009|h)&-2139062144)){continue}break}e=f}f=h&255;if(f+ -1>>>0<=126){d=d+ -1|0;e=e+1|0;continue}break}f=f+ -194|0;if(f>>>0>50){break e}e=e+1|0;h=i[(f<<2)+57664>>2];f=0;continue}}while(1){if(!f){if(!d){break a}while(1){p:{f=j[e|0];k=f+ -1|0;q:{r:{if(k>>>0>126){h=f;break r}if(e&3|d>>>0<5){break q}s:{while(1){h=i[e>>2];if((h|h+ -16843009)&-2139062144){break s}i[a>>2]=h&255;i[a+4>>2]=j[e+1|0];i[a+8>>2]=j[e+2|0];i[a+12>>2]=j[e+3|0];a=a+16|0;e=e+4|0;d=d+ -4|0;if(d>>>0>4){continue}break}h=j[e|0]}f=h&255;k=f+ -1|0}if(k>>>0>126){break p}}i[a>>2]=f;a=a+4|0;e=e+1|0;d=d+ -1|0;if(d){continue}break a}break}f=f+ -194|0;if(f>>>0>50){break e}e=e+1|0;h=i[(f<<2)+57664>>2];f=1;continue}k=j[e|0];f=k>>>3|0;if((f+ -16|f+(h>>26))>>>0>7){break f}t:{u:{f=k+ -128|h<<6;l=e+1|0;v:{if((f|0)>-1){break v}k=e;l=j[e+1|0]+ -128|0;if(l>>>0>63){break u}f=f<<6|l;l=e+2|0;if((f|0)>-1){break v}k=j[k+2|0]+ -128|0;if(k>>>0>63){break u}f=k|f<<6;l=e+3|0}e=l;i[a>>2]=f;d=d+ -1|0;a=a+4|0;break t}i[114584]=25;e=e+ -1|0;break c}f=0;continue}}e=e+ -1|0;if(h){break d}h=j[e|0]}if(h&255){break d}if(a){i[a>>2]=0;i[b>>2]=0}return c-d|0}i[114584]=25;if(!a){break b}}i[b>>2]=e}return-1}i[b>>2]=e;return c|0}function H$(a,b,c,d,e,f,g,h,k){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0;a=Xa-1072|0;Xa=a;i[a+16>>2]=f;i[a+20>>2]=g;i[a+24>>2]=h;i[a+28>>2]=k;i[a+956>>2]=a+960;l=Uu(a+960|0,100,62399,a+16|0);i[a+48>>2]=2420;p=wd(a+536|0,0,a+48|0);i[a+48>>2]=2420;o=wd(a+528|0,0,a+48|0);n=a+544|0;a:{b:{c:{if(l>>>0>=100){i[114610]=0;l=R(2445)|0;n=i[114610];i[114610]=0;if((n|0)==1){break b}i[a>>2]=f;i[a+4>>2]=g;i[114610]=0;i[a+8>>2]=h;i[a+12>>2]=k;l=N(2467,a+956|0,l|0,62399,a|0)|0;f=i[114610];i[114610]=0;if((f|0)==1){break b}f=i[a+956>>2];if(!f){i[114610]=0;K(2421);a=i[114610];i[114610]=0;if((a|0)!=1){break c}break b}de(p,f);de(o,Zc(l<<2));if(Si(o)){i[114610]=0;K(2421);a=i[114610];i[114610]=0;if((a|0)==1){break b}break c}n=i[o>>2]}i[114610]=0;fc(a+520|0,d);f=i[114610];i[114610]=0;d:{e:{f:{g:{h:{i:{j:{if((f|0)!=1){i[114610]=0;r=F(2449,a+520|0)|0;f=i[114610];i[114610]=0;if((f|0)==1){break j}i[114610]=0;f=i[a+956>>2];N(2463,r|0,f|0,f+l|0,n|0)|0;f=i[114610];i[114610]=0;if((f|0)==1){break j}q=l?j[i[a+956>>2]]==45:q;h=Ab(a+488|0);g=Ke(a+472|0);f=Ke(a+456|0);i[114610]=0;$(2503,c|0,q|0,a+520|0,a+512|0,a+508|0,a+504|0,h|0,g|0,f|0,a+452|0);c=i[114610];i[114610]=0;if((c|0)==1){break i}i[a+36>>2]=2420;k=wd(a+40|0,0,a+36|0);c=i[a+452>>2];k:{if((l|0)>(c|0)){m=lb(f)+(l-c<<1|1)|0;break k}m=lb(f)+2|0}c=a+48|0;m=(lb(g)+m|0)+i[a+452>>2]|0;if(m>>>0<101){break h}de(k,Zc(m<<2));c=i[k>>2];if(c){break h}i[114610]=0;K(2421);b=i[114610];i[114610]=0;if((b|0)!=1){break c}break g}l=B()|0;A()|0;break a}l=B()|0;A()|0;break e}l=B()|0;A()|0;break f}m=i[d+4>>2];i[114610]=0;ea(2504,c|0,a+36|0,a+32|0,m|0,n|0,(l<<2)+n|0,r|0,q|0,a+512|0,i[a+508>>2],i[a+504>>2],h|0,g|0,f|0,i[a+452>>2]);l=i[114610];i[114610]=0;if((l|0)!=1){i[114610]=0;b=Y(2479,b|0,c|0,i[a+36>>2],i[a+32>>2],d|0,e|0)|0;c=i[114610];i[114610]=0;if((c|0)!=1){break d}}}l=B()|0;A()|0;lc(k)}nc(f);nc(g);eb(h)}ub(a+520|0);break a}lc(k);nc(f);nc(g);eb(h);ub(a+520|0);lc(o);lc(p);Xa=a+1072|0;return b|0}x()}l=B()|0;A()|0}lc(o);lc(p);E(l|0);x()}function Bua(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;e=Xa-80|0;Xa=e;t=i[a+16>>2];k=tf(e+48|0);i[k+8>>2]=a+112;i[k+16>>2]=i[a+128>>2];y=k,z=of(b+327720|0,i[b+20>>2],(i[a+88>>2]&16384)>>>14|0),i[y+12>>2]=z;b=i[k+16>>2];if(b){y=k,z=sf(a+8|0,b),i[y>>2]=z;i[k+4>>2]=_a}b=i[a+44>>2];i[e+32>>2]=b;g=i[a+48>>2];i[e+36>>2]=g;j=i[a+52>>2];i[e+40>>2]=j;n=i[a+56>>2];i[e+44>>2]=n;u=i[a+24>>2];v=i[a+20>>2];l=i[a+4>>2];f=i[a>>2];i[e+24>>2]=f;i[e+28>>2]=l;m=i[a+12>>2];i[e+16>>2]=i[a+8>>2];i[e+20>>2]=m;if(d){while(1){b=0;g=b;j=f;i[e+72>>2]=f;i[e+76>>2]=b;l=((((l&2147483647)<<1|f>>>31)&2147483646)<<1)+t|0;a:{b=i[k+16>>2];if((b|0)<=0){break a}while(1){f=(g&2147483647)<<1|j>>>31;fd(i[k+8>>2],(h[(f<<1|2)+l>>1]+h[l+((f&2147483646)<<1)>>1]|0)/8<<16>>16);ed(i[k+8>>2],4);zb(e+72|0,k);if((b|0)<2){break a}b=b+ -1|0;j=i[e+72>>2];g=i[e+76>>2];continue}}b=i[k+8>>2];zb(b,b+8|0);b=i[k+8>>2];f=i[b+4>>2];if(f){m=b;b=(i[e+76>>2]&2147483647)<<1|i[e+72>>2]>>>31;fd(m,(h[(b<<1|2)+l>>1]+h[l+((b&2147483646)<<1)>>1]|0)/8<<16>>16);ed(i[k+8>>2],f);b=i[k+8>>2];f=i[b>>2];i[b>>2]=f;i[b+4>>2]=0}d=d+ -1|0;j=nf(b,i[k+12>>2]);i[e+12>>2]=j;i[e+8>>2]=j;g=0;n=1;while(1){m=i[a+60>>2];r=m;l=(e+32|0)+(g<<3)|0;p=i[l>>2];b=Eb(p,-16777216,16776704);s=i[a+64>>2];f=Eb(i[l+4>>2],-16777216,16776704);q=i[a+68>>2];w=q;q=q>>31;i[l+4>>2]=p;p=i[a+72>>2];m=m>>31;j=j<<8;m=XMa(r,m,j,j>>31);r=_a;x=(e+8|0)+(g<<2)|0;g=m;m=XMa(s,s>>31,b,b>>31);g=g+m|0;b=_a+r|0;b=g>>>0<m>>>0?b+1|0:b;m=g;g=XMa(w,q,f,f>>31);f=m+g|0;b=_a+b|0;b=f>>>0<g>>>0?b+1|0:b;f=f+8388608|0;if(f>>>0<8388608){b=b+1|0}b=(b&16777215)<<8|f>>>24;i[x>>2]=(b|0)/256;i[l>>2]=b-(j&p);if(n){g=1;n=0;j=i[e+12>>2];continue}break}i[c>>2]=i[c>>2]+o(i[e+8>>2],v);i[c+4>>2]=i[c+4>>2]+o(i[e+12>>2],u);zb(e+24|0,e+16|0);if(d){c=c+8|0;f=i[e+24>>2];l=i[e+28>>2];continue}break}f=i[e+24>>2];l=i[e+28>>2];n=i[e+44>>2];j=i[e+40>>2];g=i[e+36>>2];b=i[e+32>>2]}i[a+56>>2]=n;i[a+52>>2]=j;i[a+48>>2]=g;i[a+44>>2]=b;i[a>>2]=f;i[a+4>>2]=l;Xa=e+80|0}function tsa(a,b){var c=0,d=0,e=0,f=0,k=0,l=0,m=0;c=Xa-368|0;Xa=c;DL(c+80|0);l=Tb(b,c+80|0,282);b=0;if(sh(a,20092)){tg(a,4);f=He(c- -64|0,a);i[114610]=0;e=C(1202,f|0,l|0)|0;d=i[114610];i[114610]=0;a:{b:{c:{d:{if((d|0)==1){break d}if(!e){break a}e=l+26|0;d=j[e|0];i[114610]=0;d=C(258,f|0,d|0)|0;k=i[114610];i[114610]=0;if((k|0)==1){break d}if(!d){break a}if(!j[e|0]){d=0;break c}d=0;while(1){e:{i[114610]=0;k=F(375,f|0)|0;m=i[114610];i[114610]=0;if((m|0)==1){break e}g[(b+l|0)+27|0]=k;d=d+k|0;b=b+1|0;if(b>>>0<j[e|0]){continue}break c}break}b=B()|0;A()|0;break b}b=B()|0;A()|0;break b}b=0;i[114610]=0;k=d&65535;d=C(258,f|0,k|0)|0;m=i[114610];i[114610]=0;f:{if((m|0)==1){break f}if(!d){break a}i[114610]=0;C(338,f|0,k|0)|0;b=i[114610];i[114610]=0;if((b|0)==1){break f}tg(f,EL(l));i[114610]=0;d=F(1203,c+56|0)|0;b=i[114610];i[114610]=0;g:{if((b|0)!=1){CL(c+80|0);i[114610]=0;C(1204,f|0,c+80|0)|0;b=i[114610];i[114610]=0;if((b|0)==1){break g}i[114610]=0;h[c+102>>1]=0;h[c+104>>1]=0;I(1205,d|0,c+80|0,c+107|0)|0;b=i[114610];i[114610]=0;if((b|0)==1){break g}b=j[e|0];i[114610]=0;C(338,f|0,b|0)|0;b=i[114610];i[114610]=0;if((b|0)==1){break g}b=j[e|0];i[114610]=0;e=l+27|0;I(1205,d|0,e|0,b+e|0)|0;b=i[114610];i[114610]=0;if((b|0)==1){break g}i[114610]=0;G(341,c+40|0,f|0,k|0);b=i[114610];i[114610]=0;h:{i:{j:{if((b|0)!=1){i[114610]=0;D(862,c+16|0,c+40|0);b=i[114610];i[114610]=0;if((b|0)==1){break j}i[114610]=0;D(1207,c+8|0,c+16|0);b=i[114610];i[114610]=0;if((b|0)==1){break i}i[114610]=0;C(1208,d|0,c+8|0)|0;b=i[114610];i[114610]=0;if((b|0)==1){break i}jc(c+16|0);hb(c+40|0);b=0;i[114610]=0;d=F(1209,d|0)|0;e=i[114610];i[114610]=0;if((e|0)==1){break g}e=l+22|0;if((d|0)!=(j[e|0]|j[e+1|0]<<8|(j[e+2|0]<<16|j[e+3|0]<<24))){break a}b=EL(l);i[114610]=0;C(338,a|0,b|0)|0;a=i[114610];i[114610]=0;b=1;if((a|0)!=1){break a}break f}b=B()|0;A()|0;break b}b=B()|0;A()|0;break h}b=B()|0;A()|0;jc(c+16|0)}hb(c+40|0);break b}b=B()|0;A()|0;break b}b=B()|0;A()|0;break b}b=B()|0;A()|0}hb(f);E(b|0);x()}hb(f)}Xa=c+368|0;return b}function L$(a,b,c,d,e,f,h,k,l){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;h=h|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0;a=Xa-464|0;Xa=a;i[a+16>>2]=f;i[a+20>>2]=h;i[a+24>>2]=k;i[a+28>>2]=l;i[a+348>>2]=a+352;m=Uu(a+352|0,100,62399,a+16|0);i[a+48>>2]=2420;q=wd(a+232|0,0,a+48|0);i[a+48>>2]=2420;p=wd(a+224|0,0,a+48|0);o=a+240|0;a:{b:{c:{if(m>>>0>=100){i[114610]=0;m=R(2445)|0;o=i[114610];i[114610]=0;if((o|0)==1){break b}i[a>>2]=f;i[a+4>>2]=h;i[114610]=0;i[a+8>>2]=k;i[a+12>>2]=l;m=N(2467,a+348|0,m|0,62399,a|0)|0;f=i[114610];i[114610]=0;if((f|0)==1){break b}f=i[a+348>>2];if(!f){i[114610]=0;K(2421);a=i[114610];i[114610]=0;if((a|0)!=1){break c}break b}de(q,f);de(p,Zc(m));if(Si(p)){i[114610]=0;K(2421);a=i[114610];i[114610]=0;if((a|0)==1){break b}break c}o=i[p>>2]}i[114610]=0;fc(a+216|0,d);f=i[114610];i[114610]=0;d:{e:{f:{g:{h:{i:{j:{if((f|0)!=1){i[114610]=0;s=F(21,a+216|0)|0;f=i[114610];i[114610]=0;if((f|0)==1){break j}i[114610]=0;f=i[a+348>>2];N(2440,s|0,f|0,f+m|0,o|0)|0;f=i[114610];i[114610]=0;if((f|0)==1){break j}r=m?j[i[a+348>>2]]==45:r;k=Ab(a+192|0);h=Ab(a+176|0);f=Ab(a+160|0);i[114610]=0;$(2501,c|0,r|0,a+216|0,a+208|0,a+207|0,a+206|0,k|0,h|0,f|0,a+156|0);c=i[114610];i[114610]=0;if((c|0)==1){break i}i[a+36>>2]=2420;l=wd(a+40|0,0,a+36|0);c=i[a+156>>2];k:{if((m|0)>(c|0)){n=lb(f)+(m-c<<1|1)|0;break k}n=lb(f)+2|0}c=a+48|0;n=(lb(h)+n|0)+i[a+156>>2]|0;if(n>>>0<101){break h}de(l,Zc(n));c=i[l>>2];if(c){break h}i[114610]=0;K(2421);b=i[114610];i[114610]=0;if((b|0)!=1){break c}break g}m=B()|0;A()|0;break a}m=B()|0;A()|0;break e}m=B()|0;A()|0;break f}n=i[d+4>>2];i[114610]=0;ea(2502,c|0,a+36|0,a+32|0,n|0,o|0,m+o|0,s|0,r|0,a+208|0,g[a+207|0],g[a+206|0],k|0,h|0,f|0,i[a+156>>2]);m=i[114610];i[114610]=0;if((m|0)!=1){i[114610]=0;b=Y(17,b|0,c|0,i[a+36>>2],i[a+32>>2],d|0,e|0)|0;c=i[114610];i[114610]=0;if((c|0)!=1){break d}}}m=B()|0;A()|0;lc(l)}eb(f);eb(h);eb(k)}ub(a+216|0);break a}lc(l);eb(f);eb(h);eb(k);ub(a+216|0);lc(p);lc(q);Xa=a+464|0;return b|0}x()}m=B()|0;A()|0}lc(p);lc(q);E(m|0);x()}function Kla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,p=0,q=0,r=0,s=0;c=Xa-208|0;Xa=c;e=i[a+12>>2];l=1<<e;if(e>>>0>=2){k=l;p=2;f=1;while(1){k=k>>>2|0;if(k){r=o(f,3);s=f<<1;m=0;while(1){UI(c+192|0,_b(a,m<<1));UI(c+176|0,_b(a,m));lh(c+160|0,c+176|0,c+192|0);e=m<<p;q=f+e|0;if(e>>>0<q>>>0){while(1){d=_b(b,e);g=i[d+12>>2];i[c+152>>2]=i[d+8>>2];i[c+156>>2]=g;g=i[d+4>>2];i[c+144>>2]=i[d>>2];i[c+148>>2]=g;g=e+f|0;d=_b(b,g);h=i[d+12>>2];i[c+136>>2]=i[d+8>>2];i[c+140>>2]=h;h=i[d+4>>2];i[c+128>>2]=i[d>>2];i[c+132>>2]=h;h=e+s|0;d=_b(b,h);n=i[d+12>>2];i[c+120>>2]=i[d+8>>2];i[c+124>>2]=n;n=i[d+4>>2];i[c+112>>2]=i[d>>2];i[c+116>>2]=n;n=e+r|0;d=_b(b,n);j=i[d+12>>2];i[c+104>>2]=i[d+8>>2];i[c+108>>2]=j;j=i[d+4>>2];i[c+96>>2]=i[d>>2];i[c+100>>2]=j;Ij(c+80|0,c+144|0,c+128|0);Th(c- -64|0,c+144|0,c+128|0);Ij(c+48|0,c+112|0,c+96|0);Th(c+16|0,c+112|0,c+96|0);lh(c+32|0,30848,c+16|0);Ij(c+16|0,c+80|0,c+48|0);d=_b(b,e);j=i[c+28>>2];i[d+8>>2]=i[c+24>>2];i[d+12>>2]=j;j=i[c+20>>2];i[d>>2]=i[c+16>>2];i[d+4>>2]=j;Ij(c,c- -64|0,c+32|0);lh(c+16|0,c+192|0,c);d=_b(b,g);j=i[c+28>>2];i[d+8>>2]=i[c+24>>2];i[d+12>>2]=j;g=i[c+20>>2];i[d>>2]=i[c+16>>2];i[d+4>>2]=g;Th(c,c+80|0,c+48|0);lh(c+16|0,c+176|0,c);d=_b(b,h);h=i[c+28>>2];i[d+8>>2]=i[c+24>>2];i[d+12>>2]=h;g=i[c+20>>2];i[d>>2]=i[c+16>>2];i[d+4>>2]=g;Th(c,c- -64|0,c+32|0);lh(c+16|0,c+160|0,c);d=_b(b,n);h=i[c+28>>2];i[d+8>>2]=i[c+24>>2];i[d+12>>2]=h;g=i[c+20>>2];i[d>>2]=i[c+16>>2];i[d+4>>2]=g;e=e+1|0;if((q|0)!=(e|0)){continue}break}}m=m+1|0;if((m|0)!=(k|0)){continue}break}e=i[a+12>>2]}f=f<<2;p=p+2|0;if(p>>>0<=e>>>0){continue}break}}a:{if(!(e&1)){break a}k=l>>>1|0;if(!k){break a}e=0;while(1){l=e+k|0;a=_b(b,l);f=i[a+12>>2];i[c+200>>2]=i[a+8>>2];i[c+204>>2]=f;f=i[a+4>>2];i[c+192>>2]=i[a>>2];i[c+196>>2]=f;Th(c+176|0,_b(b,e),c+192|0);a=_b(b,l);f=i[c+188>>2];i[a+8>>2]=i[c+184>>2];i[a+12>>2]=f;l=i[c+180>>2];i[a>>2]=i[c+176>>2];i[a+4>>2]=l;Jw(_b(b,e),c+192|0);e=e+1|0;if((k|0)!=(e|0)){continue}break}}Xa=c+208|0}function ita(a,b,c){var d=0,e=0,f=0,l=0,m=0;d=Xa-160|0;Xa=d;f=Ek(d+56|0,a);i[114610]=0;e=C(686,d+40|0,18605)|0;a=i[114610];i[114610]=0;a:{b:{c:{d:{if((a|0)!=1){i[114610]=0;i[d+24>>2]=19465472;i[d+28>>2]=0;G(687,f|0,e|0,d+24|0);a=i[114610];i[114610]=0;if((a|0)==1){break d}ob(e);if(!(i[f>>2]&1073741824)){break c}break a}a=B()|0;A()|0;break b}a=B()|0;A()|0;ob(e);break b}i[114610]=0;g[d+39|0]=0;e=C(686,d+40|0,18612)|0;a=i[114610];i[114610]=0;e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{if((a|0)!=1){i[114610]=0;I(688,f|0,d+39|0,e|0)|0;a=i[114610];i[114610]=0;if((a|0)==1){break p}ob(e);e=Ab(d+40|0);i[114610]=0;l=C(686,d+24|0,18614)|0;a=i[114610];i[114610]=0;if((a|0)==1){break o}i[114610]=0;I(1183,f|0,e|0,l|0)|0;a=i[114610];i[114610]=0;if((a|0)==1){break n}ob(l);i[114610]=0;G(13,d+24|0,(j[d+39|0]?0:c)|0,e|0);a=i[114610];i[114610]=0;if((a|0)==1){break m}i[114610]=0;D(487,b|0,d+24|0);a=i[114610];i[114610]=0;if((a|0)==1){break l}eb(d+24|0);i[114610]=0;h[d+22>>1]=0;c=C(686,d+24|0,18616)|0;a=i[114610];i[114610]=0;if((a|0)==1){break f}i[114610]=0;I(1184,f|0,d+22|0,c|0)|0;a=i[114610];i[114610]=0;if((a|0)==1){break k}ob(c);Ag(d+22|0,k[i[19847]+12>>1]);i[114610]=0;c=C(686,d+24|0,18618)|0;a=i[114610];i[114610]=0;if((a|0)==1){break j}a=i[yc(d+16|0,k[d+22>>1])>>2];i[114610]=0;N(1185,f|0,b|0,c|0,a|0)|0;a=i[114610];i[114610]=0;if((a|0)==1){break i}ob(c);i[114610]=0;h[d+14>>1]=65535;c=C(686,d+24|0,18620)|0;a=i[114610];i[114610]=0;if((a|0)==1){break h}i[114610]=0;a=I(1184,f|0,d+14|0,c|0)|0;l=i[114610];i[114610]=0;if((l|0)==1){break g}l=k[d+22>>1];m=k[d+14>>1];ob(c);if(!((a|0)==1|m>>>0>=l>>>0)){Fe(b,k[d+14>>1])}eb(e);break a}a=B()|0;A()|0;break b}a=B()|0;A()|0;ob(e);break b}a=B()|0;A()|0;break e}a=B()|0;A()|0;ob(l);break e}a=B()|0;A()|0;break e}a=B()|0;A()|0;eb(d+24|0);break e}a=B()|0;A()|0;ob(c);break e}a=B()|0;A()|0;break e}a=B()|0;A()|0;ob(c);break e}a=B()|0;A()|0;break e}a=B()|0;A()|0;ob(c);break e}a=B()|0;A()|0}eb(e)}Yf(f);E(a|0);x()}Yf(f);Xa=d+160|0}function hva(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;f=Xa-48|0;Xa=f;u=i[a+16>>2];a:{b:{c:{j=i[a+8>>2];e=i[a+12>>2];d:{if((e|0)<1?1:(e|0)<=1?j>>>0<=805306368:0){if((e|0)>-2?1:(e|0)>=-2?j>>>0>=3489660928:0){break c}if((e|0)>-2?1:(e|0)>=-2?j>>>0>2147483647:0){break d}break b}if((e|0)>1?1:(e|0)>=1?j>>>0>2147483648:0){break b}}b=b+196648|0;break a}b=b+131112|0;break a}b=b+262184|0}v=b;b=i[a+44>>2];i[f+32>>2]=b;k=i[a+48>>2];i[f+36>>2]=k;m=i[a+52>>2];i[f+40>>2]=m;n=i[a+56>>2];i[f+44>>2]=n;w=i[a+24>>2];x=i[a+20>>2];g=i[a+4>>2];l=i[a>>2];i[f+24>>2]=l;i[f+28>>2]=g;i[f+16>>2]=j;i[f+20>>2]=e;if(d){while(1){n=1;e=((((g&2147483647)<<1|l>>>31)&2147483646)<<1)+u|0;b=(l>>>16&65520)+v|0;l=h[b+14>>1];j=h[b+12>>1];q=h[b+10>>1];r=h[b+8>>1];s=h[b+6>>1];p=h[b+4>>1];t=h[b+2>>1];y=h[b>>1];m=0;b=1;k=0;while(1){g=k<<1;i[(f+8|0)+(k<<2)>>2]=(((((((o(h[e+(g|-8)>>1],t)+o(h[e+(g|-12)>>1],y)|0)+o(h[e+(g|-4)>>1],p)|0)+o(h[e+g>>1],s)|0)+o(h[e+(g|4)>>1],r)|0)+o(h[e+(g|8)>>1],q)|0)+o(h[e+(g|12)>>1],j)|0)+o(l,h[e+(g|16)>>1])|0)/32768;g=b;b=0;k=1;if(g){continue}break}while(1){k=(f+8|0)+(m<<2)|0;l=i[k>>2];j=i[a+60>>2];q=j;g=(f+32|0)+(m<<3)|0;m=i[g>>2];b=Eb(m,-16777216,16776704);r=i[a+64>>2];e=Eb(i[g+4>>2],-16777216,16776704);p=i[a+68>>2];t=p;p=p>>31;i[g+4>>2]=m;m=i[a+72>>2];s=j>>31;l=l<<8;j=l;j=XMa(q,s,j,j>>31);q=_a;s=k;k=j;j=XMa(r,r>>31,b,b>>31);k=k+j|0;b=_a+q|0;b=k>>>0<j>>>0?b+1|0:b;j=k;k=XMa(t,p,e,e>>31);e=j+k|0;b=_a+b|0;b=e>>>0<k>>>0?b+1|0:b;e=e+8388608|0;if(e>>>0<8388608){b=b+1|0}b=(b&16777215)<<8|e>>>24;i[s>>2]=(b|0)/256;i[g>>2]=b-(l&m);m=1;b=n&1;n=0;if(b){continue}break}i[c>>2]=i[c>>2]+o(i[f+8>>2],x);i[c+4>>2]=i[c+4>>2]+o(i[f+12>>2],w);zb(f+24|0,f+16|0);d=d+ -1|0;if(d){c=c+8|0;l=i[f+24>>2];g=i[f+28>>2];continue}break}l=i[f+24>>2];g=i[f+28>>2];n=i[f+44>>2];m=i[f+40>>2];k=i[f+36>>2];b=i[f+32>>2]}i[a+56>>2]=n;i[a+52>>2]=m;i[a+48>>2]=k;i[a+44>>2]=b;i[a>>2]=l;i[a+4>>2]=g;Xa=f+48|0}function oU(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=Xa-16|0;Xa=f;if((d|0)<1){a=0}else{Kn(c,d);i[f+4>>2]=b;i[f>>2]=a;a=jb(i[c>>2]);i[f+12>>2]=d;i[f+8>>2]=a;q=d;a=0;b=0;while(1){a:{e=$f(f,b);n=$f(f,b+4|0)<<8|$f(f,b+5|0);g=$f(f,b+6|0);j=$f(f,b+7|0);t=b+8|0;b:{c:{d:{switch(e|0){case 0:b=0;if(!n){break c}while(1){Lp(f,a+b|0,$f(f,b+t|0));b=b+1|0;if((n|0)!=(b|0)){continue}break}break c;case 1:break d;default:break a}}o=$f(f,b+10|0);Lp(f,a,o);a=(a>>>0<d>>>0)+a|0;n=n+3&65532;r=j|g<<8;if(r>>>0<2){break b}k=b+11|0;b=r+ -1|0;g=0;l=0;m=0;p=0;while(1){j=Af(k,g,1,f);e:{f:{g:{h:{i:{if((l|0)<=7){if(j){e=g;break f}g=g+1|0;m=8;break i}e=g+1|0;j:{if(!j){if(!Af(k,e,1,f)){break f}e=2;k:{l:{h=g+2|0;if(!Af(k,h,1,f)){break l}e=3;h=g+3|0;if(!Af(k,h,1,f)){break l}e=Af(k,h,3,f);g=g+6|0;break k}g=h+1|0}h=4;m=nU(((m<<3)+e|0)+ -17|0);if((m|0)!=8){break h}break j}h=4;g=e;if((m|0)!=8){break h}}m=8;h=1;if((p|0)>19){break h}}h=0;break g}p=p+8|0}e=b;m:{if((b|0)<1){break m}while(1){o=o-mU(k,g,m,f)|0;Lp(f,a,o&255);e=b+ -1|0;g=g+m|0;a=(a>>>0<d>>>0)+a|0;if((h|0)<1){break m}h=h+ -1|0;j=(b|0)>1;b=e;if(j){continue}break}}l=(l|0)==31?31:l+1|0;b=e;break e}n:{o:{p:{h=e+1|0;if(!Af(k,h,1,f)){e=2;break p}h=e+2|0;if(!Af(k,h,1,f)){e=4;break p}h=e+3|0;if(!Af(k,h,1,f)){e=6;break p}j=e+5|0;if(!Af(k,e+4|0,1,f)){g=e+8|0;h=Af(k,j,3,f)+8|0;break n}g=e+10|0;e=16;j=Af(k,j,5,f);break o}g=h+2|0;j=Af(k,h+1|0,1,f)}h=e+j|0}q:{if(Af(k,g,1,f)){j=-256;e=12;break q}g=g+1|0;e=Af(k,g,1,f);j=e?-4352:0;e=e?14:8}g=g+1|0;s=Af(k,g,e,f);if((h|0)>=3){l=l-((h|0)!=3)|0;l=(l|0)>0?l+ -1|0:0}g=e+g|0;if((h|0)<1|(b|0)<1){break e}e=(a+j|0)+(s^-1)|0;j=b;while(1){o=lU(f,e);Lp(f,a,o);b=j+ -1|0;a=(a>>>0<d>>>0)+a|0;if((h|0)<2){break e}e=e+1|0;h=h+ -1|0;s=(j|0)>1;j=b;if(s){continue}break}}p=p-(p>>3)|0;if((b|0)>0){continue}break}break b}a=a+n|0;r=n}b=n+t|0;q=q-r|0;if((q|0)>0){continue}}break}Kn(c,i[f+12>>2]-q|0);a=Uc(c)^1}Xa=f+16|0;return a|0}function kea(a,b,c,d){var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0;e=i[a+4>>2];t=e&2047;if(d){u=a+8256|0;v=a- -64|0;w=a+24640|0;x=a+16448|0;while(1){q=h[(((e+754&2047)<<2)+u|0)+2>>1];s=h[((e+1206&2047)<<2)+u>>1];f=h[(((e+1602&2047)<<2)+v|0)+2>>1];m=h[((e+1750&2047)<<2)+v>>1];k=((e+22&2047)<<2)+w|0;g=h[k+2>>1];k=h[k>>1];j=((e+502&2047)<<2)+w|0;l=h[j+2>>1];n=h[b>>1];p=h[b+2>>1];j=h[j>>1];r=zc(h[a+32>>1]-j|0);y=h[a+24>>1];z=zc(h[a+34>>1]-l|0);A=h[a+26>>1];B=zc(h[a+36>>1]-k|0);C=h[a+28>>1];D=zc(h[a+38>>1]-g|0);E=h[a+30>>1];F=a,G=Bc(zc((o(r,y)|0)/65536<<1)+j|0),h[F+32>>1]=G;F=a,G=Bc(zc((o(z,A)|0)/65536<<1)+l|0),h[F+34>>1]=G;F=a,G=Bc(zc((o(B,C)|0)/65536<<1)+k|0),h[F+36>>1]=G;F=a,G=Bc(zc((o(D,E)|0)/65536<<1)+g|0),h[F+38>>1]=G;g=zc((o(h[a+32>>1],h[a+16>>1])|0)/32768|0);l=zc((o(h[a+38>>1],h[a+22>>1])|0)/32768|0);k=zc(g+((n|0)/4<<16>>16)|0);l=zc(l+((p|0)/4<<16>>16)|0);j=zc(k+((o(m,h[a+8>>1])|0)/-65536|0)|0);g=t<<2;n=g+v|0;p=zc(l+((o(f,h[a+10>>1])|0)/-65536|0)|0);h[n+2>>1]=p;h[n>>1]=j;m=zc(m+((o(j,h[a+8>>1])|0)/65536|0)|0);j=g+x|0;f=zc(f+((o(p,h[a+10>>1])|0)/65536|0)|0);h[j+2>>1]=f;h[j>>1]=m;m=zc(k+m|0);k=zc(f+l|0);f=((e+426&2047)<<2)+x|0;l=h[f+2>>1];j=h[f>>1];e=((e+682&2047)<<2)+x|0;n=h[e+2>>1];p=h[e>>1];e=zc((o(n,h[a+42>>1])+o(p,h[a+40>>1])|0)/32768|0);f=zc((o(l,h[a+46>>1])+o(j,h[a+44>>1])|0)/32768|0);p=zc(zc(m+p|0)-e|0);n=zc(zc(k+n|0)-f|0);m=zc(zc(j+m|0)-e|0);k=zc(zc(k+l|0)-f|0);e=zc(e+((o(h[a+8>>1],s)|0)/-65536|0)|0);f=zc(f+((o(q,h[a+10>>1])|0)/-65536|0)|0);l=h[a+8>>1];j=h[a+10>>1];r=g+u|0;h[r+2>>1]=f;h[r>>1]=e;r=s;s=(o(e,l)|0)/65536|0;e=zc(r+s|0);g=g+w|0;f=(o(f,j)|0)/65536|0;q=zc(f+q|0);h[g+2>>1]=q;h[g>>1]=e;e=zc(e+p|0);g=h[a+48>>1];q=zc(n+q|0);i[c>>2]=(i[c>>2]+o(e,g)|0)+o(q,h[a+50>>1]);e=zc(zc(s)+m|0);g=h[a+52>>1];f=zc(zc(f)+k|0);i[c+4>>2]=(i[c+4>>2]+o(e,g)|0)+o(f,h[a+54>>1]);c=c+8|0;b=b+4|0;e=t+1|0;t=e&2047;d=d+ -1|0;if(d){continue}break}}i[a+4>>2]=t}function HG(a,b,c,d,e,f,g,h,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0;l=Xa-48|0;Xa=l;a:{b:{c:{d:{e:{f:{k=In(1,28);if(!k){a=P(4)|0;zk(a);i[114610]=0;G(2009,a|0,71348,2008);a=i[114610];i[114610]=0;if((a|0)!=1){break a}break f}i[k+24>>2]=0;i[k+16>>2]=0;i[k+20>>2]=0;i[k+12>>2]=f;i[k+8>>2]=e;i[k+4>>2]=d;i[k>>2]=c?c:1997;d=Yr(l+32|0);g:{h:{if(!j){break h}c=i[j>>2];if(!c){break h}while(1){i:{e=i[j+4>>2];if(e){i[114610]=0;c=C(85,l+16|0,c|0)|0;f=i[114610];i[114610]=0;j:{if((f|0)!=1){i[114610]=0;f=C(2010,d|0,c|0)|0;m=i[114610];i[114610]=0;if((m|0)==1){break j}i[114610]=0;C(483,f|0,e|0)|0;e=i[114610];i[114610]=0;if((e|0)==1){break j}break i}j=H(0)|0;A()|0;break g}j=H(0)|0;A()|0;eb(c);break g}i[114610]=0;c=C(85,l+16|0,c|0)|0;e=i[114610];i[114610]=0;k:{if((e|0)!=1){i[114610]=0;C(2011,d|0,c|0)|0;e=i[114610];i[114610]=0;if((e|0)==1){break k}break i}j=H(0)|0;A()|0;break g}j=H(0)|0;A()|0;eb(c);break g}eb(c);c=i[j+8>>2];j=j+8|0;if(c){continue}break}}i[114610]=0;c=F(1398,80)|0;e=i[114610];i[114610]=0;l:{m:{n:{if((e|0)!=1){i[114610]=0;G(2012,l+16|0,k|0,k+4|0);e=i[114610];i[114610]=0;if((e|0)==1){break n}e=eo(l+8|0,l+16|0);i[114610]=0;S(2014,c|0,a|0,b|0,e|0,d|0)|0;a=i[114610];i[114610]=0;if((a|0)==1){break m}i[k+24>>2]=c;Ec(e);Ec(l+16|0);Pj(d);c=k;break d}j=H(0)|0;A()|0;break g}j=H(0)|0;A()|0;break l}j=H(0)|0;A()|0;Ec(e);Ec(l+16|0)}Cb(c)}Pj(d);M(j|0)|0;i[114610]=0;J(1989,34697,k|0,g|0,h|0);a=i[114610];i[114610]=0;if((a|0)!=1){i[114610]=0;K(20);a=i[114610];i[114610]=0;if((a|0)==1){break f}a=i[k+24>>2];if(a){Cb(br(a))}c=0;i[k+24>>2]=0;a=i[k+20>>2];if(a){Cb(a)}Cb(k);break d}j=H(0)|0;A()|0;i[114610]=0;K(20);a=i[114610];i[114610]=0;if((a|0)!=1){break e}break b}j=H(0)|0;A()|0}M(j|0)|0;c=0;i[114610]=0;J(1989,34697,0,g|0,h|0);a=i[114610];i[114610]=0;if((a|0)==1){break c}O()}Xa=l+48|0;return c|0}a=B()|0;A()|0;i[114610]=0;K(20);b=i[114610];i[114610]=0;if((b|0)==1){break b}E(a|0);x()}a=H(0)|0;A()|0;gb(a)}x()}function _Aa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,h=0,i=0;e=Xa-16|0;Xa=e;g[a|0]=0;c=j[b|0];if(c){g[a|0]=c>>>0>96?-1:c+12|0}g[a+1|0]=j[b+1|0];c=a;d=j[b+2|0];a:{b:{if((d+ -16&255)>>>0<=128){g[a+2|0]=1;d=(d+ -16|0)/2|0;break b}c:{switch((d+96&240)>>>4|0){case 0:g[a+2|0]=4;d=d&15;break b;case 1:g[a+2|0]=3;d=d&15;break b;case 2:g[a+2|0]=6;d=d&15;break b;case 3:break c;default:break a}}g[a+2|0]=5;d=d&15}g[c+4|0]=d}d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{c=j[b+4|0];if(c>>>0<=28){switch(c|0){case 16:break j;case 15:break k;case 12:break l;case 8:break m;case 4:break n;case 3:break o;case 2:break p;case 1:break q;case 0:break r;default:break d}}s:{switch(c+ -29|0){case 7:break f;case 5:break g;case 3:break h;case 0:break i;case 1:case 2:case 4:case 6:break d;default:break s}}if((c|0)==128){break e}if((c|0)!=157){break d}g[a+2|0]=15;c=j[b+6|0];g[a+3|0]=20;g[a+4|0]=c>>>3;g[e+15|0]=15;h=a,i=j[Xb(b+5|0,e+15|0)|0]|208,g[h+5|0]=i;break d}c=j[b+6|0];d=j[b+5|0];if(!(c|d)){break d}g[a+5|0]=d;g[a+3|0]=c;Xi(a);f=j[b+6|0]==15;break d}g[a+3|0]=2;h=a,i=_i(j[b+6|0]<<4|j[b+5|0]>>>4),g[h+5|0]=i;break d}g[a+3|0]=3;h=a,i=_i(j[b+6|0]<<4|j[b+5|0]>>>4),g[h+5|0]=i;break d}g[a+3|0]=4;h=a,i=_i(j[b+6|0]<<4|j[b+5|0]>>>4),g[h+5|0]=i;break d}g[a+3|0]=5;g[a+5|0]=j[b+6|0]&240|j[b+5|0]>>>4;break d}c=j[b+5|0];if(c){g[a+5|0]=c;g[a+3|0]=9;break d}if((j[b+6|0]+ -1&255)>>>0>1){break d}g[a+5|0]=145;g[a+3|0]=20;break d}g[a+3|0]=13;g[a+5|0]=j[b+6|0]>>>1;break d}c=j[b+6|0];if(c){g[a+5|0]=c;g[a+3|0]=17;break d}g[a+3|0]=16;g[a+5|0]=j[b+5|0]&15;break d}g[a+3|0]=j[b+6|0];g[a+5|0]=j[b+5|0];ay(a,1);f=(j[a+3|0]&254)==16;break d}g[a+3|0]=18;g[a+5|0]=j[b+5|0];break d}g[a+3|0]=31;g[a+5|0]=j[b+6|0]>>>1;break d}g[a+3|0]=31;g[a+5|0]=j[b+6|0]>>>1&120;break d}g[a+5|0]=159;g[a+3|0]=20;break d}g[a+3|0]=21;g[a+5|0]=j[b+6|0]>>>2}b=j[b+3|0];t:{if(!b){break t}if(!j[a+3|0]){g[a+5|0]=b;g[a+3|0]=9;break t}if(j[a+2|0]){break t}g[a+2|0]=2;g[a+4|0]=b>>>2}Xa=e+16|0;return f|0}function Cua(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,h=0,j=0,k=0,l=0,m=0,n=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;e=Xa-80|0;Xa=e;t=i[a+16>>2];k=tf(e+48|0);i[k+8>>2]=a+112;i[k+16>>2]=i[a+128>>2];y=k,z=of(b+327720|0,i[b+20>>2],(i[a+88>>2]&16384)>>>14|0),i[y+12>>2]=z;b=i[k+16>>2];if(b){y=k,z=sf(a+8|0,b),i[y>>2]=z;i[k+4>>2]=_a}b=i[a+44>>2];i[e+32>>2]=b;h=i[a+48>>2];i[e+36>>2]=h;j=i[a+52>>2];i[e+40>>2]=j;n=i[a+56>>2];i[e+44>>2]=n;u=i[a+24>>2];v=i[a+20>>2];l=i[a+4>>2];f=i[a>>2];i[e+24>>2]=f;i[e+28>>2]=l;m=i[a+12>>2];i[e+16>>2]=i[a+8>>2];i[e+20>>2]=m;if(d){while(1){b=0;h=b;j=f;i[e+72>>2]=f;i[e+76>>2]=b;l=(((l&2147483647)<<1|f>>>31)&-2)+t|0;a:{b=i[k+16>>2];if((b|0)<=0){break a}while(1){f=(h&2147483647)<<1|j>>>31;fd(i[k+8>>2],g[(f|1)+l|0]+g[l+(f&-2)|0]<<5);ed(i[k+8>>2],4);zb(e+72|0,k);if((b|0)<2){break a}b=b+ -1|0;j=i[e+72>>2];h=i[e+76>>2];continue}}b=i[k+8>>2];zb(b,b+8|0);b=i[k+8>>2];f=i[b+4>>2];if(f){m=b;b=(i[e+76>>2]&2147483647)<<1|i[e+72>>2]>>>31;fd(m,g[(b|1)+l|0]+g[l+(b&-2)|0]<<5);ed(i[k+8>>2],f);b=i[k+8>>2];f=i[b>>2];i[b>>2]=f;i[b+4>>2]=0}d=d+ -1|0;j=nf(b,i[k+12>>2]);i[e+12>>2]=j;i[e+8>>2]=j;h=0;n=1;while(1){m=i[a+60>>2];r=m;l=(e+32|0)+(h<<3)|0;p=i[l>>2];b=Eb(p,-16777216,16776704);s=i[a+64>>2];f=Eb(i[l+4>>2],-16777216,16776704);q=i[a+68>>2];w=q;q=q>>31;i[l+4>>2]=p;p=i[a+72>>2];m=m>>31;j=j<<8;m=XMa(r,m,j,j>>31);r=_a;x=(e+8|0)+(h<<2)|0;h=m;m=XMa(s,s>>31,b,b>>31);h=h+m|0;b=_a+r|0;b=h>>>0<m>>>0?b+1|0:b;m=h;h=XMa(w,q,f,f>>31);f=m+h|0;b=_a+b|0;b=f>>>0<h>>>0?b+1|0:b;f=f+8388608|0;if(f>>>0<8388608){b=b+1|0}b=(b&16777215)<<8|f>>>24;i[x>>2]=(b|0)/256;i[l>>2]=b-(j&p);if(n){h=1;n=0;j=i[e+12>>2];continue}break}i[c>>2]=i[c>>2]+o(i[e+8>>2],v);i[c+4>>2]=i[c+4>>2]+o(i[e+12>>2],u);zb(e+24|0,e+16|0);if(d){c=c+8|0;f=i[e+24>>2];l=i[e+28>>2];continue}break}f=i[e+24>>2];l=i[e+28>>2];n=i[e+44>>2];j=i[e+40>>2];h=i[e+36>>2];b=i[e+32>>2]}i[a+56>>2]=n;i[a+52>>2]=j;i[a+48>>2]=h;i[a+44>>2]=b;i[a>>2]=f;i[a+4>>2]=l;Xa=e+80|0}function iva(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,j=0,k=0,l=0,m=0,n=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;f=Xa-48|0;Xa=f;v=i[a+16>>2];a:{b:{c:{j=i[a+8>>2];e=i[a+12>>2];d:{if((e|0)<1?1:(e|0)<=1?j>>>0<=805306368:0){if((e|0)>-2?1:(e|0)>=-2?j>>>0>=3489660928:0){break c}if((e|0)>-2?1:(e|0)>=-2?j>>>0>2147483647:0){break d}break b}if((e|0)>1?1:(e|0)>=1?j>>>0>2147483648:0){break b}}b=b+196648|0;break a}b=b+131112|0;break a}b=b+262184|0}w=b;b=i[a+44>>2];i[f+32>>2]=b;n=i[a+48>>2];i[f+36>>2]=n;m=i[a+52>>2];i[f+40>>2]=m;p=i[a+56>>2];i[f+44>>2]=p;x=i[a+24>>2];y=i[a+20>>2];k=i[a+4>>2];l=i[a>>2];i[f+24>>2]=l;i[f+28>>2]=k;i[f+16>>2]=j;i[f+20>>2]=e;if(d){while(1){e=(((k&2147483647)<<1|l>>>31)&-2)+v|0;b=(l>>>16&65520)+w|0;l=h[b+14>>1];j=h[b+12>>1];r=h[b+10>>1];s=h[b+8>>1];t=h[b+6>>1];q=h[b+4>>1];u=h[b+2>>1];z=h[b>>1];m=0;p=1;n=1;b=0;while(1){i[(f+8|0)+(b<<2)>>2]=(((((((o(g[e+(b|-4)|0],u)+o(g[e+(b|-6)|0],z)|0)+o(g[e+(b|-2)|0],q)|0)+o(g[b+e|0],t)|0)+o(g[e+(b|2)|0],s)|0)+o(g[e+(b|4)|0],r)|0)+o(g[e+(b|6)|0],j)|0)+o(l,g[e+(b|8)|0])<<8)/32768;k=n;n=0;b=1;if(k){continue}break}while(1){e=(f+8|0)+(m<<2)|0;l=i[e>>2];j=i[a+60>>2];r=j;n=(f+32|0)+(m<<3)|0;m=i[n>>2];b=Eb(m,-16777216,16776704);s=i[a+64>>2];k=Eb(i[n+4>>2],-16777216,16776704);q=i[a+68>>2];u=q;q=q>>31;i[n+4>>2]=m;m=i[a+72>>2];t=j>>31;l=l<<8;j=l;j=XMa(r,t,j,j>>31);r=_a;t=e;e=j;j=XMa(s,s>>31,b,b>>31);e=e+j|0;b=_a+r|0;b=e>>>0<j>>>0?b+1|0:b;j=e;e=XMa(u,q,k,k>>31);k=j+e|0;b=_a+b|0;b=k>>>0<e>>>0?b+1|0:b;k=k+8388608|0;if(k>>>0<8388608){b=b+1|0}b=(b&16777215)<<8|k>>>24;i[t>>2]=(b|0)/256;i[n>>2]=b-(l&m);m=1;b=p&1;p=0;if(b){continue}break}i[c>>2]=i[c>>2]+o(i[f+8>>2],y);i[c+4>>2]=i[c+4>>2]+o(i[f+12>>2],x);zb(f+24|0,f+16|0);d=d+ -1|0;if(d){c=c+8|0;l=i[f+24>>2];k=i[f+28>>2];continue}break}l=i[f+24>>2];k=i[f+28>>2];p=i[f+44>>2];m=i[f+40>>2];n=i[f+36>>2];b=i[f+32>>2]}i[a+56>>2]=p;i[a+52>>2]=m;i[a+48>>2]=n;i[a+44>>2]=b;i[a>>2]=l;i[a+4>>2]=k;Xa=f+48|0}function yea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=p(0),f=p(0),g=0,h=0,j=0,k=0,l=p(0),n=0,o=0,q=0,r=0,s=p(0),t=0,u=0,v=0,w=p(0),x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=p(0),K=p(0),L=p(0),M=p(0),N=p(0),O=p(0);o=a+44|0;if(Wg(o)){B=ud(o,0);C=ud(o,1);D=Pc(o,0);E=Pc(o,1);t=i[a+4296>>2];r=i[a+4300>>2];if(d){k=a+4304|0;j=t+1|0;x=j+i[a+4272>>2]&4095;n=k+(x<<4)|0;y=j+i[a+4276>>2]&4095;g=((y<<4)+k|0)+4|0;z=j+i[a+4280>>2]&4095;q=((z<<4)+k|0)+8|0;A=j+i[a+4284>>2]&4095;h=((A<<4)+k|0)+12|0;u=i[a+4292>>2]+r|0;v=i[a+4288>>2]+r|0;G=a+69840|0;H=a+78032|0;F=d;while(1){x=x+ -1&4095;j=(x<<4)+k|0;e=m[j>>2];v=v&1023;I=(v<<3)+G|0;s=m[I+4>>2];J=m[h>>2];K=m[q>>2];L=m[g>>2];M=m[n>>2];N=m[C>>2];O=m[B>>2];w=m[a+4232>>2];y=y+ -1&4095;n=(y<<4)+k|0;l=m[n+4>>2];f=p(p(w*m[I>>2])+p(l*p(.6180340051651001)));h=r<<3;g=h+G|0;m[g+4>>2]=l-p(f*p(.6180340051651001));l=e;e=p(p(s*w)-p(e*p(.6180340051651001)));m[g>>2]=l+p(e*p(.6180340051651001));m[j>>2]=f;m[n+4>>2]=e;u=u&1023;g=(u<<3)+H|0;s=m[g+4>>2];z=z+ -1&4095;q=(z<<4)+k|0;f=m[q+8>>2];w=m[a+4236>>2];e=p(w*m[g>>2]);A=A+ -1&4095;g=(A<<4)+k|0;l=m[g+12>>2];e=p(e+p(l*p(.6180340051651001)));h=h+H|0;m[h+4>>2]=l-p(e*p(.6180340051651001));l=f;f=p(p(s*w)-p(f*p(.6180340051651001)));m[h>>2]=l+p(f*p(.6180340051651001));m[q+8>>2]=e;m[g+12>>2]=f;f=p(m[j>>2]+e);e=p(O+p(1.0000000031710769e-30));m[D>>2]=f+p(m[a+4224>>2]*e);f=p(N+p(1.0000000031710769e-30));m[E>>2]=p(p(m[a+4224>>2]*f)+m[n+4>>2])+m[g+12>>2];h=(t<<4)+k|0;s=m[a+4228>>2];e=p(s*e);m[h>>2]=p(p(m[a+4240>>2]*m[j>>2])+e)+p(M*m[a+4244>>2]);f=p(s*f);m[h+4>>2]=p(p(m[a+4248>>2]*m[n+4>>2])+f)+p(L*m[a+4252>>2]);m[h+8>>2]=p(p(m[a+4256>>2]*m[q+8>>2])-f)+p(K*m[a+4260>>2]);m[h+12>>2]=p(p(m[a+4264>>2]*m[g+12>>2])+e)+p(J*m[a+4268>>2]);h=g+12|0;q=q+8|0;g=n+4|0;E=E+4|0;D=D+4|0;C=C+4|0;B=B+4|0;u=u+ -1|0;v=v+ -1|0;r=r+ -1&1023;t=t+ -1&4095;n=j;F=F+ -1|0;if(F){continue}break}}i[a+4300>>2]=r;i[a+4296>>2]=t;Oh(a,b,c,Pc(o,0),Pc(o,1),d)}}function Oh(a,b,c,d,e,f){var g=0,h=0,k=0,l=p(0),n=p(0),o=0,q=0,r=p(0),s=p(0),t=0;if(!($a[i[i[a>>2]+132>>2]](a)|0)){g=j[i[a+20>>2]+25|0]}l=m[i[a+20>>2]+144>>2];n=p(1);if(!($a[i[i[a>>2]+132>>2]](a)|0)){n=m[i[a+20>>2]+144>>2]}l=p(p(1)-l);a:{if(($a[i[i[a>>2]+148>>2]](a)|0)<1){break a}if(!yH(i[a+20>>2])){break a}l=p(p(l+l)+p(-1));n=p(-l)}r=m[a+4196>>2];n=p(r*n);l=p(r*l);o=a+44|0;q=ud(o,0);o=ud(o,1);b:{c:{switch(g|0){case 4:if(!f){break b}while(1){g=k<<2;h=g+b|0;t=h;n=p(m[g+q>>2]+m[h>>2]);h=c+g|0;m[t>>2]=p(n-p(m[g+o>>2]+p(n+m[h>>2])))+p(m[d+g>>2]*l);m[h>>2]=p(m[e+g>>2]*l)-n;k=k+1|0;if((k|0)!=(f|0)){continue}break}break b;case 3:if(!f){break b}while(1){g=k<<2;h=g+b|0;m[h>>2]=p(p(m[g+q>>2]*l)-m[d+g>>2])+m[h>>2];h=c+g|0;m[h>>2]=p(p(m[g+o>>2]*l)-m[e+g>>2])+m[h>>2];k=k+1|0;if((k|0)!=(f|0)){continue}break}break b;case 2:if(!f){break b}while(1){g=k<<2;h=g+b|0;m[h>>2]=p(m[h>>2]+m[d+g>>2])-p(m[g+q>>2]*n);h=c+g|0;m[h>>2]=p(m[h>>2]+m[e+g>>2])-p(m[g+o>>2]*n);k=k+1|0;if((k|0)!=(f|0)){continue}break}break b;case 1:if(!f){break b}while(1){g=k<<2;h=g+b|0;m[h>>2]=p(m[h>>2]+m[g+q>>2])-p(m[d+g>>2]*l);h=c+g|0;m[h>>2]=p(m[h>>2]+m[g+o>>2])-p(m[e+g>>2]*l);k=k+1|0;if((k|0)!=(f|0)){continue}break}break b;case 0:if(!f){break b}while(1){g=k<<2;h=g+b|0;m[h>>2]=p(p(m[g+q>>2]*n)+p(m[d+g>>2]*l))+m[h>>2];h=c+g|0;m[h>>2]=p(p(m[g+o>>2]*n)+p(m[e+g>>2]*l))+m[h>>2];k=k+1|0;if((k|0)!=(f|0)){continue}break}break b;case 5:break c;default:break b}}g=yH(i[a+20>>2]);if(!f){break b}l=g?p(l*p(.5)):l;n=g?p(n*p(.5)):n;while(1){g=k<<2;h=g+b|0;r=p(m[d+g>>2]-m[g+q>>2]);s=p(m[g+o>>2]-m[e+g>>2]);m[h>>2]=p(m[h>>2]+p(r*l))+p(s*n);g=c+g|0;m[g>>2]=p(p(s*l)+p(r*n))+m[g>>2];k=k+1|0;if((k|0)!=(f|0)){continue}break}}d:{if(!((j[i[a+20>>2]+24|0]&4)>>>2|0)){break d}if($a[i[i[a>>2]+132>>2]](a)|!f){break d}e=0;while(1){a=e<<2;d=a+b|0;m[d>>2]=m[d>>2]+m[a+q>>2];d=a+c|0;m[d>>2]=m[d>>2]+m[a+o>>2];e=e+1|0;if((f|0)!=(e|0)){continue}break}}}function Lla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,p=0,q=0,r=0,s=0;c=Xa-208|0;Xa=c;f=1;e=i[a+12>>2];h=1<<e;if(e&1){j=h>>>1|0;if(j){e=0;while(1){k=e+j|0;f=_b(b,k);d=i[f+12>>2];i[c+200>>2]=i[f+8>>2];i[c+204>>2]=d;d=i[f+4>>2];i[c+192>>2]=i[f>>2];i[c+196>>2]=d;Th(c+176|0,_b(b,e),c+192|0);f=_b(b,k);d=i[c+188>>2];i[f+8>>2]=i[c+184>>2];i[f+12>>2]=d;k=i[c+180>>2];i[f>>2]=i[c+176>>2];i[f+4>>2]=k;Jw(_b(b,e),c+192|0);e=e+1|0;if((j|0)!=(e|0)){continue}break}e=i[a+12>>2]}f=2;h=h>>>3|0}else{h=h>>>2|0}k=e&-2;if(k){while(1){if(f){r=o(h,3);s=h<<1;j=0;while(1){e=_b(a,j<<1);d=i[e+12>>2];i[c+200>>2]=i[e+8>>2];i[c+204>>2]=d;d=i[e+4>>2];i[c+192>>2]=i[e>>2];i[c+196>>2]=d;e=_b(a,j);d=i[e+12>>2];i[c+184>>2]=i[e+8>>2];i[c+188>>2]=d;d=i[e+4>>2];i[c+176>>2]=i[e>>2];i[c+180>>2]=d;lh(c+160|0,c+176|0,c+192|0);e=j<<k;p=h+e|0;if(e>>>0<p>>>0){while(1){d=_b(b,e);g=i[d+12>>2];i[c+152>>2]=i[d+8>>2];i[c+156>>2]=g;g=i[d+4>>2];i[c+144>>2]=i[d>>2];i[c+148>>2]=g;g=e+h|0;lh(c+128|0,c+192|0,_b(b,g));l=e+s|0;lh(c+112|0,c+176|0,_b(b,l));q=e+r|0;lh(c+96|0,c+160|0,_b(b,q));Ij(c+80|0,c+144|0,c+112|0);Th(c- -64|0,c+144|0,c+112|0);Ij(c+48|0,c+128|0,c+96|0);cl(c+16|0,-n[3856],-n[3857]);Th(c,c+128|0,c+96|0);lh(c+32|0,c+16|0,c);Ij(c+16|0,c+80|0,c+48|0);d=_b(b,e);m=i[c+28>>2];i[d+8>>2]=i[c+24>>2];i[d+12>>2]=m;m=i[c+20>>2];i[d>>2]=i[c+16>>2];i[d+4>>2]=m;Th(c+16|0,c+80|0,c+48|0);d=_b(b,g);m=i[c+28>>2];i[d+8>>2]=i[c+24>>2];i[d+12>>2]=m;g=i[c+20>>2];i[d>>2]=i[c+16>>2];i[d+4>>2]=g;Ij(c+16|0,c- -64|0,c+32|0);d=_b(b,l);l=i[c+28>>2];i[d+8>>2]=i[c+24>>2];i[d+12>>2]=l;g=i[c+20>>2];i[d>>2]=i[c+16>>2];i[d+4>>2]=g;Th(c+16|0,c- -64|0,c+32|0);d=_b(b,q);l=i[c+28>>2];i[d+8>>2]=i[c+24>>2];i[d+12>>2]=l;g=i[c+20>>2];i[d>>2]=i[c+16>>2];i[d+4>>2]=g;e=e+1|0;if((p|0)!=(e|0)){continue}break}}j=j+1|0;if((f|0)!=(j|0)){continue}break}}h=h>>>2|0;f=f<<2;k=k+ -2|0;if(k){continue}break}}Xa=c+208|0}function V8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,h=0,k=0;e=Xa-96|0;Xa=e;a:{if(Cc(c)){break a}h=j[xG(c)|0];f=1;b:{if((h|0)==33){break b}if((h|0)!=63){break a}f=0}d=f;Oq(e+80|0,c,0,lb(c)+ -1|0);mb(c,e+80|0);eb(e+80|0)}jd(e+80|0);f=i[e+80>>2];jd(e+72|0);h=wG(f,i[e+76>>2],c);jd(e+80|0);c:{d:{e:{f:{g:{if(i[e+84>>2]==(h|0)){if(Bd(c,38187)){a=P(8)|0;i[114610]=0;b=C(85,e+80|0,39121)|0;c=i[114610];i[114610]=0;if((c|0)==1){break e}Ub(a,b);i[114610]=0;G(2009,a|0,83568,2017);a=i[114610];i[114610]=0;if((a|0)!=1){break c}c=B()|0;A()|0;eb(b);break d}if(!d){break g}a=P(8)|0;i[114610]=0;G(2136,e+80|0,39131,c|0);b=i[114610];i[114610]=0;if((b|0)!=1){Ub(a,e+80|0);i[114610]=0;G(2009,a|0,83568,2017);a=i[114610];i[114610]=0;if((a|0)!=1){break c}c=B()|0;A()|0;eb(e+80|0);break d}c=B()|0;A()|0;Q(a|0);break d}f=Ab(e+80|0);h:{i:{j:{k:{switch(i[h+4>>2]){case 0:mh(e- -64|0,c);i[114610]=0;c=i[e+68>>2];i[e+8>>2]=i[e+64>>2];i[e+12>>2]=c;b=I(2077,b|0,e+8|0,d|0)|0;c=i[114610];i[114610]=0;if((c|0)!=1){i[114610]=0;g[e+72|0]=b;D(2141,a|0,e+72|0);a=i[114610];i[114610]=0;if((a|0)!=1){break h}}break j;case 1:mh(e+56|0,c);i[114610]=0;c=i[e+60>>2];i[e+16>>2]=i[e+56>>2];i[e+20>>2]=c;b=JB(b,e+16|0,d);c=_a;d=i[114610];i[114610]=0;if((d|0)!=1){i[114610]=0;i[e+72>>2]=b;i[e+76>>2]=c;D(2143,a|0,e+72|0);a=i[114610];i[114610]=0;if((a|0)!=1){break h}}break j;case 2:mh(e+48|0,c);i[114610]=0;c=i[e+52>>2];i[e+24>>2]=i[e+48>>2];i[e+28>>2]=c;k=+aa(2079,b|0,e+24|0,d|0);b=i[114610];i[114610]=0;if((b|0)!=1){i[114610]=0;n[e+72>>3]=k;D(2144,a|0,e+72|0);a=i[114610];i[114610]=0;if((a|0)!=1){break h}}break j;case 3:break k;default:break i}}mh(e+40|0,c);i[114610]=0;c=i[e+44>>2];i[e+32>>2]=i[e+40>>2];i[e+36>>2]=c;J(2080,a|0,b|0,e+32|0,d|0);a=i[114610];i[114610]=0;if((a|0)!=1){break h}}c=B()|0;A()|0;eb(f);break d}Lc(a,f)}eb(f);break f}Ab(a)}Xa=e+96|0;return}c=B()|0;A()|0;Q(a|0)}E(c|0)}x()}function Nua(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;g=Xa-48|0;Xa=g;y=i[a+16>>2];l=i[a+44>>2];i[g+32>>2]=l;p=i[a+48>>2];i[g+36>>2]=p;k=i[a+52>>2];i[g+40>>2]=k;j=i[a+56>>2];i[g+44>>2]=j;s=i[a+40>>2];t=i[a+36>>2];e=i[a+4>>2];m=i[a>>2];i[g+24>>2]=m;i[g+28>>2]=e;f=i[a+12>>2];i[g+16>>2]=i[a+8>>2];i[g+20>>2]=f;a:{if(!d){n=s>>12;f=t>>12;break a}while(1){p=1;e=((((e&2147483647)<<1|m>>>31)&2147483646)<<1)+y|0;f=(((m>>>16|0)+4&131064)<<1)+b|0;m=h[f+38>>1];j=h[f+36>>1];n=h[f+34>>1];q=h[f+32>>1];u=h[f+30>>1];v=h[f+28>>1];r=h[f+26>>1];w=h[f+24>>1];l=0;k=1;f=0;while(1){x=(g+8|0)+(f<<2)|0;f=f<<1;i[x>>2]=(((((o(h[e+(f|8)>>1],n)+o(h[e+(f|4)>>1],q)|0)+o(j,h[e+(f|12)>>1])|0)+o(m,h[e+(f|16)>>1])|0)/2|0)+((((o(h[e+(f|-8)>>1],r)+o(h[e+(f|-12)>>1],w)|0)+o(h[e+(f|-4)>>1],v)|0)+o(h[e+f>>1],u)|0)/2|0)|0)/16384;x=k&1;k=0;f=1;if(x){continue}break}while(1){k=(g+8|0)+(l<<2)|0;m=i[k>>2];j=i[a+60>>2];n=j;f=(g+32|0)+(l<<3)|0;q=i[f>>2];e=Eb(q,-16777216,16776704);u=i[a+64>>2];l=Eb(i[f+4>>2],-16777216,16776704);r=i[a+68>>2];w=r;r=r>>31;i[f+4>>2]=q;q=i[a+72>>2];v=j>>31;m=m<<8;j=m;j=XMa(n,v,j,j>>31);n=_a;v=k;k=j;j=XMa(u,u>>31,e,e>>31);k=k+j|0;e=_a+n|0;e=k>>>0<j>>>0?e+1|0:e;j=k;k=XMa(w,r,l,l>>31);l=j+k|0;e=_a+e|0;e=l>>>0<k>>>0?e+1|0:e;l=l+8388608|0;if(l>>>0<8388608){e=e+1|0}e=(e&16777215)<<8|l>>>24;i[v>>2]=(e|0)/256;i[f>>2]=e-(m&q);l=1;e=p&1;p=0;if(e){continue}break}e=i[a+32>>2];t=i[a+28>>2]+t|0;f=t>>12;i[c>>2]=i[c>>2]+o(f,i[g+8>>2]);s=e+s|0;n=s>>12;i[c+4>>2]=i[c+4>>2]+o(n,i[g+12>>2]);zb(g+24|0,g+16|0);d=d+ -1|0;if(d){c=c+8|0;m=i[g+24>>2];e=i[g+28>>2];continue}break}m=i[g+24>>2];e=i[g+28>>2];j=i[g+44>>2];k=i[g+40>>2];p=i[g+36>>2];l=i[g+32>>2]}i[a+40>>2]=s;i[a+20>>2]=f;i[a+36>>2]=t;i[a+56>>2]=j;i[a+52>>2]=k;i[a+48>>2]=p;i[a+44>>2]=l;i[a+24>>2]=n;i[a>>2]=m;i[a+4>>2]=e;Xa=g+48|0}function Oua(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,j=0,k=0,l=0,m=0,n=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;j=Xa-48|0;Xa=j;y=i[a+16>>2];m=i[a+44>>2];i[j+32>>2]=m;q=i[a+48>>2];i[j+36>>2]=q;l=i[a+52>>2];i[j+40>>2]=l;k=i[a+56>>2];i[j+44>>2]=k;t=i[a+40>>2];u=i[a+36>>2];e=i[a+4>>2];n=i[a>>2];i[j+24>>2]=n;i[j+28>>2]=e;f=i[a+12>>2];i[j+16>>2]=i[a+8>>2];i[j+20>>2]=f;a:{if(!d){f=t>>12;p=u>>12;break a}while(1){e=(((e&2147483647)<<1|n>>>31)&-2)+y|0;q=1;f=(((n>>>16|0)+4&131064)<<1)+b|0;n=h[f+38>>1];k=h[f+36>>1];p=h[f+34>>1];r=h[f+32>>1];v=h[f+30>>1];w=h[f+28>>1];s=h[f+26>>1];x=h[f+24>>1];m=0;l=1;f=0;while(1){i[(j+8|0)+(f<<2)>>2]=(((((o(g[e+(f|4)|0],p)+o(g[e+(f|2)|0],r)|0)+o(k,g[e+(f|6)|0])|0)+o(n,g[e+(f|8)|0])<<8)/2|0)+((((o(g[e+(f|-4)|0],s)+o(g[e+(f|-6)|0],x)|0)+o(g[e+(f|-2)|0],w)|0)+o(g[e+f|0],v)<<8)/2|0)|0)/16384;z=l&1;l=0;f=1;if(z){continue}break}while(1){l=(j+8|0)+(m<<2)|0;n=i[l>>2];k=i[a+60>>2];p=k;f=(j+32|0)+(m<<3)|0;r=i[f>>2];e=Eb(r,-16777216,16776704);v=i[a+64>>2];m=Eb(i[f+4>>2],-16777216,16776704);s=i[a+68>>2];x=s;s=s>>31;i[f+4>>2]=r;r=i[a+72>>2];w=k>>31;n=n<<8;k=n;k=XMa(p,w,k,k>>31);p=_a;w=l;l=k;k=XMa(v,v>>31,e,e>>31);l=l+k|0;e=_a+p|0;e=l>>>0<k>>>0?e+1|0:e;k=l;l=XMa(x,s,m,m>>31);m=k+l|0;e=_a+e|0;e=m>>>0<l>>>0?e+1|0:e;m=m+8388608|0;if(m>>>0<8388608){e=e+1|0}e=(e&16777215)<<8|m>>>24;i[w>>2]=(e|0)/256;i[f>>2]=e-(n&r);m=1;e=q&1;q=0;if(e){continue}break}e=i[a+32>>2];u=i[a+28>>2]+u|0;p=u>>12;i[c>>2]=i[c>>2]+o(p,i[j+8>>2]);t=e+t|0;f=t>>12;i[c+4>>2]=i[c+4>>2]+o(f,i[j+12>>2]);zb(j+24|0,j+16|0);d=d+ -1|0;if(d){c=c+8|0;n=i[j+24>>2];e=i[j+28>>2];continue}break}n=i[j+24>>2];e=i[j+28>>2];k=i[j+44>>2];l=i[j+40>>2];q=i[j+36>>2];m=i[j+32>>2]}i[a+40>>2]=t;i[a+20>>2]=p;i[a+36>>2]=u;i[a+56>>2]=k;i[a+52>>2]=l;i[a+48>>2]=q;i[a+44>>2]=m;i[a+24>>2]=f;i[a>>2]=n;i[a+4>>2]=e;Xa=j+48|0}function xGa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,h=p(0);c=Xa+ -64|0;Xa=c;ZFa(a,b+16|0);kQ(b+48|0);g[b+143|0]=0;i[b+152>>2]=-2147483648;i[b+156>>2]=-2147483648;d=Cf(a);ad(c+48|0,a,d);i[114610]=0;e=F(337,c+48|0)|0;f=i[114610];i[114610]=0;a:{b:{c:{if((f|0)==1){break c}if(!e){break b}i[114610]=0;e=b+4|0;D(508,e|0,d|0);f=i[114610];i[114610]=0;if((f|0)==1){break c}e=i[e>>2];i[114610]=0;I(701,c+48|0,e|0,d|0)|0;d=i[114610];i[114610]=0;if((d|0)!=1){break b}}a=B()|0;A()|0;break a}i[114610]=0;d=F(390,a|0)|0;e=i[114610];i[114610]=0;d:{if((e|0)==1){break d}i[114610]=0;G(341,c+32|0,a|0,d|0);a=i[114610];i[114610]=0;if((a|0)==1){break d}i[114610]=0;a=F(337,c+32|0)|0;d=i[114610];i[114610]=0;e:{if((d|0)!=1){f:{g:{h:{if(!a){break h}while(1){i[114610]=0;a=C(258,c+32|0,5)|0;d=i[114610];i[114610]=0;if((d|0)==1){break g}if(!a){break h}i[114610]=0;C(702,c+32|0,c+28|0)|0;a=i[114610];i[114610]=0;i:{if((a|0)!=1){a=4;if((j[c+28|0]|j[c+29|0]<<8|(j[c+30|0]<<16|j[c+31|0]<<24))==1414682436|(j[c+28|0]|j[c+29|0]<<8|(j[c+30|0]<<16|j[c+31|0]<<24))==1196380752){break i}i[114610]=0;a=F(390,c+32|0)|0;d=i[114610];i[114610]=0;if((d|0)!=1){break i}a=B()|0;A()|0;break e}a=B()|0;A()|0;break e}i[114610]=0;G(341,c+8|0,c+32|0,a|0);a=i[114610];i[114610]=0;j:{k:{if((a|0)!=1){if((j[c+28|0]|j[c+29|0]<<8|(j[c+30|0]<<16|j[c+31|0]<<24))!=1414682436){break k}i[114610]=0;h=p(ma(703,c+8|0));a=i[114610];i[114610]=0;if((a|0)==1){break f}m[b+144>>2]=h;break j}a=B()|0;A()|0;break e}if((j[c+28|0]|j[c+29|0]<<8|(j[c+30|0]<<16|j[c+31|0]<<24))!=1196380752){break j}i[114610]=0;a=F(390,c+8|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break f}i[b+148>>2]=a}hb(c+8|0);continue}}hb(c+32|0);hb(c+48|0);Xa=c- -64|0;return}a=B()|0;A()|0;break e}a=B()|0;A()|0;hb(c+8|0);break e}a=B()|0;A()|0}hb(c+32|0);break a}a=B()|0;A()|0}hb(c+48|0);E(a|0);x()}function fga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=p(0),g=p(0),h=p(0),j=0,k=0,l=0,n=p(0),o=p(0),r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=p(0),A=0,B=p(0),C=0,D=0,E=0,F=p(0);a:{if(!i[a+4276>>2]){break a}j=a+44|0;if(!Wg(j)){break a}s=ud(j,0);t=ud(j,1);u=Pc(j,0);v=Pc(j,1);A=$a[i[i[a>>2]+188>>2]](a)|0;f=p($a[i[i[a>>2]+196>>2]](a));z=p($a[i[i[a>>2]+184>>2]](a));w=$a[i[i[a>>2]+208>>2]](a)|0;if(d){B=p(f*p(.009999999776482582));C=w&1;k=a+4260|0;l=i[a+4256>>2];e=i[a+4272>>2];x=d;while(1){h=m[s>>2];n=m[t>>2];l=qm(a,e+l|0);e=qm(a,e);f=m[vb(k,l)>>2];E=vb(k,e),F=p(p(B*f)+p(p(n+h)*p(.5))),m[E>>2]=F;b:{if(A){g=m[a+4244>>2];f=p(m[a+4236>>2]+g);m[a+4236>>2]=f;g=p(g+m[a+4240>>2]);m[a+4240>>2]=g;if(!(f<=p(1))){f=p(f+p(-2));m[a+4236>>2]=f}if(!(g<=p(1))){m[a+4240>>2]=g+p(-2)}f=p(q(f));f=p(p(f+f)+p(-1));g=p(q(m[a+4240>>2]));g=p(p(g+g)+p(-1));break b}g=m[a+4244>>2];o=m[a+4240>>2];f=p(p(g*o)+m[a+4236>>2]);m[a+4236>>2]=f;g=p(o-p(f*g));m[a+4240>>2]=g}o=m[vb(k,qm(a,i[a+4280>>2]+i[a+4272>>2]|0))>>2];E=u,F=p(p(p(p(o-h)+p(p(p(m[vb(k,qm(a,i[a+4284>>2]+i[a+4272>>2]|0))>>2]-o)*p(.000244140625))*p(i[a+4280>>2]&4095)))*z)+h),m[E>>2]=F;h=m[vb(k,qm(a,i[a+4288>>2]+i[a+4272>>2]|0))>>2];E=v,F=p(p(p(p(h-n)+p(p(p(m[vb(k,qm(a,i[a+4292>>2]+i[a+4272>>2]|0))>>2]-h)*p(.000244140625))*p(i[a+4288>>2]&4095)))*z)+n),m[E>>2]=F;y=a;l=i[a+4256>>2];r=l;h=m[a+4248>>2];n=p(h*(C?g:f));c:{if(p(q(n))<p(2147483648)){e=~~n;break c}e=-2147483648}r=r+(w>>>0>1?e:0-e|0)|0;i[y+4288>>2]=r;D=w>>>0<4;y=a;f=p(h*f);d:{if(p(q(f))<p(2147483648)){e=~~f;break d}e=-2147483648}e=(D?e:0-e|0)+l|0;i[y+4280>>2]=e;i[a+4292>>2]=r+4096;i[a+4284>>2]=e+4096;e=i[a+4272>>2];if((e|0)<=0){e=(i[a+4276>>2]<<12)+e|0;i[a+4272>>2]=e}t=t+4|0;s=s+4|0;v=v+4|0;u=u+4|0;e=e+ -4096|0;i[a+4272>>2]=e;x=x+ -1|0;if(x){continue}break}}Oh(a,b,c,Pc(j,0),Pc(j,1),d)}}function Y0(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0;j=Xa-432|0;Xa=j;i[j+424>>2]=37;i[j+428>>2]=0;k=pq(j+424|1,62154,i[c+4>>2]);i[j+380>>2]=j+384;a=Ud();a:{if(k){l=i[c+8>>2];i[j+72>>2]=g;i[j+76>>2]=h;m=j- -64|0;i[m>>2]=e;i[m+4>>2]=f;i[j+48>>2]=l;a=Je(j+384|0,30,a,j+424|0,j+48|0);break a}i[j+80>>2]=e;i[j+84>>2]=f;i[j+88>>2]=g;i[j+92>>2]=h;a=Je(j+384|0,30,a,j+424|0,j+80|0)}i[j+128>>2]=2420;l=wd(j+368|0,0,j+128|0);b:{c:{d:{if((a|0)>=30){e:{if(k){i[114610]=0;a=R(2445)|0;k=i[114610];i[114610]=0;if((k|0)==1){break c}k=i[c+8>>2];i[j+16>>2]=e;i[j+20>>2]=f;i[j+24>>2]=g;i[j+28>>2]=h;i[j>>2]=k;i[114610]=0;a=N(2467,j+380|0,a|0,j+424|0,j|0)|0;e=i[114610];i[114610]=0;if((e|0)!=1){break e}break c}i[114610]=0;a=R(2445)|0;k=i[114610];i[114610]=0;if((k|0)==1){break c}i[j+32>>2]=e;i[j+36>>2]=f;i[114610]=0;i[j+40>>2]=g;i[j+44>>2]=h;a=N(2467,j+380|0,a|0,j+424|0,j+32|0)|0;e=i[114610];i[114610]=0;if((e|0)==1){break c}}e=i[j+380>>2];if(!e){i[114610]=0;K(2421);a=i[114610];i[114610]=0;if((a|0)==1){break c}break d}de(l,e)}e=i[j+380>>2];g=e+a|0;h=Of(e,g,c);i[j+116>>2]=2420;f=wd(j+120|0,0,j+116|0);f:{g:{if(i[j+380>>2]==(j+384|0)){a=j+128|0;e=j+384|0;break g}a=Zc(a<<3);if(!a){i[114610]=0;K(2421);a=i[114610];i[114610]=0;if((a|0)!=1){break d}c=B()|0;A()|0;break f}de(f,a);e=i[j+380>>2]}i[114610]=0;fc(j+104|0,c);k=i[114610];i[114610]=0;h:{i:{if((k|0)!=1){i[114610]=0;X(2478,e|0,h|0,g|0,a|0,j+116|0,j+112|0,j+104|0);e=i[114610];i[114610]=0;if((e|0)==1){break i}ub(j+104|0);i[114610]=0;a=Y(2479,b|0,a|0,i[j+116>>2],i[j+112>>2],c|0,d|0)|0;b=i[114610];i[114610]=0;if((b|0)==1){break h}lc(f);lc(l);Xa=j+432|0;return a|0}c=B()|0;A()|0;break f}c=B()|0;A()|0;ub(j+104|0);break f}c=B()|0;A()|0}lc(f);break b}x()}c=B()|0;A()|0}lc(l);E(c|0);x()}function h1(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0;j=Xa-256|0;Xa=j;i[j+248>>2]=37;i[j+252>>2]=0;k=pq(j+248|1,62154,i[c+4>>2]);i[j+204>>2]=j+208;a=Ud();a:{if(k){l=i[c+8>>2];i[j+72>>2]=g;i[j+76>>2]=h;m=j- -64|0;i[m>>2]=e;i[m+4>>2]=f;i[j+48>>2]=l;a=Je(j+208|0,30,a,j+248|0,j+48|0);break a}i[j+80>>2]=e;i[j+84>>2]=f;i[j+88>>2]=g;i[j+92>>2]=h;a=Je(j+208|0,30,a,j+248|0,j+80|0)}i[j+128>>2]=2420;l=wd(j+192|0,0,j+128|0);b:{c:{d:{if((a|0)>=30){e:{if(k){i[114610]=0;a=R(2445)|0;k=i[114610];i[114610]=0;if((k|0)==1){break c}k=i[c+8>>2];i[j+16>>2]=e;i[j+20>>2]=f;i[j+24>>2]=g;i[j+28>>2]=h;i[j>>2]=k;i[114610]=0;a=N(2467,j+204|0,a|0,j+248|0,j|0)|0;e=i[114610];i[114610]=0;if((e|0)!=1){break e}break c}i[114610]=0;a=R(2445)|0;k=i[114610];i[114610]=0;if((k|0)==1){break c}i[j+32>>2]=e;i[j+36>>2]=f;i[114610]=0;i[j+40>>2]=g;i[j+44>>2]=h;a=N(2467,j+204|0,a|0,j+248|0,j+32|0)|0;e=i[114610];i[114610]=0;if((e|0)==1){break c}}e=i[j+204>>2];if(!e){i[114610]=0;K(2421);a=i[114610];i[114610]=0;if((a|0)==1){break c}break d}de(l,e)}e=i[j+204>>2];g=e+a|0;h=Of(e,g,c);i[j+116>>2]=2420;f=wd(j+120|0,0,j+116|0);f:{g:{if(i[j+204>>2]==(j+208|0)){a=j+128|0;e=j+208|0;break g}a=Zc(a<<1);if(!a){i[114610]=0;K(2421);a=i[114610];i[114610]=0;if((a|0)!=1){break d}c=B()|0;A()|0;break f}de(f,a);e=i[j+204>>2]}i[114610]=0;fc(j+104|0,c);k=i[114610];i[114610]=0;h:{i:{if((k|0)!=1){i[114610]=0;X(2468,e|0,h|0,g|0,a|0,j+116|0,j+112|0,j+104|0);e=i[114610];i[114610]=0;if((e|0)==1){break i}ub(j+104|0);i[114610]=0;a=Y(17,b|0,a|0,i[j+116>>2],i[j+112>>2],c|0,d|0)|0;b=i[114610];i[114610]=0;if((b|0)==1){break h}lc(f);lc(l);Xa=j+256|0;return a|0}c=B()|0;A()|0;break f}c=B()|0;A()|0;ub(j+104|0);break f}c=B()|0;A()|0}lc(f);break b}x()}c=B()|0;A()|0}lc(l);E(c|0);x()}function j9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,j=0;e=Xa-32|0;Xa=e;g=Mg(a);a=b+24|0;f=Db(i[a>>2]+484360|0);i[114610]=0;j=F(2193,f|0)|0;f=i[114610];i[114610]=0;a:{b:{c:{if((f|0)==1){break c}i[114610]=0;D(1532,g|0,j|0);f=i[114610];i[114610]=0;if((f|0)==1){break c}d:{e:{if(j){f=0;while(1){c=k[$b(Db(i[a>>2]+484360|0),f)>>1];d=i[a>>2];i[114610]=0;d=C(918,d+484344|0,c|0)|0;h=i[114610];i[114610]=0;if((h|0)==1){break b}f:{if(d){c=Fb(i[a>>2]+484344|0,k[$b(Db(i[a>>2]+484360|0),f)>>1]);i[114610]=0;D(2191,e|0,c|0);c=i[114610];i[114610]=0;g:{h:{i:{if((c|0)!=1){i[114610]=0;G(2185,e+16|0,b|0,e|0);c=i[114610];i[114610]=0;if((c|0)==1){break i}i[114610]=0;D(1534,g|0,e+16|0);c=i[114610];i[114610]=0;if((c|0)==1){break h}eb(e+16|0);eb(e);break f}a=B()|0;A()|0;break a}a=B()|0;A()|0;break g}a=B()|0;A()|0;eb(e+16|0)}eb(e);break a}i[114610]=0;d=R(965)|0;h=i[114610];i[114610]=0;if((h|0)==1){break b}if((c|0)==(d|0)){i[114610]=0;c=C(85,e+16|0,38799)|0;d=i[114610];i[114610]=0;j:{if((d|0)!=1){i[114610]=0;D(1534,g|0,c|0);d=i[114610];i[114610]=0;if((d|0)==1){break j}eb(c);break f}a=B()|0;A()|0;break a}a=B()|0;A()|0;eb(c);break a}i[114610]=0;d=R(964)|0;h=i[114610];i[114610]=0;if((h|0)==1){break b}if((c|0)==(d|0)){i[114610]=0;c=C(85,e+16|0,38808)|0;d=i[114610];i[114610]=0;k:{if((d|0)!=1){i[114610]=0;D(1534,g|0,c|0);d=i[114610];i[114610]=0;if((d|0)==1){break k}eb(c);break f}a=B()|0;A()|0;break a}a=B()|0;A()|0;eb(c);break a}i[114610]=0;c=C(85,e+16|0,38817)|0;d=i[114610];i[114610]=0;if((d|0)==1){break e}i[114610]=0;D(1534,g|0,c|0);d=i[114610];i[114610]=0;if((d|0)==1){break d}eb(c)}f=f+1|0;if((j|0)!=(f|0)){continue}break}}Xa=e+32|0;return}a=B()|0;A()|0;break a}a=B()|0;A()|0;eb(c);break a}a=B()|0;A()|0;break a}a=B()|0;A()|0}Sc(g);E(a|0);x()}function wma(a,b,c){var d=0,e=0,f=0,h=0,l=0;l=Xa-16|0;Xa=l;d=a+1074308|0;kb(l+8|0,d,71);a:{if(ib(l+8|0)){e=(o(b,896)+a|0)+1075843|0;d=g[e|0];if((d|0)>-1){break a}if(!(j[a+480209|0]&16|j[(o(b,896)+a|0)+1075811|0]!=18)){f=d&-33;g[e|0]=f;b:{c:{if((f|0)!=-64){d=d&223;if((d|0)!=128){break c}d=j[(o(b,896)+a|0)+1075844|0]>>>4|-64;break b}d=j[(o(b,896)+a|0)+1075844|0]&15|-128;break b}d=d+ -1|0}g[e|0]=d;e=(o(b,896)+a|0)+1075072|0;i[e>>2]=i[e>>2]|2097152}if((d&224)!=128){break a}i[c>>2]=0;break a}if(j[(o(b,896)+a|0)+1075811|0]!=18){break a}kb(l+8|0,d,22);d:{if(ib(l+8|0)){h=o(b,896)+a|0;e=h+1075843|0;f=j[e|0];d=f<<24>>24;if(!((d|0)>-1|!i[h+1075060>>2])){e:{f:{if((f|0)!=192){if((f|0)!=128){break f}d=j[(o(b,896)+a|0)+1075844|0]>>>4|-64;break e}d=j[(o(b,896)+a|0)+1075844|0]&15|-128;break e}d=d+ -1|0}g[e|0]=d}if((d&192)!=128){break d}i[c>>2]=0;break d}d=j[(o(b,896)+a|0)+1075844|0];e=d>>>4|0;f=e+(d&15)|0;if(!(j[a+480208|0]&4?0:i[a+480180>>2]&16777248)){f=f+2|0;e=e+1|0}h=(o(b,896)+a|0)+1075843|0;d=j[h|0];if(!(i[a+480180>>2]&4)){d=(d&255)>>>0<f>>>0?d:0;if((d&255)>>>0>=e>>>0){i[c>>2]=0}g[h|0]=d+1;break d}g:{if(j[a+480209|0]&16){d=d&255?d+ -1|0:0;break g}g[h|0]=d+1}if(((d&255)>>>0)%(f>>>0)>>>0<e>>>0){break d}i[c>>2]=0}d=(o(b,896)+a|0)+1075072|0;i[d>>2]=i[d>>2]|2097152}d=o(b,896)+a|0;h:{if(j[d+1075811|0]!=18){break h}f=d+1075640|0;d=i[f>>2];if(!d|!j[d+34|0]|j[d+15|0]&2){break h}d=o(b,896)+a|0;if(i[d+1075072>>2]&134218752){break h}e=d+1075805|0;if(!Jd(j[e|0])){break h}f=i[f>>2];d=i[(o(j[f+34|0],160)+a|0)+906140>>2];if(!d){break h}h=$a[i[i[d>>2]+96>>2]](d,j[e|0],b)|0;c=i[c>>2];if(!(!h|c)){$a[i[i[d>>2]+88>>2]](d,f,j[e|0]+255|0,0,b);break h}if(h|!c){break h}$a[i[i[d>>2]+88>>2]](d,f,j[e|0],k[(o(b,896)+a|0)+1075672>>1],b)}Xa=l+16|0}function m6(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0;e=Xa-16|0;Xa=e;d=-2;a:{if(!a){break a}c=i[a+28>>2];if(!c){break a}b=(b|0)==1?2:b;if(b>>>0>4|!(1<<b&21)){break a}f=i[c+11e3>>2];k=i[a+4>>2];i[c+11e3>>2]=0;b:{if(i[c+43780>>2]<0){break b}h=(b|0)==4;g=i[c+11004>>2];if(g?!h:0){break a}d=i[c+11008>>2]>0?9:8;i[c+11004>>2]=h|g;if(!(!f|(b|0)!=4)){i[e+12>>2]=i[a+4>>2];i[e+8>>2]=i[a+16>>2];b=i[a+12>>2];b=jF(c,i[a>>2],e+12|0,b,b,e+8|0,d|4);i[c+43780>>2]=b;d=i[e+12>>2];i[a>>2]=d+i[a>>2];i[a+4>>2]=i[a+4>>2]-d;i[a+8>>2]=d+i[a+8>>2];i[a+48>>2]=i[c+28>>2];d=i[e+8>>2];i[a+12>>2]=d+i[a+12>>2];i[a+16>>2]=i[a+16>>2]-d;i[a+20>>2]=d+i[a+20>>2];d=-3;if((b|0)<0){break a}if(!b){d=1;break a}i[c+43780>>2]=-1;d=-5;break a}f=i[c+10996>>2];if(!f){j=(b|0)!=4;l=j?d|2:d;h=c+11012|0;b=i[c+10992>>2];while(1){d=i[a+4>>2];i[e+8>>2]=32768-b;i[e+12>>2]=d;f=jF(c,i[a>>2],e+12|0,h,b+h|0,e+8|0,l);i[c+43780>>2]=f;b=i[e+12>>2];i[a>>2]=b+i[a>>2];i[a+4>>2]=i[a+4>>2]-b;i[a+8>>2]=b+i[a+8>>2];i[a+48>>2]=i[c+28>>2];b=i[e+8>>2];i[c+10996>>2]=b;d=i[a+16>>2];b=b>>>0<d>>>0?b:d;Tb(i[a+12>>2],h+i[c+10992>>2]|0,b);i[a+12>>2]=b+i[a+12>>2];i[a+16>>2]=i[a+16>>2]-b;i[a+20>>2]=b+i[a+20>>2];g=i[c+10996>>2]-b|0;i[c+10996>>2]=g;b=b+i[c+10992>>2]&32767;i[c+10992>>2]=b;if((f|0)<0){break b}d=-5;if((f|0)==1?!k:0){break a}if(!j){if(!f){d=g?-5:1;break a}if(i[a+16>>2]){continue}break a}if(f){d=0;if(g|!i[a+4>>2]){break a}if(i[a+16>>2]){continue}break a}break}d=!g;break a}b=i[a+16>>2];b=f>>>0<b>>>0?f:b;Tb(i[a+12>>2],(i[c+10992>>2]+c|0)+11012|0,b);i[a+12>>2]=b+i[a+12>>2];i[a+16>>2]=i[a+16>>2]-b;i[a+20>>2]=b+i[a+20>>2];a=i[c+10996>>2]-b|0;i[c+10996>>2]=a;i[c+10992>>2]=b+i[c+10992>>2]&32767;d=0;if(i[c+43780>>2]){break a}d=!a;break a}d=-3}Xa=e+16|0;return d|0}function bxa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,h=0,k=0,l=0,m=0,n=0,o=0;e=Xa-32|0;Xa=e;m=c+484344|0;Gf(m,j[b+70|0]|j[b+71|0]<<8);a:{if(j[b+70|0]|j[b+71|0]<<8){while(1){f=i[a+8>>2];h=Cf(a);Ib(a,1);b:{if((j[b+58|0]|j[b+59|0]<<8)==258){c=id(a)+1|0;break b}c=_f(a)}d=_f(a);vc(a,f+h|0);ad(e+16|0,a,d);i[114610]=0;c=I(402,m|0,l&65535,(c?c>>>0<1024?c:1024:64)|0)|0;f=i[114610];i[114610]=0;if((f|0)==1){break a}c:{if(!d|c^1){break c}c=Fb(m,l);n=e,o=Jb(c),i[n+8>>2]=o;n=e,o=Kb(c),i[n>>2]=o;if(!pb(e+8|0,e)){break c}while(1){d=i[e+8>>2];i[114610]=0;c=F(387,e+16|0)|0;f=i[114610];i[114610]=0;d:{e:{f:{if((f|0)!=1){if(!(c&128)){break f}if(c&1){i[114610]=0;f=F(387,e+16|0)|0;h=i[114610];i[114610]=0;if((h|0)==1){break a}g[d|0]=f}if(c&2){break e}break d}break a}g[d|0]=c;c=255}i[114610]=0;f=F(387,e+16|0)|0;h=i[114610];i[114610]=0;if((h|0)==1){break a}g[d+1|0]=f}f=0;if(c&4){i[114610]=0;f=F(387,e+16|0)|0;h=i[114610];i[114610]=0;if((h|0)==1){break a}}if(c&8){i[114610]=0;h=F(387,e+16|0)|0;k=i[114610];i[114610]=0;if((k|0)==1){break a}g[d+3|0]=h}if(c&16){i[114610]=0;c=F(387,e+16|0)|0;h=i[114610];i[114610]=0;if((h|0)==1){break a}g[d+5|0]=c}c=d;g:{h:{h=j[d|0];if(!h){break h}k=255;if((h|0)==97){break g}if(h>>>0>96){break h}k=h+12|0;break g}k=0}g[c|0]=k;i:{if(j[d+5|0]|j[d+3|0]){i[114610]=0;L(577,d|0);c=i[114610];i[114610]=0;if((c|0)!=1){break i}break a}g[d+3|0]=0}if(j[d+1|0]==255){g[d+1|0]=0}c=f+ -16|0;j:{if((c&255)>>>0<=64){g[d+4|0]=c;g[d+2|0]=1;break j}if(f>>>0<96){break j}c=f&15;g[d+4|0]=c;f=f+ -96>>4;g[d+2|0]=j[f+17967|0];if((f|0)!=6){break j}g[d+4|0]=c<<2}jk(e+8|0);if(pb(e+8|0,e)){continue}break}}hb(e+16|0);l=l+1|0;if(l>>>0<(j[b+70|0]|j[b+71|0]<<8)>>>0){continue}break}}Xa=e+32|0;return}a=B()|0;A()|0;hb(e+16|0);E(a|0);x()}function Oka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,k=0,l=0,m=0,n=0;e=Xa-1136|0;Xa=e;pc(b);d=e+1112|0;h=zka(b,d);if(!h){KI(d)}a:{if(!h){break a}if(!OI(e+1112|0)){break a}d=e+1120|0;if((j[d|0]|j[d+1|0]<<8|(j[d+2|0]<<16|j[d+3|0]<<24))!=(hj(b)|0)){break a}d=e+1128|0;if((j[d|0]|j[d+1|0]<<8|(j[d+2|0]<<16|j[d+3|0]<<24))!=(cf(b)|0)){break a}if(!c){f=1;break a}yb(e+1056|0,0,56);if(n6(e+1056|0)){break a}d=j[d|0]|j[d+1|0]<<8|(j[d+2|0]<<16|j[d+3|0]<<24);i[e+1052>>2]=d;f=e+1132|0;f=j[f|0]|j[f+1|0]<<8|(j[f+2|0]<<16|j[f+3|0]<<24);g=(f|0)!=0;h=cz(e+1040|0,f);b:{c:{d:{e:{if(!f|!d){break e}while(1){i[114610]=0;i[e+12>>2]=1024;d=C(632,e+12|0,e+1052|0)|0;g=i[114610];i[114610]=0;if((g|0)==1){break d}d=i[d>>2];i[114610]=0;I(261,b|0,e+16|0,d|0)|0;g=i[114610];i[114610]=0;if((g|0)==1){break c}i[114610]=0;k=I(1556,k|0,e+16|0,d|0)|0;g=i[114610];i[114610]=0;if((g|0)==1){break c}i[e+1072>>2]=f;i[e+1060>>2]=d;i[e+1056>>2]=e+16;g=i[h>>2];i[114610]=0;i[e+1068>>2]=g+l;m=C(1557,e+1056|0,0)|0;g=i[114610];i[114610]=0;if((g|0)==1){break c}n=i[e+1052>>2]-d|0;i[e+1052>>2]=n;d=i[e+1072>>2];g=(d|0)!=0;if(!d|(m|0)==1){break e}l=(f+l|0)-d|0;f=d;if(n){continue}break}}i[114610]=0;F(1558,e+1056|0)|0;b=i[114610];i[114610]=0;f:{g:{if((b|0)!=1){f=0;b=e+1124|0;if(!((j[b|0]|j[b+1|0]<<8|(j[b+2|0]<<16|j[b+3|0]<<24))!=(k|0)|g|(m|0)!=1)){i[114610]=0;D(836,e|0,h|0);b=i[114610];i[114610]=0;if((b|0)==1){break g}i[114610]=0;b=I(837,e+16|0,e|0,0)|0;f=i[114610];i[114610]=0;if((f|0)==1){break g}i[114610]=0;f=I(1496,a|0,b|0,c|0)|0;a=i[114610];i[114610]=0;if((a|0)==1){break f}hb(b)}Md(h);break a}a=B()|0;A()|0;break b}a=B()|0;A()|0;break b}a=B()|0;A()|0;hb(b);break b}a=B()|0;A()|0;break b}a=B()|0;A()|0}Md(h);E(a|0);x()}Xa=e+1136|0;return f|0}function E5(a,b,c){var d=0,e=0,f=0,g=0,h=0,k=0,l=0,m=0,n=0;a:{b:{c:{f=i[a+1420>>2];if((f|0)<1){break c}while(1){i[(o(d,20)+a|0)+1436>>2]=0;d=d+1|0;if((f|0)!=(d|0)){continue}break}if((f|0)<=3){break c}g=c;break b}if((c|0)<4){break a}h=c+ -3|0;d:{while(1){e:{e=b+g|0;if(j[e|0]!=79|(j[e|0]|j[e+1|0]<<8|(j[e+2|0]<<16|j[e+3|0]<<24))!=(j[84608]|j[84609]<<8|(j[84610]<<16|j[84611]<<24))){break e}l=g+26|0;if((l|0)>=(h|0)){break d}k=g+27|0;n=b+l|0;c=j[n|0];if((k+c|0)>=(h|0)){break d}m=c+27|0;d=0;if(c){while(1){m=j[(d+k|0)+b|0]+m|0;d=d+1|0;if((c|0)!=(d|0)){continue}break}}d=0;c=0;while(1){k=22;d=Av(d,j[(c+g|0)+b|0]);c=c+1|0;if((c|0)!=22){continue}break}while(1){d=Av(d,0);k=k+1|0;if((k|0)!=26){continue}break}i[a+1420>>2]=f+1;c=o(f,20)+a|0;i[c+1432>>2]=d;i[c+1428>>2]=m+ -26;i[c+1424>>2]=j[e+22|0]|j[e+23|0]<<8|(j[e+24|0]<<16|j[e+25|0]<<24);if(j[(l+j[n|0]|0)+b|0]==255){d=-1}else{d=j[e+6|0]|j[e+7|0]<<8|(j[e+8|0]<<16|j[e+9|0]<<24)}i[c+1436>>2]=l;i[c+1440>>2]=d;f=i[a+1420>>2];if((f|0)!=4){break e}g=h;break b}g=g+1|0;if((h|0)!=(g|0)){continue}break}g=h}if((f|0)<1){break a}}h=0;while(1){e=o(h,20)+a|0;k=e+1432|0;c=i[k>>2];d=0;l=i[e+1436>>2];f=g-l|0;n=e+1428|0;m=i[n>>2];f=(m|0)>(f|0)?f:m;if((f|0)>=1){while(1){c=Av(c,j[(d+l|0)+b|0]);d=d+1|0;if((f|0)!=(d|0)){continue}break}}d=m-f|0;i[n>>2]=d;i[k>>2]=c;f:{if(!d){d=c;c=e+1424|0;if((d|0)==i[c>>2]){i[a+1380>>2]=-1;i[a+992>>2]=0;i[a+1420>>2]=-1;b=i[(o(h,20)+a|0)+1440>>2];i[a+1060>>2]=b;i[a+1064>>2]=(b|0)!=-1;return f+l|0}d=i[a+1420>>2]+ -1|0;i[a+1420>>2]=d;d=o(d,20)+a|0;i[c+16>>2]=i[d+1440>>2];e=d+1432|0;f=i[e+4>>2];i[c+8>>2]=i[e>>2];i[c+12>>2]=f;d=d+1424|0;e=i[d+4>>2];i[c>>2]=i[d>>2];i[c+4>>2]=e;break f}h=h+1|0}if((h|0)<i[a+1420>>2]){continue}break}}return g}function qf(a,b,c,d,e){var f=0,g=0,l=0,m=0,n=0;l=i[a+8>>2]+(o(k[a+14>>1],(j[a+80|0]?c:0)+b|0)>>>1|0)|0;i[a+8>>2]=l;b=k[a+20>>1];g=k[a+22>>1];n=k[a+70>>1];m=j[a+79|0]?k[i[a>>2]+3836>>1]:m;a:{b:{c:{switch(i[a+16>>2]){case 0:c=k[i[a>>2]+3832>>1];c=b+(c&k[a+34>>1]?0:k[a+24>>1]?o((b^-1)<<16>>16,k[a+36>>1]>>>k[i[a+40>>2]+((c>>>k[a+32>>1]&7)<<1)>>1]|0)>>>3|0:0)|0;h[a+20>>1]=c;if(c<<16>>16>0){break b}i[a+16>>2]=1;h[a+20>>1]=0;break b;case 1:c=k[i[a>>2]+3832>>1];c=b+(c&k[a+46>>1]?0:k[a+26>>1]?k[a+48>>1]>>>k[i[a+52>>2]+((c>>>k[a+44>>1]&7)<<1)>>1]|0:0)|0;h[a+20>>1]=c;f=c<<16>>16;c=k[a+28>>1];if((f|0)<(c|0)){break b}i[a+16>>2]=2;h[a+20>>1]=c;break b;case 2:if(j[a+78|0]){break b};case 3:c=0;f=k[i[a>>2]+3832>>1];f=b+(f&k[a+58>>1]?0:k[a+30>>1]?k[a+60>>1]>>>k[i[a+64>>2]+((f>>>k[a+56>>1]&7)<<1)>>1]|0:0)|0;h[a+20>>1]=f;if(f<<16>>16<511){break b}i[a+16>>2]=-1;h[a+20>>1]=511;i[a+72>>2]=0;break a;default:break c}}c=0;i[a+72>>2]=0;break a}g=((b+g|0)+n|0)+m<<3;if(e){d=(h[a+74>>1]+h[a+72>>1]>>e)+d|0}d=(l>>>10|0)+d|0;c=d&255;b=d&65535;d:{e:{switch(k[a+12>>1]){case 0:d=(b&512)>>>9|0;b=k[((b&256?c^255:c)<<1)+19280>>1];break d;case 1:d=0;b=k[((b&512?0:b&256?c^255:c)<<1)+19280>>1];break d;case 2:d=0;b=k[((b&256?c^255:c)<<1)+19280>>1];break d;case 3:d=0;b=k[((b&256?0:c)<<1)+19280>>1];break d;case 4:e=0;d=0;if(!(b&512)){e=(c<<1^b<<24>>31)&254;d=(b&256)>>>8|0}b=k[(e<<1)+19280>>1];break d;case 5:d=0;if(b&512){b=0}else{c=c<<1&254;b=b&128?c^255:c}b=k[(b<<1)+19280>>1];break d;case 6:d=(d&512)>>>9|0;b=0;break d;default:break e}}c=d<<3&4088;d=(b&512)>>>9|0;b=d?c^4088:c}h[a+74>>1]=k[a+72>>1];e=a;a=b+g|0;a=(a&65535)>>>0<8191?a:8191;c=0-d^k[((a&255)<<1)+18768>>1]+1024>>>((a&65280)>>>8)<<1;h[e+72>>1]=c}return c<<16>>16}function tq(a,b,c,d,e,f,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;h=h|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;l=Xa-128|0;Xa=l;i[l+120>>2]=b;n=ps(c,d);i[l+4>>2]=2420;p=wd(l+8|0,0,l+4|0);m=l+16|0;a:{b:{if(n>>>0>=101){m=Zc(n);if(!m){i[114610]=0;K(2421);a=i[114610];i[114610]=0;if((a|0)!=1){break a}b=B()|0;A()|0;break b}de(p,m)}k=m;b=c;while(1){if((b|0)==(d|0)){c:{d:{e:while(1){f:{i[114610]=0;k=C(2422,a|0,l+120|0)|0;b=i[114610];i[114610]=0;if((b|0)==1){break f}if(!(k&(n|0)!=0)){i[114610]=0;b=C(2423,a|0,l+120|0)|0;a=i[114610];i[114610]=0;if((a|0)==1){break c}if(!b){break d}i[f>>2]=i[f>>2]|2;break d}i[114610]=0;q=F(2424,a|0)|0;b=i[114610];i[114610]=0;g:{if((b|0)!=1){if(h){break g}i[114610]=0;q=C(2425,e|0,q|0)|0;b=i[114610];i[114610]=0;if((b|0)!=1){break g}}b=B()|0;A()|0;break b}r=t+1|0;u=0;k=m;b=c;while(1){if((b|0)==(d|0)){t=r;if(!u){continue e}i[114610]=0;F(2426,a|0)|0;b=i[114610];i[114610]=0;if((b|0)!=1){k=m;b=c;if(n+o>>>0<2){continue e}while(1){if((b|0)==(d|0)){continue e}h:{if(j[k|0]!=2){break h}if((lb(b)|0)==(r|0)){break h}g[k|0]=0;o=o+ -1|0}k=k+1|0;b=b+12|0;continue}}b=B()|0;A()|0;break b}i:{if(j[k|0]!=1){break i}s=g[Sb(b,t)|0];j:{if(h){break j}i[114610]=0;s=C(2425,e|0,s<<24>>24)|0;v=i[114610];i[114610]=0;if((v|0)!=1){break j}b=B()|0;A()|0;break b}k:{if((q&255)==(s&255)){u=1;if((lb(b)|0)!=(r|0)){break i}g[k|0]=2;o=o+1|0;break k}g[k|0]=0}n=n+ -1|0}k=k+1|0;b=b+12|0;continue}}break}b=B()|0;A()|0;break b}l:{m:{while(1){if((c|0)==(d|0)){break m}if(j[m|0]!=2){m=m+1|0;c=c+12|0;continue}break}d=c;break l}i[f>>2]=i[f>>2]|4}lc(p);Xa=l+128|0;return d|0}b=B()|0;A()|0}else{n:{if(!Cc(b)){g[k|0]=1;break n}g[k|0]=2;o=o+1|0;n=n+ -1|0}k=k+1|0;b=b+12|0;continue}break}}lc(p);E(b|0)}x()}function LT(a,b,c){var d=0,e=0,f=0,k=0,l=0,m=0;e=Xa-32|0;Xa=e;a:{if((j[a|0]|j[a+1|0]<<8|(j[a+2|0]<<16|j[a+3|0]<<24))==1229999433){Et(e,3,a+32|0);oc(e+16|0,e);i[114610]=0;C(369,b+492|0,e+16|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break a}eb(e+16|0);oi(e,1,a+4|0);oc(e+16|0,e);i[114610]=0;C(369,b+524|0,e+16|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break a}eb(e+16|0);d=a+20|0;i[b>>2]=(j[d|0]|j[d+1|0]<<8)<<5;i[b+4>>2]=j[a+24|0]>>>1;kc(b+4|0,64);d=a+25|0;f=j[d|0]&127;i[b+8>>2]=f>>>0>64?128:f<<2;g[b+15|0]=j[b+15|0]&254|((j[d|0]^-1)&128)>>>7;g[e+16|0]=j[a+26|0];g[e|0]=100;l=b,m=j[Xb(e+16|0,e)|0],g[l+20|0]=m;g[e+16|0]=j[a+27|0];g[e|0]=64;l=b,m=j[Xb(e+16|0,e)|0],g[l+19|0]=m;g[b+16|0]=j[a+17|0];g[b+17|0]=j[a+18|0];g[b+18|0]=j[a+19|0];g[b+26|0]=j[a+22|0];g[b+27|0]=j[a+23|0];d=a+58|0;At(b,j[d|0]&127,j[d|0]>>>7|0);d=a+59|0;zt(b,j[d|0]&127,j[d|0]>>>7|0);b:{c:{d:{d=a+28|0;if(!((j[d|0]|j[d+1|0]<<8)==514|(j[d|0]|j[d+1|0]<<8)==529|(j[d|0]|j[d+1|0]<<8)==544)){if((j[d|0]|j[d+1|0]<<8)!=532){break d}}d=a+61|0;if(j[d|0]==255){break d}if(j[d|0]<=128){g[b+30|0]=j[d|0]}d=j[a+62|0]|j[a+63|0]<<8;if(d>>>0<129){break c}break b}d=0;f=a+61|0;if(g[f|0]>=0){g[b+30|0]=j[f|0]+1}f=a+62|0;if(g[f|0]>=0){d=j[f|0]+1|0}f=a+63|0;if(g[f|0]<0){break c}d=(j[f|0]<<7)+d|0}h[b+28>>1]=d}d=g[a+60|0];g[b+31|0]=d;if((d|0)<=-1){g[b+31|0]=0;g[b+34|0]=d^128}d=0;c=c&16777216?240:25;Gt(a+304|0,b+48|0,0,c);Gt(a+386|0,b+68|0,32,c);Gt(a+468|0,b+88|0,32,c);g[b+100|0]=j[b+100|0]&239|j[a+468|0]>>>3&16;c=b+108|0;f=b+236|0;a=a- -64|0;while(1){k=d<<1;b=j[k+a|0];k=j[a+(k|1)|0];l=Mc(f,d),m=k,h[l>>1]=m;l=Nb(c,d),m=(b>>>0<120?b:d)+1|0,g[l|0]=m;d=d+1|0;if((d|0)!=120){continue}break}d=554}Xa=e+32|0;return d}a=B()|0;A()|0;eb(e+16|0);E(a|0);x()}function rX(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;g=i[a+4>>2];d=g&-8;f=d+a|0;a:{if(!(g&3)){if(b>>>0<256){break a}if(d>>>0>=b+4>>>0){c=a;if(d-b>>>0<=i[116040]<<1>>>0){break a}}return 0}b:{if(d>>>0>=b>>>0){c=d-b|0;if(c>>>0<16){break b}i[a+4>>2]=g&1|b|2;b=a+b|0;i[b+4>>2]=c|3;i[f+4>>2]=i[f+4>>2]|1;cq(b,c);break b}if(i[115926]==(f|0)){d=d+i[115923]|0;if(d>>>0<=b>>>0){break a}i[a+4>>2]=g&1|b|2;c=a+b|0;b=d-b|0;i[c+4>>2]=b|1;i[115923]=b;i[115926]=c;break b}if(i[115925]==(f|0)){d=d+i[115922]|0;if(d>>>0<b>>>0){break a}c=d-b|0;c:{if(c>>>0>=16){i[a+4>>2]=g&1|b|2;b=a+b|0;i[b+4>>2]=c|1;d=a+d|0;i[d>>2]=c;i[d+4>>2]=i[d+4>>2]&-2;break c}i[a+4>>2]=d|g&1|2;b=a+d|0;i[b+4>>2]=i[b+4>>2]|1;c=0;b=0}i[115925]=b;i[115922]=c;break b}e=i[f+4>>2];if(e&2){break a}h=d+(e&-8)|0;if(h>>>0<b>>>0){break a}k=h-b|0;d:{if(e>>>0<=255){c=i[f+8>>2];e=e>>>3|0;d=i[f+12>>2];if((d|0)==(c|0)){m=463680,n=i[115920]&aNa(-2,e),i[m>>2]=n;break d}i[c+12>>2]=d;i[d+8>>2]=c;break d}j=i[f+24>>2];d=i[f+12>>2];e:{if((f|0)!=(d|0)){c=i[f+8>>2];i[c+12>>2]=d;i[d+8>>2]=c;break e}f:{c=f+20|0;e=i[c>>2];if(e){break f}c=f+16|0;e=i[c>>2];if(e){break f}d=0;break e}while(1){l=c;d=e;c=d+20|0;e=i[c>>2];if(e){continue}c=d+16|0;e=i[d+16>>2];if(e){continue}break}i[l>>2]=0}if(!j){break d}c=i[f+28>>2];e=(c<<2)+463984|0;g:{if(i[e>>2]==(f|0)){i[e>>2]=d;if(d){break g}m=463684,n=i[115921]&aNa(-2,c),i[m>>2]=n;break d}i[j+(i[j+16>>2]==(f|0)?16:20)>>2]=d;if(!d){break d}}i[d+24>>2]=j;c=i[f+16>>2];if(c){i[d+16>>2]=c;i[c+24>>2]=d}c=i[f+20>>2];if(!c){break d}i[d+20>>2]=c;i[c+24>>2]=d}if(k>>>0<=15){i[a+4>>2]=g&1|h|2;b=a+h|0;i[b+4>>2]=i[b+4>>2]|1;break b}i[a+4>>2]=g&1|b|2;b=a+b|0;i[b+4>>2]=k|3;c=a+h|0;i[c+4>>2]=i[c+4>>2]|1;cq(b,k)}c=a}return c}function V$(a,b,c,d,e,f,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;h=h|0;var k=0,m=0,n=0,o=0;a=Xa-624|0;Xa=a;i[a+608>>2]=c;i[a+616>>2]=b;i[a+16>>2]=2482;b=wd(a+200|0,a+208|0,a+16|0);i[114610]=0;fc(a+192|0,e);k=i[114610];i[114610]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{if((k|0)!=1){i[114610]=0;k=F(2449,a+192|0)|0;m=i[114610];i[114610]=0;if((m|0)==1){break j}g[a+191|0]=0;e=i[e+4>>2];i[114610]=0;c=fa(2493,a+616|0,c|0,d|0,a+192|0,e|0,f|0,a+191|0,k|0,b|0,a+196|0,a+608|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break e}if(!c){break f}c=j[62395]|j[62396]<<8|(j[62397]<<16|j[62398]<<24);g[a+183|0]=c;g[a+184|0]=c>>>8;g[a+185|0]=c>>>16;g[a+186|0]=c>>>24;c=j[62392]|j[62393]<<8|(j[62394]<<16|j[62395]<<24);i[a+176>>2]=j[62388]|j[62389]<<8|(j[62390]<<16|j[62391]<<24);i[a+180>>2]=c;i[114610]=0;N(2463,k|0,a+176|0,a+186|0,a+128|0)|0;c=i[114610];i[114610]=0;if((c|0)==1){break i}i[a+4>>2]=2420;d=wd(a+8|0,0,a+4|0);c=a+16|0;if((i[a+196>>2]-i[b>>2]|0)<393){break g}de(d,Zc((i[a+196>>2]-i[b>>2]>>2)+2|0));if(i[d>>2]){break h}i[114610]=0;K(2421);c=i[114610];i[114610]=0;if((c|0)==1){break d}break a}e=B()|0;A()|0;break b}e=B()|0;A()|0;break c}e=B()|0;A()|0;break c}c=i[d>>2]}if(j[a+191|0]){g[c|0]=45;c=c+1|0}e=i[b>>2];while(1){if(e>>>0>=l[a+196>>2]){g[c|0]=0;i[a>>2]=h;if((xD(a+16|0,a)|0)!=1){i[114610]=0;L(2484,62372);c=i[114610];i[114610]=0;if((c|0)!=1){break a}break d}lc(d)}else{n=c,o=j[(a+176|0)+(Ju(a+128|0,a+168|0,e)-(a+128|0)>>2)|0],g[n|0]=o;c=c+1|0;e=e+4|0;continue}break}}i[114610]=0;c=C(2455,a+616|0,a+608|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break e}if(c){i[f>>2]=i[f>>2]|2}c=i[a+616>>2];ub(a+192|0);lc(b);Xa=a+624|0;return c|0}e=B()|0;A()|0;break c}e=B()|0;A()|0;lc(d)}ub(a+192|0)}lc(b);E(e|0);x()}x()}function rq(a,b,c,d,e,f,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;h=h|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;l=Xa-128|0;Xa=l;i[l+120>>2]=b;n=ps(c,d);i[l+4>>2]=2420;p=wd(l+8|0,0,l+4|0);m=l+16|0;a:{b:{if(n>>>0>=101){m=Zc(n);if(!m){i[114610]=0;K(2421);a=i[114610];i[114610]=0;if((a|0)!=1){break a}b=B()|0;A()|0;break b}de(p,m)}k=m;b=c;while(1){if((b|0)==(d|0)){c:{d:{e:while(1){f:{i[114610]=0;k=C(2454,a|0,l+120|0)|0;b=i[114610];i[114610]=0;if((b|0)==1){break f}if(!(k&(n|0)!=0)){i[114610]=0;b=C(2455,a|0,l+120|0)|0;a=i[114610];i[114610]=0;if((a|0)==1){break c}if(!b){break d}i[f>>2]=i[f>>2]|2;break d}i[114610]=0;q=F(2456,a|0)|0;b=i[114610];i[114610]=0;g:{if((b|0)!=1){if(h){break g}i[114610]=0;q=C(2457,e|0,q|0)|0;b=i[114610];i[114610]=0;if((b|0)!=1){break g}}b=B()|0;A()|0;break b}r=t+1|0;u=0;k=m;b=c;while(1){if((b|0)==(d|0)){t=r;if(!u){continue e}i[114610]=0;F(2458,a|0)|0;b=i[114610];i[114610]=0;if((b|0)!=1){k=m;b=c;if(n+o>>>0<2){continue e}while(1){if((b|0)==(d|0)){continue e}h:{if(j[k|0]!=2){break h}if((lb(b)|0)==(r|0)){break h}g[k|0]=0;o=o+ -1|0}k=k+1|0;b=b+12|0;continue}}b=B()|0;A()|0;break b}i:{if(j[k|0]!=1){break i}s=i[Ki(b,t)>>2];j:{if(h){break j}i[114610]=0;s=C(2457,e|0,s|0)|0;v=i[114610];i[114610]=0;if((v|0)!=1){break j}b=B()|0;A()|0;break b}k:{if((q|0)==(s|0)){u=1;if((lb(b)|0)!=(r|0)){break i}g[k|0]=2;o=o+1|0;break k}g[k|0]=0}n=n+ -1|0}k=k+1|0;b=b+12|0;continue}}break}b=B()|0;A()|0;break b}l:{m:{while(1){if((c|0)==(d|0)){break m}if(j[m|0]!=2){m=m+1|0;c=c+12|0;continue}break}d=c;break l}i[f>>2]=i[f>>2]|4}lc(p);Xa=l+128|0;return d|0}b=B()|0;A()|0}else{n:{if(!Cc(b)){g[k|0]=1;break n}g[k|0]=2;o=o+1|0;n=n+ -1|0}k=k+1|0;b=b+12|0;continue}break}}lc(p);E(b|0)}x()}function t1(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;a=Xa-352|0;Xa=a;i[a+336>>2]=c;i[a+344>>2]=b;h=Ab(a+208|0);i[114610]=0;fc(a+16|0,d);b=i[114610];i[114610]=0;a:{b:{c:{d:{if((b|0)!=1){i[114610]=0;b=F(2449,a+16|0)|0;c=i[114610];i[114610]=0;if((c|0)==1){break d}i[114610]=0;N(2463,b|0,62112,62138,a+224|0)|0;b=i[114610];i[114610]=0;if((b|0)==1){break d}ub(a+16|0);c=Ab(a+192|0);b=qc(c);i[114610]=0;D(149,c|0,b|0);b=i[114610];i[114610]=0;if((b|0)==1){break b}b=Sb(c,0);i[a+188>>2]=b;i[a+12>>2]=a+16;i[a+8>>2]=0;while(1){e:{i[114610]=0;d=C(2454,a+344|0,a+336|0)|0;g=i[114610];i[114610]=0;if((g|0)==1){break e}if(!d){break c}if(i[a+188>>2]==(lb(c)+b|0)){d=lb(c);b=lb(c);i[114610]=0;D(149,c|0,b<<1);b=i[114610];i[114610]=0;if((b|0)==1){break b}b=qc(c);i[114610]=0;D(149,c|0,b|0);b=i[114610];i[114610]=0;if((b|0)==1){break b}b=Sb(c,0);i[a+188>>2]=d+b}i[114610]=0;d=F(2456,a+344|0)|0;g=i[114610];i[114610]=0;if((g|0)==1){break e}i[114610]=0;d=uj(d,16,b,a+188|0,a+8|0,0,h,a+16|0,a+12|0,a+224|0);g=i[114610];i[114610]=0;if((g|0)==1){break e}if(d){break c}i[114610]=0;F(2458,a+344|0)|0;d=i[114610];i[114610]=0;if((d|0)!=1){continue}}break}break b}b=B()|0;A()|0;break a}b=B()|0;A()|0;ub(a+16|0);break a}i[114610]=0;D(149,c|0,i[a+188>>2]-b|0);b=i[114610];i[114610]=0;f:{if((b|0)==1){break f}b=xb(c);i[114610]=0;d=R(2445)|0;g=i[114610];i[114610]=0;if((g|0)==1){break f}i[a>>2]=f;i[114610]=0;b=N(2446,b|0,d|0,62145,a|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break f}if((b|0)!=1){i[e>>2]=4}i[114610]=0;b=C(2455,a+344|0,a+336|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break f}if(b){i[e>>2]=i[e>>2]|2}b=i[a+344>>2];eb(c);eb(h);Xa=a+352|0;return b|0}}b=B()|0;A()|0;eb(c)}eb(h);E(b|0);x()}function Rua(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;f=Xa-48|0;Xa=f;v=i[a+16>>2];e=i[a+44>>2];i[f+32>>2]=e;k=i[a+48>>2];i[f+36>>2]=k;n=i[a+52>>2];i[f+40>>2]=n;p=i[a+56>>2];i[f+44>>2]=p;w=i[a+24>>2];x=i[a+20>>2];g=i[a+4>>2];l=i[a>>2];i[f+24>>2]=l;i[f+28>>2]=g;j=i[a+12>>2];i[f+16>>2]=i[a+8>>2];i[f+20>>2]=j;if(d){while(1){p=1;j=((((g&2147483647)<<1|l>>>31)&2147483646)<<1)+v|0;e=(((l>>>16|0)+4&131064)<<1)+b|0;l=h[e+38>>1];m=h[e+36>>1];r=h[e+34>>1];s=h[e+32>>1];t=h[e+30>>1];q=h[e+28>>1];u=h[e+26>>1];y=h[e+24>>1];n=0;e=1;k=0;while(1){g=k<<1;i[(f+8|0)+(k<<2)>>2]=(((((o(h[j+(g|8)>>1],r)+o(h[j+(g|4)>>1],s)|0)+o(h[j+(g|12)>>1],m)|0)+o(l,h[j+(g|16)>>1])|0)/2|0)+((((o(h[j+(g|-8)>>1],u)+o(h[j+(g|-12)>>1],y)|0)+o(h[j+(g|-4)>>1],q)|0)+o(h[j+g>>1],t)|0)/2|0)|0)/16384;g=e;e=0;k=1;if(g){continue}break}while(1){k=(f+8|0)+(n<<2)|0;l=i[k>>2];m=i[a+60>>2];r=m;g=(f+32|0)+(n<<3)|0;n=i[g>>2];e=Eb(n,-16777216,16776704);s=i[a+64>>2];j=Eb(i[g+4>>2],-16777216,16776704);q=i[a+68>>2];u=q;q=q>>31;i[g+4>>2]=n;n=i[a+72>>2];m=m>>31;l=l<<8;m=XMa(r,m,l,l>>31);r=_a;t=k;k=m;m=XMa(s,s>>31,e,e>>31);k=k+m|0;e=_a+r|0;e=k>>>0<m>>>0?e+1|0:e;m=k;k=XMa(u,q,j,j>>31);j=m+k|0;e=_a+e|0;e=j>>>0<k>>>0?e+1|0:e;j=j+8388608|0;if(j>>>0<8388608){e=e+1|0}e=(e&16777215)<<8|j>>>24;i[t>>2]=(e|0)/256;i[g>>2]=e-(l&n);n=1;e=p&1;p=0;if(e){continue}break}i[c>>2]=i[c>>2]+o(i[f+8>>2],x);i[c+4>>2]=i[c+4>>2]+o(i[f+12>>2],w);zb(f+24|0,f+16|0);d=d+ -1|0;if(d){c=c+8|0;l=i[f+24>>2];g=i[f+28>>2];continue}break}l=i[f+24>>2];g=i[f+28>>2];p=i[f+44>>2];n=i[f+40>>2];k=i[f+36>>2];e=i[f+32>>2]}i[a+56>>2]=p;i[a+52>>2]=n;i[a+48>>2]=k;i[a+44>>2]=e;i[a>>2]=l;i[a+4>>2]=g;Xa=f+48|0}function P1(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;a=Xa-272|0;Xa=a;i[a+256>>2]=c;i[a+264>>2]=b;h=Ab(a+208|0);i[114610]=0;fc(a+16|0,d);b=i[114610];i[114610]=0;a:{b:{c:{d:{if((b|0)!=1){i[114610]=0;b=F(21,a+16|0)|0;c=i[114610];i[114610]=0;if((c|0)==1){break d}i[114610]=0;N(2440,b|0,62112,62138,a+224|0)|0;b=i[114610];i[114610]=0;if((b|0)==1){break d}ub(a+16|0);c=Ab(a+192|0);b=qc(c);i[114610]=0;D(149,c|0,b|0);b=i[114610];i[114610]=0;if((b|0)==1){break b}b=Sb(c,0);i[a+188>>2]=b;i[a+12>>2]=a+16;i[a+8>>2]=0;while(1){e:{i[114610]=0;d=C(2422,a+264|0,a+256|0)|0;g=i[114610];i[114610]=0;if((g|0)==1){break e}if(!d){break c}if(i[a+188>>2]==(lb(c)+b|0)){d=lb(c);b=lb(c);i[114610]=0;D(149,c|0,b<<1);b=i[114610];i[114610]=0;if((b|0)==1){break b}b=qc(c);i[114610]=0;D(149,c|0,b|0);b=i[114610];i[114610]=0;if((b|0)==1){break b}b=Sb(c,0);i[a+188>>2]=d+b}i[114610]=0;d=F(2424,a+264|0)|0;g=i[114610];i[114610]=0;if((g|0)==1){break e}i[114610]=0;d=vj(d,16,b,a+188|0,a+8|0,0,h,a+16|0,a+12|0,a+224|0);g=i[114610];i[114610]=0;if((g|0)==1){break e}if(d){break c}i[114610]=0;F(2426,a+264|0)|0;d=i[114610];i[114610]=0;if((d|0)!=1){continue}}break}break b}b=B()|0;A()|0;break a}b=B()|0;A()|0;ub(a+16|0);break a}i[114610]=0;D(149,c|0,i[a+188>>2]-b|0);b=i[114610];i[114610]=0;f:{if((b|0)==1){break f}b=xb(c);i[114610]=0;d=R(2445)|0;g=i[114610];i[114610]=0;if((g|0)==1){break f}i[a>>2]=f;i[114610]=0;b=N(2446,b|0,d|0,62145,a|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break f}if((b|0)!=1){i[e>>2]=4}i[114610]=0;b=C(2423,a+264|0,a+256|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break f}if(b){i[e>>2]=i[e>>2]|2}b=i[a+264>>2];eb(c);eb(h);Xa=a+272|0;return b|0}}b=B()|0;A()|0;eb(c)}eb(h);E(b|0);x()}function gva(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,j=0,k=0,l=0,m=0,n=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0;l=Xa-16|0;Xa=l;v=i[a+16>>2];a:{b:{c:{m=i[a+8>>2];j=i[a+12>>2];d:{if((j|0)<1?1:(j|0)<=1?m>>>0<=805306368:0){if((j|0)>-2?1:(j|0)>=-2?m>>>0>=3489660928:0){break c}if((j|0)>-2?1:(j|0)>=-2?m>>>0>2147483647:0){break d}break b}if((j|0)>1?1:(j|0)>=1?m>>>0>2147483648:0){break b}}s=b+196648|0;break a}s=b+131112|0;break a}s=b+262184|0}f=i[a+48>>2];p=i[a+40>>2];q=i[a+36>>2];e=i[a+44>>2];k=i[a+4>>2];n=i[a>>2];i[l+8>>2]=n;i[l+12>>2]=k;i[l>>2]=m;i[l+4>>2]=j;e:{if(!d){j=p>>12;m=q>>12;break e}while(1){b=k+v|0;j=g[b+4|0];k=(n>>>16&65520)+s|0;n=h[k+14>>1];m=g[b+3|0];w=h[k+12>>1];x=g[b+2|0];y=h[k+10>>1];z=g[b+1|0];A=h[k+8>>1];B=g[b|0];C=h[k+6>>1];D=g[b+ -1|0];E=h[k+4>>1];F=g[b+ -2|0];G=h[k+2>>1];H=g[b+ -3|0];I=h[k>>1];b=i[a+60>>2];J=b;K=b>>31;b=e;e=Eb(e,-16777216,16776704);r=i[a+64>>2];f=Eb(f,-16777216,16776704);L=i[a+72>>2];M=i[a+32>>2];k=c;N=i[k>>2];e=XMa(r,r>>31,e,e>>31);r=_a;t=e;e=i[a+68>>2];u=XMa(e,e>>31,f,f>>31);e=t+u|0;f=_a+r|0;f=e>>>0<u>>>0?f+1|0:f;t=e;n=(((((((o(F,G)+o(H,I)|0)+o(D,E)|0)+o(B,C)|0)+o(z,A)|0)+o(x,y)|0)+o(m,w)|0)+o(j,n)<<8)/32768<<8;e=n;j=XMa(J,K,e,e>>31);e=t+j|0;f=_a+f|0;f=e>>>0<j>>>0?f+1|0:f;e=e+8388608|0;if(e>>>0<8388608){f=f+1|0}e=(f&16777215)<<8|e>>>24;f=(e|0)/256|0;q=i[a+28>>2]+q|0;m=q>>12;i[k>>2]=o(f,m)+N;p=p+M|0;j=p>>12;i[c+4>>2]=i[c+4>>2]+o(f,j);e=e-(n&L)|0;zb(l+8|0,l);d=d+ -1|0;if(d){c=c+8|0;n=i[l+8>>2];k=i[l+12>>2];f=b;continue}break}n=i[l+8>>2];k=i[l+12>>2];f=b}i[a+40>>2]=p;i[a+20>>2]=m;i[a+36>>2]=q;i[a+48>>2]=f;i[a+44>>2]=e;i[a+24>>2]=j;i[a>>2]=n;i[a+4>>2]=k;Xa=l+16|0}function fva(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0;k=Xa-16|0;Xa=k;v=i[a+16>>2];a:{b:{c:{l=i[a+8>>2];g=i[a+12>>2];d:{if((g|0)<1?1:(g|0)<=1?l>>>0<=805306368:0){if((g|0)>-2?1:(g|0)>=-2?l>>>0>=3489660928:0){break c}if((g|0)>-2?1:(g|0)>=-2?l>>>0>2147483647:0){break d}break b}if((g|0)>1?1:(g|0)>=1?l>>>0>2147483648:0){break b}}s=b+196648|0;break a}s=b+131112|0;break a}s=b+262184|0}e=i[a+48>>2];n=i[a+40>>2];p=i[a+36>>2];m=i[a+44>>2];j=i[a+4>>2];f=i[a>>2];i[k+8>>2]=f;i[k+12>>2]=j;i[k>>2]=l;i[k+4>>2]=g;e:{if(!d){g=n>>12;l=p>>12;break e}while(1){b=(f>>>16&65520)+s|0;g=h[b>>1];j=(j<<1)+v|0;l=h[j+ -6>>1];q=h[b+2>>1];w=h[j+ -4>>1];x=h[b+4>>1];y=h[j+ -2>>1];z=h[b+6>>1];A=h[j>>1];B=h[b+8>>1];C=h[j+2>>1];D=h[b+10>>1];E=h[j+4>>1];F=h[b+12>>1];G=h[j+6>>1];H=h[b+14>>1];I=h[j+8>>1];u=i[a+60>>2];b=m;f=Eb(b,-16777216,16776704);r=i[a+64>>2];m=Eb(e,-16777216,16776704);J=i[a+72>>2];K=i[a+32>>2];j=c;L=i[j>>2];e=XMa(r,r>>31,f,f>>31);r=_a;t=e;q=(((((((o(q,w)+o(g,l)|0)+o(x,y)|0)+o(z,A)|0)+o(B,C)|0)+o(D,E)|0)+o(F,G)|0)+o(H,I)|0)/32768<<8;e=q;g=XMa(u,u>>31,e,e>>31);f=t+g|0;e=_a+r|0;e=f>>>0<g>>>0?e+1|0:e;t=f;f=i[a+68>>2];m=XMa(f,f>>31,m,m>>31);f=t+m|0;e=_a+e|0;e=f>>>0<m>>>0?e+1|0:e;f=f+8388608|0;if(f>>>0<8388608){e=e+1|0}f=(e&16777215)<<8|f>>>24;e=(f|0)/256|0;p=i[a+28>>2]+p|0;l=p>>12;i[j>>2]=o(e,l)+L;n=n+K|0;g=n>>12;i[c+4>>2]=i[c+4>>2]+o(e,g);m=f-(q&J)|0;zb(k+8|0,k);d=d+ -1|0;if(d){c=c+8|0;f=i[k+8>>2];j=i[k+12>>2];e=b;continue}break}f=i[k+8>>2];j=i[k+12>>2];e=b}i[a+40>>2]=n;i[a+20>>2]=l;i[a+36>>2]=p;i[a+48>>2]=e;i[a+44>>2]=m;i[a+24>>2]=g;i[a>>2]=f;i[a+4>>2]=j;Xa=k+16|0}function d0(a,b,c,d,e,f,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;h=h|0;var k=0,m=0,n=0,o=0;a=Xa-288|0;Xa=a;i[a+272>>2]=c;i[a+280>>2]=b;i[a+16>>2]=2482;b=wd(a+152|0,a+160|0,a+16|0);i[114610]=0;fc(a+144|0,e);k=i[114610];i[114610]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{if((k|0)!=1){i[114610]=0;k=F(21,a+144|0)|0;m=i[114610];i[114610]=0;if((m|0)==1){break j}g[a+143|0]=0;e=i[e+4>>2];i[114610]=0;c=fa(2483,a+280|0,c|0,d|0,a+144|0,e|0,f|0,a+143|0,k|0,b|0,a+148|0,a+260|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break e}if(!c){break f}c=j[62395]|j[62396]<<8|(j[62397]<<16|j[62398]<<24);g[a+135|0]=c;g[a+136|0]=c>>>8;g[a+137|0]=c>>>16;g[a+138|0]=c>>>24;c=j[62392]|j[62393]<<8|(j[62394]<<16|j[62395]<<24);i[a+128>>2]=j[62388]|j[62389]<<8|(j[62390]<<16|j[62391]<<24);i[a+132>>2]=c;i[114610]=0;N(2440,k|0,a+128|0,a+138|0,a+118|0)|0;c=i[114610];i[114610]=0;if((c|0)==1){break i}i[a+4>>2]=2420;d=wd(a+8|0,0,a+4|0);c=a+16|0;if((i[a+148>>2]-i[b>>2]|0)<99){break g}de(d,Zc((i[a+148>>2]-i[b>>2]|0)+2|0));if(i[d>>2]){break h}i[114610]=0;K(2421);c=i[114610];i[114610]=0;if((c|0)==1){break d}break a}e=B()|0;A()|0;break b}e=B()|0;A()|0;break c}e=B()|0;A()|0;break c}c=i[d>>2]}if(j[a+143|0]){g[c|0]=45;c=c+1|0}e=i[b>>2];while(1){if(e>>>0>=l[a+148>>2]){g[c|0]=0;i[a>>2]=h;if((xD(a+16|0,a)|0)!=1){i[114610]=0;L(2484,62372);c=i[114610];i[114610]=0;if((c|0)!=1){break a}break d}lc(d)}else{n=c,o=j[((um(a+118|0,a+128|0,e)-a|0)+a|0)+10|0],g[n|0]=o;c=c+1|0;e=e+1|0;continue}break}}i[114610]=0;c=C(2423,a+280|0,a+272|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break e}if(c){i[f>>2]=i[f>>2]|2}c=i[a+280>>2];ub(a+144|0);lc(b);Xa=a+288|0;return c|0}e=B()|0;A()|0;break c}e=B()|0;A()|0;lc(d)}ub(a+144|0)}lc(b);E(e|0);x()}x()}function Sua(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,j=0,k=0,l=0,m=0,n=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;f=Xa-48|0;Xa=f;w=i[a+16>>2];j=i[a+44>>2];i[f+32>>2]=j;e=i[a+48>>2];i[f+36>>2]=e;n=i[a+52>>2];i[f+40>>2]=n;q=i[a+56>>2];i[f+44>>2]=q;x=i[a+24>>2];y=i[a+20>>2];p=i[a+4>>2];l=i[a>>2];i[f+24>>2]=l;i[f+28>>2]=p;k=i[a+12>>2];i[f+16>>2]=i[a+8>>2];i[f+20>>2]=k;if(d){while(1){k=(((p&2147483647)<<1|l>>>31)&-2)+w|0;q=1;e=(((l>>>16|0)+4&131064)<<1)+b|0;l=h[e+38>>1];m=h[e+36>>1];s=h[e+34>>1];t=h[e+32>>1];u=h[e+30>>1];r=h[e+28>>1];v=h[e+26>>1];z=h[e+24>>1];n=0;e=1;j=0;while(1){i[(f+8|0)+(j<<2)>>2]=(((((o(g[k+(j|4)|0],s)+o(g[k+(j|2)|0],t)|0)+o(g[k+(j|6)|0],m)|0)+o(l,g[k+(j|8)|0])<<8)/2|0)+((((o(g[k+(j|-4)|0],v)+o(g[k+(j|-6)|0],z)|0)+o(g[k+(j|-2)|0],r)|0)+o(g[j+k|0],u)<<8)/2|0)|0)/16384;p=e;e=0;j=1;if(p){continue}break}while(1){k=(f+8|0)+(n<<2)|0;l=i[k>>2];m=i[a+60>>2];s=m;p=(f+32|0)+(n<<3)|0;n=i[p>>2];e=Eb(n,-16777216,16776704);t=i[a+64>>2];j=Eb(i[p+4>>2],-16777216,16776704);r=i[a+68>>2];v=r;r=r>>31;i[p+4>>2]=n;n=i[a+72>>2];m=m>>31;l=l<<8;m=XMa(s,m,l,l>>31);s=_a;u=k;k=m;m=XMa(t,t>>31,e,e>>31);k=k+m|0;e=_a+s|0;e=k>>>0<m>>>0?e+1|0:e;m=k;k=XMa(v,r,j,j>>31);j=m+k|0;e=_a+e|0;e=j>>>0<k>>>0?e+1|0:e;j=j+8388608|0;if(j>>>0<8388608){e=e+1|0}e=(e&16777215)<<8|j>>>24;i[u>>2]=(e|0)/256;i[p>>2]=e-(l&n);n=1;e=q&1;q=0;if(e){continue}break}i[c>>2]=i[c>>2]+o(i[f+8>>2],y);i[c+4>>2]=i[c+4>>2]+o(i[f+12>>2],x);zb(f+24|0,f+16|0);d=d+ -1|0;if(d){c=c+8|0;l=i[f+24>>2];p=i[f+28>>2];continue}break}l=i[f+24>>2];p=i[f+28>>2];q=i[f+44>>2];n=i[f+40>>2];j=i[f+32>>2];e=i[f+36>>2]}i[a+56>>2]=q;i[a+52>>2]=n;i[a+48>>2]=e;i[a+44>>2]=j;i[a>>2]=l;i[a+4>>2]=p;Xa=f+48|0}function Ew(a,b,c){var d=0,e=0,f=0,h=0,i=0,k=0,l=0;f=Xa-16|0;Xa=f;e=1;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{d=j[a|0];switch(d|0){case 0:break a;case 3:break j;case 2:break k;case 13:break l;case 5:break b;case 9:break d;case 11:break e;case 20:break f;case 1:case 6:case 7:case 8:case 10:case 12:case 14:case 15:case 16:case 17:case 18:case 19:break g;case 4:break i;default:break h}}g[a|0]=1;g[f+15|0]=64;k=b,l=j[Xb(b,f+15|0)|0],g[k|0]=l;break a}d=j[b|0];if(!c){e=0;if(d&3|d>>>0>223){break a}}g[b|0]=(d&252)>>>2;g[a|0]=12;e=1;break a}d=j[b|0];if(!c){e=0;if(d&3|d>>>0>223){break a}}g[b|0]=(d&252)>>>2;g[a|0]=13;e=1;break a}h=j[b|0];if(h>>>0<240){d=0;while(1){i=j[d+20816|0];m:{n:{if(c){if(h>>>0<=i>>>0){break n}break m}if((h|0)!=(i|0)){break m}}g[a|0]=11;g[b|0]=d;break a}e=d>>>0<9;d=d+1|0;if((d|0)!=10){continue}break}break a}g[a|0]=11;g[b|0]=9;break a}if((d|0)==26){break c}}e=0;break a}e=0;o:{p:{q:{d=j[b|0]>>>4|0;switch(d|0){case 3:case 4:case 5:case 6:case 7:break a;case 8:break o;case 0:case 1:case 2:break p;default:break q}}if((d|0)!=15){break a}}if(!c){break a}g[b|0]=0;g[a|0]=0;e=1;break a}g[a|0]=2;g[b|0]=j[b|0]<<2&60|2;e=1;break a}e=0;c=j[b|0];if(!c){break a}d=c&15;if(!d){g[b|0]=c>>>4;g[a|0]=3;e=1;break a}h=c&240;if(!h){g[a|0]=4;e=1;break a}if((d|0)==15){g[b|0]=c>>>4;g[a|0]=5;e=1;break a}if((h|0)!=240){break a}g[b|0]=d;g[a|0]=6;e=1;break a}c=b;b=j[b|0];g[c|0]=(b|0)==255?64:b>>>2|0;g[a|0]=2;break a}r:{if(c){g[b|0]=0;break r}e=0;if(j[b|0]){break a}}g[a|0]=8;e=1;break a}s:{if(c){g[f+14|0]=j[b|0]&15;g[f+13|0]=9;d=j[Xb(f+14|0,f+13|0)|0];g[b|0]=d;break s}e=0;d=j[b|0];if((d&14)>>>0>9|d&240){break a}}g[b|0]=d&15;g[a|0]=8;e=1}Xa=f+16|0;return e}function Iaa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=Xa-128|0;Xa=e;a:{if(Cc(b)){break a}f=j[xG(b)|0];g=1;b:{if((f|0)==33){break b}if((f|0)!=63){break a}g=0}d=g;Oq(e+112|0,b,0,lb(b)+ -1|0);mb(b,e+112|0);eb(e+112|0)}jd(e+112|0);f=i[e+112>>2];jd(e+96|0);f=wG(f,i[e+100>>2],b);jd(e+112|0);c:{d:{e:{f:{if((f|0)==i[e+116>>2]){if(Bd(b,38187)){a=P(8)|0;i[114610]=0;G(2136,e+112|0,39252,c|0);b=i[114610];i[114610]=0;if((b|0)==1){break e}Ub(a,e+112|0);i[114610]=0;G(2009,a|0,83568,2017);a=i[114610];i[114610]=0;if((a|0)!=1){break c}b=B()|0;A()|0;eb(e+112|0);break d}if(!d){break f}a=P(8)|0;i[114610]=0;G(2136,e+80|0,39131,b|0);b=i[114610];i[114610]=0;g:{h:{i:{j:{k:{if((b|0)!=1){i[114610]=0;G(2137,e+96|0,e+80|0,39267);b=i[114610];i[114610]=0;if((b|0)==1){break k}i[114610]=0;G(805,e+112|0,e+96|0,c|0);b=i[114610];i[114610]=0;c=1;if((b|0)==1){break j}Ub(a,e+112|0);i[114610]=0;G(2009,a|0,83568,2017);b=i[114610];i[114610]=0;if((b|0)!=1){break c}b=B()|0;A()|0;eb(e+112|0);c=0;break i}b=B()|0;A()|0;break g}b=B()|0;c=1;A()|0;break h}b=B()|0;A()|0}eb(e+96|0)}eb(e+80|0);if(!c){break d}}Q(a|0);break d}l:{switch(i[f+4>>2]){case 0:mh(e+72|0,b);b=(cG(c)|0)!=0;c=i[e+76>>2];i[e>>2]=i[e+72>>2];i[e+4>>2]=c;vG(a,e,b,d);break f;case 1:mh(e- -64|0,b);b=K8(c);c=i[e+68>>2];i[e+8>>2]=i[e+64>>2];i[e+12>>2]=c;uG(a,e+8|0,b,_a,d);break f;case 2:mh(e+56|0,b);h=A8(c);b=i[e+60>>2];i[e+16>>2]=i[e+56>>2];i[e+20>>2]=b;tG(a,e+16|0,h,d);break f;case 3:break l;default:break f}}mh(e+48|0,b);mh(e+40|0,c);b=i[e+52>>2];i[e+32>>2]=i[e+48>>2];i[e+36>>2]=b;b=i[e+44>>2];i[e+24>>2]=i[e+40>>2];i[e+28>>2]=b;sG(a,e+32|0,e+24|0,d)}Xa=e+128|0;return}b=B()|0;A()|0;Q(a|0)}E(b|0)}x()}function uva(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;b=Xa-48|0;Xa=b;v=i[a+16>>2];j=i[a+44>>2];i[b+32>>2]=j;n=i[a+48>>2];i[b+36>>2]=n;k=i[a+52>>2];i[b+40>>2]=k;g=i[a+56>>2];i[b+44>>2]=g;r=i[a+40>>2];s=i[a+36>>2];e=i[a+4>>2];l=i[a>>2];i[b+24>>2]=l;i[b+28>>2]=e;f=i[a+12>>2];i[b+16>>2]=i[a+8>>2];i[b+20>>2]=f;a:{if(!d){m=r>>12;f=s>>12;break a}while(1){n=1;e=((((e&2147483647)<<1|l>>>31)&2147483646)<<1)+v|0;j=(l>>>21&2040)+27872|0;l=h[j+6>>1];g=h[j+4>>1];m=h[j+2>>1];p=h[j>>1];j=0;k=1;f=0;while(1){q=(b+8|0)+(f<<2)|0;f=f<<1;i[q>>2]=(((o(h[f+e>>1],m)+o(h[e+(f|-4)>>1],p)|0)+o(g,h[e+(f|4)>>1])|0)+o(l,h[e+(f|8)>>1])|0)/16384;t=k&1;k=0;f=1;if(t){continue}break}while(1){k=(b+8|0)+(j<<2)|0;l=i[k>>2];g=i[a+60>>2];m=g;j=(b+32|0)+(j<<3)|0;p=i[j>>2];e=Eb(p,-16777216,16776704);t=i[a+64>>2];f=Eb(i[j+4>>2],-16777216,16776704);q=i[a+68>>2];w=q;q=q>>31;i[j+4>>2]=p;p=i[a+72>>2];u=g>>31;l=l<<8;g=l;g=XMa(m,u,g,g>>31);m=_a;u=k;k=g;g=XMa(t,t>>31,e,e>>31);k=k+g|0;e=_a+m|0;e=k>>>0<g>>>0?e+1|0:e;g=k;k=XMa(w,q,f,f>>31);f=g+k|0;e=_a+e|0;e=f>>>0<k>>>0?e+1|0:e;f=f+8388608|0;if(f>>>0<8388608){e=e+1|0}e=(e&16777215)<<8|f>>>24;i[u>>2]=(e|0)/256;i[j>>2]=e-(l&p);j=1;e=n&1;n=0;if(e){continue}break}e=i[a+32>>2];s=i[a+28>>2]+s|0;f=s>>12;i[c>>2]=i[c>>2]+o(f,i[b+8>>2]);r=e+r|0;m=r>>12;i[c+4>>2]=i[c+4>>2]+o(m,i[b+12>>2]);zb(b+24|0,b+16|0);d=d+ -1|0;if(d){c=c+8|0;l=i[b+24>>2];e=i[b+28>>2];continue}break}l=i[b+24>>2];e=i[b+28>>2];g=i[b+44>>2];k=i[b+40>>2];n=i[b+36>>2];j=i[b+32>>2]}i[a+40>>2]=r;i[a+20>>2]=f;i[a+36>>2]=s;i[a+56>>2]=g;i[a+52>>2]=k;i[a+48>>2]=n;i[a+44>>2]=j;i[a+24>>2]=m;i[a>>2]=l;i[a+4>>2]=e;Xa=b+48|0}function m9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,l=0;c=Xa+ -64|0;Xa=c;f=Mg(a);a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{if(Mh(b)){bo(c+56|0);break n}i[114610]=0;D(2189,c+40|0,b|0);a=i[114610];i[114610]=0;if((a|0)==1){break m}i[114610]=0;D(2175,c+56|0,c+40|0);a=i[114610];i[114610]=0;if((a|0)==1){break l}We(c+40|0)}a=b+36|0;o:{if(Mh(b)){break o}a=i[c+56>>2]}e=nd(a);i[114610]=0;D(1532,f|0,e|0);e=i[114610];i[114610]=0;if((e|0)==1){break k}h=c,l=Jb(a),i[h+32>>2]=l;h=c,l=Kb(a),i[h+24>>2]=l;if(pb(c+32|0,c+24|0)){a=b+24|0;while(1){e=i[c+32>>2];b=bi(i[a>>2]+484360|0,j[e+16|0]);i[114610]=0;D(2190,c+8|0,b|0);d=i[114610];i[114610]=0;if((d|0)==1){break j}i[114610]=0;G(9,c+40|0,0,c+8|0);d=i[114610];i[114610]=0;if((d|0)==1){break i}i[114610]=0;D(1534,f|0,c+40|0);d=i[114610];i[114610]=0;if((d|0)==1){break h}eb(c+40|0);eb(c+8|0);p:{if(!Cc(aG(f))){break p}d=j[e+12|0];i[114610]=0;d=C(546,b|0,d|0)|0;g=i[114610];i[114610]=0;if((g|0)==1){break c}if(!d){break p}d=i[a>>2];i[114610]=0;d=F(689,d|0)|0;g=i[114610];i[114610]=0;if((g|0)==1){break f}b=Fb(i[a>>2]+484344|0,k[$b(b,i[e+12>>2])>>1]);i[114610]=0;D(2191,c+8|0,b|0);b=i[114610];i[114610]=0;if((b|0)==1){break e}i[114610]=0;J(438,c+40|0,0,d|0,c+8|0);b=i[114610];i[114610]=0;if((b|0)==1){break d}mb(aG(f),c+40|0);eb(c+40|0);eb(c+8|0)}dk(c+32|0);if(pb(c+32|0,c+24|0)){continue}break}}Ej(c+56|0);Xa=c- -64|0;return}b=B()|0;A()|0;break a}b=B()|0;A()|0;We(c+40|0);break a}b=B()|0;A()|0;break b}b=B()|0;A()|0;break b}b=B()|0;A()|0;break g}b=B()|0;A()|0;eb(c+40|0)}eb(c+8|0);break b}b=B()|0;A()|0;break b}b=B()|0;A()|0;break b}b=B()|0;A()|0;eb(c+8|0);break b}b=B()|0;A()|0}Ej(c+56|0)}Sc(f);E(b|0);x()}function Soa(a,b,c){var d=0,e=0,f=0,h=0,l=0;d=c&15;f=o(b,896)+a|0;e=f+1074984|0;a:{b:{switch(c>>>4|0){case 0:if(!k[a+480188>>1]){break a}b=(c&1)<<14;c=0;while(1){d=(o(c,896)+a|0)+1075072|0;i[d>>2]=(b|i[d>>2]&-16385)^16384;c=c+1|0;if(c>>>0<k[a+480188>>1]){continue}break}break a;case 1:if(i[a+480180>>2]&1048580?0:!d){break a}nK(a,e,d);return;case 2:if(i[a+480180>>2]&1048580?0:!d){break a}lK(a,e,d);return;case 3:a=f+1075072|0;i[a>>2]=i[a>>2]&-1048577|((d|0)!=0)<<20;return;case 4:g[f+1075826|0]=c&7;return;case 5:if(!(j[a+480209|0]&16)){break a}if(i[a+480180>>2]&69206025){c=o(b,896)+a|0;e=c+1075752|0;i[e>>2]=d<<28>>24;d=c+1075684|0;if(!i[d>>2]){break a}if(!Jf(c+1075794|0)){break a}c=a;a=o(b,896)+a|0;h=d,l=Vf(c,j[a+1075803|0],i[e>>2],i[a+1075688>>2]),i[h>>2]=l;return}f=i[a+480180>>2];e=Jf((o(b,896)+a|0)+1075794|0);if((f|0)==16){if(!e){break a}c=o(b,896)+a|0;e=i[c+1075088>>2];if(!e){break a}g[e+37|0]=d;i[c+1075752>>2]=d;c=c+1075684|0;if(!i[c>>2]){break a}e=a;a=o(b,896)+a|0;h=c,l=Vf(e,j[a+1075803|0],d,i[a+1075688>>2]),i[h>>2]=l;return}if(!e){break a}b=o(b,896)+a|0;c=c<<28>>24^-128;i[b+1075752>>2]=c;d=b+1075684|0;if(!i[d>>2]){break a}h=d,l=Vf(a,j[b+1075803|0],c,i[b+1075688>>2]),i[h>>2]=l;return;case 7:g[f+1075829|0]=c&7;return;case 8:if(!(j[a+480209|0]&16)){break a}$k(a,e,d,4);return;case 9:mx(a,b,d,0);return;case 10:if(i[a+480180>>2]&1048580?0:!d){break a}Ao(a,e,d,0);return;case 11:if(i[a+480180>>2]&1048580?0:!d){break a}zo(a,e,d,0);return;case 12:ox(a,b,d,0);return;case 15:break b;default:break a}}if(i[a+480180>>2]==1){g[(o(b,896)+a|0)+1075850|0]=d;if(!(j[a+480209|0]&16)){break a}zK(a,e);return}g[(o(b,896)+a|0)+1075848|0]=d}}function eMa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,h=0,k=0,m=0,n=0,o=0;k=Xa-16|0;Xa=k;pc(c);a:{if(!wb(c,3)){break a}while(1){wt(k+8|0,c);n=Nc(k+8|0);d=yf(k+8|0);f=k+8|0;if(l[a+12>>2]<=j[f|0]){break a}h=Qe(a,j[f|0],b);e=j[n|0];b:{if(e>>>0<=126){if(!(e|j[d|0])){g[h|0]=254;break b}g[h|0]=e+1;if(j[d|0]==255){break b}if(!j[h+1|0]){g[h+1|0]=o}g[h+2|0]=1;g[h+4|0]=j[d|0];break b}c:{switch(e+ -127|0){case 0:f=j[f|0]+g[d|0]|0;if((f|0)<0|(f|0)>=i[a+12>>2]<<16>>16){break b}e=Qe(a,f,b);f=j[e|0]|j[e+1|0]<<8|(j[e+2|0]<<16|j[e+3|0]<<24);g[h|0]=f;g[h+1|0]=f>>>8;g[h+2|0]=f>>>16;g[h+3|0]=f>>>24;f=j[e+4|0]|j[e+5|0]<<8;g[h+4|0]=f;g[h+5|0]=f>>>8;break b;case 1:o=j[d|0]+1|0;g[h+1|0]=o;break b;default:break c}}d=g[d|0];g[k+7|0]=d;m=0;f=e&127;if(f>>>0<=23){m=j[f+12144|0]}f=k;d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{e=j[n|0];switch((e&127)+ -2|0){case 21:break h;case 18:break i;case 17:break j;case 16:case 20:break k;case 15:break l;case 2:break m;case 1:break n;case 0:case 8:case 9:break o;default:break e}}if((d|0)>-1){break g}e=0-d&15;break f}g[k+6|0]=64;d=j[Xb(k+7|0,k+6|0)|0];g[k+7|0]=d;if(j[h+2|0]>1){break e}g[h+4|0]=d;g[h+2|0]=1;break b}if((d|0)>-1){m=3;break d}e=0-d&127;break f}if(!d){break b}e=0-d|-16;if((d|0)<=-1){break f}e=d<<4|15;break f}if(!d){break b}f=(d|0)>-1;if(!f){d=0-d&15;g[k+7|0]=d;e=j[n|0]}m=f?3:2;d=((e|0)==22?-32:-16)|d;g[k+7|0]=d;break d}e=d&15|-48;break f}e=d&15|-64;break f}d=d- -64&127;g[k+7|0]=d;if(!j[h+3|0]){break e}p:{switch(j[h+2|0]){case 0:case 2:break p;default:break b}}g[h+2|0]=2;g[h+4|0]=d>>>1;break b}e=d<<4}d=e;g[f+7|0]=d}if(!(m&255)){break b}}g[h+5|0]=d;g[h+3|0]=m}if(wb(c,3)){continue}break}}Xa=k+16|0}function tMa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,l=0,m=0,n=0,p=0,q=0,r=0,s=0,t=0;d=Xa-384|0;Xa=d;pc(b);f=d+344|0;l=ULa(b,f);if(!l){MS(f)}a:{b:{if(!l){break b}if(!eT(d+344|0)){break b}if(!wb(b,Vc(dT(d+344|0),_a))){break b}c:{if(!c){break c}md(a,2097152);Vh(a);Ni(a,1);h[a+480188>>1]=8;i[a+480196>>2]=j[d+376|0];i[a+480204>>2]=o(j[d+377|0],1e4);h[a+480190>>1]=j[d+378|0];if(j[d+381|0]<j[d+380|0]){Fe(Db(a+484360|0),j[d+381|0])}e=Bb(d+80|0,12002);mb(a+1304436|0,e);eb(e);e=Bb(d+80|0,12022);mb(a+1304448|0,e);eb(e);i[a+1304496>>2]=4;Wz(b,d+80|0);st(Db(a+484360|0),d+80|0,j[d+380|0],65535,65535);if(k[a+480190>>1]){e=1;f=1;while(1){cT(b,d+40|0);sMa(d+40|0,(o(e,104)+a|0)+484380|0);on(d+8|0,2,d+40|0);oc(d+24|0,d+8|0);i[114610]=0;C(369,((e<<5)+a|0)+946300|0,d+24|0)|0;e=i[114610];i[114610]=0;if((e|0)==1){break a}eb(d+24|0);f=f+1|0;e=f&65535;if(e>>>0<=k[a+480190>>1]){continue}break}}Ib(b,o(64-j[d+378|0]|0,37));l=a+484344|0;Gf(l,j[d+379|0]);if(j[d+379|0]){n=c&1;f=0;while(1){d:{e:{if(n){if(Sf(l,f&65535,64)){break e}}Ib(b,2048);break d}e=Fb(l,f);s=d,t=Jb(e),i[s+40>>2]=t;s=d,t=Kb(e),i[s+24>>2]=t;if(!pb(d+40|0,d+24|0)){break d}while(1){e=i[d+40>>2];nn(d+8|0,b);p=Nc(d+8|0);q=yf(d+8|0);r=li(d+8|0);m=j[d+8|0];if((m+ -1&255)>>>0<=106){g[e|0]=m+13}g[e+1|0]=j[p|0];g[e+3|0]=j[q|0];g[e+5|0]=j[r|0];Xi(e);jk(d+40|0);if(pb(d+40|0,d+24|0)){continue}break}}f=f+1|0;if(f>>>0<j[d+379|0]){continue}break}}if(!(c&2)){break c}e=1;c=Ic(d+40|0,8,1,0,0);if(!k[a+480190>>1]){break c}while(1){Xf(c,(o(e&65535,104)+a|0)+484380|0,b);e=e+1|0;if((e&65535)>>>0<=k[a+480190>>1]){continue}break}}e=1}Xa=d+384|0;return e|0}a=B()|0;A()|0;eb(d+24|0);E(a|0);x()}function T5(a,b){var c=0,d=p(0),e=p(0),f=0,g=p(0),h=p(0),i=p(0),j=0,k=0,l=0,n=0,q=p(0),r=p(0),s=0,t=p(0),u=p(0),v=p(0),w=p(0),x=p(0),y=p(0),z=p(0);j=Xa-128|0;if((b|0)>=1){while(1){k=(s<<2)+a|0;f=0;c=j;l=c;while(1){r=m[o(31-f|0,72)+k>>2];n=o(f,72)+k|0;g=m[n>>2];h=p(r+g);e=m[n+1152>>2];d=m[o(15-f|0,72)+k>>2];i=p(e+d);m[l>>2]=h+i;n=o(f,12)+48992|0;g=p(m[n+4>>2]*p(g-r));e=p(m[n>>2]*p(d-e));m[l+64>>2]=g+e;d=m[n+8>>2];m[l+32>>2]=d*p(h-i);m[l+96>>2]=p(g-e)*d;l=l+4|0;f=f+1|0;if((f|0)!=8){continue}break}f=0;while(1){t=m[c+28>>2];u=m[c>>2];v=p(t+u);w=m[c+16>>2];x=m[c+12>>2];y=p(w+x);q=p(v+y);z=m[c+24>>2];r=m[c+4>>2];h=p(z+r);i=m[c+20>>2];g=m[c+8>>2];e=p(i+g);d=p(h+e);m[c>>2]=q+d;m[c+16>>2]=p(q-d)*p(.7071067690849304);q=p(v-y);d=p(p(q+p(h-e))*p(.7071067690849304));m[c+24>>2]=p(q-d)*p(1.3065630197525024);m[c+8>>2]=p(d+q)*p(.5411961078643799);e=p(r-z);d=p(g-i);i=p(p(e+d)*p(.7071067690849304));h=p(u-t);g=p(i+h);e=p(h+e);d=p(p(p(x-w)+d)+p(e*p(-.1989123672246933)));e=p(p(d*p(.3826834261417389))+e);m[c+28>>2]=p(g-e)*p(2.562915563583374);m[c+4>>2]=p(e+g)*p(.509795606136322);e=p(d+p(e*p(-.1989123672246933)));d=p(h-i);m[c+20>>2]=p(e+d)*p(.8999761939048767);m[c+12>>2]=p(d-e)*p(.601344883441925);c=c+32|0;f=f+1|0;if((f|0)!=4){continue}break}f=0;g=m[j+32>>2];d=m[j+96>>2];h=m[j+64>>2];while(1){c=k;m[c>>2]=m[(f<<2)+j>>2];f=f+1|0;k=(f<<2)+j|0;e=m[k+96>>2];i=p(e+d);m[c+72>>2]=i+h;d=m[k+32>>2];m[c+144>>2]=d+g;h=m[k- -64>>2];m[c+216>>2]=i+h;k=c+288|0;g=d;d=e;if((f|0)!=7){continue}break}m[c+288>>2]=m[j+28>>2];e=m[j+124>>2];m[c+360>>2]=e+m[j+92>>2];d=m[j+60>>2];m[c+504>>2]=e;m[c+432>>2]=d;s=s+1|0;if((s|0)!=(b|0)){continue}break}}}function vva(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,j=0,k=0,l=0,m=0,n=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;b=Xa-48|0;Xa=b;w=i[a+16>>2];l=i[a+44>>2];i[b+32>>2]=l;p=i[a+48>>2];i[b+36>>2]=p;k=i[a+52>>2];i[b+40>>2]=k;j=i[a+56>>2];i[b+44>>2]=j;r=i[a+40>>2];s=i[a+36>>2];e=i[a+4>>2];m=i[a>>2];i[b+24>>2]=m;i[b+28>>2]=e;f=i[a+12>>2];i[b+16>>2]=i[a+8>>2];i[b+20>>2]=f;a:{if(!d){f=r>>12;n=s>>12;break a}while(1){e=(((e&2147483647)<<1|m>>>31)&-2)+w|0;f=(m>>>21&2040)+27872|0;m=h[f+6>>1];j=h[f+4>>1];n=h[f+2>>1];q=h[f>>1];l=0;p=1;k=1;f=0;while(1){i[(b+8|0)+(f<<2)>>2]=(((o(g[e+f|0],n)+o(g[e+(f|-2)|0],q)|0)+o(j,g[e+(f|2)|0])|0)+o(m,g[e+(f|4)|0])<<8)/16384;t=k&1;k=0;f=1;if(t){continue}break}while(1){k=(b+8|0)+(l<<2)|0;m=i[k>>2];j=i[a+60>>2];n=j;f=(b+32|0)+(l<<3)|0;q=i[f>>2];e=Eb(q,-16777216,16776704);t=i[a+64>>2];l=Eb(i[f+4>>2],-16777216,16776704);u=i[a+68>>2];x=u;u=u>>31;i[f+4>>2]=q;q=i[a+72>>2];v=j>>31;m=m<<8;j=m;j=XMa(n,v,j,j>>31);n=_a;v=k;k=j;j=XMa(t,t>>31,e,e>>31);k=k+j|0;e=_a+n|0;e=k>>>0<j>>>0?e+1|0:e;j=k;k=XMa(x,u,l,l>>31);l=j+k|0;e=_a+e|0;e=l>>>0<k>>>0?e+1|0:e;l=l+8388608|0;if(l>>>0<8388608){e=e+1|0}e=(e&16777215)<<8|l>>>24;i[v>>2]=(e|0)/256;i[f>>2]=e-(m&q);l=1;e=p&1;p=0;if(e){continue}break}e=i[a+32>>2];s=i[a+28>>2]+s|0;n=s>>12;i[c>>2]=i[c>>2]+o(n,i[b+8>>2]);r=e+r|0;f=r>>12;i[c+4>>2]=i[c+4>>2]+o(f,i[b+12>>2]);zb(b+24|0,b+16|0);d=d+ -1|0;if(d){c=c+8|0;m=i[b+24>>2];e=i[b+28>>2];continue}break}m=i[b+24>>2];e=i[b+28>>2];j=i[b+44>>2];k=i[b+40>>2];p=i[b+36>>2];l=i[b+32>>2]}i[a+40>>2]=r;i[a+20>>2]=n;i[a+36>>2]=s;i[a+56>>2]=j;i[a+52>>2]=k;i[a+48>>2]=p;i[a+44>>2]=l;i[a+24>>2]=f;i[a>>2]=m;i[a+4>>2]=e;Xa=b+48|0}function Ng(a,b,c){var d=0,e=0,f=0,l=0,m=0;l=Xa-16|0;Xa=l;a:{if((b|0)==189){g[a+3843|0]=c>>>7;g[a+3844|0]=c>>>6&1;break a}d=b&224;if(!d){if((b|0)!=8){if((b|0)!=260){break a}d=1;b=0;while(1){e=o(b>>>0<3?b:b+6|0,44)+a|0;f=e+148|0;e=e+16|0;m=c&d;b:{if(m){Km(e,f);break b}Km(e,0)}g[f+40|0]=!m;d=d<<1&510;b=b+1|0;if((b|0)!=6){continue}break}break a}g[a+3842|0]=c>>>6&1;b=0;while(1){Ix((o(b,44)+a|0)+16|0);b=b+1|0;if((b|0)!=18){continue}break}break a}if((d+ -160&65535)>>>0<=32){d=b&15;if(d>>>0>8){break a}d=(o(b&256?d+9|0:d,44)+a|0)+16|0;i[l+8>>2]=d;e=i[d+36>>2];i[l+12>>2]=e;a=1;f=e?2:1;c:{b=b&240;if((b|0)!=160){if((b|0)==192){break c}if((b|0)!=176){break a}a=c&32;OL(d,a>>>5|0);m=c>>>2&7;NL(d,m);c=c&3;ML(d,c);if(!e){break a}b=1;d=f>>>0>1?f:1;f=(a|0)!=0;while(1){a=i[(l+8|0)+(b<<2)>>2];OL(a,f);NL(a,m);ML(a,c);b=b+1|0;if((d|0)!=(b|0)){continue}break}break a}LL(d,c);if(!e){break a}b=f>>>0>1?f:1;while(1){LL(i[(l+8|0)+(a<<2)>>2],c);a=a+1|0;if((b|0)!=(a|0)){continue}break}break a}g[d+42|0]=(c&32)>>>5;g[d+41|0]=(c&16)>>>4;a=c>>>1&7;h[d+30>>1]=a?9-a|0:0;h[d+32>>1]=c&1;break a}if((d|0)!=224?d>>>0>=129:0){break a}f=b&31;if(-4144960>>>f&1){break a}e=a;a=g[f+19872|0];a=(e+o(b&256?a+18|0:a,84)|0)+808|0;d:{switch(d+ -32>>>5|0){case 0:g[a+79|0]=c>>>7;g[a+80|0]=(c&64)>>>6;g[a+78|0]=(c&32)>>>5;g[a+77|0]=(c&16)>>>4;Lm(a);h[a+14>>1]=k[((c&15)<<1)+19904>>1];break a;case 1:h[a+68>>1]=j[(c>>>6|0)+19936|0];KL(a);h[a+22>>1]=(c&63)<<2;break a;case 2:h[a+24>>1]=c>>>4;Lm(a);h[a+26>>1]=c&15;Lm(a);break a;case 3:b=c>>>4|0;h[a+28>>1]=b>>>0<15?b<<4:496;h[a+30>>1]=c&15;Lm(a);break a;case 6:break d;default:break a}}h[a+12>>1]=c&7}Xa=l+16|0}function xia(a,b){var c=0,d=0,e=0,f=0,h=0,k=0;a:{b:{e=i[b>>2];c:{if(!e){d=b;break c}if(!i[b+4>>2]){d=b;break b}d=hP(b);e=i[d>>2];if(e){break b}}e=i[d+4>>2];if(e){break b}e=0;h=1;break a}i[e+8>>2]=i[d+8>>2];h=0}d:{e:{if(Pg(d)){i[i[d+8>>2]>>2]=e;if((a|0)==(d|0)){a=e;c=0;break d}c=i[d+8>>2]+4|0;break e}i[i[d+8>>2]+4>>2]=e;c=i[d+8>>2]}c=i[c>>2]}k=!j[d+12|0];if((b|0)!=(d|0)){i[d+8>>2]=i[b+8>>2];f:{if(Pg(b)){f=i[d+8>>2];break f}f=i[d+8>>2]+4|0}i[f>>2]=d;f=i[b>>2];i[d>>2]=f;Ym(f,d);f=i[b+4>>2];i[d+4>>2]=f;if(f){Ym(f,d)}g[d+12|0]=j[b+12|0];a=(a|0)==(b|0)?d:a}if(!(k|!a)){if(h){while(1){d=Pg(c);b=j[c+12|0];g:{h:{if(!d){if(!b){g[c+12|0]=1;g[i[c+8>>2]+12|0]=0;cp(i[c+8>>2]);b=i[c>>2];a=(b|0)==(a|0)?c:a;c=i[b+4>>2]}d=i[c>>2];i:{j:{k:{if(!(j[d+12|0]?0:d)){b=i[c+4>>2];if(j[b+12|0]?0:b){break k}g[c+12|0]=0;l:{b=i[c+8>>2];if((b|0)!=(a|0)){if(j[b+12|0]){break l}a=b}g[a+12|0]=1;return}if(!Pg(b)){break h}b=i[b+8>>2]+4|0;break g}b=i[c+4>>2];if(!b){break j}}if(!j[b+12|0]){break i}}g[d+12|0]=1;g[c+12|0]=0;bp(c);c=i[c+8>>2]}g[c+12|0]=j[i[c+8>>2]+12|0];g[i[c+8>>2]+12|0]=1;g[i[c+4>>2]+12|0]=1;cp(i[c+8>>2]);return}if(!b){g[c+12|0]=1;g[i[c+8>>2]+12|0]=0;bp(i[c+8>>2]);b=i[c+4>>2];a=(b|0)==(a|0)?c:a;c=i[b>>2]}d=i[c>>2];m:{if(j[d+12|0]?0:d){break m}b=i[c+4>>2];if(!(j[b+12|0]?0:b)){g[c+12|0]=0;b=i[c+8>>2];if(!(j[b+12|0]?(b|0)!=(a|0):0)){g[b+12|0]=1;return}if(Pg(b)){b=i[b+8>>2]+4|0;break g}b=i[b+8>>2];break g}if(d){if(!j[d+12|0]){break m}b=i[c+4>>2]}g[b+12|0]=1;g[c+12|0]=0;cp(c);c=i[c+8>>2]}g[c+12|0]=j[i[c+8>>2]+12|0];g[i[c+8>>2]+12|0]=1;g[i[c>>2]+12|0]=1;bp(i[c+8>>2]);return}b=i[b+8>>2]}c=i[b>>2];continue}}g[e+12|0]=1}}function zua(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;g=Xa-48|0;Xa=g;s=i[a+16>>2];j=tf(g+16|0);i[j+8>>2]=a+112;i[j+16>>2]=i[a+128>>2];w=j,x=of(b+327720|0,i[b+20>>2],(i[a+88>>2]&16384)>>>14|0),i[w+12>>2]=x;b=i[j+16>>2];if(b){w=j,x=sf(a+8|0,b),i[w>>2]=x;i[j+4>>2]=_a}m=i[a+48>>2];n=i[a+40>>2];p=i[a+36>>2];b=i[a+44>>2];f=i[a+4>>2];e=i[a>>2];i[g+8>>2]=e;i[g+12>>2]=f;q=i[a+12>>2];i[g>>2]=i[a+8>>2];i[g+4>>2]=q;a:{if(!d){k=n>>12;l=p>>12;break a}while(1){q=b;b=0;k=b;i[g+40>>2]=e;i[g+44>>2]=b;f=(f<<1)+s|0;b:{b=i[j+16>>2];if((b|0)<=0){break b}while(1){fd(i[j+8>>2],h[(k<<1)+f>>1]/4<<16>>16);ed(i[j+8>>2],4);zb(g+40|0,j);if((b|0)<2){break b}b=b+ -1|0;k=i[g+44>>2];continue}}d=d+ -1|0;b=i[j+8>>2];zb(b,b+8|0);b=i[j+8>>2];e=i[b+4>>2];if(e){fd(b,h[f+(i[g+44>>2]<<1)>>1]/4<<16>>16);ed(i[j+8>>2],e);b=i[j+8>>2];e=i[b>>2];i[b>>2]=e;i[b+4>>2]=0}e=nf(b,i[j+12>>2]);k=i[a+60>>2];b=Eb(q,-16777216,16776704);l=i[a+64>>2];f=Eb(m,-16777216,16776704);t=i[a+72>>2];u=i[a+32>>2];m=c;v=i[c>>2];r=e<<8;e=r;e=XMa(k,k>>31,e,e>>31);k=_a;l=XMa(l,l>>31,b,b>>31);e=l+e|0;b=_a+k|0;b=e>>>0<l>>>0?b+1|0:b;k=e;e=i[a+68>>2];e=XMa(e,e>>31,f,f>>31);f=k+e|0;b=_a+b|0;b=f>>>0<e>>>0?b+1|0:b;f=f+8388608|0;if(f>>>0<8388608){b=b+1|0}f=(b&16777215)<<8|f>>>24;b=(f|0)/256|0;p=i[a+28>>2]+p|0;l=p>>12;i[m>>2]=o(b,l)+v;n=n+u|0;k=n>>12;i[c+4>>2]=i[c+4>>2]+o(b,k);b=f-(t&r)|0;zb(g+8|0,g);if(d){c=c+8|0;e=i[g+8>>2];f=i[g+12>>2];m=q;continue}break}e=i[g+8>>2];f=i[g+12>>2];m=q}i[a+40>>2]=n;i[a+20>>2]=l;i[a+36>>2]=p;i[a+48>>2]=m;i[a+44>>2]=b;i[a+24>>2]=k;i[a>>2]=e;i[a+4>>2]=f;Xa=g+48|0}function Er(a,b,c){var d=0,e=0,f=0,g=0,h=0,j=0,k=0,m=0,n=0,o=0;f=Xa-160|0;Xa=f;a:{b:{c:{d:{e:{f:{g:{h:{if(!c){break h}d=i[c+4>>2];if(!d&l[c>>2]>=Vg(b)>>>0|d>>>0>0){break h}b=P(8)|0;i[114610]=0;C(214,b|0,20509)|0;a=i[114610];i[114610]=0;if((a|0)!=1){break g}a=B()|0;A()|0;Q(b|0);break a}if(!i[b>>2]){b=P(8)|0;i[114610]=0;C(1403,b|0,20509)|0;a=i[114610];i[114610]=0;if((a|0)!=1){break f}a=B()|0;A()|0;Q(b|0);break a}k=Lna(f+136|0,$g(f+128|0,b));i:{j:{if(a&2){d=po(f+104|0,k);i[114610]=0;g=C(1404,d|0,c|0)|0;e=i[114610];i[114610]=0;d=1;if((e|0)==1){break i}if((g|0)==1){break j}e=po(f+80|0,k);i[114610]=0;e=C(1405,e|0,c|0)|0;h=i[114610];i[114610]=0;if((h|0)==1){break e}m=(e|0)==1;if(m){break j}h=po(f+56|0,k);i[114610]=0;h=C(1406,h|0,c|0)|0;j=i[114610];i[114610]=0;if((j|0)==1){break d}n=(h|0)==1;if(n){break j}j=po(f+32|0,k);i[114610]=0;j=C(1407,j|0,c|0)|0;o=i[114610];i[114610]=0;if((o|0)==1){break c}if((j|0)==1){break j}d=(g|0)==-1?-1:0;d=m?d:(e|0)==-1?-1:d;g=(j|0)==-1?-1:n?d:(h|0)==-1?-1:d}if(a&1){a=77888;while(1){d=i[a>>2];if(d){e=po(f+8|0,k);i[114610]=0;e=C(d|0,e|0,c|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break b}d=1;if((e|0)==1){break j}g=(e|0)==-1?-1:g}a=a+12|0;if((a|0)!=78344){continue}break}}if(c){d=0;if((g|0)!=-1){break j}a=i[c+4>>2];c=i[c>>2];i[114610]=0;a=eg(446,c,a);c=i[114610];i[114610]=0;if((c|0)!=1){d=a>>>0>Vg(b)>>>0?-1:0;break j}a=B()|0;A()|0;break a}d=0;if((g|0)!=-1){break j}d=Vg(b)>>>0>2047?1:-1}Xa=f+160|0;return d}a=B()|0;A()|0;break a}W(b|0,71608,24);x()}W(b|0,71504,24);x()}a=B()|0;A()|0;break a}a=B()|0;A()|0;break a}a=B()|0;A()|0;break a}a=B()|0;A()|0}E(a|0);x()}function eAa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,h=0,i=0,l=0,m=0,n=0,p=0,q=0,r=0,s=0,t=0,u=0;d=Xa-16|0;Xa=d;a:{if(!wb(a,2)){Sf(c+484344|0,b,64);break a}m=c+484344|0;i=hd(pp(a),1,1024);if(!Sf(m,b,i)|!i){break a}n=k[c+480188>>1];while(1){r=zp(Fb(m,b),l);h=0;if(n){while(1){nn(d+8|0,a);e=Nc(d+8|0);s=yf(d+8|0);c=o(h,6)+r|0;f=j[li(d+8|0)|0];g[c+5|0]=f;p=0;q=j[d+8|0];if((q+ -1&255)>>>0<=35){g[c|0]=q+48;p=j[e|0]+1|0}e=c+5|0;g[c+1|0]=p;b:{c:{d:{switch(j[s|0]){case 1:g[c+3|0]=2;g[e|0]=f&15;break b;case 2:g[c+3|0]=3;g[e|0]=f&15;break b;case 12:if(!f){break b}g[c+3|0]=1;break b;case 13:if(!f){break b}g[c+3|0]=36;g[d+7|0]=15;t=e,u=j[Xb(d+7|0,e)|0]|16,g[t|0]=u;break b;case 30:if(!f){break b}g[c+3|0]=35;g[d+6|0]=15;t=e,u=j[Xb(d+6|0,e)|0]|16,g[t|0]=u;break b;case 21:if(!f){break b}g[c+3|0]=36;g[d+5|0]=15;t=e,u=j[Xb(d+5|0,e)|0]|80,g[t|0]=u;break b;case 17:if(!f){break b}g[c+3|0]=35;g[d+4|0]=15;t=e,u=j[Xb(d+4|0,e)|0]|80,g[t|0]=u;break b;case 15:g[c+3|0]=19;g[e|0]=(f|0)!=0;break b;case 25:g[c+3|0]=12;break b;case 27:vs(c);g[c|0]=255;break b;case 28:g[c+3|0]=16;break b;case 31:g[c+3|0]=11;e:{f:{g:{switch(f>>>4|0){case 4:if((f|0)==64){break f}g[e|0]=f&15;break b;case 5:g[e|0]=f<<4;break b;case 6:g[d+3|0]=f&15;g[d+2|0]=14;t=e,u=j[Xb(d+3|0,d+2|0)|0]|240,g[t|0]=u;break b;case 0:case 1:case 2:case 3:break f;case 7:break g;default:break e}}g[d+1|0]=f&15;g[d|0]=14;t=e,u=j[Xb(d+1|0,d)|0]<<4|15,g[t|0]=u;break b}g[c+4|0]=f;g[c+2|0]=1}g[c+3|0]=0;break c;case 0:break c;default:break d}}g[c+3|0]=0}g[e|0]=0}h=h+1|0;if((n|0)!=(h|0)){continue}break}}l=l+1|0;if((l|0)!=(i|0)){continue}break}}Xa=d+16|0}function cHa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,j=0;d=Xa-96|0;Xa=d;b=b&4095;h[d+94>>1]=b;a:{b:{c:{d:{e:{f:{g:{if(b>>>0>=81){e=((b|0)==4095?c:b+ -80|0)+734016|0;c=XMa(e,e>>31,1e4,0)+14780|0;b=_a;b=YMa(c,c>>>0<14780?b+1|0:b,3652425,0);c=(((((b|0)/-4|0)+e|0)+o(b,-365)|0)+((b|0)/100|0)|0)+((b|0)/-400|0)|0;if((c|0)<=-1){b=b+ -1|0;c=(((e+((b|0)/-4|0)|0)+o(b,-365)|0)+((b|0)/100|0)|0)+((b|0)/-400|0)|0}e=Bb(d- -64|0,13390);i[114610]=0;D(219,d+80|0,e|0);f=i[114610];i[114610]=0;j=(o(c,100)+52|0)/3060|0;h:{i:{j:{k:{l:{m:{n:{o:{if((f|0)!=1){i[114610]=0;g=b;b=j+2|0;f=(b|0)/12|0;i[d+44>>2]=g+f;D(191,d+48|0,d+44|0);g=i[114610];i[114610]=0;if((g|0)==1){break o}i[114610]=0;i[d+28>>2]=(b-o(f,12)|0)+1;D(193,d+32|0,d+28|0);b=i[114610];i[114610]=0;if((b|0)==1){break n}i[114610]=0;i[d+12>>2]=(((o(j,306)+5|0)/-10|0)+c|0)+1;D(193,d+16|0,d+12|0);b=i[114610];i[114610]=0;if((b|0)==1){break m}i[114610]=0;T(622,a|0,d+80|0,d+48|0,d+32|0,d+16|0);a=i[114610];i[114610]=0;if((a|0)==1){break l}eb(d+16|0);eb(d+32|0);eb(d+48|0);ob(d+80|0);eb(e);break g}b=B()|0;A()|0;break h}b=B()|0;A()|0;break i}b=B()|0;A()|0;break j}b=B()|0;A()|0;break k}b=B()|0;A()|0;eb(d+16|0)}eb(d+32|0)}eb(d+48|0)}ob(d+80|0)}eb(e);break a}c=Bb(d,13414);i[114610]=0;D(219,d+80|0,c|0);b=i[114610];i[114610]=0;if((b|0)==1){break f}i[114610]=0;D(623,d+48|0,d+94|0);b=i[114610];i[114610]=0;if((b|0)==1){break e}i[114610]=0;G(247,a|0,d+80|0,d+48|0);a=i[114610];i[114610]=0;if((a|0)==1){break d}eb(d+48|0);ob(d+80|0);eb(c)}Xa=d+96|0;return}b=B()|0;A()|0;break b}b=B()|0;A()|0;break c}b=B()|0;A()|0;eb(d+48|0)}ob(d+80|0)}eb(c)}E(b|0);x()}function gka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;c=Xa-144|0;Xa=c;e=Ek(c+40|0,a);i[114610]=0;d=C(686,c+24|0,32283)|0;a=i[114610];i[114610]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{if((a|0)!=1){i[114610]=0;i[c>>2]=19465472;i[c+4>>2]=0;G(687,e|0,d|0,c|0);a=i[114610];i[114610]=0;if((a|0)==1){break n}ob(d);if(i[e>>2]&1073741824){break e}i[114610]=0;d=C(686,c+24|0,32288)|0;a=i[114610];i[114610]=0;if((a|0)==1){break m}i[114610]=0;N(1569,e|0,b|0,d|0,1570)|0;a=i[114610];i[114610]=0;if((a|0)==1){break l}ob(d);i[114610]=0;i[c+20>>2]=0;i[c+16>>2]=0;d=C(686,c+24|0,32293)|0;a=i[114610];i[114610]=0;if((a|0)==1){break k}i[114610]=0;I(1571,e|0,c+20|0,d|0)|0;a=i[114610];i[114610]=0;if((a|0)==1){break j}ob(d);i[114610]=0;d=C(686,c+24|0,32298)|0;a=i[114610];i[114610]=0;if((a|0)==1){break i}i[114610]=0;I(1571,e|0,c+16|0,d|0)|0;a=i[114610];i[114610]=0;if((a|0)==1){break h}ob(d);vka(b,i[c+20>>2],i[c+16>>2]);d=hx(c+24|0);i[114610]=0;f=C(686,c|0,32303)|0;a=i[114610];i[114610]=0;if((a|0)==1){break d}i[114610]=0;N(1572,e|0,d|0,f|0,678)|0;a=i[114610];i[114610]=0;if((a|0)==1){break g}ob(f);if(Uc(d)){break f}i[114610]=0;G(1573,d|0,i[c+20>>2],16777216);a=i[114610];i[114610]=0;if((a|0)!=1){break f}break c}a=B()|0;A()|0;break a}a=B()|0;A()|0;ob(d);break a}a=B()|0;A()|0;break a}a=B()|0;A()|0;ob(d);break a}a=B()|0;A()|0;break a}a=B()|0;A()|0;ob(d);break a}a=B()|0;A()|0;break a}a=B()|0;A()|0;ob(d);break a}a=B()|0;A()|0;ob(f);break b}i[114610]=0;D(1574,b|0,d|0);a=i[114610];i[114610]=0;if((a|0)==1){break c}Sd(d)}Yf(e);Xa=c+144|0;return}a=B()|0;A()|0;break b}a=B()|0;A()|0}Sd(d)}Yf(e);E(a|0);x()}function BB(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=Xa-128|0;Xa=c;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{b=i[b>>2];l:{if(!b){Bb(a,7037);break l}if(!(b&65535)){e=Bb(c+96|0,7045);i[114610]=0;D(219,c+112|0,e|0);d=i[114610];i[114610]=0;m:{n:{o:{p:{q:{r:{if((d|0)!=1){i[114610]=0;i[c+24>>2]=b>>>24;D(220,c+80|0,c+24|0);d=i[114610];i[114610]=0;if((d|0)==1){break r}i[114610]=0;i[c+8>>2]=b>>>16&255;D(221,c- -64|0,c+8|0);b=i[114610];i[114610]=0;if((b|0)==1){break q}i[114610]=0;J(222,a|0,c+112|0,c+80|0,c- -64|0);a=i[114610];i[114610]=0;if((a|0)==1){break p}eb(c- -64|0);eb(c+80|0);ob(c+112|0);eb(e);break l}b=B()|0;A()|0;break m}b=B()|0;A()|0;break n}b=B()|0;A()|0;break o}b=B()|0;A()|0;eb(c- -64|0)}eb(c+80|0)}ob(c+112|0)}break a}e=Bb(c+48|0,7051);i[114610]=0;D(219,c+112|0,e|0);d=i[114610];i[114610]=0;if((d|0)==1){break k}i[114610]=0;i[c+44>>2]=b>>>24;D(220,c+80|0,c+44|0);d=i[114610];i[114610]=0;if((d|0)==1){break j}i[114610]=0;i[c+40>>2]=b>>>16&255;D(221,c- -64|0,c+40|0);d=i[114610];i[114610]=0;if((d|0)==1){break i}i[114610]=0;i[c+20>>2]=b>>>8&255;D(221,c+24|0,c+20|0);d=i[114610];i[114610]=0;if((d|0)==1){break h}i[114610]=0;i[c+4>>2]=b&255;D(221,c+8|0,c+4|0);b=i[114610];i[114610]=0;if((b|0)==1){break g}i[114610]=0;_(223,a|0,c+112|0,c+80|0,c- -64|0,c+24|0,c+8|0);a=i[114610];i[114610]=0;if((a|0)==1){break f}eb(c+8|0);eb(c+24|0);eb(c- -64|0);eb(c+80|0);ob(c+112|0);eb(e)}Xa=c+128|0;return}b=B()|0;A()|0;break a}b=B()|0;A()|0;break b}b=B()|0;A()|0;break c}b=B()|0;A()|0;break d}b=B()|0;A()|0;break e}b=B()|0;A()|0;eb(c+8|0)}eb(c+24|0)}eb(c- -64|0)}eb(c+80|0)}ob(c+112|0)}eb(e);E(b|0);x()}function _0(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=+e;var f=0,g=0,h=0,j=0,k=0,l=0,m=0;f=Xa-384|0;Xa=f;i[f+376>>2]=37;i[f+380>>2]=0;g=pq(f+376|1,62153,i[c+4>>2]);i[f+332>>2]=f+336;a=Ud();a:{if(g){h=i[c+8>>2];n[f+40>>3]=e;i[f+32>>2]=h;a=Je(f+336|0,30,a,f+376|0,f+32|0);break a}n[f+48>>3]=e;a=Je(f+336|0,30,a,f+376|0,f+48|0)}i[f+80>>2]=2420;h=wd(f+320|0,0,f+80|0);b:{c:{d:{if((a|0)>=30){e:{if(g){i[114610]=0;a=R(2445)|0;g=i[114610];i[114610]=0;if((g|0)==1){break c}i[f>>2]=i[c+8>>2];i[114610]=0;n[f+8>>3]=e;a=N(2467,f+332|0,a|0,f+376|0,f|0)|0;g=i[114610];i[114610]=0;if((g|0)!=1){break e}break c}i[114610]=0;a=R(2445)|0;g=i[114610];i[114610]=0;if((g|0)==1){break c}n[f+16>>3]=e;i[114610]=0;a=N(2467,f+332|0,a|0,f+376|0,f+16|0)|0;g=i[114610];i[114610]=0;if((g|0)==1){break c}}g=i[f+332>>2];if(!g){i[114610]=0;K(2421);a=i[114610];i[114610]=0;if((a|0)==1){break c}break d}de(h,g)}g=i[f+332>>2];k=g+a|0;l=Of(g,k,c);i[f+68>>2]=2420;j=wd(f+72|0,0,f+68|0);f:{g:{if(i[f+332>>2]==(f+336|0)){a=f+80|0;g=f+336|0;break g}a=Zc(a<<3);if(!a){i[114610]=0;K(2421);a=i[114610];i[114610]=0;if((a|0)!=1){break d}c=B()|0;A()|0;break f}de(j,a);g=i[f+332>>2]}i[114610]=0;fc(f+56|0,c);m=i[114610];i[114610]=0;h:{i:{if((m|0)!=1){i[114610]=0;X(2478,g|0,l|0,k|0,a|0,f+68|0,f- -64|0,f+56|0);g=i[114610];i[114610]=0;if((g|0)==1){break i}ub(f+56|0);i[114610]=0;a=Y(2479,b|0,a|0,i[f+68>>2],i[f+64>>2],c|0,d|0)|0;b=i[114610];i[114610]=0;if((b|0)==1){break h}lc(j);lc(h);Xa=f+384|0;return a|0}c=B()|0;A()|0;break f}c=B()|0;A()|0;ub(f+56|0);break f}c=B()|0;A()|0}lc(j);break b}x()}c=B()|0;A()|0}lc(h);E(c|0);x()}function k1(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=+e;var f=0,g=0,h=0,j=0,k=0,l=0,m=0;f=Xa-208|0;Xa=f;i[f+200>>2]=37;i[f+204>>2]=0;g=pq(f+200|1,62153,i[c+4>>2]);i[f+156>>2]=f+160;a=Ud();a:{if(g){h=i[c+8>>2];n[f+40>>3]=e;i[f+32>>2]=h;a=Je(f+160|0,30,a,f+200|0,f+32|0);break a}n[f+48>>3]=e;a=Je(f+160|0,30,a,f+200|0,f+48|0)}i[f+80>>2]=2420;h=wd(f+144|0,0,f+80|0);b:{c:{d:{if((a|0)>=30){e:{if(g){i[114610]=0;a=R(2445)|0;g=i[114610];i[114610]=0;if((g|0)==1){break c}i[f>>2]=i[c+8>>2];i[114610]=0;n[f+8>>3]=e;a=N(2467,f+156|0,a|0,f+200|0,f|0)|0;g=i[114610];i[114610]=0;if((g|0)!=1){break e}break c}i[114610]=0;a=R(2445)|0;g=i[114610];i[114610]=0;if((g|0)==1){break c}n[f+16>>3]=e;i[114610]=0;a=N(2467,f+156|0,a|0,f+200|0,f+16|0)|0;g=i[114610];i[114610]=0;if((g|0)==1){break c}}g=i[f+156>>2];if(!g){i[114610]=0;K(2421);a=i[114610];i[114610]=0;if((a|0)==1){break c}break d}de(h,g)}g=i[f+156>>2];k=g+a|0;l=Of(g,k,c);i[f+68>>2]=2420;j=wd(f+72|0,0,f+68|0);f:{g:{if(i[f+156>>2]==(f+160|0)){a=f+80|0;g=f+160|0;break g}a=Zc(a<<1);if(!a){i[114610]=0;K(2421);a=i[114610];i[114610]=0;if((a|0)!=1){break d}c=B()|0;A()|0;break f}de(j,a);g=i[f+156>>2]}i[114610]=0;fc(f+56|0,c);m=i[114610];i[114610]=0;h:{i:{if((m|0)!=1){i[114610]=0;X(2468,g|0,l|0,k|0,a|0,f+68|0,f- -64|0,f+56|0);g=i[114610];i[114610]=0;if((g|0)==1){break i}ub(f+56|0);i[114610]=0;a=Y(17,b|0,a|0,i[f+68>>2],i[f+64>>2],c|0,d|0)|0;b=i[114610];i[114610]=0;if((b|0)==1){break h}lc(j);lc(h);Xa=f+208|0;return a|0}c=B()|0;A()|0;break f}c=B()|0;A()|0;ub(f+56|0);break f}c=B()|0;A()|0}lc(j);break b}x()}c=B()|0;A()|0}lc(h);E(c|0);x()}function Aua(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,h=0,j=0,k=0,l=0,m=0,n=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;h=Xa-48|0;Xa=h;s=i[a+16>>2];j=tf(h+16|0);i[j+8>>2]=a+112;i[j+16>>2]=i[a+128>>2];w=j,x=of(b+327720|0,i[b+20>>2],(i[a+88>>2]&16384)>>>14|0),i[w+12>>2]=x;b=i[j+16>>2];if(b){w=j,x=sf(a+8|0,b),i[w>>2]=x;i[j+4>>2]=_a}m=i[a+48>>2];n=i[a+40>>2];p=i[a+36>>2];b=i[a+44>>2];f=i[a+4>>2];e=i[a>>2];i[h+8>>2]=e;i[h+12>>2]=f;q=i[a+12>>2];i[h>>2]=i[a+8>>2];i[h+4>>2]=q;a:{if(!d){k=n>>12;l=p>>12;break a}while(1){q=b;b=0;k=b;i[h+40>>2]=e;i[h+44>>2]=b;f=f+s|0;b:{b=i[j+16>>2];if((b|0)<=0){break b}while(1){fd(i[j+8>>2],g[f+k|0]<<6);ed(i[j+8>>2],4);zb(h+40|0,j);if((b|0)<2){break b}b=b+ -1|0;k=i[h+44>>2];continue}}d=d+ -1|0;b=i[j+8>>2];zb(b,b+8|0);b=i[j+8>>2];e=i[b+4>>2];if(e){fd(b,g[f+i[h+44>>2]|0]<<6);ed(i[j+8>>2],e);b=i[j+8>>2];e=i[b>>2];i[b>>2]=e;i[b+4>>2]=0}e=nf(b,i[j+12>>2]);k=i[a+60>>2];b=Eb(q,-16777216,16776704);l=i[a+64>>2];f=Eb(m,-16777216,16776704);t=i[a+72>>2];u=i[a+32>>2];m=c;v=i[c>>2];r=e<<8;e=r;e=XMa(k,k>>31,e,e>>31);k=_a;l=XMa(l,l>>31,b,b>>31);e=l+e|0;b=_a+k|0;b=e>>>0<l>>>0?b+1|0:b;k=e;e=i[a+68>>2];e=XMa(e,e>>31,f,f>>31);f=k+e|0;b=_a+b|0;b=f>>>0<e>>>0?b+1|0:b;f=f+8388608|0;if(f>>>0<8388608){b=b+1|0}f=(b&16777215)<<8|f>>>24;b=(f|0)/256|0;p=i[a+28>>2]+p|0;l=p>>12;i[m>>2]=o(b,l)+v;n=n+u|0;k=n>>12;i[c+4>>2]=i[c+4>>2]+o(b,k);b=f-(t&r)|0;zb(h+8|0,h);if(d){c=c+8|0;e=i[h+8>>2];f=i[h+12>>2];m=q;continue}break}e=i[h+8>>2];f=i[h+12>>2];m=q}i[a+40>>2]=n;i[a+20>>2]=l;i[a+36>>2]=p;i[a+48>>2]=m;i[a+44>>2]=b;i[a+24>>2]=k;i[a>>2]=e;i[a+4>>2]=f;Xa=h+48|0}function u1(a,b,c,d,e){var f=0,h=0;f=Xa-384|0;Xa=f;i[f+368>>2]=b;i[f+376>>2]=a;Ku(f+216|0,c,f+240|0,f+236|0,f+232|0);b=Ab(f+200|0);a=qc(b);i[114610]=0;D(149,b|0,a|0);a=i[114610];i[114610]=0;a:{b:{if((a|0)!=1){a=Sb(b,0);i[f+196>>2]=a;i[f+28>>2]=f+32;i[f+24>>2]=0;g[f+23|0]=1;g[f+22|0]=69;while(1){c:{i[114610]=0;c=C(2454,f+376|0,f+368|0)|0;h=i[114610];i[114610]=0;if((h|0)==1){break c}if(!c){break b}if(i[f+196>>2]==(lb(b)+a|0)){c=lb(b);a=lb(b);i[114610]=0;D(149,b|0,a<<1);a=i[114610];i[114610]=0;if((a|0)==1){break a}a=qc(b);i[114610]=0;D(149,b|0,a|0);a=i[114610];i[114610]=0;if((a|0)==1){break a}a=Sb(b,0);i[f+196>>2]=c+a}i[114610]=0;c=F(2456,f+376|0)|0;h=i[114610];i[114610]=0;if((h|0)==1){break c}i[114610]=0;c=qq(c,f+23|0,f+22|0,a,f+196|0,i[f+236>>2],i[f+232>>2],f+216|0,f+32|0,f+28|0,f+24|0,f+240|0);h=i[114610];i[114610]=0;if((h|0)==1){break c}if(c){break b}i[114610]=0;F(2458,f+376|0)|0;c=i[114610];i[114610]=0;if((c|0)!=1){continue}}break}break a}break a}d:{if(!lb(f+216|0)|!j[f+23|0]){break d}c=i[f+28>>2];if((c-(f+32|0)|0)>159){break d}i[f+28>>2]=c+4;i[c>>2]=i[f+24>>2]}i[114610]=0;J(2443,f|0,a|0,i[f+196>>2],d|0);a=i[114610];i[114610]=0;e:{if((a|0)==1){break e}a=i[f+8>>2];c=i[f+12>>2];h=i[f+4>>2];i[e>>2]=i[f>>2];i[e+4>>2]=h;i[e+8>>2]=a;i[e+12>>2]=c;i[114610]=0;je(f+216|0,f+32|0,i[f+28>>2],d);a=i[114610];i[114610]=0;if((a|0)==1){break e}i[114610]=0;a=C(2455,f+376|0,f+368|0)|0;c=i[114610];i[114610]=0;if((c|0)==1){break e}if(a){i[d>>2]=i[d>>2]|2}a=i[f+376>>2];eb(b);eb(f+216|0);Xa=f+384|0;return a}}a=B()|0;A()|0;eb(b);eb(f+216|0);E(a|0);x()}function S1(a,b,c,d,e){var f=0,h=0;f=Xa-288|0;Xa=f;i[f+272>>2]=b;i[f+280>>2]=a;Mu(f+224|0,c,f+240|0,f+239|0,f+238|0);b=Ab(f+208|0);a=qc(b);i[114610]=0;D(149,b|0,a|0);a=i[114610];i[114610]=0;a:{b:{if((a|0)!=1){a=Sb(b,0);i[f+204>>2]=a;i[f+28>>2]=f+32;i[f+24>>2]=0;g[f+23|0]=1;g[f+22|0]=69;while(1){c:{i[114610]=0;c=C(2422,f+280|0,f+272|0)|0;h=i[114610];i[114610]=0;if((h|0)==1){break c}if(!c){break b}if(i[f+204>>2]==(lb(b)+a|0)){c=lb(b);a=lb(b);i[114610]=0;D(149,b|0,a<<1);a=i[114610];i[114610]=0;if((a|0)==1){break a}a=qc(b);i[114610]=0;D(149,b|0,a|0);a=i[114610];i[114610]=0;if((a|0)==1){break a}a=Sb(b,0);i[f+204>>2]=c+a}i[114610]=0;c=F(2424,f+280|0)|0;h=i[114610];i[114610]=0;if((h|0)==1){break c}i[114610]=0;c=sq(c,f+23|0,f+22|0,a,f+204|0,g[f+239|0],g[f+238|0],f+224|0,f+32|0,f+28|0,f+24|0,f+240|0);h=i[114610];i[114610]=0;if((h|0)==1){break c}if(c){break b}i[114610]=0;F(2426,f+280|0)|0;c=i[114610];i[114610]=0;if((c|0)!=1){continue}}break}break a}break a}d:{if(!lb(f+224|0)|!j[f+23|0]){break d}c=i[f+28>>2];if((c-(f+32|0)|0)>159){break d}i[f+28>>2]=c+4;i[c>>2]=i[f+24>>2]}i[114610]=0;J(2443,f|0,a|0,i[f+204>>2],d|0);a=i[114610];i[114610]=0;e:{if((a|0)==1){break e}a=i[f+8>>2];c=i[f+12>>2];h=i[f+4>>2];i[e>>2]=i[f>>2];i[e+4>>2]=h;i[e+8>>2]=a;i[e+12>>2]=c;i[114610]=0;je(f+224|0,f+32|0,i[f+28>>2],d);a=i[114610];i[114610]=0;if((a|0)==1){break e}i[114610]=0;a=C(2423,f+280|0,f+272|0)|0;c=i[114610];i[114610]=0;if((c|0)==1){break e}if(a){i[d>>2]=i[d>>2]|2}a=i[f+280>>2];eb(b);eb(f+224|0);Xa=f+288|0;return a}}a=B()|0;A()|0;eb(b);eb(f+224|0);E(a|0);x()}function jva(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;j=Xa-16|0;Xa=j;s=i[a+16>>2];a:{b:{c:{l=i[a+8>>2];g=i[a+12>>2];d:{if((g|0)<1?1:(g|0)<=1?l>>>0<=805306368:0){if((g|0)>-2?1:(g|0)>=-2?l>>>0>=3489660928:0){break c}if((g|0)>-2?1:(g|0)>=-2?l>>>0>2147483647:0){break d}break b}if((g|0)>1?1:(g|0)>=1?l>>>0>2147483648:0){break b}}p=b+196648|0;break a}p=b+131112|0;break a}p=b+262184|0}f=i[a+48>>2];t=i[a+24>>2];u=i[a+20>>2];m=i[a+44>>2];e=i[a+4>>2];k=i[a>>2];i[j+8>>2]=k;i[j+12>>2]=e;i[j>>2]=l;i[j+4>>2]=g;e:{if(!d){b=m;m=f;break e}while(1){b=(k>>>16&65520)+p|0;g=h[b>>1];e=(e<<1)+s|0;k=h[e+ -6>>1];l=h[b+2>>1];v=h[e+ -4>>1];w=h[b+4>>1];x=h[e+ -2>>1];y=h[b+6>>1];z=h[e>>1];A=h[b+8>>1];B=h[e+2>>1];C=h[b+10>>1];D=h[e+4>>1];E=h[b+12>>1];F=h[e+6>>1];G=h[b+14>>1];e=h[e+8>>1];r=i[a+60>>2];b=Eb(m,-16777216,16776704);n=i[a+64>>2];f=Eb(f,-16777216,16776704);H=i[a+72>>2];I=i[c>>2];b=XMa(n,n>>31,b,b>>31);n=_a;q=b;k=(((((((o(l,v)+o(g,k)|0)+o(w,x)|0)+o(y,z)|0)+o(A,B)|0)+o(C,D)|0)+o(E,F)|0)+o(e,G)|0)/32768<<8;b=k;g=XMa(r,r>>31,b,b>>31);e=q+g|0;b=_a+n|0;b=e>>>0<g>>>0?b+1|0:b;q=e;e=i[a+68>>2];e=XMa(e,e>>31,f,f>>31);f=q+e|0;b=_a+b|0;b=f>>>0<e>>>0?b+1|0:b;f=f+8388608|0;if(f>>>0<8388608){b=b+1|0}b=(b&16777215)<<8|f>>>24;f=(b|0)/256|0;i[c>>2]=o(f,u)+I;i[c+4>>2]=i[c+4>>2]+o(f,t);b=b-(k&H)|0;zb(j+8|0,j);d=d+ -1|0;if(d){c=c+8|0;k=i[j+8>>2];e=i[j+12>>2];f=m;m=b;continue}break}k=i[j+8>>2];e=i[j+12>>2]}i[a+48>>2]=m;i[a+44>>2]=b;i[a>>2]=k;i[a+4>>2]=e;Xa=j+16|0}function kva(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,j=0,k=0,l=0,m=0,n=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0;k=Xa-16|0;Xa=k;s=i[a+16>>2];a:{b:{c:{l=i[a+8>>2];j=i[a+12>>2];d:{if((j|0)<1?1:(j|0)<=1?l>>>0<=805306368:0){if((j|0)>-2?1:(j|0)>=-2?l>>>0>=3489660928:0){break c}if((j|0)>-2?1:(j|0)>=-2?l>>>0>2147483647:0){break d}break b}if((j|0)>1?1:(j|0)>=1?l>>>0>2147483648:0){break b}}q=b+196648|0;break a}q=b+131112|0;break a}q=b+262184|0}f=i[a+48>>2];t=i[a+24>>2];u=i[a+20>>2];n=i[a+44>>2];e=i[a+4>>2];m=i[a>>2];i[k+8>>2]=m;i[k+12>>2]=e;i[k>>2]=l;i[k+4>>2]=j;e:{if(!d){b=n;n=f;break e}while(1){b=e+s|0;j=g[b+4|0];e=(m>>>16&65520)+q|0;m=h[e+14>>1];l=g[b+3|0];v=h[e+12>>1];w=g[b+2|0];x=h[e+10>>1];y=g[b+1|0];z=h[e+8>>1];A=g[b|0];B=h[e+6>>1];C=g[b+ -1|0];D=h[e+4>>1];E=g[b+ -2|0];F=h[e+2>>1];G=g[b+ -3|0];e=h[e>>1];b=i[a+60>>2];H=b;I=b>>31;b=Eb(n,-16777216,16776704);p=i[a+64>>2];f=Eb(f,-16777216,16776704);J=i[a+72>>2];K=i[c>>2];b=XMa(p,p>>31,b,b>>31);p=_a;L=b;b=i[a+68>>2];r=XMa(b,b>>31,f,f>>31);f=L+r|0;b=_a+p|0;b=f>>>0<r>>>0?b+1|0:b;e=(((((((o(E,F)+o(e,G)|0)+o(C,D)|0)+o(A,B)|0)+o(y,z)|0)+o(w,x)|0)+o(l,v)|0)+o(j,m)<<8)/32768<<8;j=XMa(H,I,e,e>>31);f=f+j|0;b=_a+b|0;b=f>>>0<j>>>0?b+1|0:b;f=f+8388608|0;if(f>>>0<8388608){b=b+1|0}b=(b&16777215)<<8|f>>>24;f=(b|0)/256|0;i[c>>2]=o(f,u)+K;i[c+4>>2]=i[c+4>>2]+o(f,t);b=b-(e&J)|0;zb(k+8|0,k);d=d+ -1|0;if(d){c=c+8|0;m=i[k+8>>2];e=i[k+12>>2];f=n;n=b;continue}break}m=i[k+8>>2];e=i[k+12>>2]}i[a+48>>2]=n;i[a+44>>2]=b;i[a>>2]=m;i[a+4>>2]=e;Xa=k+16|0}function Mva(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;b=Xa-48|0;Xa=b;v=i[a+16>>2];n=i[a+44>>2];i[b+32>>2]=n;f=i[a+48>>2];i[b+36>>2]=f;l=i[a+52>>2];i[b+40>>2]=l;m=i[a+56>>2];i[b+44>>2]=m;p=i[a+40>>2];q=i[a+36>>2];e=i[a+4>>2];k=i[a>>2];i[b+24>>2]=k;i[b+28>>2]=e;g=i[a+12>>2];i[b+16>>2]=i[a+8>>2];i[b+20>>2]=g;a:{if(!d){g=p>>12;j=q>>12;break a}while(1){f=k>>>18|0;n=1;e=((((e&2147483647)<<1|k>>>31)&2147483646)<<1)+v|0;g=0;l=1;j=0;while(1){m=j<<1;k=h[m+e>>1];i[(b+8|0)+(j<<2)>>2]=k+((o(f,h[e+(m|4)>>1]-k|0)|0)/16384|0);k=l&1;l=0;j=1;if(k){continue}break}while(1){j=(b+8|0)+(g<<2)|0;l=i[j>>2];f=i[a+60>>2];m=f;k=(b+32|0)+(g<<3)|0;r=i[k>>2];e=Eb(r,-16777216,16776704);u=i[a+64>>2];g=Eb(i[k+4>>2],-16777216,16776704);s=i[a+68>>2];w=s;s=s>>31;i[k+4>>2]=r;r=i[a+72>>2];t=f>>31;l=l<<8;f=l;f=XMa(m,t,f,f>>31);m=_a;t=j;j=f;f=XMa(u,u>>31,e,e>>31);j=j+f|0;e=_a+m|0;e=j>>>0<f>>>0?e+1|0:e;f=j;j=XMa(w,s,g,g>>31);g=f+j|0;e=_a+e|0;e=g>>>0<j>>>0?e+1|0:e;g=g+8388608|0;if(g>>>0<8388608){e=e+1|0}e=(e&16777215)<<8|g>>>24;i[t>>2]=(e|0)/256;i[k>>2]=e-(l&r);g=1;e=n&1;n=0;if(e){continue}break}e=i[a+32>>2];q=i[a+28>>2]+q|0;j=q>>12;i[c>>2]=i[c>>2]+o(j,i[b+8>>2]);p=e+p|0;g=p>>12;i[c+4>>2]=i[c+4>>2]+o(g,i[b+12>>2]);zb(b+24|0,b+16|0);d=d+ -1|0;if(d){c=c+8|0;k=i[b+24>>2];e=i[b+28>>2];continue}break}k=i[b+24>>2];e=i[b+28>>2];m=i[b+44>>2];l=i[b+40>>2];f=i[b+36>>2];n=i[b+32>>2]}i[a+40>>2]=p;i[a+20>>2]=j;i[a+36>>2]=q;i[a+56>>2]=m;i[a+52>>2]=l;i[a+48>>2]=f;i[a+44>>2]=n;i[a+24>>2]=g;i[a>>2]=k;i[a+4>>2]=e;Xa=b+48|0}function CCa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,h=0,i=0,k=0,l=0,m=0,n=0,o=0,p=0;h=Xa-16|0;Xa=h;if(c){o=b,p=id(a),g[o|0]=p;k=b+1|0;l=c+ -1|0;a:{if(!l){break a}while(1){b:{c:{d=f<<1;f=d&254;d:{if(!f){if(!pe(a,h+15|0)){break a}d=j[h+15|0]<<1|1;f=d&255;if(d>>>0>255){break d}break c}if((d&65535)>>>0<256){break c}}i=1;while(1){e:{f:{g:{e=f<<1&254;d=f>>>0>127;h:{if(e){break h}if(!pe(a,h+14|0)){break g}d=j[h+14|0]<<1|1;e=d&255;d=d>>>0>255}i=d|i<<1;f=e<<1&254;if(f){break f}if(!pe(a,h+13|0)){break g}d=j[h+13|0]<<1|1;f=d&255;if(d>>>0>255){continue}break e}f=0;break e}if(e>>>0>127){continue}}break}i:{if((i|0)<=2){n=0;i=i+ -2|0;break i}if(!pe(a,h+12|0)){break a}d=(j[h+12|0]|i<<8)+ -768|0;n=((d|0)>1279?2:1)+((d|0)>31999)|0;m=d^-1;i=0}e=f<<1&254;d=f>>>0>127;j:{if(e){break j}if(!pe(a,h+11|0)){break a}d=j[h+11|0]<<1|1;e=d&255;d=d>>>0>255}f=e<<1&254;e=e>>>0>127;k:{if(f){break k}if(!pe(a,h+10|0)){break a}e=j[h+10|0]<<1|1;f=e&255;e=e>>>0>255}e=e|(i<<2|(d?2:0));if(!e){i=1;while(1){l:{m:{n:{e=f<<1&254;d=f>>>0>127;o:{if(e){break o}if(!pe(a,h+9|0)){break n}d=j[h+9|0]<<1|1;e=d&255;d=d>>>0>255}i=d|i<<1;f=e<<1&254;if(f){break m}if(!pe(a,h+8|0)){break n}d=j[h+8|0]<<1|1;f=d&255;if(d>>>0>255){continue}break l}f=0;break l}if(e>>>0>127){continue}}break}e=i+2|0}if((m|0)>-1){break a}e=e+n|0;if(l>>>0<e>>>0|(e|0)<1|((k-b|0)+m|0)<0){break a}i=k+m|0;l=l-e|0;while(1){g[k|0]=j[i|0];k=k+1|0;i=i+1|0;d=(e|0)>1;e=e+ -1|0;if(d){continue}break}break b}if(!pe(a,k)){break a}l=l+ -1|0;k=k+1|0}if(l){continue}break}}a=(k-b|0)==(c|0)}else{a=0}Xa=h+16|0;return a|0}function Nva(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,h=0,j=0,k=0,l=0,m=0,n=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;b=Xa-48|0;Xa=b;t=i[a+16>>2];l=i[a+44>>2];i[b+32>>2]=l;n=i[a+48>>2];i[b+36>>2]=n;k=i[a+52>>2];i[b+40>>2]=k;m=i[a+56>>2];i[b+44>>2]=m;p=i[a+40>>2];q=i[a+36>>2];e=i[a+4>>2];j=i[a>>2];i[b+24>>2]=j;i[b+28>>2]=e;h=i[a+12>>2];i[b+16>>2]=i[a+8>>2];i[b+20>>2]=h;a:{if(!d){h=p>>12;f=q>>12;break a}while(1){l=j>>>10&4194048;e=(((e&2147483647)<<1|j>>>31)&-2)+t|0;f=0;n=1;k=1;h=0;while(1){j=g[e+h|0];i[(b+8|0)+(h<<2)>>2]=((o(l,g[e+(h|2)|0]-j|0)|0)/16384|0)+(j<<8);j=k&1;k=0;h=1;if(j){continue}break}while(1){k=(b+8|0)+(f<<2)|0;l=i[k>>2];m=i[a+60>>2];j=(b+32|0)+(f<<3)|0;f=i[j>>2];e=Eb(f,-16777216,16776704);s=i[a+64>>2];h=Eb(i[j+4>>2],-16777216,16776704);r=i[a+68>>2];u=r;r=r>>31;i[j+4>>2]=f;v=i[a+72>>2];l=l<<8;f=l;f=XMa(m,m>>31,f,f>>31);m=_a;w=k;k=XMa(s,s>>31,e,e>>31);f=k+f|0;e=_a+m|0;e=f>>>0<k>>>0?e+1|0:e;k=f;f=XMa(u,r,h,h>>31);h=k+f|0;e=_a+e|0;e=h>>>0<f>>>0?e+1|0:e;h=h+8388608|0;if(h>>>0<8388608){e=e+1|0}e=(e&16777215)<<8|h>>>24;i[w>>2]=(e|0)/256;i[j>>2]=e-(l&v);f=1;e=n&1;n=0;if(e){continue}break}e=i[a+32>>2];q=i[a+28>>2]+q|0;f=q>>12;i[c>>2]=i[c>>2]+o(f,i[b+8>>2]);p=e+p|0;h=p>>12;i[c+4>>2]=i[c+4>>2]+o(h,i[b+12>>2]);zb(b+24|0,b+16|0);d=d+ -1|0;if(d){c=c+8|0;j=i[b+24>>2];e=i[b+28>>2];continue}break}j=i[b+24>>2];e=i[b+28>>2];m=i[b+44>>2];k=i[b+40>>2];n=i[b+36>>2];l=i[b+32>>2]}i[a+40>>2]=p;i[a+20>>2]=f;i[a+36>>2]=q;i[a+56>>2]=m;i[a+52>>2]=k;i[a+48>>2]=n;i[a+44>>2]=l;i[a+24>>2]=h;i[a>>2]=j;i[a+4>>2]=e;Xa=b+48|0}function k6(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,h=0,k=0,l=0,m=0,n=0,p=0,q=0,r=0;f=Xa-17168|0;Xa=f;i[f+17164>>2]=0;a:{b:{c:{if(j[a+6152|0]!=255|(c|0)<5){break c}if(!$n(a+6152|0,b)){break c}k=Fv(b,i[a+6148>>2])+_n(b)|0;i[f+17164>>2]=k;if((c|0)==(k|0)){k=c;break b}d:{if((k+4|0)<=(c|0)){if($n(b,b+k|0)){break d}}i[f+17164>>2]=0;break c}if(k){break b}}h=i6(b,c,yb(a,0,6668)+6148|0,f+17164|0);k=i[f+17164>>2];if((h+k|0)<=(c|0)?k:0){break b}i[e>>2]=h;h=0;break a}c=b+h|0;i[a+6152>>2]=j[c|0]|j[c+1|0]<<8|(j[c+2|0]<<16|j[c+3|0]<<24);i[e+4>>2]=h;i[e>>2]=h+k;i[e+8>>2]=j[c+3|0]>191?1:2;q=e,r=iF(c),i[q+12>>2]=r;i[e+16>>2]=4-(j[c+1|0]>>>1&3);q=e,r=Ev(c),i[q+20>>2]=r;if(!d){h=Dv(c);break a}hF(f+17152|0,c+4|0,k+ -4|0);if(!(g[c+1|0]&1)){zd(f+17152|0,16)}e:{if(i[e+16>>2]==3){h=0;b=h6(f+17152|0,f+3740|0,c);if(!((b|0)<0|i[f+17156>>2]>i[f+17160>>2])){k=f6(a,f+17152|0,f+912|0,b);if(k){l=a+2304|0;h=i[e+8>>2];m=f+8620|0;n=f+3852|0;b=0;while(1){p=yb(n,0,4608);e6(a,f+912|0,(o(o(b,h),28)+f|0)+3740|0,h);gF(l,p,18,i[e+8>>2],d,m);h=i[e+8>>2];d=o(h,1152)+d|0;b=b+1|0;if(b>>>0<(j[c+1|0]&8?2:1)>>>0){continue}break}}d6(a,f+912|0);break e}Gv(a);break a}c6(c,f+17152|0,f);h=0;b=yb(f+3852|0,0,4608);k=a+2304|0;l=f+8620|0;c=0;f:{while(1){c=b6(((c<<2)+f|0)+3852|0,f+17152|0,f,i[e+16>>2]|1)+c|0;if((c|0)==12){a6(f,(h<<2)+f|0,b);gF(k,b,12,i[e+8>>2],d,l);yb(b,0,4608);d=o(i[e+8>>2],768)+d|0;c=0}if(i[f+17156>>2]<=i[f+17160>>2]){h=h+1|0;if((h|0)==3){break f}continue}break}Gv(a);h=0;break a}k=1}h=o(Dv(a+6152|0),k)}Xa=f+17168|0;return h|0}function F$(a,b,c,d,e,f,h,k,l,m,n,o,p,q,r){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;h=h|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;p=p|0;q=q|0;r=r|0;var s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;x=Xa-16|0;Xa=x;i[c>>2]=a;A=d&512;while(1){if((z|0)==4){if(lb(q)>>>0>1){C=x,D=ld(q),i[C+8>>2]=D;C=c,D=$i(Oo(x+8|0,1),rj(q),i[c>>2]),i[C>>2]=D}d=d&176;if((d|0)!=16){if((d|0)==32){a=i[c>>2]}i[b>>2]=a}Xa=x+16|0}else{a:{b:{switch(g[l+z|0]){case 0:i[b>>2]=i[c>>2];break a;case 1:i[b>>2]=i[c>>2];t=Aq(h,32);s=i[c>>2];i[c>>2]=s+4;i[s>>2]=t;break a;case 3:if(Cc(q)){break a}t=i[Ki(q,0)>>2];s=i[c>>2];i[c>>2]=s+4;i[s>>2]=t;break a;case 2:if(Cc(p)|!A){break a}C=c,D=$i(ld(p),rj(p),i[c>>2]),i[C>>2]=D;break a;case 4:break b;default:break a}}B=i[c>>2];e=k?e+4|0:e;u=e;while(1){c:{if(u>>>0>=f>>>0){break c}if(!xj(h,2048,i[u>>2])){break c}u=u+4|0;continue}break}s=r;if((s|0)>=1){while(1){t=(s|0)<1;if(!(t|u>>>0<=e>>>0)){u=u+ -4|0;v=i[u>>2];t=i[c>>2];i[c>>2]=t+4;i[t>>2]=v;s=s+ -1|0;continue}break}if(t){y=0}else{y=Aq(h,48)}t=i[c>>2];while(1){v=t+4|0;if((s|0)>=1){i[t>>2]=y;s=s+ -1|0;t=v;continue}break}i[c>>2]=v;i[t>>2]=m}d:{if((e|0)==(u|0)){t=Aq(h,48);s=i[c>>2];u=s+4|0;i[c>>2]=u;i[s>>2]=t;break d}v=-1;e:{if(Cc(o)){break e}v=g[Sb(o,0)|0]}s=0;w=0;while(1){if((e|0)!=(u|0)){f:{if((s|0)!=(v|0)){t=s;break f}t=i[c>>2];i[c>>2]=t+4;i[t>>2]=n;t=0;w=w+1|0;if(w>>>0>=lb(o)>>>0){v=s;break f}if(j[Sb(o,w)|0]==127){v=-1;break f}v=g[Sb(o,w)|0]}u=u+ -4|0;y=i[u>>2];s=i[c>>2];i[c>>2]=s+4;i[s>>2]=y;s=t+1|0;continue}break}u=i[c>>2]}On(B,u)}z=z+1|0;continue}break}}function UK(a,b,c){var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,p=0,q=0,r=0,s=0;h=Xa-16|0;Xa=h;a:{if((b|0)==(c|0)){break a}i[h+12>>2]=-1953789045;RK(b,c,h+12|0);d=c-b>>2;i[h+8>>2]=d;p=qb(a);g=p+1|0;i[h+4>>2]=g;l=i[Jc(h+4|0,h+8|0)>>2];k=i[((i[h+8>>2]<<2)+b|0)+ -4>>2];c=d;e=c;f=11;b:{if(c>>>0>622){break b}f=7;if(d>>>0>67){break b}f=5;if(d>>>0>38){break b}f=3;if(d>>>0>6){break b}f=d+ -1>>>1|0}m=e-f>>>1|0;c=(m<<2)+b|0;e=o(Qr(k^(i[c>>2]^i[b>>2])),1664525);i[c>>2]=e+i[c>>2];q=m+f|0;c=(q<<2)+b|0;d=c;f=i[c>>2];c=e+p|0;i[d>>2]=f+c;i[b>>2]=c;if(p){n=i[h+8>>2];c=1;while(1){e=c+ -1|0;d=((c+m>>>0)%(n>>>0)<<2)+b|0;f=(c>>>0)%(n>>>0)|0;j=(f<<2)+b|0;r=o(Qr(i[((e>>>0)%(n>>>0)<<2)+b>>2]^(i[d>>2]^i[j>>2])),1664525);i[d>>2]=r+i[d>>2];d=vb(a,e);n=i[h+8>>2];e=((c+q>>>0)%(n>>>0)<<2)+b|0;k=e;s=i[e>>2];e=i[d>>2]+(f+r|0)|0;i[k>>2]=s+e;i[j>>2]=e;c=c+1|0;if(c>>>0<=p>>>0){continue}break}}c=i[h+8>>2];if(g>>>0<l>>>0){while(1){a=((g+m>>>0)%(c>>>0)<<2)+b|0;d=(g>>>0)%(c>>>0)|0;e=(d<<2)+b|0;j=o(Qr(i[((g+ -1>>>0)%(c>>>0)<<2)+b>>2]^(i[a>>2]^i[e>>2])),1664525);i[a>>2]=j+i[a>>2];c=i[h+8>>2];a=((g+q>>>0)%(c>>>0)<<2)+b|0;f=a;k=i[a>>2];a=d+j|0;i[f>>2]=k+a;i[e>>2]=a;g=g+1|0;if((l|0)!=(g|0)){continue}break}}if(l>>>0>=c+l>>>0){break a}g=l;while(1){a=((g+m>>>0)%(c>>>0)<<2)+b|0;d=(g>>>0)%(c>>>0)|0;e=(d<<2)+b|0;j=o(Qr(i[((g+ -1>>>0)%(c>>>0)<<2)+b>>2]+(i[a>>2]+i[e>>2]|0)|0),1566083941);i[a>>2]=j^i[a>>2];c=i[h+8>>2];a=((g+q>>>0)%(c>>>0)<<2)+b|0;f=a;k=i[a>>2];a=j-d|0;i[f>>2]=k^a;i[e>>2]=a;g=g+1|0;if(g>>>0<c+l>>>0){continue}break}}Xa=h+16|0}function rna(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,h=0,m=0,n=0,p=0,q=0;d=Xa-48|0;Xa=d;c=k[a+480190>>1];g[d+32|0]=0;nL(b,c+1|0,d+32|0);if(k[a+480192>>1]){h=Mt(d+32|0);c=a+484344|0;p=d,q=Jb(c),i[p+24>>2]=q;p=d,q=Kb(c),i[p+16>>2]=q;if(pb(d+24|0,d+16|0)){while(1){a:{m=i[d+24>>2];if(!rh(m)){break a}c=k[a+480188>>1];i[114610]=0;g[d|0]=0;G(1424,h|0,c|0,d|0);c=i[114610];i[114610]=0;if((c|0)!=1){b:{p=d,q=Jb(m),i[p+8>>2]=q;n=0;if(!i[m+12>>2]){break a}while(1){f=0;c:{if(!k[a+480188>>1]){break c}while(1){d:{c=i[d+8>>2];i[114610]=0;c=F(556,c|0)|0;e=i[114610];i[114610]=0;if((e|0)==1){break d}e:{if(!c){break e}c=j[i[d+8>>2]+1|0];if(!j[i[d+8>>2]+1|0]){c=j[dc(h,f)|0]}e=c&255;if(e){f:{if(!(e>>>0<=256&e>>>0>=0)){break f}e=i[((j[i[d+8>>2]+1|0]<<2)+a|0)+900380>>2];if(!e){break f}e=k[Mc(e+236|0,j[i[d+8>>2]]+ -1|0)>>1];if(e>>>0>k[a+480190>>1]){break f}Ld(d,b,e);Od(d,1)}p=dc(h,f),q=c,g[p|0]=q;break e}c=k[a+480192>>1];if(!c){break e}while(1){e=c;c=i[((c<<2)+a|0)+900380>>2];g:{if(!c){break g}c=k[Mc(c+236|0,j[i[d+8>>2]]+ -1|0)>>1];if(c>>>0>k[a+480190>>1]){break g}Ld(d,b,c);Od(d,1)}c=e+ -1|0;if((e&65535)!=1){continue}break}}jk(d+8|0);f=f+1|0;if(f>>>0<k[a+480188>>1]){continue}break c}break}break b}n=n+1|0;if(n>>>0<l[m+12>>2]){continue}break}break a}}a=B()|0;A()|0;Md(h);E(a|0);x()}Bx(d+24|0);if(pb(d+24|0,d+16|0)){continue}break}}c=k[a+480190>>1];h:{if(!c){f=0;break h}f=0;while(1){Ld(d,b,c);if(!ib(d)){f=ie((o(c,104)+a|0)+484380|0)+f|0}e=c&65535;c=c+ -1|0;if((e|0)!=1){continue}break}}Md(h)}Xa=d+48|0;return f&65535}function zva(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;e=Xa-48|0;Xa=e;s=i[a+16>>2];b=i[a+44>>2];i[e+32>>2]=b;j=i[a+48>>2];i[e+36>>2]=j;f=i[a+52>>2];i[e+40>>2]=f;n=i[a+56>>2];i[e+44>>2]=n;t=i[a+24>>2];u=i[a+20>>2];g=i[a+4>>2];k=i[a>>2];i[e+24>>2]=k;i[e+28>>2]=g;l=i[a+12>>2];i[e+16>>2]=i[a+8>>2];i[e+20>>2]=l;if(d){while(1){n=1;l=((((g&2147483647)<<1|k>>>31)&2147483646)<<1)+s|0;b=(k>>>21&2040)+27872|0;k=h[b+6>>1];m=h[b+4>>1];r=h[b+2>>1];p=h[b>>1];f=0;b=1;j=0;while(1){g=j<<1;i[(e+8|0)+(j<<2)>>2]=(((o(h[g+l>>1],r)+o(h[l+(g|-4)>>1],p)|0)+o(h[l+(g|4)>>1],m)|0)+o(k,h[l+(g|8)>>1])|0)/16384;g=b;b=0;j=1;if(g){continue}break}while(1){k=(e+8|0)+(f<<2)|0;l=i[k>>2];m=i[a+60>>2];g=(e+32|0)+(f<<3)|0;f=i[g>>2];b=Eb(f,-16777216,16776704);p=i[a+64>>2];j=Eb(i[g+4>>2],-16777216,16776704);q=i[a+68>>2];v=q;q=q>>31;i[g+4>>2]=f;w=i[a+72>>2];l=l<<8;f=l;f=XMa(m,m>>31,f,f>>31);m=_a;x=k;k=XMa(p,p>>31,b,b>>31);f=k+f|0;b=_a+m|0;b=f>>>0<k>>>0?b+1|0:b;r=f;f=XMa(v,q,j,j>>31);j=r+f|0;b=_a+b|0;b=j>>>0<f>>>0?b+1|0:b;j=j+8388608|0;if(j>>>0<8388608){b=b+1|0}b=(b&16777215)<<8|j>>>24;i[x>>2]=(b|0)/256;i[g>>2]=b-(l&w);f=1;b=n&1;n=0;if(b){continue}break}i[c>>2]=i[c>>2]+o(i[e+8>>2],u);i[c+4>>2]=i[c+4>>2]+o(i[e+12>>2],t);zb(e+24|0,e+16|0);d=d+ -1|0;if(d){c=c+8|0;k=i[e+24>>2];g=i[e+28>>2];continue}break}k=i[e+24>>2];g=i[e+28>>2];n=i[e+44>>2];f=i[e+40>>2];j=i[e+36>>2];b=i[e+32>>2]}i[a+56>>2]=n;i[a+52>>2]=f;i[a+48>>2]=j;i[a+44>>2]=b;i[a>>2]=k;i[a+4>>2]=g;Xa=e+48|0}function cta(a,b,c){var d=0,e=0,f=0,h=0;d=Xa-160|0;Xa=d;f=Ek(d+56|0,a);i[114610]=0;e=C(686,d+8|0,18622)|0;a=i[114610];i[114610]=0;a:{b:{c:{d:{if((a|0)!=1){i[114610]=0;i[d+48>>2]=19465472;i[d+52>>2]=0;G(687,f|0,e|0,d+48|0);a=i[114610];i[114610]=0;if((a|0)==1){break d}ob(e);if(!(i[f>>2]&1073741824)){break c}break a}a=B()|0;A()|0;break b}a=B()|0;A()|0;ob(e);break b}i[114610]=0;g[d+48|0]=0;g[d+47|0]=0;e=C(686,d+8|0,18614)|0;a=i[114610];i[114610]=0;e:{if((a|0)!=1){i[114610]=0;I(1188,f|0,d+48|0,e|0)|0;a=i[114610];i[114610]=0;if((a|0)==1){break e}ob(e);if(!j[d+48|0]){break a}ze(d+48|0,50);i[114610]=0;e=C(686,d+8|0,18630)|0;a=i[114610];i[114610]=0;f:{g:{h:{i:{if((a|0)!=1){i[114610]=0;I(1188,f|0,d+47|0,e|0)|0;a=i[114610];i[114610]=0;if((a|0)==1){break i}ob(e);e=ph(b);a=j[d+48|0];if(e>>>0<a>>>0){e=Lx(d+8|0,i[b+12>>2]);i[114610]=0;G(1189,b|0,a|0,e|0);a=i[114610];i[114610]=0;if((a|0)==1){break h}dl(e)}e=k[bi(b,0)+28>>1];g[d+7|0]=0;if(j[d+48|0]){a=0;while(1){Fe(bi(b,a&255),e);a=bi(b,j[d+7|0]);i[114610]=0;D(1190,d+8|0,d+7|0);h=i[114610];i[114610]=0;if((h|0)==1){break g}i[114610]=0;J(1191,f|0,a|0,d+8|0,c|0);a=i[114610];i[114610]=0;if((a|0)==1){break f}ob(d+8|0);a=j[d+7|0]+1|0;g[d+7|0]=a;if((a&255)>>>0<j[d+48|0]){continue}break}}a=j[d+47|0];c=ph(b);g[b+16|0]=a>>>0<c>>>0?j[d+47|0]:0;break a}a=B()|0;A()|0;break b}a=B()|0;A()|0;ob(e);break b}a=B()|0;A()|0;dl(e);break b}a=B()|0;A()|0;break b}a=B()|0;A()|0;ob(d+8|0);break b}a=B()|0;A()|0;break b}a=B()|0;A()|0;ob(e)}Yf(f);E(a|0);x()}Yf(f);Xa=d+160|0}function lw(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=Xa-208|0;Xa=d;a:{b:{c:{if(j[c|0]&2){if(i[b>>2]==-2147483648){e=ej(d+48|0,1,45);b=i[b>>2];i[114610]=0;i[d+188>>2]=b;G(137,d+192|0,d+188|0,c|0);b=i[114610];i[114610]=0;d:{e:{if((b|0)!=1){i[114610]=0;G(138,a|0,e|0,d+192|0);a=i[114610];i[114610]=0;if((a|0)==1){break e}eb(d+192|0);eb(e);break b}c=B()|0;A()|0;break d}c=B()|0;A()|0;eb(d+192|0)}eb(e);break a}e=i[b>>2];if((e|0)>-1){break c}e=ej(d+48|0,1,45);b=i[b>>2];i[114610]=0;i[d+188>>2]=0-b;G(137,d+192|0,d+188|0,c|0);b=i[114610];i[114610]=0;f:{g:{if((b|0)!=1){i[114610]=0;G(138,a|0,e|0,d+192|0);a=i[114610];i[114610]=0;if((a|0)==1){break g}eb(d+192|0);eb(e);break b}c=B()|0;A()|0;break f}c=B()|0;A()|0;eb(d+192|0)}eb(e);break a}e=Kg(d+48|0);f=i[i[e>>2]+ -12>>2];i[114610]=0;g=R(122)|0;h=i[114610];i[114610]=0;h:{i:{j:{k:{l:{if((h|0)==1){break l}i[114610]=0;G(123,d+40|0,f+(d+48|0)|0,g|0);f=i[114610];i[114610]=0;if((f|0)==1){break l}ub(d+40|0);i[114610]=0;D(139,e|0,c|0);f=i[114610];i[114610]=0;if((f|0)==1){break l}i[114610]=0;D(124,e|0,b|0);b=i[114610];i[114610]=0;if((b|0)==1){break l}i[114610]=0;D(125,d+8|0,e|0);b=i[114610];i[114610]=0;if((b|0)==1){break l}i[114610]=0;G(140,d+24|0,d+8|0,c|0);b=i[114610];i[114610]=0;if((b|0)==1){break k}i[114610]=0;G(141,a|0,d+24|0,c|0);a=i[114610];i[114610]=0;if((a|0)==1){break j}eb(d+24|0);eb(d+8|0);Fd(e);break b}c=B()|0;A()|0;break h}c=B()|0;A()|0;break i}c=B()|0;A()|0;eb(d+24|0)}eb(d+8|0)}Fd(e);break a}i[d+48>>2]=e;pr(a,d+48|0,c)}Xa=d+208|0;return}E(c|0);x()}function gra(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,m=0;d=Xa-48|0;Xa=d;kd(b,2);bk(d+16|0,2,a+1|0);oc(d+32|0,d+16|0);i[114610]=0;C(370,b+43|0,d+32|0)|0;c=i[114610];i[114610]=0;if((c|0)!=1){eb(d+32|0);a:{if(!(j[a|0]?j[a|0]!=1:0)){if(j[a|0]==1){c=a+16|0;i[b>>2]=j[c|0]|j[c+1|0]<<8|(j[c+2|0]<<16|j[c+3|0]<<24);c=a+20|0;i[d+32>>2]=j[c|0]|j[c+1|0]<<8|(j[c+2|0]<<16|j[c+3|0]<<24);i[d+16>>2]=i[b>>2]+ -1;f=b,m=i[rb(d+32|0,d+16|0)>>2],i[f+4>>2]=m;c=a+24|0;i[d+32>>2]=j[c|0]|j[c+1|0]<<8|(j[c+2|0]<<16|j[c+3|0]<<24);f=b,m=i[rb(d+32|0,b)>>2],i[f+8>>2]=m;h[b+34>>1]=k[b+34>>1]&65533|j[a+31|0]<<1&2}c=i[b+8>>2];if(c>>>0>l[b+4>>2]?c>>>0>=2:0){break a}h[b+34>>1]=0;i[b+4>>2]=0;i[b+8>>2]=0;break a}if(j[a|0]!=2){break a}_g(d+16|0,a+16|0);c=d+32|0;e=i[d+16>>2];e=j[e|0]|j[e+1|0]<<8|(j[e+2|0]<<16|j[e+3|0]<<24);g[c|0]=e;g[c+1|0]=e>>>8;g[c+2|0]=e>>>16;g[c+3|0]=e>>>24;_g(d+16|0,a+20|0);c=d+32|0;e=i[d+16>>2];e=j[e|0]|j[e+1|0]<<8|(j[e+2|0]<<16|j[e+3|0]<<24);g[c+4|0]=e;g[c+5|0]=e>>>8;g[c+6|0]=e>>>16;g[c+7|0]=e>>>24;_g(d+16|0,a+24|0);c=d+32|0;e=i[d+16>>2];e=j[e|0]|j[e+1|0]<<8|(j[e+2|0]<<16|j[e+3|0]<<24);g[c+8|0]=e;g[c+9|0]=e>>>8;g[c+10|0]=e>>>16;g[c+11|0]=e>>>24;i[d+8>>2]=i[d+40>>2];c=i[d+36>>2];i[d>>2]=i[d+32>>2];i[d+4>>2]=c;No(b,1,d)}g[d+32|0]=j[a+28|0];g[d+16|0]=64;f=b,m=j[Xb(d+32|0,d+16|0)|0]<<2,h[f+30>>1]=m;a=a+32|0;a=j[a|0]|j[a+1|0]<<8|(j[a+2|0]<<16|j[a+3|0]<<24);i[b+24>>2]=a;b:{c:{if(!a){c=8363;break c}c=1024;if(a>>>0>1023){break b}}i[b+24>>2]=c}Xa=d+48|0;return}a=B()|0;A()|0;eb(d+32|0);E(a|0);x()}function J$(a,b,c,d,e,f,h,k,l,m,n,o,p,q,r){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;h=h|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;p=p|0;q=q|0;r=r|0;var s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;x=Xa-16|0;Xa=x;i[c>>2]=a;A=d&512;while(1){if((y|0)==4){if(lb(q)>>>0>1){C=x,D=ld(q),i[C+8>>2]=D;C=c,D=$i(Ze(x+8|0,1),Ye(q),i[c>>2]),i[C>>2]=D}d=d&176;if((d|0)!=16){if((d|0)==32){a=i[c>>2]}i[b>>2]=a}Xa=x+16|0;return}a:{b:{switch(g[l+y|0]){case 0:i[b>>2]=i[c>>2];break a;case 1:i[b>>2]=i[c>>2];t=qk(h,32);s=i[c>>2];i[c>>2]=s+1;g[s|0]=t;break a;case 3:if(Cc(q)){break a}t=j[Sb(q,0)|0];s=i[c>>2];i[c>>2]=s+1;g[s|0]=t;break a;case 2:if(Cc(p)|!A){break a}C=c,D=$i(ld(p),Ye(p),i[c>>2]),i[C>>2]=D;break a;case 4:break b;default:break a}}B=i[c>>2];e=k?e+1|0:e;u=e;while(1){c:{if(u>>>0>=f>>>0){break c}if(!jg(h,2048,g[u|0])){break c}u=u+1|0;continue}break}t=r;if((t|0)>=1){while(1){s=(t|0)<1;if(!(s|u>>>0<=e>>>0)){u=u+ -1|0;s=j[u|0];v=i[c>>2];i[c>>2]=v+1;g[v|0]=s;t=t+ -1|0;continue}break}if(s){s=0}else{s=qk(h,48)}while(1){v=i[c>>2];i[c>>2]=v+1;if((t|0)>=1){g[v|0]=s;t=t+ -1|0;continue}break}g[v|0]=m}d:{if((e|0)==(u|0)){t=qk(h,48);s=i[c>>2];i[c>>2]=s+1;g[s|0]=t;break d}s=-1;e:{if(Cc(o)){break e}s=g[Sb(o,0)|0]}t=0;w=0;while(1){if((e|0)==(u|0)){break d}f:{if((t|0)!=(s|0)){v=t;break f}s=i[c>>2];i[c>>2]=s+1;g[s|0]=n;v=0;w=w+1|0;if(w>>>0>=lb(o)>>>0){s=t;break f}if(j[Sb(o,w)|0]==127){s=-1;break f}s=g[Sb(o,w)|0]}u=u+ -1|0;t=j[u|0];z=i[c>>2];i[c>>2]=z+1;g[z|0]=t;t=v+1|0;continue}}sj(B,i[c>>2])}y=y+1|0;continue}}function Dua(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;f=Xa-48|0;Xa=f;p=i[a+16>>2];j=tf(f+16|0);i[j+8>>2]=a+112;i[j+16>>2]=i[a+128>>2];v=j,w=of(b+327720|0,i[b+20>>2],(i[a+88>>2]&16384)>>>14|0),i[v+12>>2]=w;b=i[j+16>>2];if(b){v=j,w=sf(a+8|0,b),i[v>>2]=w;i[j+4>>2]=_a}k=i[a+48>>2];q=i[a+24>>2];r=i[a+20>>2];m=i[a+44>>2];e=i[a+4>>2];g=i[a>>2];i[f+8>>2]=g;i[f+12>>2]=e;b=i[a+12>>2];i[f>>2]=i[a+8>>2];i[f+4>>2]=b;a:{if(!d){b=m;m=k;break a}while(1){b=0;l=b;i[f+40>>2]=g;i[f+44>>2]=b;e=(e<<1)+p|0;b:{b=i[j+16>>2];if((b|0)<=0){break b}while(1){fd(i[j+8>>2],h[(l<<1)+e>>1]/4<<16>>16);ed(i[j+8>>2],4);zb(f+40|0,j);if((b|0)<2){break b}b=b+ -1|0;l=i[f+44>>2];continue}}d=d+ -1|0;b=i[j+8>>2];zb(b,b+8|0);b=i[j+8>>2];g=i[b+4>>2];if(g){fd(b,h[e+(i[f+44>>2]<<1)>>1]/4<<16>>16);ed(i[j+8>>2],g);b=i[j+8>>2];g=i[b>>2];i[b>>2]=g;i[b+4>>2]=0}e=nf(b,i[j+12>>2]);g=i[a+60>>2];l=g;b=Eb(m,-16777216,16776704);n=i[a+64>>2];k=Eb(k,-16777216,16776704);s=i[a+72>>2];t=i[c>>2];u=g>>31;g=e<<8;e=g;e=XMa(l,u,e,e>>31);l=_a;n=XMa(n,n>>31,b,b>>31);e=n+e|0;b=_a+l|0;b=e>>>0<n>>>0?b+1|0:b;l=e;e=i[a+68>>2];e=XMa(e,e>>31,k,k>>31);k=l+e|0;b=_a+b|0;b=k>>>0<e>>>0?b+1|0:b;k=k+8388608|0;if(k>>>0<8388608){b=b+1|0}b=(b&16777215)<<8|k>>>24;k=(b|0)/256|0;i[c>>2]=o(k,r)+t;i[c+4>>2]=i[c+4>>2]+o(k,q);b=b-(g&s)|0;zb(f+8|0,f);if(d){c=c+8|0;g=i[f+8>>2];e=i[f+12>>2];k=m;m=b;continue}break}g=i[f+8>>2];e=i[f+12>>2]}i[a+48>>2]=m;i[a+44>>2]=b;i[a>>2]=g;i[a+4>>2]=e;Xa=f+48|0}function Ava(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,j=0,k=0,l=0,m=0,n=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;e=Xa-48|0;Xa=e;t=i[a+16>>2];j=i[a+44>>2];i[e+32>>2]=j;b=i[a+48>>2];i[e+36>>2]=b;f=i[a+52>>2];i[e+40>>2]=f;p=i[a+56>>2];i[e+44>>2]=p;u=i[a+24>>2];v=i[a+20>>2];l=i[a+4>>2];k=i[a>>2];i[e+24>>2]=k;i[e+28>>2]=l;m=i[a+12>>2];i[e+16>>2]=i[a+8>>2];i[e+20>>2]=m;if(d){while(1){m=(((l&2147483647)<<1|k>>>31)&-2)+t|0;b=(k>>>21&2040)+27872|0;k=h[b+6>>1];n=h[b+4>>1];s=h[b+2>>1];q=h[b>>1];f=0;p=1;b=1;j=0;while(1){i[(e+8|0)+(j<<2)>>2]=(((o(g[j+m|0],s)+o(g[m+(j|-2)|0],q)|0)+o(g[m+(j|2)|0],n)|0)+o(k,g[m+(j|4)|0])<<8)/16384;l=b;b=0;j=1;if(l){continue}break}while(1){k=(e+8|0)+(f<<2)|0;m=i[k>>2];n=i[a+60>>2];l=(e+32|0)+(f<<3)|0;f=i[l>>2];b=Eb(f,-16777216,16776704);q=i[a+64>>2];j=Eb(i[l+4>>2],-16777216,16776704);r=i[a+68>>2];w=r;r=r>>31;i[l+4>>2]=f;x=i[a+72>>2];m=m<<8;f=m;f=XMa(n,n>>31,f,f>>31);n=_a;y=k;k=XMa(q,q>>31,b,b>>31);f=k+f|0;b=_a+n|0;b=f>>>0<k>>>0?b+1|0:b;s=f;f=XMa(w,r,j,j>>31);j=s+f|0;b=_a+b|0;b=j>>>0<f>>>0?b+1|0:b;j=j+8388608|0;if(j>>>0<8388608){b=b+1|0}b=(b&16777215)<<8|j>>>24;i[y>>2]=(b|0)/256;i[l>>2]=b-(m&x);f=1;b=p&1;p=0;if(b){continue}break}i[c>>2]=i[c>>2]+o(i[e+8>>2],v);i[c+4>>2]=i[c+4>>2]+o(i[e+12>>2],u);zb(e+24|0,e+16|0);d=d+ -1|0;if(d){c=c+8|0;k=i[e+24>>2];l=i[e+28>>2];continue}break}k=i[e+24>>2];l=i[e+28>>2];p=i[e+44>>2];f=i[e+40>>2];j=i[e+32>>2];b=i[e+36>>2]}i[a+56>>2]=p;i[a+52>>2]=f;i[a+48>>2]=b;i[a+44>>2]=j;i[a>>2]=k;i[a+4>>2]=l;Xa=e+48|0}function y1(a,b,c,d,e){var f=0,h=0,k=p(0);f=Xa-368|0;Xa=f;i[f+352>>2]=b;i[f+360>>2]=a;Ku(f+200|0,c,f+224|0,f+220|0,f+216|0);b=Ab(f+184|0);a=qc(b);i[114610]=0;D(149,b|0,a|0);a=i[114610];i[114610]=0;a:{b:{if((a|0)!=1){a=Sb(b,0);i[f+180>>2]=a;i[f+12>>2]=f+16;i[f+8>>2]=0;g[f+7|0]=1;g[f+6|0]=69;while(1){c:{i[114610]=0;c=C(2454,f+360|0,f+352|0)|0;h=i[114610];i[114610]=0;if((h|0)==1){break c}if(!c){break b}if(i[f+180>>2]==(lb(b)+a|0)){c=lb(b);a=lb(b);i[114610]=0;D(149,b|0,a<<1);a=i[114610];i[114610]=0;if((a|0)==1){break a}a=qc(b);i[114610]=0;D(149,b|0,a|0);a=i[114610];i[114610]=0;if((a|0)==1){break a}a=Sb(b,0);i[f+180>>2]=c+a}i[114610]=0;c=F(2456,f+360|0)|0;h=i[114610];i[114610]=0;if((h|0)==1){break c}i[114610]=0;c=qq(c,f+7|0,f+6|0,a,f+180|0,i[f+220>>2],i[f+216>>2],f+200|0,f+16|0,f+12|0,f+8|0,f+224|0);h=i[114610];i[114610]=0;if((h|0)==1){break c}if(c){break b}i[114610]=0;F(2458,f+360|0)|0;c=i[114610];i[114610]=0;if((c|0)!=1){continue}}break}break a}break a}d:{if(!lb(f+200|0)|!j[f+7|0]){break d}c=i[f+12>>2];if((c-(f+16|0)|0)>159){break d}i[f+12>>2]=c+4;i[c>>2]=i[f+8>>2]}i[114610]=0;k=p(ha(2439,a|0,i[f+180>>2],d|0));a=i[114610];i[114610]=0;e:{if((a|0)==1){break e}m[e>>2]=k;i[114610]=0;je(f+200|0,f+16|0,i[f+12>>2],d);a=i[114610];i[114610]=0;if((a|0)==1){break e}i[114610]=0;a=C(2455,f+360|0,f+352|0)|0;c=i[114610];i[114610]=0;if((c|0)==1){break e}if(a){i[d>>2]=i[d>>2]|2}a=i[f+360>>2];eb(b);eb(f+200|0);Xa=f+368|0;return a}}a=B()|0;A()|0;eb(b);eb(f+200|0);E(a|0);x()}function Y1(a,b,c,d,e){var f=0,h=0,k=p(0);f=Xa-272|0;Xa=f;i[f+256>>2]=b;i[f+264>>2]=a;Mu(f+208|0,c,f+224|0,f+223|0,f+222|0);b=Ab(f+192|0);a=qc(b);i[114610]=0;D(149,b|0,a|0);a=i[114610];i[114610]=0;a:{b:{if((a|0)!=1){a=Sb(b,0);i[f+188>>2]=a;i[f+12>>2]=f+16;i[f+8>>2]=0;g[f+7|0]=1;g[f+6|0]=69;while(1){c:{i[114610]=0;c=C(2422,f+264|0,f+256|0)|0;h=i[114610];i[114610]=0;if((h|0)==1){break c}if(!c){break b}if(i[f+188>>2]==(lb(b)+a|0)){c=lb(b);a=lb(b);i[114610]=0;D(149,b|0,a<<1);a=i[114610];i[114610]=0;if((a|0)==1){break a}a=qc(b);i[114610]=0;D(149,b|0,a|0);a=i[114610];i[114610]=0;if((a|0)==1){break a}a=Sb(b,0);i[f+188>>2]=c+a}i[114610]=0;c=F(2424,f+264|0)|0;h=i[114610];i[114610]=0;if((h|0)==1){break c}i[114610]=0;c=sq(c,f+7|0,f+6|0,a,f+188|0,g[f+223|0],g[f+222|0],f+208|0,f+16|0,f+12|0,f+8|0,f+224|0);h=i[114610];i[114610]=0;if((h|0)==1){break c}if(c){break b}i[114610]=0;F(2426,f+264|0)|0;c=i[114610];i[114610]=0;if((c|0)!=1){continue}}break}break a}break a}d:{if(!lb(f+208|0)|!j[f+7|0]){break d}c=i[f+12>>2];if((c-(f+16|0)|0)>159){break d}i[f+12>>2]=c+4;i[c>>2]=i[f+8>>2]}i[114610]=0;k=p(ha(2439,a|0,i[f+188>>2],d|0));a=i[114610];i[114610]=0;e:{if((a|0)==1){break e}m[e>>2]=k;i[114610]=0;je(f+208|0,f+16|0,i[f+12>>2],d);a=i[114610];i[114610]=0;if((a|0)==1){break e}i[114610]=0;a=C(2423,f+264|0,f+256|0)|0;c=i[114610];i[114610]=0;if((c|0)==1){break e}if(a){i[d>>2]=i[d>>2]|2}a=i[f+264>>2];eb(b);eb(f+208|0);Xa=f+272|0;return a}}a=B()|0;A()|0;eb(b);eb(f+208|0);E(a|0);x()}function w1(a,b,c,d,e){var f=0,h=0,k=0;f=Xa-368|0;Xa=f;i[f+352>>2]=b;i[f+360>>2]=a;Ku(f+200|0,c,f+224|0,f+220|0,f+216|0);b=Ab(f+184|0);a=qc(b);i[114610]=0;D(149,b|0,a|0);a=i[114610];i[114610]=0;a:{b:{if((a|0)!=1){a=Sb(b,0);i[f+180>>2]=a;i[f+12>>2]=f+16;i[f+8>>2]=0;g[f+7|0]=1;g[f+6|0]=69;while(1){c:{i[114610]=0;c=C(2454,f+360|0,f+352|0)|0;h=i[114610];i[114610]=0;if((h|0)==1){break c}if(!c){break b}if(i[f+180>>2]==(lb(b)+a|0)){c=lb(b);a=lb(b);i[114610]=0;D(149,b|0,a<<1);a=i[114610];i[114610]=0;if((a|0)==1){break a}a=qc(b);i[114610]=0;D(149,b|0,a|0);a=i[114610];i[114610]=0;if((a|0)==1){break a}a=Sb(b,0);i[f+180>>2]=c+a}i[114610]=0;c=F(2456,f+360|0)|0;h=i[114610];i[114610]=0;if((h|0)==1){break c}i[114610]=0;c=qq(c,f+7|0,f+6|0,a,f+180|0,i[f+220>>2],i[f+216>>2],f+200|0,f+16|0,f+12|0,f+8|0,f+224|0);h=i[114610];i[114610]=0;if((h|0)==1){break c}if(c){break b}i[114610]=0;F(2458,f+360|0)|0;c=i[114610];i[114610]=0;if((c|0)!=1){continue}}break}break a}break a}d:{if(!lb(f+200|0)|!j[f+7|0]){break d}c=i[f+12>>2];if((c-(f+16|0)|0)>159){break d}i[f+12>>2]=c+4;i[c>>2]=i[f+8>>2]}i[114610]=0;k=+aa(2442,a|0,i[f+180>>2],d|0);a=i[114610];i[114610]=0;e:{if((a|0)==1){break e}n[e>>3]=k;i[114610]=0;je(f+200|0,f+16|0,i[f+12>>2],d);a=i[114610];i[114610]=0;if((a|0)==1){break e}i[114610]=0;a=C(2455,f+360|0,f+352|0)|0;c=i[114610];i[114610]=0;if((c|0)==1){break e}if(a){i[d>>2]=i[d>>2]|2}a=i[f+360>>2];eb(b);eb(f+200|0);Xa=f+368|0;return a}}a=B()|0;A()|0;eb(b);eb(f+200|0);E(a|0);x()}function V1(a,b,c,d,e){var f=0,h=0,k=0;f=Xa-272|0;Xa=f;i[f+256>>2]=b;i[f+264>>2]=a;Mu(f+208|0,c,f+224|0,f+223|0,f+222|0);b=Ab(f+192|0);a=qc(b);i[114610]=0;D(149,b|0,a|0);a=i[114610];i[114610]=0;a:{b:{if((a|0)!=1){a=Sb(b,0);i[f+188>>2]=a;i[f+12>>2]=f+16;i[f+8>>2]=0;g[f+7|0]=1;g[f+6|0]=69;while(1){c:{i[114610]=0;c=C(2422,f+264|0,f+256|0)|0;h=i[114610];i[114610]=0;if((h|0)==1){break c}if(!c){break b}if(i[f+188>>2]==(lb(b)+a|0)){c=lb(b);a=lb(b);i[114610]=0;D(149,b|0,a<<1);a=i[114610];i[114610]=0;if((a|0)==1){break a}a=qc(b);i[114610]=0;D(149,b|0,a|0);a=i[114610];i[114610]=0;if((a|0)==1){break a}a=Sb(b,0);i[f+188>>2]=c+a}i[114610]=0;c=F(2424,f+264|0)|0;h=i[114610];i[114610]=0;if((h|0)==1){break c}i[114610]=0;c=sq(c,f+7|0,f+6|0,a,f+188|0,g[f+223|0],g[f+222|0],f+208|0,f+16|0,f+12|0,f+8|0,f+224|0);h=i[114610];i[114610]=0;if((h|0)==1){break c}if(c){break b}i[114610]=0;F(2426,f+264|0)|0;c=i[114610];i[114610]=0;if((c|0)!=1){continue}}break}break a}break a}d:{if(!lb(f+208|0)|!j[f+7|0]){break d}c=i[f+12>>2];if((c-(f+16|0)|0)>159){break d}i[f+12>>2]=c+4;i[c>>2]=i[f+8>>2]}i[114610]=0;k=+aa(2442,a|0,i[f+188>>2],d|0);a=i[114610];i[114610]=0;e:{if((a|0)==1){break e}n[e>>3]=k;i[114610]=0;je(f+208|0,f+16|0,i[f+12>>2],d);a=i[114610];i[114610]=0;if((a|0)==1){break e}i[114610]=0;a=C(2423,f+264|0,f+256|0)|0;c=i[114610];i[114610]=0;if((c|0)==1){break e}if(a){i[d>>2]=i[d>>2]|2}a=i[f+264>>2];eb(b);eb(f+208|0);Xa=f+272|0;return a}}a=B()|0;A()|0;eb(b);eb(f+208|0);E(a|0);x()}function gJ(a,b){var c=0,d=0,e=0,f=0,l=0,m=0,n=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;c=Xa-16|0;Xa=c;d=o(b,896)+a|0;a:{if(i[d+1075072>>2]&134218752){break a}if(!Pi(d+1074984|0)){break a}m=i[(o(b,896)+a|0)+1075640>>2];if(j[m+15|0]&2){break a}d=ym(a,b,2,1);if(d+ -251>>>0<5|!d){break a}l=i[(o(d,160)+a|0)+906140>>2];if(!l){break a}e=o(b,896)+a|0;d=j[e+1075794|0];b:{if(j[e+1075796|0]==1){g[c+8|0]=64;f=j[Xb(e+1075798|0,c+8|0)|0];break b}f=255;if(j[e+1075797|0]!=13){break b}g[c+8|0]=64;f=j[Xb((o(b,896)+a|0)+1075799|0,c+8|0)|0]}p=a+1074308|0;kb(c+8|0,p,2);if(ib(c+8|0)){if(d){e=a;f=b;if(Jd(d)){d=j[Nb(m+108|0,d+ -1|0)|0]}Kj(e,f,d,k[(o(b,896)+a|0)+1075672>>1]);break a}if((f|0)==255){break a}$a[i[i[l>>2]+76>>2]](l,39,f,b);break a}q=i[m+4>>2];if(d){e=q<<2;i[c+4>>2]=e;if(!j[m+35|0]){e=i[(o(b,896)+a|0)+1075672>>2];i[c+4>>2]=e}n=h[(o(b,896)+a|0)+1075772>>1];kb(c+8|0,p,28);r=c,s=(ib(c+8|0)?n<<2:n)+e|0,i[r+4>>2]=s;Kd(c+4|0,0,256);e=d;n=b;if(Jd(d)){e=j[Nb(m+108|0,d+ -1|0)|0]}Kj(a,n,e&255,k[c+4>>1])}e=j[m+35|0];kb(c+8|0,p,101);a=(d|0)!=0;c:{if(ib(c+8|0)){break c}a=Jd(d)}a=a^1;if(a|(e|0)!=1?!(a&(f|0)!=255):0){break a}d:{switch(j[m+36|0]){case 1:if((f|0)!=255){zH(l,f<<1);break a}zH(l,q<<1);break a;case 0:break d;default:break a}}if((f|0)!=255){g[c+8|0]=127;g[c+4|0]=f<<1;s=l,t=7,u=j[Xb(c+8|0,c+4|0)|0],v=b,r=i[i[l>>2]+76>>2],$a[r](s|0,t|0,u|0,v|0);break a}i[c+8>>2]=127;i[c+4>>2]=q<<1;v=l,u=7,t=j[rb(c+8|0,c+4|0)|0],s=b,r=i[i[l>>2]+76>>2],$a[r](v|0,u|0,t|0,s|0)}Xa=c+16|0}function cx(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;h=92;i=91;j=85;k=84;l=83;m=5;n=107;o=106;p=96;c=88;q=82;r=80;s=78;t=79;u=77;v=57;w=47;d=10;e=8;f=7;a=gx(a);a:{b:{c:{d:{switch(b+ -1|0){default:c=(b|0)==16777216;if((b|0)!=32?!c:0){break c}tb(a,0,1);tb(a,7,1);tb(a,8,1);tb(a,9,1);tb(a,10,1);tb(a,11,1);tb(a,12,1);tb(a,13,1);tb(a,14,1);tb(a,15,1);tb(a,16,1);tb(a,17,1);tb(a,18,1);tb(a,19,1);tb(a,20,1);tb(a,21,1);tb(a,22,1);tb(a,23,1);tb(a,24,1);tb(a,25,1);tb(a,26,1);tb(a,27,1);tb(a,28,1);tb(a,29,1);tb(a,30,1);tb(a,31,1);tb(a,32,1);tb(a,33,1);tb(a,34,1);tb(a,35,1);tb(a,36,1);tb(a,37,1);tb(a,38,1);tb(a,39,1);tb(a,40,1);tb(a,41,1);tb(a,42,1);tb(a,43,1);tb(a,44,1);tb(a,45,1);tb(a,46,1);tb(a,47,1);tb(a,48,1);tb(a,103,1);tb(a,50,1);tb(a,87,1);tb(a,88,1);tb(a,100,1);tb(a,102,1);tb(a,104,1);if(!c){break a}d=108;e=105;f=99;break b;case 3:tb(a,0,1);tb(a,4,1);tb(a,8,1);tb(a,9,1);tb(a,10,1);tb(a,17,1);tb(a,40,1);tb(a,51,1);tb(a,52,1);tb(a,53,1);tb(a,54,1);tb(a,55,1);tb(a,56,1);tb(a,57,1);tb(a,58,1);tb(a,59,1);tb(a,60,1);tb(a,61,1);tb(a,62,1);tb(a,63,1);tb(a,64,1);tb(a,65,1);tb(a,66,1);tb(a,67,1);tb(a,68,1);n=98;o=93;p=90;c=89;q=88;r=86;s=76;t=75;u=74;v=73;w=72;d=71;e=70;g=69;case 1:tb(a,g,1);tb(a,e,1);tb(a,d,1);tb(a,w,1);tb(a,v,1);tb(a,u,1);tb(a,t,1);m=s;l=r;k=q;j=c;i=p;h=o;c=n;break;case 2:break c;case 0:break d}}tb(a,m,1);tb(a,l,1);tb(a,k,1);g=j;f=i;e=h;d=c}tb(a,g,1)}tb(a,f,1);tb(a,e,1);tb(a,d,1)}}function bsa(a){var b=0,c=0,d=0,e=0;b=Xa-400|0;Xa=b;yL(b+384|0,8);i[114610]=0;da(1211,b+368|0,9);e=i[114610];i[114610]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{if((e|0)!=1){i[114610]=0;e=C(1212,b+352|0,14)|0;c=i[114610];i[114610]=0;if((c|0)==1){break k}i[114610]=0;D(1213,b+384|0,e|0);c=i[114610];i[114610]=0;if((c|0)==1){break j}i[114610]=0;D(1213,b+368|0,e|0);c=i[114610];i[114610]=0;if((c|0)==1){break j}xL(b+280|0,4900);xL(b+208|0,32e3);uL(b+136|0,8377175819504598e-21,16754351639009197e-21,8377175819504598e-21,-1.991112714669597,.9911462233728751);i[114610]=0;c=C(1214,b+104|0,b+384|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break i}as(b+120|0,b+280|0,c);pf(c);i[114610]=0;c=C(1214,b+72|0,b+368|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break h}as(b+88|0,b+208|0,c);pf(c);i[114610]=0;c=C(1214,b+40|0,b+120|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break g}as(b+56|0,b+136|0,c);pf(c);i[114610]=0;c=C(1214,b+8|0,b+88|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break f}as(b+24|0,b+136|0,c);pf(c);Io(b+120|0);Io(b+56|0);Io(b+88|0);Io(b+24|0);Io(b+368|0);Ho(b+120|0,Yh(a,0));Ho(b+56|0,Yh(a,1));Ho(b+88|0,Yh(a,2));Ho(b+24|0,Yh(a,3));Ho(b+368|0,Yh(a,4));pf(b+24|0);pf(b+56|0);pf(b+88|0);pf(b+120|0);Go(e);pf(b+368|0);pf(b+384|0);Xa=b+400|0;return}a=B()|0;A()|0;break a}a=B()|0;A()|0;break b}a=B()|0;A()|0;break c}a=B()|0;A()|0;break c}a=B()|0;A()|0;break d}a=B()|0;A()|0;break e}a=B()|0;A()|0;pf(b+56|0)}pf(b+88|0)}pf(b+120|0)}Go(e)}pf(b+368|0)}pf(b+384|0);E(a|0);x()}function Tea(a){var b=0,c=0,d=p(0),e=p(0),f=0,g=p(0),h=0,j=p(0),k=0,l=p(0),n=0;f=Xa-16|0;Xa=f;g=m[a+4268>>2];d=p(m[a+4232>>2]*p(.30000001192092896));m[f+12>>2]=m[a+4240>>2]*p(.10000000149011612);i[f+8>>2]=1000593162;b=a;j=m[jw(f+12|0,f+8|0)>>2];e=p(g*p(p(d+p(.007000000216066837))+j));a:{if(p(q(e))<p(2147483648)){c=~~e;break a}c=-2147483648}i[b+4352>>2]=c;b=1;while(1){h=((o(b&1,24)+a|0)+(b<<1&-4)|0)+4352|0;e=p(p(p(m[(b<<2)+33552>>2]*j)+d)*g);b:{if(p(q(e))<p(2147483648)){c=~~e;break b}c=-2147483648}i[h>>2]=c;b=b+1|0;if((b|0)!=12){continue}break}m[f+12>>2]=p(p(m[a+4248>>2]*p(100))*p(.009091000072658062))+p(.09091000258922577);i[f+8>>2]=1065353216;d=p(m[Sk(f+12|0,f+8|0)>>2]*g);j=p(d*p(.07500000298023224));d=p(d*p(.06700000166893005));b=0;while(1){c=(b<<2)+a|0;n=c+4316|0;k=b+k|0;e=Wd(p(.9300000071525574),p(k|0));l=p(j*e);c:{if(p(q(l))<p(2147483648)){h=~~l;break c}h=-2147483648}i[n>>2]=h;h=c+4292|0;e=p(d*e);d:{if(p(q(e))<p(2147483648)){c=~~e;break d}c=-2147483648}i[h>>2]=c;b=b+1|0;if((b|0)!=6){continue}break}c=a+4348|0;d=p(g*p(.0035299998708069324));e:{if(p(q(d))<p(2147483648)){b=~~d;break e}b=-2147483648}i[c>>2]=b;c=a+4344|0;d=p(g*p(.0032500000670552254));f:{if(p(q(d))<p(2147483648)){b=~~d;break f}b=-2147483648}i[c>>2]=b;c=a+4340|0;g=p(g*p(.009999999776482582));g:{if(p(q(g))<p(2147483648)){b=~~g;break g}b=-2147483648}i[c>>2]=b;b=0;while(1){cH((o(b,24)+a|0)+4504|0,i[((b<<2)+a|0)+4292>>2]);b=b+1|0;if(b>>>0<15){continue}break}Xa=f+16|0}function Pua(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0;k=Xa-16|0;Xa=k;f=i[a+48>>2];p=i[a+40>>2];q=i[a+36>>2];e=i[a+44>>2];t=i[a+16>>2];g=i[a+4>>2];l=i[a>>2];i[k+8>>2]=l;i[k+12>>2]=g;j=i[a+12>>2];i[k>>2]=i[a+8>>2];i[k+4>>2]=j;a:{if(!d){m=p>>12;r=q>>12;break a}while(1){j=(g<<1)+t|0;m=h[j+ -6>>1];g=(((l>>>16|0)+4&131064)<<1)+b|0;l=h[g+24>>1];r=h[j+ -4>>1];u=h[g+26>>1];v=h[j+ -2>>1];w=h[g+28>>1];x=h[j>>1];y=h[g+30>>1];z=h[j+2>>1];A=h[g+32>>1];B=h[j+4>>1];C=h[g+34>>1];D=h[j+6>>1];E=h[g+36>>1];F=h[j+8>>1];G=h[g+38>>1];j=i[a+60>>2];H=j;I=j>>31;j=e;e=Eb(e,-16777216,16776704);n=i[a+64>>2];f=Eb(f,-16777216,16776704);J=i[a+72>>2];K=i[a+32>>2];g=c;L=i[g>>2];e=XMa(n,n>>31,e,e>>31);n=_a;M=e;e=i[a+68>>2];s=XMa(e,e>>31,f,f>>31);e=M+s|0;f=_a+n|0;f=e>>>0<s>>>0?f+1|0:f;n=e;l=(((((o(B,C)+o(z,A)|0)+o(D,E)|0)+o(F,G)|0)/2|0)+((((o(r,u)+o(l,m)|0)+o(v,w)|0)+o(x,y)|0)/2|0)|0)/16384<<8;e=l;m=XMa(H,I,e,e>>31);e=n+m|0;f=_a+f|0;f=e>>>0<m>>>0?f+1|0:f;e=e+8388608|0;if(e>>>0<8388608){f=f+1|0}e=(f&16777215)<<8|e>>>24;f=(e|0)/256|0;q=i[a+28>>2]+q|0;r=q>>12;i[g>>2]=o(f,r)+L;p=p+K|0;m=p>>12;i[c+4>>2]=i[c+4>>2]+o(f,m);e=e-(l&J)|0;zb(k+8|0,k);d=d+ -1|0;if(d){c=c+8|0;l=i[k+8>>2];g=i[k+12>>2];f=j;continue}break}l=i[k+8>>2];g=i[k+12>>2];f=j}i[a+40>>2]=p;i[a+20>>2]=r;i[a+36>>2]=q;i[a+48>>2]=f;i[a+44>>2]=e;i[a+24>>2]=m;i[a>>2]=l;i[a+4>>2]=g;Xa=k+16|0}function Eua(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,h=0,j=0,k=0,l=0,m=0,n=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;f=Xa-48|0;Xa=f;p=i[a+16>>2];j=tf(f+16|0);i[j+8>>2]=a+112;i[j+16>>2]=i[a+128>>2];v=j,w=of(b+327720|0,i[b+20>>2],(i[a+88>>2]&16384)>>>14|0),i[v+12>>2]=w;b=i[j+16>>2];if(b){v=j,w=sf(a+8|0,b),i[v>>2]=w;i[j+4>>2]=_a}k=i[a+48>>2];q=i[a+24>>2];r=i[a+20>>2];m=i[a+44>>2];e=i[a+4>>2];h=i[a>>2];i[f+8>>2]=h;i[f+12>>2]=e;b=i[a+12>>2];i[f>>2]=i[a+8>>2];i[f+4>>2]=b;a:{if(!d){b=m;m=k;break a}while(1){b=0;l=b;i[f+40>>2]=h;i[f+44>>2]=b;e=e+p|0;b:{b=i[j+16>>2];if((b|0)<=0){break b}while(1){fd(i[j+8>>2],g[e+l|0]<<6);ed(i[j+8>>2],4);zb(f+40|0,j);if((b|0)<2){break b}b=b+ -1|0;l=i[f+44>>2];continue}}d=d+ -1|0;b=i[j+8>>2];zb(b,b+8|0);b=i[j+8>>2];h=i[b+4>>2];if(h){fd(b,g[e+i[f+44>>2]|0]<<6);ed(i[j+8>>2],h);b=i[j+8>>2];h=i[b>>2];i[b>>2]=h;i[b+4>>2]=0}e=nf(b,i[j+12>>2]);h=i[a+60>>2];l=h;b=Eb(m,-16777216,16776704);n=i[a+64>>2];k=Eb(k,-16777216,16776704);s=i[a+72>>2];t=i[c>>2];u=h>>31;h=e<<8;e=h;e=XMa(l,u,e,e>>31);l=_a;n=XMa(n,n>>31,b,b>>31);e=n+e|0;b=_a+l|0;b=e>>>0<n>>>0?b+1|0:b;l=e;e=i[a+68>>2];e=XMa(e,e>>31,k,k>>31);k=l+e|0;b=_a+b|0;b=k>>>0<e>>>0?b+1|0:b;k=k+8388608|0;if(k>>>0<8388608){b=b+1|0}b=(b&16777215)<<8|k>>>24;k=(b|0)/256|0;i[c>>2]=o(k,r)+t;i[c+4>>2]=i[c+4>>2]+o(k,q);b=b-(h&s)|0;zb(f+8|0,f);if(d){c=c+8|0;h=i[f+8>>2];e=i[f+12>>2];k=m;m=b;continue}break}h=i[f+8>>2];e=i[f+12>>2]}i[a+48>>2]=m;i[a+44>>2]=b;i[a>>2]=h;i[a+4>>2]=e;Xa=f+48|0}function Qua(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,j=0,k=0,l=0,m=0,n=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0;l=Xa-16|0;Xa=l;f=i[a+48>>2];q=i[a+40>>2];r=i[a+36>>2];e=i[a+44>>2];u=i[a+16>>2];j=i[a+4>>2];m=i[a>>2];i[l+8>>2]=m;i[l+12>>2]=j;k=i[a+12>>2];i[l>>2]=i[a+8>>2];i[l+4>>2]=k;a:{if(!d){n=q>>12;s=r>>12;break a}while(1){k=j+u|0;n=g[k+ -3|0];j=(((m>>>16|0)+4&131064)<<1)+b|0;m=h[j+24>>1];s=g[k+ -2|0];v=h[j+26>>1];w=g[k+ -1|0];x=h[j+28>>1];y=g[k|0];z=h[j+30>>1];A=g[k+1|0];B=h[j+32>>1];C=g[k+2|0];D=h[j+34>>1];E=g[k+3|0];F=h[j+36>>1];G=g[k+4|0];H=h[j+38>>1];k=i[a+60>>2];I=k;J=k>>31;k=e;e=Eb(e,-16777216,16776704);p=i[a+64>>2];f=Eb(f,-16777216,16776704);K=i[a+72>>2];L=i[a+32>>2];j=c;M=i[j>>2];e=XMa(p,p>>31,e,e>>31);p=_a;N=e;e=i[a+68>>2];t=XMa(e,e>>31,f,f>>31);e=N+t|0;f=_a+p|0;f=e>>>0<t>>>0?f+1|0:f;p=e;m=(((((o(C,D)+o(A,B)|0)+o(E,F)|0)+o(G,H)<<8)/2|0)+((((o(s,v)+o(m,n)|0)+o(w,x)|0)+o(y,z)<<8)/2|0)|0)/16384<<8;e=m;n=XMa(I,J,e,e>>31);e=p+n|0;f=_a+f|0;f=e>>>0<n>>>0?f+1|0:f;e=e+8388608|0;if(e>>>0<8388608){f=f+1|0}e=(f&16777215)<<8|e>>>24;f=(e|0)/256|0;r=i[a+28>>2]+r|0;s=r>>12;i[j>>2]=o(f,s)+M;q=q+L|0;n=q>>12;i[c+4>>2]=i[c+4>>2]+o(f,n);e=e-(m&K)|0;zb(l+8|0,l);d=d+ -1|0;if(d){c=c+8|0;m=i[l+8>>2];j=i[l+12>>2];f=k;continue}break}m=i[l+8>>2];j=i[l+12>>2];f=k}i[a+40>>2]=q;i[a+20>>2]=s;i[a+36>>2]=r;i[a+48>>2]=f;i[a+44>>2]=e;i[a+24>>2]=n;i[a>>2]=m;i[a+4>>2]=j;Xa=l+16|0}function awa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;b=Xa-48|0;Xa=b;v=i[a+16>>2];l=i[a+44>>2];i[b+32>>2]=l;n=i[a+48>>2];i[b+36>>2]=n;g=i[a+52>>2];i[b+40>>2]=g;j=i[a+56>>2];i[b+44>>2]=j;p=i[a+40>>2];q=i[a+36>>2];e=i[a+4>>2];k=i[a>>2];i[b+24>>2]=k;i[b+28>>2]=e;f=i[a+12>>2];i[b+16>>2]=i[a+8>>2];i[b+20>>2]=f;a:{if(!d){m=p>>12;f=q>>12;break a}while(1){e=((((e&2147483647)<<1|k>>>31)&2147483646)<<1)+v|0;j=h[e>>1];i[b+8>>2]=j;i[b+12>>2]=h[e+2>>1];f=0;n=1;while(1){g=i[a+60>>2];m=g;k=(b+32|0)+(f<<3)|0;r=i[k>>2];e=Eb(r,-16777216,16776704);u=i[a+64>>2];l=Eb(i[k+4>>2],-16777216,16776704);s=i[a+68>>2];w=s;s=s>>31;i[k+4>>2]=r;r=i[a+72>>2];t=g>>31;j=j<<8;g=j;g=XMa(m,t,g,g>>31);m=_a;t=(b+8|0)+(f<<2)|0;f=g;g=XMa(u,u>>31,e,e>>31);f=f+g|0;e=_a+m|0;e=f>>>0<g>>>0?e+1|0:e;l=XMa(w,s,l,l>>31);f=l+f|0;e=_a+e|0;e=f>>>0<l>>>0?e+1|0:e;f=f+8388608|0;if(f>>>0<8388608){e=e+1|0}e=(e&16777215)<<8|f>>>24;i[t>>2]=(e|0)/256;i[k>>2]=e-(j&r);if(n){f=1;n=0;j=i[b+12>>2];continue}break}e=i[a+32>>2];q=i[a+28>>2]+q|0;f=q>>12;i[c>>2]=i[c>>2]+o(f,i[b+8>>2]);p=e+p|0;m=p>>12;i[c+4>>2]=i[c+4>>2]+o(m,i[b+12>>2]);zb(b+24|0,b+16|0);d=d+ -1|0;if(d){c=c+8|0;k=i[b+24>>2];e=i[b+28>>2];continue}break}k=i[b+24>>2];e=i[b+28>>2];j=i[b+44>>2];g=i[b+40>>2];n=i[b+36>>2];l=i[b+32>>2]}i[a+40>>2]=p;i[a+20>>2]=f;i[a+36>>2]=q;i[a+56>>2]=j;i[a+52>>2]=g;i[a+48>>2]=n;i[a+44>>2]=l;i[a+24>>2]=m;i[a>>2]=k;i[a+4>>2]=e;Xa=b+48|0}function J1(a,b,c,d,e){var f=0,g=0,h=0,j=0;f=Xa-352|0;Xa=f;i[f+336>>2]=b;i[f+344>>2]=a;h=Cg(c);j=Vl(c,f+224|0);Ul(f+208|0,c,f+332|0);a=Ab(f+192|0);b=qc(a);i[114610]=0;D(149,a|0,b|0);b=i[114610];i[114610]=0;a:{b:{if((b|0)!=1){b=Sb(a,0);i[f+188>>2]=b;i[f+12>>2]=f+16;i[f+8>>2]=0;while(1){c:{i[114610]=0;c=C(2454,f+344|0,f+336|0)|0;g=i[114610];i[114610]=0;if((g|0)==1){break c}if(!c){break b}if(i[f+188>>2]==(lb(a)+b|0)){c=lb(a);b=lb(a);i[114610]=0;D(149,a|0,b<<1);b=i[114610];i[114610]=0;if((b|0)==1){break a}b=qc(a);i[114610]=0;D(149,a|0,b|0);b=i[114610];i[114610]=0;if((b|0)==1){break a}b=Sb(a,0);i[f+188>>2]=c+b}i[114610]=0;c=F(2456,f+344|0)|0;g=i[114610];i[114610]=0;if((g|0)==1){break c}i[114610]=0;c=uj(c,h,b,f+188|0,f+8|0,i[f+332>>2],f+208|0,f+16|0,f+12|0,j);g=i[114610];i[114610]=0;if((g|0)==1){break c}if(c){break b}i[114610]=0;F(2458,f+344|0)|0;c=i[114610];i[114610]=0;if((c|0)!=1){continue}}break}break a}break a}d:{if(!lb(f+208|0)){break d}c=i[f+12>>2];if((c-(f+16|0)|0)>159){break d}i[f+12>>2]=c+4;i[c>>2]=i[f+8>>2]}i[114610]=0;b=Hn(2433,b,i[f+188>>2],d,h);c=_a;h=i[114610];i[114610]=0;e:{if((h|0)==1){break e}i[e>>2]=b;i[e+4>>2]=c;i[114610]=0;je(f+208|0,f+16|0,i[f+12>>2],d);b=i[114610];i[114610]=0;if((b|0)==1){break e}i[114610]=0;b=C(2455,f+344|0,f+336|0)|0;c=i[114610];i[114610]=0;if((c|0)==1){break e}if(b){i[d>>2]=i[d>>2]|2}b=i[f+344>>2];eb(a);eb(f+208|0);Xa=f+352|0;return b}}b=B()|0;A()|0;eb(a);eb(f+208|0);E(b|0);x()}function A1(a,b,c,d,e){var f=0,g=0,h=0,j=0;f=Xa-352|0;Xa=f;i[f+336>>2]=b;i[f+344>>2]=a;h=Cg(c);j=Vl(c,f+224|0);Ul(f+208|0,c,f+332|0);a=Ab(f+192|0);b=qc(a);i[114610]=0;D(149,a|0,b|0);b=i[114610];i[114610]=0;a:{b:{if((b|0)!=1){b=Sb(a,0);i[f+188>>2]=b;i[f+12>>2]=f+16;i[f+8>>2]=0;while(1){c:{i[114610]=0;c=C(2454,f+344|0,f+336|0)|0;g=i[114610];i[114610]=0;if((g|0)==1){break c}if(!c){break b}if(i[f+188>>2]==(lb(a)+b|0)){c=lb(a);b=lb(a);i[114610]=0;D(149,a|0,b<<1);b=i[114610];i[114610]=0;if((b|0)==1){break a}b=qc(a);i[114610]=0;D(149,a|0,b|0);b=i[114610];i[114610]=0;if((b|0)==1){break a}b=Sb(a,0);i[f+188>>2]=c+b}i[114610]=0;c=F(2456,f+344|0)|0;g=i[114610];i[114610]=0;if((g|0)==1){break c}i[114610]=0;c=uj(c,h,b,f+188|0,f+8|0,i[f+332>>2],f+208|0,f+16|0,f+12|0,j);g=i[114610];i[114610]=0;if((g|0)==1){break c}if(c){break b}i[114610]=0;F(2458,f+344|0)|0;c=i[114610];i[114610]=0;if((c|0)!=1){continue}}break}break a}break a}d:{if(!lb(f+208|0)){break d}c=i[f+12>>2];if((c-(f+16|0)|0)>159){break d}i[f+12>>2]=c+4;i[c>>2]=i[f+8>>2]}i[114610]=0;b=Hn(2437,b,i[f+188>>2],d,h);c=_a;h=i[114610];i[114610]=0;e:{if((h|0)==1){break e}i[e>>2]=b;i[e+4>>2]=c;i[114610]=0;je(f+208|0,f+16|0,i[f+12>>2],d);b=i[114610];i[114610]=0;if((b|0)==1){break e}i[114610]=0;b=C(2455,f+344|0,f+336|0)|0;c=i[114610];i[114610]=0;if((c|0)==1){break e}if(b){i[d>>2]=i[d>>2]|2}b=i[f+344>>2];eb(a);eb(f+208|0);Xa=f+352|0;return b}}b=B()|0;A()|0;eb(a);eb(f+208|0);E(b|0);x()}function bla(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,i=0,l=0,m=0,n=0,p=0,q=0,r=0,s=0,t=0,u=0;f=Xa-16|0;Xa=f;a:{if(Ms(a)){break a}q=d+484344|0;m=hd(id(a)+1|0,1,1024);if(!Sf(q,b,m)){break a}d=k[d+480188>>1];if(!d|!m){break a}r=d+ -1|0;while(1){if(!wb(a,1)){break a}i=id(a);b:{if(!i){n=n+1|0;break b}d=Fb(q,b);h[f+14>>1]=i&31;h[f+12>>1]=r;d=Qe(d,n,k[ef(f+14|0,f+12|0)>>1]);if(!(i&224)){break b}c:{if(!(i&128)){break c}t=d,u=id(a),g[t+5|0]=u;d:{e=id(a);if(e>>>0>=26){break d}e=j[e+31808|0];g[d+3|0]=e;e:{switch(e+ -1|0){case 0:if(!j[d+5|0]){break d}break c;case 12:if(j[d+2|0]){break c}g[d+2|0]=1;e=hd(j[d+5|0],0,64);g[d+5|0]=0;g[d+3|0]=0;g[d+4|0]=e;break c;case 5:case 6:case 10:case 23:case 28:e=j[d+5|0]&240;if(!e){break c}g[d+5|0]=e;break c;case 8:e=j[d+5|0];if(e>>>0<=128){t=d,u=_i(e<<1),g[t+5|0]=u;break c}if((e|0)!=164){break c}g[d+5|0]=145;g[d+3|0]=20;break c;case 13:e=j[d+5|0];g[d+5|0]=o(e>>>4|0,10)+(e&15);break c;case 18:Fw(d);break c;case 16:if(j[d+5|0]>31){break c}g[d+3|0]=16;break c;case 27:break e;default:break c}}s=d;e=j[d+5|0];l=e&240;p=2;f:{g:{if((l|0)==16){break g}if((l|0)!=32){break f}p=3}g[s+3|0]=p}g[d+5|0]=e&15|224;break c}g[d+3|0]=0}h:{if(!(i&64)){break h}rt(f+8|0,a);e=Nc(f+8|0);g[d+1|0]=j[f+8|0];e=j[e|0];g[d|0]=e;l=255;if((e|0)!=128){l=253;if(e>>>0<129){break h}}g[d|0]=l}if(!(i&32)){break b}g[d+2|0]=1;e=id(a);g[d+4|0]=e;if(!c){break b}g[d+4|0]=(e<<6>>>0)/127}if(n>>>0<m>>>0){continue}break}}Xa=f+16|0}function tCa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,l=0,m=0,n=0,o=0,p=0;e=Xa-16|0;Xa=e;a:{if((c|0)!=4){l=b+236|0;m=b+108|0;while(1){f=(d<<2)+a|0;n=j[f+4|0];o=Nb(m,d),p=n+1|0,g[o|0]=p;f=f+6|0;f=j[f|0]|j[f+1|0]<<8;o=Mc(l,d),p=f+1|0,h[o>>1]=p;d=d+1|0;if((d|0)!=120){continue}break}break a}l=b+236|0;while(1){m=((d<<2)+a|0)+6|0;m=j[m|0]|j[m+1|0]<<8;o=Mc(l,d+12|0),p=m+1|0,h[o>>1]=p;d=d+1|0;if((d|0)!=96){continue}break}}yy(a+484|0,b+48|0,0);yy(a+590|0,b+68|0,0);yy(a+696|0,b+88|0,5);d=a+806|0;i[b>>2]=j[d|0]|j[d+1|0]<<8;d=a+808|0;l=j[d|0];b:{if(g[d|0]<=-1){g[b+34|0]=l+ -127;break b}if(!(!(g[a|0]&1)|l>>>0>16)){g[b+31|0]=j[d|0]+1;break b}if(!j[d|0]|j[d|0]>16){break b}g[b+31|0]=j[d|0]+1}if(j[b+31|0]){c:{d:{if((c|0)==4){d=a+810|0;break d}d=a+809|0;if(g[d|0]>=0){h[b+28>>1]=j[d|0]+1}d=a+810|0;if(g[d|0]<0){break c}}g[b+30|0]=j[d|0]+1}g[b+33|0]=j[a+811|0]}if((c|0)==32){g[e+15|0]=j[a+812|0];g[e+14|0]=128;o=b,p=j[Xb(e+15|0,e+14|0)|0]>>>1|0,i[o+4>>2]=p}c=a+813|0;if((j[c|0]|j[c+1|0]<<8)>>>0<=256){i[b+8>>2]=j[c|0]|j[c+1|0]<<8;g[b+15|0]=j[b+15|0]|1}g[b+16|0]=j[a+815|0];g[b+26|0]=j[a+816|0];g[b+27|0]=j[a+817|0];g[b+17|0]=j[a+818|0];g[b+18|0]=j[a+819|0];c=a+820|0;h[e+12>>1]=j[c|0]|j[c+1|0]<<8;h[e+10>>1]=100;o=b,p=j[ef(e+12|0,e+10|0)|0],g[o+20|0]=p;c=a+822|0;h[e+8>>1]=j[c|0]|j[c+1|0]<<8;h[e+6>>1]=256;o=b,p=k[ef(e+8|0,e+6|0)>>1]>>>2|0,g[o+19|0]=p;c=a+824|0;At(b,j[c|0]&127,j[c|0]>>>7|0);a=a+825|0;zt(b,j[a|0]&127,j[a|0]>>>7|0);Xa=e+16|0}function bwa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,h=0,j=0,k=0,l=0,m=0,n=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;b=Xa-48|0;Xa=b;v=i[a+16>>2];l=i[a+44>>2];i[b+32>>2]=l;n=i[a+48>>2];i[b+36>>2]=n;h=i[a+52>>2];i[b+40>>2]=h;j=i[a+56>>2];i[b+44>>2]=j;p=i[a+40>>2];q=i[a+36>>2];e=i[a+4>>2];k=i[a>>2];i[b+24>>2]=k;i[b+28>>2]=e;f=i[a+12>>2];i[b+16>>2]=i[a+8>>2];i[b+20>>2]=f;a:{if(!d){m=p>>12;f=q>>12;break a}while(1){e=(((e&2147483647)<<1|k>>>31)&-2)+v|0;j=g[e|0]<<8;i[b+8>>2]=j;i[b+12>>2]=g[e+1|0]<<8;f=0;n=1;while(1){h=i[a+60>>2];m=h;k=(b+32|0)+(f<<3)|0;r=i[k>>2];e=Eb(r,-16777216,16776704);u=i[a+64>>2];l=Eb(i[k+4>>2],-16777216,16776704);s=i[a+68>>2];w=s;s=s>>31;i[k+4>>2]=r;r=i[a+72>>2];t=h>>31;j=j<<8;h=j;h=XMa(m,t,h,h>>31);m=_a;t=(b+8|0)+(f<<2)|0;f=h;h=XMa(u,u>>31,e,e>>31);f=f+h|0;e=_a+m|0;e=f>>>0<h>>>0?e+1|0:e;l=XMa(w,s,l,l>>31);f=l+f|0;e=_a+e|0;e=f>>>0<l>>>0?e+1|0:e;f=f+8388608|0;if(f>>>0<8388608){e=e+1|0}e=(e&16777215)<<8|f>>>24;i[t>>2]=(e|0)/256;i[k>>2]=e-(j&r);if(n){f=1;n=0;j=i[b+12>>2];continue}break}e=i[a+32>>2];q=i[a+28>>2]+q|0;f=q>>12;i[c>>2]=i[c>>2]+o(f,i[b+8>>2]);p=e+p|0;m=p>>12;i[c+4>>2]=i[c+4>>2]+o(m,i[b+12>>2]);zb(b+24|0,b+16|0);d=d+ -1|0;if(d){c=c+8|0;k=i[b+24>>2];e=i[b+28>>2];continue}break}k=i[b+24>>2];e=i[b+28>>2];j=i[b+44>>2];h=i[b+40>>2];n=i[b+36>>2];l=i[b+32>>2]}i[a+40>>2]=p;i[a+20>>2]=f;i[a+36>>2]=q;i[a+56>>2]=j;i[a+52>>2]=h;i[a+48>>2]=n;i[a+44>>2]=l;i[a+24>>2]=m;i[a>>2]=k;i[a+4>>2]=e;Xa=b+48|0}function asa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0;d=Xa-48|0;Xa=d;e=wL(d+32|0,1<<i[b+12>>2]);if(bg(a)){while(1){g=n[uk(a,c)>>3];vL(_b(e,c),g);c=c+1|0;if(c>>>0<bg(a)>>>0){continue}break}}i[114610]=0;D(1216,b|0,e|0);c=i[114610];i[114610]=0;a:{if((c|0)==1){break a}h=d,j=Jb(e),i[h>>2]=j;h=d,j=Kb(e),i[h+24>>2]=j;b:{if(pb(d,d+24|0)){while(1){c=i[d>>2];i[114610]=0;g=+Z(1217,c|0);f=i[114610];i[114610]=0;if((f|0)==1){break b}vL(c,Vn(g));vf(d);if(pb(d,d+24|0)){continue}break}}i[114610]=0;D(1218,b|0,e|0);c=i[114610];i[114610]=0;if((c|0)==1){break a}i[114610]=0;L(1219,e|0);c=i[114610];i[114610]=0;if((c|0)==1){break a}if(Wc(e)>>>0>3){c=1;while(1){Ex(_b(e,c),2);Ex(_b(e,(Wc(e)>>>1|0)+c|0),0);c=c+1|0;if(c>>>0<Wc(e)>>>1>>>0){continue}break}}i[114610]=0;D(1216,b|0,e|0);c=i[114610];i[114610]=0;if((c|0)==1){break a}h=d,j=Jb(e),i[h+24>>2]=j;h=d,j=Kb(e),i[h+16>>2]=j;if(pb(d+24|0,d+16|0)){while(1){c=i[d+24>>2];i[114610]=0;D(1220,d|0,c|0);f=i[114610];i[114610]=0;if((f|0)==1){break b}f=i[d+4>>2];i[c>>2]=i[d>>2];i[c+4>>2]=f;f=i[d+12>>2];i[c+8>>2]=i[d+8>>2];i[c+12>>2]=f;vf(d+24|0);if(pb(d+24|0,d+16|0)){continue}break}}i[114610]=0;D(1218,b|0,e|0);b=i[114610];i[114610]=0;if((b|0)==1){break a}i[114610]=0;L(1219,e|0);b=i[114610];i[114610]=0;if((b|0)==1){break a}if(bg(a)){c=0;while(1){g=n[_b(e,c)>>3];h=uk(a,c),k=g,n[h>>3]=k;c=c+1|0;if(c>>>0<bg(a)>>>0){continue}break}}Go(e);Xa=d+48|0;return}}a=B()|0;A()|0;Go(e);E(a|0);x()}function L1(a,b,c,d,e){var f=0,g=0,h=0,j=0;f=Xa-352|0;Xa=f;i[f+336>>2]=b;i[f+344>>2]=a;h=Cg(c);j=Vl(c,f+224|0);Ul(f+208|0,c,f+332|0);a=Ab(f+192|0);b=qc(a);i[114610]=0;D(149,a|0,b|0);b=i[114610];i[114610]=0;a:{b:{if((b|0)!=1){b=Sb(a,0);i[f+188>>2]=b;i[f+12>>2]=f+16;i[f+8>>2]=0;while(1){c:{i[114610]=0;c=C(2454,f+344|0,f+336|0)|0;g=i[114610];i[114610]=0;if((g|0)==1){break c}if(!c){break b}if(i[f+188>>2]==(lb(a)+b|0)){c=lb(a);b=lb(a);i[114610]=0;D(149,a|0,b<<1);b=i[114610];i[114610]=0;if((b|0)==1){break a}b=qc(a);i[114610]=0;D(149,a|0,b|0);b=i[114610];i[114610]=0;if((b|0)==1){break a}b=Sb(a,0);i[f+188>>2]=c+b}i[114610]=0;c=F(2456,f+344|0)|0;g=i[114610];i[114610]=0;if((g|0)==1){break c}i[114610]=0;c=uj(c,h,b,f+188|0,f+8|0,i[f+332>>2],f+208|0,f+16|0,f+12|0,j);g=i[114610];i[114610]=0;if((g|0)==1){break c}if(c){break b}i[114610]=0;F(2458,f+344|0)|0;c=i[114610];i[114610]=0;if((c|0)!=1){continue}}break}break a}break a}d:{if(!lb(f+208|0)){break d}c=i[f+12>>2];if((c-(f+16|0)|0)>159){break d}i[f+12>>2]=c+4;i[c>>2]=i[f+8>>2]}i[114610]=0;b=N(2429,b|0,i[f+188>>2],d|0,h|0)|0;c=i[114610];i[114610]=0;e:{if((c|0)==1){break e}i[e>>2]=b;i[114610]=0;je(f+208|0,f+16|0,i[f+12>>2],d);b=i[114610];i[114610]=0;if((b|0)==1){break e}i[114610]=0;b=C(2455,f+344|0,f+336|0)|0;c=i[114610];i[114610]=0;if((c|0)==1){break e}if(b){i[d>>2]=i[d>>2]|2}b=i[f+344>>2];eb(a);eb(f+208|0);Xa=f+352|0;return b}}b=B()|0;A()|0;eb(a);eb(f+208|0);E(b|0);x()}function H1(a,b,c,d,e){var f=0,g=0,j=0,k=0;f=Xa-352|0;Xa=f;i[f+336>>2]=b;i[f+344>>2]=a;j=Cg(c);k=Vl(c,f+224|0);Ul(f+208|0,c,f+332|0);a=Ab(f+192|0);b=qc(a);i[114610]=0;D(149,a|0,b|0);b=i[114610];i[114610]=0;a:{b:{if((b|0)!=1){b=Sb(a,0);i[f+188>>2]=b;i[f+12>>2]=f+16;i[f+8>>2]=0;while(1){c:{i[114610]=0;c=C(2454,f+344|0,f+336|0)|0;g=i[114610];i[114610]=0;if((g|0)==1){break c}if(!c){break b}if(i[f+188>>2]==(lb(a)+b|0)){c=lb(a);b=lb(a);i[114610]=0;D(149,a|0,b<<1);b=i[114610];i[114610]=0;if((b|0)==1){break a}b=qc(a);i[114610]=0;D(149,a|0,b|0);b=i[114610];i[114610]=0;if((b|0)==1){break a}b=Sb(a,0);i[f+188>>2]=c+b}i[114610]=0;c=F(2456,f+344|0)|0;g=i[114610];i[114610]=0;if((g|0)==1){break c}i[114610]=0;c=uj(c,j,b,f+188|0,f+8|0,i[f+332>>2],f+208|0,f+16|0,f+12|0,k);g=i[114610];i[114610]=0;if((g|0)==1){break c}if(c){break b}i[114610]=0;F(2458,f+344|0)|0;c=i[114610];i[114610]=0;if((c|0)!=1){continue}}break}break a}break a}d:{if(!lb(f+208|0)){break d}c=i[f+12>>2];if((c-(f+16|0)|0)>159){break d}i[f+12>>2]=c+4;i[c>>2]=i[f+8>>2]}i[114610]=0;b=N(2434,b|0,i[f+188>>2],d|0,j|0)|0;c=i[114610];i[114610]=0;e:{if((c|0)==1){break e}h[e>>1]=b;i[114610]=0;je(f+208|0,f+16|0,i[f+12>>2],d);b=i[114610];i[114610]=0;if((b|0)==1){break e}i[114610]=0;b=C(2455,f+344|0,f+336|0)|0;c=i[114610];i[114610]=0;if((c|0)==1){break e}if(b){i[d>>2]=i[d>>2]|2}b=i[f+344>>2];eb(a);eb(f+208|0);Xa=f+352|0;return b}}b=B()|0;A()|0;eb(a);eb(f+208|0);E(b|0);x()}function E1(a,b,c,d,e){var f=0,g=0,h=0,j=0;f=Xa-352|0;Xa=f;i[f+336>>2]=b;i[f+344>>2]=a;h=Cg(c);j=Vl(c,f+224|0);Ul(f+208|0,c,f+332|0);a=Ab(f+192|0);b=qc(a);i[114610]=0;D(149,a|0,b|0);b=i[114610];i[114610]=0;a:{b:{if((b|0)!=1){b=Sb(a,0);i[f+188>>2]=b;i[f+12>>2]=f+16;i[f+8>>2]=0;while(1){c:{i[114610]=0;c=C(2454,f+344|0,f+336|0)|0;g=i[114610];i[114610]=0;if((g|0)==1){break c}if(!c){break b}if(i[f+188>>2]==(lb(a)+b|0)){c=lb(a);b=lb(a);i[114610]=0;D(149,a|0,b<<1);b=i[114610];i[114610]=0;if((b|0)==1){break a}b=qc(a);i[114610]=0;D(149,a|0,b|0);b=i[114610];i[114610]=0;if((b|0)==1){break a}b=Sb(a,0);i[f+188>>2]=c+b}i[114610]=0;c=F(2456,f+344|0)|0;g=i[114610];i[114610]=0;if((g|0)==1){break c}i[114610]=0;c=uj(c,h,b,f+188|0,f+8|0,i[f+332>>2],f+208|0,f+16|0,f+12|0,j);g=i[114610];i[114610]=0;if((g|0)==1){break c}if(c){break b}i[114610]=0;F(2458,f+344|0)|0;c=i[114610];i[114610]=0;if((c|0)!=1){continue}}break}break a}break a}d:{if(!lb(f+208|0)){break d}c=i[f+12>>2];if((c-(f+16|0)|0)>159){break d}i[f+12>>2]=c+4;i[c>>2]=i[f+8>>2]}i[114610]=0;b=N(2435,b|0,i[f+188>>2],d|0,h|0)|0;c=i[114610];i[114610]=0;e:{if((c|0)==1){break e}i[e>>2]=b;i[114610]=0;je(f+208|0,f+16|0,i[f+12>>2],d);b=i[114610];i[114610]=0;if((b|0)==1){break e}i[114610]=0;b=C(2455,f+344|0,f+336|0)|0;c=i[114610];i[114610]=0;if((c|0)==1){break e}if(b){i[d>>2]=i[d>>2]|2}b=i[f+344>>2];eb(a);eb(f+208|0);Xa=f+352|0;return b}}b=B()|0;A()|0;eb(a);eb(f+208|0);E(b|0);x()}function C1(a,b,c,d,e){var f=0,g=0,h=0,j=0;f=Xa-352|0;Xa=f;i[f+336>>2]=b;i[f+344>>2]=a;h=Cg(c);j=Vl(c,f+224|0);Ul(f+208|0,c,f+332|0);a=Ab(f+192|0);b=qc(a);i[114610]=0;D(149,a|0,b|0);b=i[114610];i[114610]=0;a:{b:{if((b|0)!=1){b=Sb(a,0);i[f+188>>2]=b;i[f+12>>2]=f+16;i[f+8>>2]=0;while(1){c:{i[114610]=0;c=C(2454,f+344|0,f+336|0)|0;g=i[114610];i[114610]=0;if((g|0)==1){break c}if(!c){break b}if(i[f+188>>2]==(lb(a)+b|0)){c=lb(a);b=lb(a);i[114610]=0;D(149,a|0,b<<1);b=i[114610];i[114610]=0;if((b|0)==1){break a}b=qc(a);i[114610]=0;D(149,a|0,b|0);b=i[114610];i[114610]=0;if((b|0)==1){break a}b=Sb(a,0);i[f+188>>2]=c+b}i[114610]=0;c=F(2456,f+344|0)|0;g=i[114610];i[114610]=0;if((g|0)==1){break c}i[114610]=0;c=uj(c,h,b,f+188|0,f+8|0,i[f+332>>2],f+208|0,f+16|0,f+12|0,j);g=i[114610];i[114610]=0;if((g|0)==1){break c}if(c){break b}i[114610]=0;F(2458,f+344|0)|0;c=i[114610];i[114610]=0;if((c|0)!=1){continue}}break}break a}break a}d:{if(!lb(f+208|0)){break d}c=i[f+12>>2];if((c-(f+16|0)|0)>159){break d}i[f+12>>2]=c+4;i[c>>2]=i[f+8>>2]}i[114610]=0;b=N(2436,b|0,i[f+188>>2],d|0,h|0)|0;c=i[114610];i[114610]=0;e:{if((c|0)==1){break e}i[e>>2]=b;i[114610]=0;je(f+208|0,f+16|0,i[f+12>>2],d);b=i[114610];i[114610]=0;if((b|0)==1){break e}i[114610]=0;b=C(2455,f+344|0,f+336|0)|0;c=i[114610];i[114610]=0;if((c|0)==1){break e}if(b){i[d>>2]=i[d>>2]|2}b=i[f+344>>2];eb(a);eb(f+208|0);Xa=f+352|0;return b}}b=B()|0;A()|0;eb(a);eb(f+208|0);E(b|0);x()}function rea(a,b,c){var d=0,e=0,f=p(0),g=0,j=0,l=0,n=0,r=0,t=0,u=0,v=0,w=p(0);e=i[a+24>>2];i[b>>2]=e;d=i[a+16>>2];i[b+4>>2]=d;i[b+8>>2]=i[a+4>>2];j=(e|0)>(d|0)?e:d;if((j|0)<=-601){g=d;d=j+600|0;i[b+4>>2]=g-d;i[b>>2]=e-d}d=b;f=p(m[a+36>>2]*p(79.30999755859375));a:{if(p(q(f))<p(2147483648)){e=~~f;break a}e=-2147483648}i[d+16>>2]=e- -8192;e=b;f=p(p(m[a+32>>2]*p(117.9612045288086))+p(4915.05029296875));b:{if(p(q(f))<p(2147483648)){d=~~f;break b}d=-2147483648}i[e+20>>2]=(d|0)<32512?d:32512;j=0;f=p(p(s(m[a+20>>2],p(.10000000149011612)))*c);c:{if(p(q(f))<p(2147483648)){e=~~f;break c}e=-2147483648}d=(e|0)<96;l=d?96:e;n=(l|0)>7500;g=n?l+ -7500|0:0;d=d?e+ -96|0:0;f=p(m[a+28>>2]*c);d:{if(p(q(f))<p(2147483648)){e=~~f;break d}e=-2147483648}f=m[a+8>>2];e=g+(d+e|0)|0;d=(e|0)<128;g=d?128:e;r=(g|0)>3800;t=r?3800:g;i[b+24>>2]=t;e=d?e+ -128|0:0;d=b;c=p(f*c);e:{if(p(q(c))<p(2147483648)){u=~~c;break e}u=-2147483648}g=(u+e|0)+(r?g+ -3800|0:0)|0;i[d+32>>2]=g;l=n?7500:l;while(1){d=o(j,12);e=d+b|0;d=d+33984|0;h[e+42>>1]=k[d+10>>1];h[e+36>>1]=k[d+4>>1];n=k[d+6>>1]|k[d+8>>1]<<16;h[e+38>>1]=n;h[e+40>>1]=n>>>16;i[e+44>>2]=l+((o(i[d>>2],t)+50|0)/100|0);j=j+1|0;if((j|0)!=8){continue}break}d=b;c=p(g|0);f=p(Wd(p(.0010000000474974513),(g|0)<4721?p(1):p(p(4720)/c))*p(32768));f:{if(p(q(f))<p(2147483648)){e=~~f;break f}e=-2147483648}i[d+12>>2]=e;c=p(m[a+12>>2]*c);v=b,w=Wd(p(.0010000000474974513),c>p(4720)?p(p(4720)/c):p(1)),m[v+28>>2]=w}function I9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;b=Xa-176|0;Xa=b;d=Bb(b+8|0,38671);i[114610]=0;C(85,b+20|0,38676)|0;e=i[114610];i[114610]=0;c=1;a:{b:{if((e|0)==1){break b}i[114610]=0;C(85,b+32|0,38686)|0;c=i[114610];i[114610]=0;if((c|0)==1){c=2;break b}i[114610]=0;C(85,b+44|0,38699)|0;c=i[114610];i[114610]=0;if((c|0)==1){c=3;break b}i[114610]=0;C(85,b+56|0,38717)|0;c=i[114610];i[114610]=0;if((c|0)==1){c=4;break b}i[114610]=0;C(85,b+68|0,38727)|0;c=i[114610];i[114610]=0;if((c|0)==1){c=5;break b}i[114610]=0;C(85,b+80|0,38742)|0;c=i[114610];i[114610]=0;if((c|0)==1){c=6;break b}i[114610]=0;C(85,b+92|0,38750)|0;c=i[114610];i[114610]=0;if((c|0)==1){c=7;break b}i[114610]=0;C(85,b+104|0,38757)|0;c=i[114610];i[114610]=0;if((c|0)==1){c=8;break b}i[114610]=0;C(85,b+116|0,38763)|0;c=i[114610];i[114610]=0;if((c|0)==1){c=9;break b}i[114610]=0;C(85,b+128|0,38768)|0;c=i[114610];i[114610]=0;if((c|0)==1){c=10;break b}i[114610]=0;C(85,b+140|0,38776)|0;c=i[114610];i[114610]=0;if((c|0)==1){c=11;break b}i[114610]=0;C(85,b+152|0,38788)|0;c=i[114610];i[114610]=0;if((c|0)==1){c=12;break b}i[114610]=0;i[b+172>>2]=13;i[b+168>>2]=d;c=i[b+172>>2];i[b>>2]=i[b+168>>2];i[b+4>>2]=c;C(2179,a|0,b|0)|0;a=i[114610];i[114610]=0;if((a|0)!=1){c=b+164|0;while(1){c=eb(c+ -12|0);if((d|0)!=(c|0)){continue}break}Xa=b+176|0;return}c=b+164|0;break a}c=(b+8|0)+o(c,12)|0}a=B()|0;A()|0;while(1){c=eb(c+ -12|0);if((d|0)!=(c|0)){continue}break}E(a|0);x()}function k2(a,b,c,d,e){var f=0,h=0,j=0;f=Xa-272|0;Xa=f;i[f+256>>2]=b;i[f+264>>2]=a;j=Cg(c);Wl(f+208|0,c,f+255|0);a=Ab(f+192|0);b=qc(a);i[114610]=0;D(149,a|0,b|0);b=i[114610];i[114610]=0;a:{b:{if((b|0)!=1){b=Sb(a,0);i[f+188>>2]=b;i[f+12>>2]=f+16;i[f+8>>2]=0;while(1){c:{i[114610]=0;c=C(2422,f+264|0,f+256|0)|0;h=i[114610];i[114610]=0;if((h|0)==1){break c}if(!c){break b}if(i[f+188>>2]==(lb(a)+b|0)){c=lb(a);b=lb(a);i[114610]=0;D(149,a|0,b<<1);b=i[114610];i[114610]=0;if((b|0)==1){break a}b=qc(a);i[114610]=0;D(149,a|0,b|0);b=i[114610];i[114610]=0;if((b|0)==1){break a}b=Sb(a,0);i[f+188>>2]=c+b}i[114610]=0;c=F(2424,f+264|0)|0;h=i[114610];i[114610]=0;if((h|0)==1){break c}i[114610]=0;c=vj(c,j,b,f+188|0,f+8|0,g[f+255|0],f+208|0,f+16|0,f+12|0,62112);h=i[114610];i[114610]=0;if((h|0)==1){break c}if(c){break b}i[114610]=0;F(2426,f+264|0)|0;c=i[114610];i[114610]=0;if((c|0)!=1){continue}}break}break a}break a}d:{if(!lb(f+208|0)){break d}c=i[f+12>>2];if((c-(f+16|0)|0)>159){break d}i[f+12>>2]=c+4;i[c>>2]=i[f+8>>2]}i[114610]=0;b=Hn(2433,b,i[f+188>>2],d,j);c=_a;j=i[114610];i[114610]=0;e:{if((j|0)==1){break e}i[e>>2]=b;i[e+4>>2]=c;i[114610]=0;je(f+208|0,f+16|0,i[f+12>>2],d);b=i[114610];i[114610]=0;if((b|0)==1){break e}i[114610]=0;b=C(2423,f+264|0,f+256|0)|0;c=i[114610];i[114610]=0;if((c|0)==1){break e}if(b){i[d>>2]=i[d>>2]|2}b=i[f+264>>2];eb(a);eb(f+208|0);Xa=f+272|0;return b}}b=B()|0;A()|0;eb(a);eb(f+208|0);E(b|0);x()}function a2(a,b,c,d,e){var f=0,h=0,j=0;f=Xa-272|0;Xa=f;i[f+256>>2]=b;i[f+264>>2]=a;j=Cg(c);Wl(f+208|0,c,f+255|0);a=Ab(f+192|0);b=qc(a);i[114610]=0;D(149,a|0,b|0);b=i[114610];i[114610]=0;a:{b:{if((b|0)!=1){b=Sb(a,0);i[f+188>>2]=b;i[f+12>>2]=f+16;i[f+8>>2]=0;while(1){c:{i[114610]=0;c=C(2422,f+264|0,f+256|0)|0;h=i[114610];i[114610]=0;if((h|0)==1){break c}if(!c){break b}if(i[f+188>>2]==(lb(a)+b|0)){c=lb(a);b=lb(a);i[114610]=0;D(149,a|0,b<<1);b=i[114610];i[114610]=0;if((b|0)==1){break a}b=qc(a);i[114610]=0;D(149,a|0,b|0);b=i[114610];i[114610]=0;if((b|0)==1){break a}b=Sb(a,0);i[f+188>>2]=c+b}i[114610]=0;c=F(2424,f+264|0)|0;h=i[114610];i[114610]=0;if((h|0)==1){break c}i[114610]=0;c=vj(c,j,b,f+188|0,f+8|0,g[f+255|0],f+208|0,f+16|0,f+12|0,62112);h=i[114610];i[114610]=0;if((h|0)==1){break c}if(c){break b}i[114610]=0;F(2426,f+264|0)|0;c=i[114610];i[114610]=0;if((c|0)!=1){continue}}break}break a}break a}d:{if(!lb(f+208|0)){break d}c=i[f+12>>2];if((c-(f+16|0)|0)>159){break d}i[f+12>>2]=c+4;i[c>>2]=i[f+8>>2]}i[114610]=0;b=Hn(2437,b,i[f+188>>2],d,j);c=_a;j=i[114610];i[114610]=0;e:{if((j|0)==1){break e}i[e>>2]=b;i[e+4>>2]=c;i[114610]=0;je(f+208|0,f+16|0,i[f+12>>2],d);b=i[114610];i[114610]=0;if((b|0)==1){break e}i[114610]=0;b=C(2423,f+264|0,f+256|0)|0;c=i[114610];i[114610]=0;if((c|0)==1){break e}if(b){i[d>>2]=i[d>>2]|2}b=i[f+264>>2];eb(a);eb(f+208|0);Xa=f+272|0;return b}}b=B()|0;A()|0;eb(a);eb(f+208|0);E(b|0);x()}function _E(a){var b=0,c=0,d=0,e=0;Dd(a,i[a+20>>2]);if(i[a+24>>2]>=1){while(1){Dd(a,i[i[a+28>>2]+(b<<2)>>2]);b=b+1|0;if((b|0)<i[a+24>>2]){continue}break}}Dd(a,i[a+28>>2]);a:{b=i[a+396>>2];if(!b|i[a+264>>2]<1){break a}while(1){c=o(e,24)+b|0;b=i[c+16>>2];if(b){d=a;if(i[(i[a+124>>2]+o(j[c+13|0],2096)|0)+4>>2]>=1){Dd(a,i[b>>2]);b=1;if(i[(i[a+124>>2]+o(j[c+13|0],2096)|0)+4>>2]>=2){while(1){Dd(a,i[i[c+16>>2]+(b<<2)>>2]);b=b+1|0;if((b|0)<i[(i[a+124>>2]+o(j[c+13|0],2096)|0)+4>>2]){continue}break}}b=i[c+16>>2]}Dd(d,b)}Dd(a,i[c+20>>2]);e=e+1|0;if((e|0)>=i[a+264>>2]){break a}b=i[a+396>>2];continue}}b=i[a+124>>2];if(b){d=a;if(i[a+120>>2]>=1){c=0;while(1){b=o(c,2096)+b|0;Dd(a,i[b+8>>2]);Dd(a,i[b+28>>2]);Dd(a,i[b+32>>2]);Dd(a,i[b+2084>>2]);b=i[b+2088>>2];Dd(a,b?b+ -4|0:0);c=c+1|0;if((c|0)<i[a+120>>2]){b=i[a+124>>2];continue}break}b=i[a+124>>2]}Dd(d,b)}Dd(a,i[a+260>>2]);Dd(a,i[a+396>>2]);d=i[a+404>>2];if(d){b=1;c=a;if(i[a+400>>2]>=1){Dd(a,i[d+4>>2]);if(i[a+400>>2]>=2){while(1){Dd(a,i[(i[a+404>>2]+o(b,40)|0)+4>>2]);b=b+1|0;if((b|0)<i[a+400>>2]){continue}break}}d=i[a+404>>2]}Dd(c,d)}c=1;b:{if(i[a+4>>2]<1){break b}b=0;while(1){d=(b<<2)+a|0;Dd(a,i[d+800>>2]);Dd(a,i[d+928>>2]);Dd(a,i[d+996>>2]);if(b>>>0>14){break b}b=b+1|0;if((b|0)<i[a+4>>2]){continue}break}}b=0;while(1){b=(b<<2)+a|0;Dd(a,i[b+1068>>2]);Dd(a,i[b+1076>>2]);Dd(a,i[b+1084>>2]);Dd(a,i[b+1092>>2]);Dd(a,i[b+1100>>2]);b=1;d=c&1;c=0;if(d){continue}break}}function n2(a,b,c,d,e){var f=0,h=0,j=0;f=Xa-272|0;Xa=f;i[f+256>>2]=b;i[f+264>>2]=a;j=Cg(c);Wl(f+208|0,c,f+255|0);a=Ab(f+192|0);b=qc(a);i[114610]=0;D(149,a|0,b|0);b=i[114610];i[114610]=0;a:{b:{if((b|0)!=1){b=Sb(a,0);i[f+188>>2]=b;i[f+12>>2]=f+16;i[f+8>>2]=0;while(1){c:{i[114610]=0;c=C(2422,f+264|0,f+256|0)|0;h=i[114610];i[114610]=0;if((h|0)==1){break c}if(!c){break b}if(i[f+188>>2]==(lb(a)+b|0)){c=lb(a);b=lb(a);i[114610]=0;D(149,a|0,b<<1);b=i[114610];i[114610]=0;if((b|0)==1){break a}b=qc(a);i[114610]=0;D(149,a|0,b|0);b=i[114610];i[114610]=0;if((b|0)==1){break a}b=Sb(a,0);i[f+188>>2]=c+b}i[114610]=0;c=F(2424,f+264|0)|0;h=i[114610];i[114610]=0;if((h|0)==1){break c}i[114610]=0;c=vj(c,j,b,f+188|0,f+8|0,g[f+255|0],f+208|0,f+16|0,f+12|0,62112);h=i[114610];i[114610]=0;if((h|0)==1){break c}if(c){break b}i[114610]=0;F(2426,f+264|0)|0;c=i[114610];i[114610]=0;if((c|0)!=1){continue}}break}break a}break a}d:{if(!lb(f+208|0)){break d}c=i[f+12>>2];if((c-(f+16|0)|0)>159){break d}i[f+12>>2]=c+4;i[c>>2]=i[f+8>>2]}i[114610]=0;b=N(2429,b|0,i[f+188>>2],d|0,j|0)|0;c=i[114610];i[114610]=0;e:{if((c|0)==1){break e}i[e>>2]=b;i[114610]=0;je(f+208|0,f+16|0,i[f+12>>2],d);b=i[114610];i[114610]=0;if((b|0)==1){break e}i[114610]=0;b=C(2423,f+264|0,f+256|0)|0;c=i[114610];i[114610]=0;if((c|0)==1){break e}if(b){i[d>>2]=i[d>>2]|2}b=i[f+264>>2];eb(a);eb(f+208|0);Xa=f+272|0;return b}}b=B()|0;A()|0;eb(a);eb(f+208|0);E(b|0);x()}function h2(a,b,c,d,e){var f=0,j=0,k=0;f=Xa-272|0;Xa=f;i[f+256>>2]=b;i[f+264>>2]=a;k=Cg(c);Wl(f+208|0,c,f+255|0);a=Ab(f+192|0);b=qc(a);i[114610]=0;D(149,a|0,b|0);b=i[114610];i[114610]=0;a:{b:{if((b|0)!=1){b=Sb(a,0);i[f+188>>2]=b;i[f+12>>2]=f+16;i[f+8>>2]=0;while(1){c:{i[114610]=0;c=C(2422,f+264|0,f+256|0)|0;j=i[114610];i[114610]=0;if((j|0)==1){break c}if(!c){break b}if(i[f+188>>2]==(lb(a)+b|0)){c=lb(a);b=lb(a);i[114610]=0;D(149,a|0,b<<1);b=i[114610];i[114610]=0;if((b|0)==1){break a}b=qc(a);i[114610]=0;D(149,a|0,b|0);b=i[114610];i[114610]=0;if((b|0)==1){break a}b=Sb(a,0);i[f+188>>2]=c+b}i[114610]=0;c=F(2424,f+264|0)|0;j=i[114610];i[114610]=0;if((j|0)==1){break c}i[114610]=0;c=vj(c,k,b,f+188|0,f+8|0,g[f+255|0],f+208|0,f+16|0,f+12|0,62112);j=i[114610];i[114610]=0;if((j|0)==1){break c}if(c){break b}i[114610]=0;F(2426,f+264|0)|0;c=i[114610];i[114610]=0;if((c|0)!=1){continue}}break}break a}break a}d:{if(!lb(f+208|0)){break d}c=i[f+12>>2];if((c-(f+16|0)|0)>159){break d}i[f+12>>2]=c+4;i[c>>2]=i[f+8>>2]}i[114610]=0;b=N(2434,b|0,i[f+188>>2],d|0,k|0)|0;c=i[114610];i[114610]=0;e:{if((c|0)==1){break e}h[e>>1]=b;i[114610]=0;je(f+208|0,f+16|0,i[f+12>>2],d);b=i[114610];i[114610]=0;if((b|0)==1){break e}i[114610]=0;b=C(2423,f+264|0,f+256|0)|0;c=i[114610];i[114610]=0;if((c|0)==1){break e}if(b){i[d>>2]=i[d>>2]|2}b=i[f+264>>2];eb(a);eb(f+208|0);Xa=f+272|0;return b}}b=B()|0;A()|0;eb(a);eb(f+208|0);E(b|0);x()}function e2(a,b,c,d,e){var f=0,h=0,j=0;f=Xa-272|0;Xa=f;i[f+256>>2]=b;i[f+264>>2]=a;j=Cg(c);Wl(f+208|0,c,f+255|0);a=Ab(f+192|0);b=qc(a);i[114610]=0;D(149,a|0,b|0);b=i[114610];i[114610]=0;a:{b:{if((b|0)!=1){b=Sb(a,0);i[f+188>>2]=b;i[f+12>>2]=f+16;i[f+8>>2]=0;while(1){c:{i[114610]=0;c=C(2422,f+264|0,f+256|0)|0;h=i[114610];i[114610]=0;if((h|0)==1){break c}if(!c){break b}if(i[f+188>>2]==(lb(a)+b|0)){c=lb(a);b=lb(a);i[114610]=0;D(149,a|0,b<<1);b=i[114610];i[114610]=0;if((b|0)==1){break a}b=qc(a);i[114610]=0;D(149,a|0,b|0);b=i[114610];i[114610]=0;if((b|0)==1){break a}b=Sb(a,0);i[f+188>>2]=c+b}i[114610]=0;c=F(2424,f+264|0)|0;h=i[114610];i[114610]=0;if((h|0)==1){break c}i[114610]=0;c=vj(c,j,b,f+188|0,f+8|0,g[f+255|0],f+208|0,f+16|0,f+12|0,62112);h=i[114610];i[114610]=0;if((h|0)==1){break c}if(c){break b}i[114610]=0;F(2426,f+264|0)|0;c=i[114610];i[114610]=0;if((c|0)!=1){continue}}break}break a}break a}d:{if(!lb(f+208|0)){break d}c=i[f+12>>2];if((c-(f+16|0)|0)>159){break d}i[f+12>>2]=c+4;i[c>>2]=i[f+8>>2]}i[114610]=0;b=N(2435,b|0,i[f+188>>2],d|0,j|0)|0;c=i[114610];i[114610]=0;e:{if((c|0)==1){break e}i[e>>2]=b;i[114610]=0;je(f+208|0,f+16|0,i[f+12>>2],d);b=i[114610];i[114610]=0;if((b|0)==1){break e}i[114610]=0;b=C(2423,f+264|0,f+256|0)|0;c=i[114610];i[114610]=0;if((c|0)==1){break e}if(b){i[d>>2]=i[d>>2]|2}b=i[f+264>>2];eb(a);eb(f+208|0);Xa=f+272|0;return b}}b=B()|0;A()|0;eb(a);eb(f+208|0);E(b|0);x()}function c2(a,b,c,d,e){var f=0,h=0,j=0;f=Xa-272|0;Xa=f;i[f+256>>2]=b;i[f+264>>2]=a;j=Cg(c);Wl(f+208|0,c,f+255|0);a=Ab(f+192|0);b=qc(a);i[114610]=0;D(149,a|0,b|0);b=i[114610];i[114610]=0;a:{b:{if((b|0)!=1){b=Sb(a,0);i[f+188>>2]=b;i[f+12>>2]=f+16;i[f+8>>2]=0;while(1){c:{i[114610]=0;c=C(2422,f+264|0,f+256|0)|0;h=i[114610];i[114610]=0;if((h|0)==1){break c}if(!c){break b}if(i[f+188>>2]==(lb(a)+b|0)){c=lb(a);b=lb(a);i[114610]=0;D(149,a|0,b<<1);b=i[114610];i[114610]=0;if((b|0)==1){break a}b=qc(a);i[114610]=0;D(149,a|0,b|0);b=i[114610];i[114610]=0;if((b|0)==1){break a}b=Sb(a,0);i[f+188>>2]=c+b}i[114610]=0;c=F(2424,f+264|0)|0;h=i[114610];i[114610]=0;if((h|0)==1){break c}i[114610]=0;c=vj(c,j,b,f+188|0,f+8|0,g[f+255|0],f+208|0,f+16|0,f+12|0,62112);h=i[114610];i[114610]=0;if((h|0)==1){break c}if(c){break b}i[114610]=0;F(2426,f+264|0)|0;c=i[114610];i[114610]=0;if((c|0)!=1){continue}}break}break a}break a}d:{if(!lb(f+208|0)){break d}c=i[f+12>>2];if((c-(f+16|0)|0)>159){break d}i[f+12>>2]=c+4;i[c>>2]=i[f+8>>2]}i[114610]=0;b=N(2436,b|0,i[f+188>>2],d|0,j|0)|0;c=i[114610];i[114610]=0;e:{if((c|0)==1){break e}i[e>>2]=b;i[114610]=0;je(f+208|0,f+16|0,i[f+12>>2],d);b=i[114610];i[114610]=0;if((b|0)==1){break e}i[114610]=0;b=C(2423,f+264|0,f+256|0)|0;c=i[114610];i[114610]=0;if((c|0)==1){break e}if(b){i[d>>2]=i[d>>2]|2}b=i[f+264>>2];eb(a);eb(f+208|0);Xa=f+272|0;return b}}b=B()|0;A()|0;eb(a);eb(f+208|0);E(b|0);x()}function Qva(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;e=Xa-48|0;Xa=e;r=i[a+16>>2];f=i[a+44>>2];i[e+32>>2]=f;j=i[a+48>>2];i[e+36>>2]=j;n=i[a+52>>2];i[e+40>>2]=n;k=i[a+56>>2];i[e+44>>2]=k;s=i[a+24>>2];t=i[a+20>>2];b=i[a+4>>2];g=i[a>>2];i[e+24>>2]=g;i[e+28>>2]=b;l=i[a+12>>2];i[e+16>>2]=i[a+8>>2];i[e+20>>2]=l;u=a;if(d){while(1){l=g>>>18|0;n=1;k=((((b&2147483647)<<1|g>>>31)&2147483646)<<1)+r|0;f=0;b=1;j=0;while(1){m=j<<1;g=h[m+k>>1];i[(e+8|0)+(j<<2)>>2]=g+((o(l,h[k+(m|4)>>1]-g|0)|0)/16384|0);g=b;b=0;j=1;if(g){continue}break}while(1){j=(e+8|0)+(f<<2)|0;l=i[j>>2];m=i[a+60>>2];g=(e+32|0)+(f<<3)|0;f=i[g>>2];b=Eb(f,-16777216,16776704);q=i[a+64>>2];k=Eb(i[g+4>>2],-16777216,16776704);p=i[a+68>>2];v=p;p=p>>31;i[g+4>>2]=f;w=i[a+72>>2];l=l<<8;f=l;f=XMa(m,m>>31,f,f>>31);m=_a;x=j;j=XMa(q,q>>31,b,b>>31);f=j+f|0;b=_a+m|0;b=f>>>0<j>>>0?b+1|0:b;j=f;f=XMa(v,p,k,k>>31);k=j+f|0;b=_a+b|0;b=k>>>0<f>>>0?b+1|0:b;k=k+8388608|0;if(k>>>0<8388608){b=b+1|0}b=(b&16777215)<<8|k>>>24;i[x>>2]=(b|0)/256;i[g>>2]=b-(l&w);f=1;b=n&1;n=0;if(b){continue}break}i[c>>2]=i[c>>2]+o(i[e+8>>2],t);i[c+4>>2]=i[c+4>>2]+o(i[e+12>>2],s);zb(e+24|0,e+16|0);d=d+ -1|0;if(d){c=c+8|0;g=i[e+24>>2];b=i[e+28>>2];continue}break}g=i[e+24>>2];b=i[e+28>>2];n=i[e+40>>2];j=i[e+36>>2];f=i[e+32>>2];k=i[e+44>>2]}i[u+56>>2]=k;i[a+52>>2]=n;i[a+48>>2]=j;i[a+44>>2]=f;i[a>>2]=g;i[a+4>>2]=b;Xa=e+48|0}function c1(a,b,c,d,e,f,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;h=h|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;n=Xa-16|0;Xa=n;o=ev(h);h=Lu(h);Pf(n,h);a:{b:{if(Cc(n)){i[114610]=0;N(2463,o|0,a|0,c|0,d|0)|0;h=i[114610];i[114610]=0;if((h|0)==1){break b}h=(c-a<<2)+d|0;i[f>>2]=h;break a}i[f>>2]=d;c:{d:{m=a;k=j[m|0];switch(k+ -43|0){case 0:case 2:break d;default:break c}}i[114610]=0;m=C(2475,o|0,k<<24>>24)|0;k=i[114610];i[114610]=0;if((k|0)==1){break b}k=i[f>>2];i[f>>2]=k+4;i[k>>2]=m;m=a+1|0}if(!(j[m|0]!=48|(c-m|0)<2|(j[m+1|0]|32)!=120)){i[114610]=0;k=C(2475,o|0,48)|0;l=i[114610];i[114610]=0;if((l|0)==1){break b}l=i[f>>2];i[f>>2]=l+4;i[l>>2]=k;k=g[m+1|0];i[114610]=0;k=C(2475,o|0,k|0)|0;l=i[114610];i[114610]=0;if((l|0)==1){break b}l=i[f>>2];i[f>>2]=l+4;i[l>>2]=k;m=m+2|0}l=0;i[114610]=0;sj(m,c);k=i[114610];i[114610]=0;if((k|0)==1){break b}i[114610]=0;r=F(2460,h|0)|0;h=i[114610];i[114610]=0;if((h|0)==1){break b}k=0;h=m;while(1){e:{if(h>>>0>=c>>>0){h=i[f>>2];i[114610]=0;On((m-a<<2)+d|0,h);h=i[114610];i[114610]=0;if((h|0)==1){break e}h=i[f>>2];break a}f:{if(!j[Sb(n,k)|0]){break f}if(g[Sb(n,k)|0]!=(l|0)){break f}l=i[f>>2];i[f>>2]=l+4;i[l>>2]=r;k=(k>>>0<lb(n)+ -1>>>0)+k|0;l=0}q=g[h|0];i[114610]=0;q=C(2475,o|0,q|0)|0;p=i[114610];i[114610]=0;if((p|0)!=1){p=i[f>>2];i[f>>2]=p+4;i[p>>2]=q;h=h+1|0;l=l+1|0;continue}}break}}a=B()|0;A()|0;eb(n);E(a|0);x()}i[e>>2]=(b|0)==(c|0)?h:(b-a<<2)+d|0;eb(n);Xa=n+16|0}function Rva(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,h=0,j=0,k=0,l=0,m=0,n=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;e=Xa-48|0;Xa=e;t=i[a+16>>2];f=i[a+44>>2];i[e+32>>2]=f;k=i[a+48>>2];i[e+36>>2]=k;b=i[a+52>>2];i[e+40>>2]=b;n=i[a+56>>2];i[e+44>>2]=n;u=i[a+24>>2];v=i[a+20>>2];j=i[a+4>>2];h=i[a>>2];i[e+24>>2]=h;i[e+28>>2]=j;m=i[a+12>>2];i[e+16>>2]=i[a+8>>2];i[e+20>>2]=m;if(d){while(1){m=h>>>10&4194048;h=(((j&2147483647)<<1|h>>>31)&-2)+t|0;k=0;n=1;b=1;f=0;while(1){j=g[h+f|0];i[(e+8|0)+(f<<2)>>2]=((o(m,g[h+(f|2)|0]-j|0)|0)/16384|0)+(j<<8);j=b;b=0;f=1;if(j){continue}break}while(1){f=(e+8|0)+(k<<2)|0;m=i[f>>2];l=i[a+60>>2];q=l;j=(e+32|0)+(k<<3)|0;k=i[j>>2];b=Eb(k,-16777216,16776704);s=i[a+64>>2];h=Eb(i[j+4>>2],-16777216,16776704);p=i[a+68>>2];w=p;p=p>>31;i[j+4>>2]=k;k=i[a+72>>2];r=l>>31;m=m<<8;l=m;l=XMa(q,r,l,l>>31);q=_a;r=f;f=l;l=XMa(s,s>>31,b,b>>31);f=f+l|0;b=_a+q|0;b=f>>>0<l>>>0?b+1|0:b;l=f;f=XMa(w,p,h,h>>31);h=l+f|0;b=_a+b|0;b=h>>>0<f>>>0?b+1|0:b;h=h+8388608|0;if(h>>>0<8388608){b=b+1|0}b=(b&16777215)<<8|h>>>24;i[r>>2]=(b|0)/256;i[j>>2]=b-(k&m);k=1;b=n&1;n=0;if(b){continue}break}i[c>>2]=i[c>>2]+o(i[e+8>>2],v);i[c+4>>2]=i[c+4>>2]+o(i[e+12>>2],u);zb(e+24|0,e+16|0);d=d+ -1|0;if(d){c=c+8|0;h=i[e+24>>2];j=i[e+28>>2];continue}break}h=i[e+24>>2];j=i[e+28>>2];n=i[e+44>>2];k=i[e+36>>2];f=i[e+32>>2];b=i[e+40>>2]}i[a+56>>2]=n;i[a+52>>2]=b;i[a+48>>2]=k;i[a+44>>2]=f;i[a>>2]=h;i[a+4>>2]=j;Xa=e+48|0}function Eo(a,b,c,d){var e=0,f=p(0),n=p(0),q=p(0),r=0,s=0,t=0,u=0,v=p(0),w=0,x=0,y=0;e=Xa-16|0;Xa=e;i[e+12>>2]=h[b+792>>1]+j[b+857|0];i[e+8>>2]=h[b+794>>1]+(j[b+858|0]&127);Kd(e+12|0,0,127);Kd(e+8|0,0,127);t=a+1074308|0;kb(e,t,1);r=ib(e);s=i[e+12>>2];if(!r){h[b+792>>1]=0;g[b+857|0]=s;r=i[e+8>>2];h[b+794>>1]=0;g[b+858|0]=r}kb(e,t,36);r=o(s,d+256|0);s=(r|0)/256|0;w=ib(e);u=i[e+8>>2];a:{if(!(u|!w|(r|0)<65024)){s=-1;a=b+810|0;if(!Jf(a)){break a}if(Ur(a)|k[b+808>>1]|(i[b>>2]|i[b+4>>2])){break a}a=i[b+88>>2];if(a&8192){break a}i[b+88>>2]=a&-32769;break a}i[b+88>>2]=i[b+88>>2]|32768;f=Wd(p(10),p(p(0-u|0)*p(.00937500037252903)));d=Apa(a,i[e+12>>2],d);kb(e,t,36);q=p(p(d>>>0)*p(6.2831854820251465));b:{if(!(!ib(e)|i[a+480208>>2]&32768)){n=p(p(l[a+24620>>2])/q);q=p(p(f+p(-1))+p(n*f));m[e>>2]=q;f=p(n*n);break b}n=p(q/p(l[a+24620>>2]));f=p(f+f);m[e>>2]=n*p(p(1)-f);VK(e,p(2));q=p(p(f-m[e>>2])/n);m[e>>2]=q;f=p(p(1)/p(n*n))}n=p(p(q+f)+p(1));q=p(p(p(f+f)+q)/n);v=p(p(16777216)/n);f=p(p(-f)/n);c:{if(j[b+865|0]==1){x=b,y=oh(p(p(16777216)-v)),i[x+60>>2]=y;x=b,y=oh(p(q*p(16777216))),i[x+64>>2]=y;x=b,y=oh(p(f*p(16777216))),i[x+68>>2]=y;a=-1;break c}x=b,y=oh(v),i[x+60>>2]=y;x=b,y=oh(p(q*p(16777216))),i[x+64>>2]=y;x=b,y=oh(p(f*p(16777216))),i[x+68>>2]=y;a=0;if(i[b+60>>2]){break c}i[b+60>>2]=1}i[b+72>>2]=a;if(!c){break a}i[b+44>>2]=0;i[b+48>>2]=0;i[b+52>>2]=0;i[b+56>>2]=0}Xa=e+16|0;return s}function p1(a,b,c,d,e,f,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;h=h|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;n=Xa-16|0;Xa=n;o=Ot(h);h=Ou(h);Pf(n,h);a:{b:{if(Cc(n)){i[114610]=0;N(2440,o|0,a|0,c|0,d|0)|0;h=i[114610];i[114610]=0;if((h|0)==1){break b}h=(c-a|0)+d|0;i[f>>2]=h;break a}i[f>>2]=d;c:{d:{m=a;k=j[m|0];switch(k+ -43|0){case 0:case 2:break d;default:break c}}i[114610]=0;m=C(22,o|0,k<<24>>24)|0;k=i[114610];i[114610]=0;if((k|0)==1){break b}k=i[f>>2];i[f>>2]=k+1;g[k|0]=m;m=a+1|0}if(!(j[m|0]!=48|(c-m|0)<2|(j[m+1|0]|32)!=120)){i[114610]=0;k=C(22,o|0,48)|0;l=i[114610];i[114610]=0;if((l|0)==1){break b}l=i[f>>2];i[f>>2]=l+1;g[l|0]=k;k=g[m+1|0];i[114610]=0;k=C(22,o|0,k|0)|0;l=i[114610];i[114610]=0;if((l|0)==1){break b}l=i[f>>2];i[f>>2]=l+1;g[l|0]=k;m=m+2|0}l=0;i[114610]=0;sj(m,c);k=i[114610];i[114610]=0;if((k|0)==1){break b}i[114610]=0;r=F(2431,h|0)|0;h=i[114610];i[114610]=0;if((h|0)==1){break b}k=0;h=m;while(1){e:{if(h>>>0>=c>>>0){h=i[f>>2];i[114610]=0;sj((m-a|0)+d|0,h);h=i[114610];i[114610]=0;if((h|0)==1){break e}h=i[f>>2];break a}f:{if(!j[Sb(n,k)|0]){break f}if(g[Sb(n,k)|0]!=(l|0)){break f}l=i[f>>2];i[f>>2]=l+1;g[l|0]=r;k=(k>>>0<lb(n)+ -1>>>0)+k|0;l=0}q=g[h|0];i[114610]=0;q=C(22,o|0,q|0)|0;p=i[114610];i[114610]=0;if((p|0)!=1){p=i[f>>2];i[f>>2]=p+1;g[p|0]=q;h=h+1|0;l=l+1|0;continue}}break}}a=B()|0;A()|0;eb(n);E(a|0);x()}i[e>>2]=(b|0)==(c|0)?h:(b-a|0)+d|0;eb(n);Xa=n+16|0}function efa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,n=0,o=0,q=0,r=p(0),s=p(0),t=0,u=0,v=p(0),w=0;g=Xa-16|0;Xa=g;q=a+44|0;if(Wg(q)){k=ud(q,0);n=ud(q,1);h=Pc(q,0);j=Pc(q,1);v=m[a+4212>>2];i[g+12>>2]=d;if(d){e=i[a+4224>>2];while(1){w=a;f=i[a+4220>>2];a:{if(f>>>0>e>>>0){i[g+8>>2]=f-e;f=i[rb(g+12|0,g+8|0)>>2];b:{if(!(v<p(1))){e=0;if(!f){break b}while(1){m[h>>2]=m[k>>2];m[j>>2]=m[n>>2];j=j+4|0;n=n+4|0;h=h+4|0;k=k+4|0;e=e+1|0;if((f|0)!=(e|0)){continue}break}break b}e=i[a+4224>>2];o=f+e|0;if(e>>>0>=o>>>0){break b}s=p(p(1)/p(l[a+4220>>2]));while(1){r=p(p(e>>>0)*s);m[h>>2]=r*m[k>>2];m[j>>2]=r*m[n>>2];j=j+4|0;n=n+4|0;h=h+4|0;k=k+4|0;e=e+1|0;if((o|0)!=(e|0)){continue}break}}o=i[g+12>>2]-f|0;i[g+12>>2]=o;e=f+i[a+4224>>2]|0;break a}i[g+4>>2]=i[a+4216>>2]-e;f=i[rb(g+12|0,g+4|0)>>2];c:{d:{e:{if(!(v<p(1))){e=0;if(f){break e}break d}t=i[a+4216>>2];u=i[a+4224>>2];e=t-u|0;o=e-f|0;if(e>>>0<=o>>>0){break c}s=p(p(1)/p(l[a+4220>>2]));while(1){r=p(p(e>>>0)*s);m[h>>2]=r*m[k>>2];m[j>>2]=r*m[n>>2];j=j+4|0;n=n+4|0;h=h+4|0;k=k+4|0;e=e+ -1|0;if(e>>>0>o>>>0){continue}break}break c}while(1){i[h>>2]=0;i[j>>2]=0;j=j+4|0;h=h+4|0;e=e+1|0;if((f|0)!=(e|0)){continue}break}}e=f<<2;n=e+n|0;k=e+k|0;t=i[a+4216>>2];u=i[a+4224>>2]}o=i[g+12>>2]-f|0;i[g+12>>2]=o;e=f+u|0;i[a+4224>>2]=e;e=e>>>0<t>>>0?e:0}i[w+4224>>2]=e;if(o){continue}break}}Oh(a,b,c,Pc(q,0),Pc(q,1),d)}Xa=g+16|0}function mv(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;a:while(1){i=b+ -4|0;b:while(1){d=a;c:while(1){d:{e:{f:{g:{h:{i:{j:{k:{a=b-d|0;e=a>>2;switch(e|0){case 4:break j;case 2:break k;case 0:case 1:break d;case 3:break g;case 5:break i;default:break h}}a=b+ -4|0;if(!pd(a,d)){break d}Gb(d,a);return}lv(d,d+4|0,d+8|0,b+ -4|0);return}kv(d,d+4|0,d+8|0,d+12|0,b+ -4|0);return}if((a|0)<=123){A4(d,b);return}g=((e|0)/2<<2)+d|0;l:{if((a|0)>=3997){a=(e|0)/4<<2;h=kv(d,a+d|0,g,a+g|0,i);break l}h=bm(d,g,i)}a=i;if(!pd(d,g)){while(1){a=a+ -4|0;if((d|0)==(a|0)){f=d+4|0;if(pd(d,i)){break e}while(1){if((f|0)==(i|0)){break d}if(pd(d,f)){Gb(f,i);f=f+4|0;break e}else{f=f+4|0;continue}}}if(!pd(a,g)){continue}break}Gb(d,a);h=h+1|0}e=d+4|0;if(e>>>0>=a>>>0){break f}while(1){f=e;e=e+4|0;if(pd(f,g)){continue}while(1){a=a+ -4|0;if(!pd(a,g)){continue}break}if(f>>>0>a>>>0){e=f;break f}else{Gb(f,a);g=(f|0)==(g|0)?a:g;h=h+1|0;continue}}}bm(d,d+4|0,b+ -4|0);break d}m:{if((e|0)==(g|0)){break m}if(!pd(g,e)){break m}Gb(e,g);h=h+1|0}if(!h){f=uE(d,e);a=e+4|0;if(uE(a,b)){b=e;a=d;if(!f){continue a}break d}if(f){continue b}}if((e-d|0)<(b-e|0)){mv(d,e,c);a=e+4|0;continue b}mv(e+4|0,b,c);b=e;a=d;continue a}a=i;if((f|0)==(a|0)){break d}while(1){e=f;f=e+4|0;if(!pd(d,e)){continue}while(1){a=a+ -4|0;if(pd(d,a)){continue}break}if(e>>>0>=a>>>0){d=e;continue c}else{Gb(e,a);continue}}}break}break}break}}function wba(a,b){var c=0,d=0;c=Xa-32|0;Xa=c;a:{b:{c:{if(Bd(b,38187)){Ab(a);break c}if(Bd(b,38188)){vba(a);break c}if(Bd(b,38204)){i[c>>2]=0;dr(a,c);break c}if(Bd(b,38226)){i[c>>2]=5;dr(a,c);break c}if(Bd(b,38248)){i[c>>2]=3;dr(a,c);break c}if(Bd(b,38270)){b=Xa-16|0;Xa=b;gba(a);Xa=b+16|0;break c}if(Bd(b,38293)){d=Bb(c,38187);b=lb(d);i[114610]=0;C(85,a|0,(b?38322:38320)|0)|0;a=i[114610];i[114610]=0;if((a|0)==1){break b}eb(d);break c}if(Bd(b,38324)){uba(a);break c}if(Bd(b,38341)){tba(a);break c}if(Bd(b,38354)){sba(a);break c}if(Bd(b,38365)){rba(a);break c}if(Bd(b,38377)){qba(a);break c}if(Bd(b,38393)){vk(c);b=j[c+16|0];i[114610]=0;C(85,a|0,(b?38320:38322)|0)|0;a=i[114610];i[114610]=0;if((a|0)!=1){Ie(c);break c}b=B()|0;A()|0;Ie(c);break a}if(Bd(b,38412)){vk(c);b=j[c+17|0];i[114610]=0;C(85,a|0,(b?38320:38322)|0)|0;a=i[114610];i[114610]=0;if((a|0)!=1){Ie(c);break c}b=B()|0;A()|0;Ie(c);break a}if(Bd(b,38438)){vk(c);b=j[c+18|0];i[114610]=0;C(85,a|0,(b?38320:38322)|0)|0;a=i[114610];i[114610]=0;if((a|0)!=1){Ie(c);break c}b=B()|0;A()|0;Ie(c);break a}if(Bd(b,38456)){pba(a);break c}if(Bd(b,38462)){oba(a);break c}if(Bd(b,38477)){nba(a);break c}if(Bd(b,38485)){mba(a);break c}if(Bd(b,38493)){lba(a);break c}if(Bd(b,38501)){kba(a);break c}if(Bd(b,38505)){jba(a);break c}if(Bd(b,38523)){iba(a);break c}Ab(a)}Xa=c+32|0;return}b=B()|0;A()|0;eb(d)}E(b|0);x()}function Ota(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,l=0,m=0;f=Xa-32|0;Xa=f;d=b&5;a:{if(!(c&5)){if(!d){break a}l=a,m=hs(g[a+36|0],g[a+37|0]),i[l+24>>2]=m;h[a+36>>1]=0;if((b|0)!=1){break a}e=XMa(i[a+24>>2],0,8272,0)+4181|0;d=_a;l=a,m=Vc(_Ma(e,e>>>0<4181?d+1|0:d,8363,0),_a),i[l+24>>2]=m;break a}if(d){break a}if((c|0)==1){e=XMa(i[a+24>>2],0,8363,0)+4136|0;d=_a;l=a,m=Vc(_Ma(e,e>>>0<4136?d+1|0:d,8272,0),_a),i[l+24>>2]=m}Nta(a)}if(c&3){h[a+38>>1]=0;h[a+40>>1]=0;g[a+36|0]=0;h[a+34>>1]=k[a+34>>1]&65499}if(c&7){h[a+32>>1]=64;d=k[a+34>>1];if(d&8){e=i[a+16>>2];i[a+4>>2]=i[a+12>>2];i[a+8>>2]=e;d=d&16?d|6:d&65529|2;h[a+34>>1]=d}i[a+12>>2]=0;i[a+16>>2]=0;h[a+34>>1]=d&65511}d=c&4;if(d){e=k[a+34>>1];if(!(e&32)){h[a+28>>1]=128;h[a+34>>1]=e|32}ze(a+40|0,15);ze(a+41|0,63)}b:{if(!j[a+41|0]|(!(b&16777248)|!d?!(c&16777248?b&4:0):0)){break b}d=j[a+40|0];if(!d){break b}b=j[a+39|0];if(b){l=a,m=Vm(Vc(((d<<8|b>>>1)>>>0)/(b>>>0)|0,0)),g[l+39|0]=m;break b}g[a+39|0]=255}c:{d:{if((c|0)!=4){if((c|0)==16777216){break c}if((c|0)!=32|j[a+38|0]!=2){break d}g[a+38|0]=3;break d}if(j[a+38|0]!=4){break d}g[a+38|0]=0}h[a+34>>1]=k[a+34>>1]&49151}e:{if(!(!(j[a+35|0]&2)|c&16777218)){i[f+24>>2]=0;i[f+8>>2]=0;i[f+16>>2]=0;i[f+20>>2]=0;i[f>>2]=0;i[f+4>>2]=0;No(a,0,f);break e}if(!(j[a+35|0]&2)|(c|0)!=2){break e}a=a+68|0;b=Nb(a,8);g[b|0]=j[b|0]&3;a=Nb(a,9);g[a|0]=j[a|0]&3}Xa=f+32|0}function Ema(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,k=0,l=0,m=0,n=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;g=Xa-32|0;Xa=g;m=a+24604|0;if(!Dma(m)){MJ(g+16|0,20640,20660,207);xba(g+16|0)}k=a+946300|0;e=a+906300|0;while(1){a:{n=i[e>>2];e=e+160|0;if((k|0)==(e|0)){break a}if(!n){continue}}break}b:{if(!b){break b}e=i[a+480208>>2];if(e&512){break b}r=a+8204|0;s=a+1074328|0;t=a+393352|0;k=a+12|0;p=a+1304392|0;h=i[a+1074380>>2];while(1){c:{if(h){break c}l=a;h=e|512;d:{if(e&256){break d}if(Cma(a)){e=i[a+480208>>2];break c}h=i[a+480208>>2]|512;if(j[a+1304512|0]){break d}e=Gma(a);f=i[a+480208>>2];h=f|256;if(e){break d}h=f|512}e=h;i[l+480208>>2]=e}if(e&512){u=a+1074392|0,v=Zk(a),i[u>>2]=v;break b}i[g+16>>2]=512;e=i[a+1074380>>2];i[g+12>>2]=3;i[g+24>>2]=b;i[g+20>>2]=e;i[g+8>>2]=g+16;e=i[g+12>>2];i[g>>2]=i[g+8>>2];i[g+4>>2]=e;f=YQ(g);if(i[a+24632>>2]){Fma(a,d,f)}jU(a,f);if($c(p)){zsa(i[p>>2],k,f,(o(i[a+480232>>2],i[a+480236>>2])>>>0)/48|0)}pea(t,k,f);if(n){fU(a,f)}if(i[a+24624>>2]==1){sua(k,f)}if(j[s+36|0]){Bma(a,f)}if(i[m>>2]!=128){nma(a+12|0,a+8204|0,i[a+24624>>2],f,i[a+24604>>2])}h=c;l=k;e=i[a+24624>>2];if((e|0)==4){tua(k,r,f);e=i[a+24624>>2]}$a[i[i[c>>2]+8>>2]](h,l,e,f);h=i[a+1074380>>2]-f|0;i[a+1074380>>2]=h;i[a+1074376>>2]=f+i[a+1074376>>2];q=f+q|0;b=b-f|0;if(!b){break b}e=i[a+480208>>2];if(!(e&512)){continue}break}}Xa=g+32|0;return q|0}function P4(a){var b=0,c=p(0),d=p(0),e=p(0),f=0,g=p(0);a:{b:{c:{d:{e:{b=(hNa(a),dNa(2));f=b&2147483647;if(f>>>0>=1100331076){if(f>>>0>2139095040){break a}if((b|0)<0){return p(-1)}if(a>p(88.7216796875)^1){break e}return p(a*p(1.7014118346046923e+38))}if(f>>>0<1051816473){break c}if(f>>>0>1065686417){break e}if((b|0)>=0){b=1;g=p(905800061445916e-20);e=p(a+p(-.6931381225585938));break d}b=-1;g=p(-905800061445916e-20);e=p(a+p(.6931381225585938));break d}c=p(p(a*p(1.4426950216293335))+(eNa(2,(hNa(a),dNa(2))&-2147483648|1056964608),iNa()));f:{if(p(q(c))<p(2147483648)){b=~~c;break f}b=-2147483648}c=p(b|0);g=p(c*p(905800061445916e-20));e=p(a+p(c*p(-.6931381225585938)))}a=e;a=p(a-g);g=p(p(e-a)-g);break b}if(f>>>0<855638016){break a}b=0}c=p(a*p(.5));d=p(a*c);e=p(p(d*p(p(d*p(.0015807170420885086))+p(-.03333321213722229)))+p(1));c=p(p(3)-p(c*e));c=p(d*p(p(e-c)/p(p(6)-p(a*c))));if(!b){return p(a-p(p(a*c)-d))}d=p(p(p(a*p(c-g))-g)-d);g:{switch(b+1|0){case 0:return p(p(p(a-d)*p(.5))+p(-.5));case 2:if(!(a<p(-.25)^1)){return p(p(d-p(a+p(.5)))*p(-2))}a=p(a-d);return p(p(a+a)+p(1));default:break g}}f=b<<23;e=(eNa(2,f+1065353216|0),iNa());if(b>>>0>=57){a=p(p(a-d)+p(1));return p(((b|0)==128?p(p(a+a)*p(1.7014118346046923e+38)):p(a*e))+p(-1))}c=(eNa(2,1065353216-f|0),iNa());b=(b|0)<23;a=p(p((b?p(p(1)-c):p(a-p(d+c)))+(b?p(a-d):p(1)))*e)}return a}function Rw(a,b,c){var d=0,e=0,f=0,h=0,l=0,m=0,n=0,o=0,p=0,q=0;e=Xa-16|0;Xa=e;l=kJ(b,c);a:{if(!i[b+656>>2]|!(g[l|0]&1)){break a}h=i[l+4>>2];m=a+1074308|0;kb(e+8|0,m,31);f=ib(e+8|0);d=bA(i[b+656>>2],c);if(Uc(d)){break a}h=h+(f^1)|0;kb(e+8|0,m,31);n=ib(e+8|0);f=j[d+12|0];b:{c:{if(!n){d:{if(!(f&2)){break d}f=k[vb(d,j[d+14|0])>>1]+!(i[a+480180>>2]&1048580)|0;if(!(!(j[b+89|0]&8)|(!(j[d+12|0]&4)|j[d+14|0]!=j[d+16|0]))){kb(e+8|0,m,70);o=ib(e+8|0)}if((h|0)!=(f|0)|o){break d}h=k[vb(d,j[d+13|0])>>1]}if(!(!(j[d+12|0]&4)|j[b+89|0]&8)){if((k[vb(d,j[d+16|0])>>1]+1|0)!=(h|0)){break b}h=k[vb(d,j[d+15|0])>>1];kb(e+8|0,m,93);if(!ib(e+8|0)|(c|0)!=1|i[b+88>>2]&2048){break b}g[l|0]=j[l|0]&254;break b}if(h>>>0<=k[Qi(d)>>1]){break b}o=1;h=k[Qi(d)>>1];break c}e:{f:{if(!(!(f&4)|j[b+669|0]&8)){if(i[l+8>>2]==-1){break f}kb(e+8|0,m,97);if(ib(e+8|0)){break f}f=j[d+12|0]}if(f&2){f=k[vb(d,j[d+13|0])>>1];n=k[vb(d,j[d+14|0])>>1]+1|0;break e}f=k[Qi(d)>>1];o=h>>>0>f>>>0;n=f;break e}f=k[vb(d,j[d+15|0])>>1];n=k[vb(d,j[d+16|0])>>1]+1|0}h=h>>>0<n>>>0?h:f}if(!o|c){break b}if(!(!(j[b+89|0]&8)|i[a+480180>>2]==16384?!(i[a+480180>>2]&16777248):0)){i[b+88>>2]=i[b+88>>2]|4096}if(j[Qi(d)+2|0]|(i[a+480180>>2]&16777248?0:!k[b+808>>1])){break b}i[b+696>>2]=0;i[b+720>>2]=0;i[b+680>>2]=0;i[b+88>>2]=i[b+88>>2]|4096}kb(e+8|0,m,31);p=l,q=ib(e+8|0)+h|0,i[p+4>>2]=q}Xa=e+16|0}function lva(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;g=Xa-32|0;Xa=g;p=i[a+16>>2];a:{b:{c:{j=i[a+8>>2];e=i[a+12>>2];d:{if((e|0)<1?1:(e|0)<=1?j>>>0<=805306368:0){if((e|0)>-2?1:(e|0)>=-2?j>>>0>=3489660928:0){break c}if((e|0)>-2?1:(e|0)>=-2?j>>>0>2147483647:0){break d}break b}if((e|0)>1?1:(e|0)>=1?j>>>0>2147483648:0){break b}}n=b+196648|0;break a}n=b+131112|0;break a}n=b+262184|0}l=i[a+40>>2];m=i[a+36>>2];f=i[a+4>>2];k=i[a>>2];i[g+24>>2]=k;i[g+28>>2]=f;i[g+16>>2]=j;i[g+20>>2]=e;e:{if(!d){b=l>>12;j=m>>12;break e}while(1){e=((((f&2147483647)<<1|k>>>31)&2147483646)<<1)+p|0;b=(k>>>16&65520)+n|0;k=h[b+14>>1];q=h[b+12>>1];r=h[b+10>>1];s=h[b+8>>1];t=h[b+6>>1];u=h[b+4>>1];v=h[b+2>>1];w=h[b>>1];j=0;b=1;while(1){f=j<<1;i[(g+8|0)+(j<<2)>>2]=(((((((o(h[(f|-8)+e>>1],v)+o(h[(f|-12)+e>>1],w)|0)+o(h[(f|-4)+e>>1],u)|0)+o(h[e+f>>1],t)|0)+o(h[(f|4)+e>>1],s)|0)+o(h[(f|8)+e>>1],r)|0)+o(h[(f|12)+e>>1],q)|0)+o(h[(f|16)+e>>1],k)|0)/32768;f=b;b=0;j=1;if(f){continue}break}b=i[a+32>>2];m=i[a+28>>2]+m|0;j=m>>12;i[c>>2]=i[c>>2]+o(j,i[g+8>>2]);l=b+l|0;b=l>>12;i[c+4>>2]=i[c+4>>2]+o(b,i[g+12>>2]);zb(g+24|0,g+16|0);d=d+ -1|0;if(d){c=c+8|0;k=i[g+24>>2];f=i[g+28>>2];continue}break}k=i[g+24>>2];f=i[g+28>>2]}i[a+40>>2]=l;i[a+20>>2]=j;i[a+36>>2]=m;i[a+24>>2]=b;i[a>>2]=k;i[a+4>>2]=f;Xa=g+32|0}function lF(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=+d;e=+e;var f=0,l=0,m=0,n=0,p=0,q=0,r=0,s=0;l=Xa-16|0;Xa=l;a:{b:{c:{d:{e:{m=(b|0)>=0;n=a+8|0;f:{if(Qk(n)){f=Qk(n);break f}f=ar(n)}if(!((f|0)>(b|0)?m:0)){a=P(8)|0;i[114610]=0;b=C(85,l|0,40625)|0;c=i[114610];i[114610]=0;if((c|0)==1){break e}Ub(a,b);i[114610]=0;G(2009,a|0,83568,2017);a=i[114610];i[114610]=0;if((a|0)!=1){break c}c=B()|0;A()|0;eb(b);break d}if(c>>>0>=120){a=P(8)|0;i[114610]=0;b=C(85,l|0,40644)|0;c=i[114610];i[114610]=0;if((c|0)!=1){Ub(a,b);i[114610]=0;G(2009,a|0,83568,2017);a=i[114610];i[114610]=0;if((a|0)!=1){break c}c=B()|0;A()|0;eb(b);break d}c=B()|0;A()|0;Q(a|0);break d}p=c+1|0;f=255;h[l>>1]=255;if((Rk(n)|0)>255){break a}q=a+32|0;m=255;c=255;while(1){m=i[q>>2]+o(m,896)|0;if(!i[m+1075060>>2]){break b}if(j[m+1075073|0]&16){h[l>>1]=c;f=c}c=c+ -1|0;m=c&65535;if((Rk(n)|0)<=(m|0)){continue}break}break a}c=B()|0;A()|0;Q(a|0)}E(c|0)}x()}h[l>>1]=c;f=c}a=a+32|0;c=i[a>>2]+o(f&65535,896)|0;f=c+1074984|0;Pm(f,i[a>>2],65535);g[c+1075808|0]=p;g[c+1075805|0]=p;h[c+1075792>>1]=0;_k(f);Co(i[a>>2],f,b+1|0,0,1,1);i[c+1075680>>2]=65536;Rr(i[a>>2],f,p,0,1,1,65535);r=c+1075676|0,s=Mm(tx(e*128,-128,128)+128),i[r>>2]=s;r=c+1075672|0,s=Mm(tx(d*256,0,256)),i[r>>2]=s;b=i[a>>2]+1074466|0;b=xx(b,w6(b,b+(k[i[a>>2]+480212>>1]<<1)|0,l));h[i[a>>2]+480212>>1]=b;Xa=l+16|0;return k[l>>1]}function Fua(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,p=0,q=0,r=0;e=Xa-48|0;Xa=e;p=i[a+16>>2];f=tf(e+16|0);i[f+8>>2]=a+112;i[f+16>>2]=i[a+128>>2];q=f,r=of(b+327720|0,i[b+20>>2],(i[a+88>>2]&16384)>>>14|0),i[q+12>>2]=r;b=i[f+16>>2];if(b){q=f,r=sf(a+8|0,b),i[q>>2]=r;i[f+4>>2]=_a}l=i[a+40>>2];m=i[a+36>>2];j=i[a+4>>2];g=i[a>>2];i[e+8>>2]=g;i[e+12>>2]=j;b=i[a+12>>2];i[e>>2]=i[a+8>>2];i[e+4>>2]=b;a:{if(!d){b=l>>12;k=m>>12;break a}while(1){b=0;k=b;n=g;i[e+40>>2]=g;i[e+44>>2]=b;j=((((j&2147483647)<<1|g>>>31)&2147483646)<<1)+p|0;b:{b=i[f+16>>2];if((b|0)<=0){break b}while(1){g=(k&2147483647)<<1|n>>>31;fd(i[f+8>>2],(h[(g<<1|2)+j>>1]+h[j+((g&2147483646)<<1)>>1]|0)/8<<16>>16);ed(i[f+8>>2],4);zb(e+40|0,f);if((b|0)<2){break b}b=b+ -1|0;n=i[e+40>>2];k=i[e+44>>2];continue}}d=d+ -1|0;b=i[f+8>>2];zb(b,b+8|0);b=i[f+8>>2];g=i[b+4>>2];if(g){k=b;b=(i[e+44>>2]&2147483647)<<1|i[e+40>>2]>>>31;fd(k,(h[(b<<1|2)+j>>1]+h[j+((b&2147483646)<<1)>>1]|0)/8<<16>>16);ed(i[f+8>>2],g);b=i[f+8>>2];g=i[b>>2];i[b>>2]=g;i[b+4>>2]=0}j=nf(b,i[f+12>>2]);b=i[a+32>>2];m=i[a+28>>2]+m|0;k=m>>12;i[c>>2]=i[c>>2]+o(j,k);l=b+l|0;b=l>>12;i[c+4>>2]=i[c+4>>2]+o(j,b);zb(e+8|0,e);if(d){c=c+8|0;g=i[e+8>>2];j=i[e+12>>2];continue}break}g=i[e+8>>2];j=i[e+12>>2]}i[a+40>>2]=l;i[a+20>>2]=k;i[a+36>>2]=m;i[a+24>>2]=b;i[a>>2]=g;i[a+4>>2]=j;Xa=e+48|0}function Uua(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0;j=Xa-16|0;Xa=j;f=i[a+48>>2];p=i[a+24>>2];q=i[a+20>>2];m=i[a+44>>2];r=i[a+16>>2];g=i[a+4>>2];k=i[a>>2];i[j+8>>2]=k;i[j+12>>2]=g;e=i[a+12>>2];i[j>>2]=i[a+8>>2];i[j+4>>2]=e;a:{if(!d){e=m;m=f;break a}while(1){e=(g<<1)+r|0;s=h[e+ -6>>1];g=(((k>>>16|0)+4&131064)<<1)+b|0;k=h[g+24>>1];t=h[e+ -4>>1];u=h[g+26>>1];v=h[e+ -2>>1];w=h[g+28>>1];x=h[e>>1];y=h[g+30>>1];z=h[e+2>>1];A=h[g+32>>1];B=h[e+4>>1];C=h[g+34>>1];D=h[e+6>>1];E=h[g+36>>1];F=h[e+8>>1];g=h[g+38>>1];e=i[a+60>>2];G=e;H=e>>31;e=Eb(m,-16777216,16776704);l=i[a+64>>2];f=Eb(f,-16777216,16776704);I=i[a+72>>2];J=i[c>>2];e=XMa(l,l>>31,e,e>>31);l=_a;K=e;e=i[a+68>>2];n=XMa(e,e>>31,f,f>>31);e=K+n|0;f=_a+l|0;f=e>>>0<n>>>0?f+1|0:f;l=e;g=(((((o(B,C)+o(z,A)|0)+o(D,E)|0)+o(g,F)|0)/2|0)+((((o(t,u)+o(k,s)|0)+o(v,w)|0)+o(x,y)|0)/2|0)|0)/16384<<8;e=g;k=XMa(G,H,e,e>>31);e=l+k|0;f=_a+f|0;f=e>>>0<k>>>0?f+1|0:f;e=e+8388608|0;if(e>>>0<8388608){f=f+1|0}f=(f&16777215)<<8|e>>>24;e=(f|0)/256|0;i[c>>2]=o(e,q)+J;i[c+4>>2]=i[c+4>>2]+o(e,p);e=f-(g&I)|0;zb(j+8|0,j);d=d+ -1|0;if(d){c=c+8|0;k=i[j+8>>2];g=i[j+12>>2];f=m;m=e;continue}break}k=i[j+8>>2];g=i[j+12>>2]}i[a+48>>2]=m;i[a+44>>2]=e;i[a>>2]=k;i[a+4>>2]=g;Xa=j+16|0}function JT(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=Xa-32|0;Xa=d;a:{if((j[a|0]|j[a+1|0]<<8|(j[a+2|0]<<16|j[a+3|0]<<24))==1397771593){kd(b,32);oi(d,1,a+4|0);oc(d+16|0,d);i[114610]=0;C(370,b+43|0,d+16|0)|0;c=i[114610];i[114610]=0;if((c|0)==1){break a}eb(d+16|0);h[b+30>>1]=j[a+19|0]<<2;Ag(b+30|0,256);h[b+32>>1]=j[a+17|0];Ag(b+32|0,64);c=a+47|0;h[b+28>>1]=(j[c|0]&127)<<2;Ag(b+28|0,256);if(g[c|0]<=-1){h[b+34>>1]=k[b+34>>1]|32}c=a+18|0;if(j[c|0]&16){h[b+34>>1]=k[b+34>>1]|2}if(j[c|0]&32){h[b+34>>1]=k[b+34>>1]|8}if(j[c|0]&64){h[b+34>>1]=k[b+34>>1]|4}if(g[c|0]<=-1){h[b+34>>1]=k[b+34>>1]|16}c=a+60|0;c=j[c|0]|j[c+1|0]<<8|(j[c+2|0]<<16|j[c+3|0]<<24);c=c?c:8363;i[b+24>>2]=c>>>0>256?c:256;c=a+48|0;i[b>>2]=j[c|0]|j[c+1|0]<<8|(j[c+2|0]<<16|j[c+3|0]<<24);c=a+52|0;i[b+4>>2]=j[c|0]|j[c+1|0]<<8|(j[c+2|0]<<16|j[c+3|0]<<24);c=a+56|0;i[b+8>>2]=j[c|0]|j[c+1|0]<<8|(j[c+2|0]<<16|j[c+3|0]<<24);c=a- -64|0;i[b+12>>2]=j[c|0]|j[c+1|0]<<8|(j[c+2|0]<<16|j[c+3|0]<<24);c=a+68|0;i[b+16>>2]=j[c|0]|j[c+1|0]<<8|(j[c+2|0]<<16|j[c+3|0]<<24);Nm(b);g[b+38|0]=j[(j[a+79|0]&7)+27856|0];g[b+41|0]=j[a+76|0];g[b+40|0]=j[a+77|0]&127;g[b+39|0]=j[a+78|0];c=512;e=a+46|0;b:{if(j[e|0]!=64){c=16384;if(j[e|0]!=128){break b}}h[b+34>>1]=k[b+34>>1]|c}a=a+72|0;c=j[a|0]|j[a+1|0]<<8|(j[a+2|0]<<16|j[a+3|0]<<24)}Xa=d+32|0;return c|0}a=B()|0;A()|0;eb(d+16|0);E(a|0);x()}function Vf(a,b,c,d){var e=0,f=0,g=0,h=0,l=0,m=0,n=0;f=Xa-16|0;Xa=f;i[f+12>>2]=d;e=b+ -1|0;g=0;a:{if(e>>>0>249){break a}h=Ts(a);g=i[a+480180>>2];if(!h){if(g&17408){a=((e&255)>>>0)/12|0;g=k[((e-o(a,12)&255)<<1)+21408>>1]<<4>>>a|0;break a}if(!(i[a+480180>>2]!=64?!(j[a+480208|0]&16):0)){kb(f,a+1074308|0,7);if(!(l=!ib(f),m=0,n=i[a+480180>>2]!=64,n?l:m)){a=((e&255)>>>0)/12|0;b=XMa(i[f+12>>2],0,i[(e-o(a,12)<<6&960)+25296>>2]<<a,0);a=_a;c=a>>>21|0;g=Vc((a&2097151)<<11|b>>>21,c);break a}a=((e&255)>>>0)/12|0;g=k[((e-o(a,12)&255)<<1)+21408>>1]<<5>>>a|0;break a}if(!d){i[f+12>>2]=8363}a=((e&255)>>>0)/12|0;kc(f+12|0,-1>>>a|0);g=Vc(_Ma(XMa(k[((e-o(a,12)&255)<<1)+21408>>1],0,267616,0),_a,i[f+12>>2]<<a,0),_a);break a}if(g&20){d=e>>>0>12;if(i[a+480180>>2]==16){b=c<<4}else{kb(f,a+1074308|0,76);b=ib(f)?c&-8:c}c=d?e:12;if(j[a+480208|0]&16){a=(((b|0)/-2|0)-(c<<6)|0)+8448|0;g=(a|0)>1?a:1;break a}c=c+ -12|0;a=((c&255)>>>0)/12|0;c=((b|0)/16|0)+(c-o(a,12)<<3&248)|0;i[f>>2]=c+8;Kd(f,0,103);c=c+((b|0)<0?-1:1)|0;c=(c|0)>-8?c:-8;d=b;b=b>>31;b=(d+b^b)&15;g=o(k[((((c|0)<95?c:95)<<1)+21888|0)+16>>1],b)+o(k[(i[f>>2]<<1)+21888>>1],16-b|0)<<1>>>a|0;break a}a=c>>>4&15;if(!(e>>>0<108?!(a|e>>>0<24):0)){b=o(a,12);a=((e&255)>>>0)/12|0;g=k[(b+(e-o(a,12)&255)<<1)+21008>>1]<<5>>>a|0;break a}g=k[(b<<1)+20782>>1]<<2}Xa=f+16|0;return g}function Vua(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,j=0,k=0,l=0,m=0,n=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0;k=Xa-16|0;Xa=k;f=i[a+48>>2];q=i[a+24>>2];r=i[a+20>>2];n=i[a+44>>2];s=i[a+16>>2];j=i[a+4>>2];l=i[a>>2];i[k+8>>2]=l;i[k+12>>2]=j;e=i[a+12>>2];i[k>>2]=i[a+8>>2];i[k+4>>2]=e;a:{if(!d){e=n;n=f;break a}while(1){e=j+s|0;t=g[e+ -3|0];j=(((l>>>16|0)+4&131064)<<1)+b|0;l=h[j+24>>1];u=g[e+ -2|0];v=h[j+26>>1];w=g[e+ -1|0];x=h[j+28>>1];y=g[e|0];z=h[j+30>>1];A=g[e+1|0];B=h[j+32>>1];C=g[e+2|0];D=h[j+34>>1];E=g[e+3|0];F=h[j+36>>1];G=g[e+4|0];j=h[j+38>>1];e=i[a+60>>2];H=e;I=e>>31;e=Eb(n,-16777216,16776704);m=i[a+64>>2];f=Eb(f,-16777216,16776704);J=i[a+72>>2];K=i[c>>2];e=XMa(m,m>>31,e,e>>31);m=_a;L=e;e=i[a+68>>2];p=XMa(e,e>>31,f,f>>31);e=L+p|0;f=_a+m|0;f=e>>>0<p>>>0?f+1|0:f;m=e;j=(((((o(C,D)+o(A,B)|0)+o(E,F)|0)+o(j,G)<<8)/2|0)+((((o(u,v)+o(l,t)|0)+o(w,x)|0)+o(y,z)<<8)/2|0)|0)/16384<<8;e=j;l=XMa(H,I,e,e>>31);e=m+l|0;f=_a+f|0;f=e>>>0<l>>>0?f+1|0:f;e=e+8388608|0;if(e>>>0<8388608){f=f+1|0}f=(f&16777215)<<8|e>>>24;e=(f|0)/256|0;i[c>>2]=o(e,r)+K;i[c+4>>2]=i[c+4>>2]+o(e,q);e=f-(j&J)|0;zb(k+8|0,k);d=d+ -1|0;if(d){c=c+8|0;l=i[k+8>>2];j=i[k+12>>2];f=n;n=e;continue}break}l=i[k+8>>2];j=i[k+12>>2]}i[a+48>>2]=n;i[a+44>>2]=e;i[a>>2]=l;i[a+4>>2]=j;Xa=k+16|0}function ewa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;b=Xa-48|0;Xa=b;t=i[a+16>>2];l=i[a+44>>2];i[b+32>>2]=l;f=i[a+48>>2];i[b+36>>2]=f;j=i[a+52>>2];i[b+40>>2]=j;m=i[a+56>>2];i[b+44>>2]=m;u=i[a+24>>2];v=i[a+20>>2];e=i[a+4>>2];k=i[a>>2];i[b+24>>2]=k;i[b+28>>2]=e;g=i[a+12>>2];i[b+16>>2]=i[a+8>>2];i[b+20>>2]=g;if(d){while(1){e=((((e&2147483647)<<1|k>>>31)&2147483646)<<1)+t|0;j=h[e>>1];i[b+8>>2]=j;i[b+12>>2]=h[e+2>>1];f=0;m=1;while(1){g=i[a+60>>2];q=g;k=(b+32|0)+(f<<3)|0;n=i[k>>2];e=Eb(n,-16777216,16776704);s=i[a+64>>2];l=Eb(i[k+4>>2],-16777216,16776704);p=i[a+68>>2];w=p;p=p>>31;i[k+4>>2]=n;n=i[a+72>>2];r=g>>31;j=j<<8;g=j;g=XMa(q,r,g,g>>31);q=_a;r=(b+8|0)+(f<<2)|0;f=g;g=XMa(s,s>>31,e,e>>31);f=f+g|0;e=_a+q|0;e=f>>>0<g>>>0?e+1|0:e;l=XMa(w,p,l,l>>31);f=l+f|0;e=_a+e|0;e=f>>>0<l>>>0?e+1|0:e;f=f+8388608|0;if(f>>>0<8388608){e=e+1|0}e=(e&16777215)<<8|f>>>24;i[r>>2]=(e|0)/256;i[k>>2]=e-(j&n);if(m){f=1;m=0;j=i[b+12>>2];continue}break}i[c>>2]=i[c>>2]+o(i[b+8>>2],v);i[c+4>>2]=i[c+4>>2]+o(i[b+12>>2],u);zb(b+24|0,b+16|0);d=d+ -1|0;if(d){c=c+8|0;k=i[b+24>>2];e=i[b+28>>2];continue}break}k=i[b+24>>2];m=i[b+44>>2];j=i[b+40>>2];l=i[b+32>>2];f=i[b+36>>2];e=i[b+28>>2]}i[a+56>>2]=m;i[a+52>>2]=j;i[a+48>>2]=f;i[a+44>>2]=l;i[a>>2]=k;i[a+4>>2]=e;Xa=b+48|0}function mva(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,j=0,k=0,l=0,m=0,n=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;f=Xa-32|0;Xa=f;q=i[a+16>>2];a:{b:{c:{j=i[a+8>>2];e=i[a+12>>2];d:{if((e|0)<1?1:(e|0)<=1?j>>>0<=805306368:0){if((e|0)>-2?1:(e|0)>=-2?j>>>0>=3489660928:0){break c}if((e|0)>-2?1:(e|0)>=-2?j>>>0>2147483647:0){break d}break b}if((e|0)>1?1:(e|0)>=1?j>>>0>2147483648:0){break b}}p=b+196648|0;break a}p=b+131112|0;break a}p=b+262184|0}m=i[a+40>>2];n=i[a+36>>2];l=i[a+4>>2];k=i[a>>2];i[f+24>>2]=k;i[f+28>>2]=l;i[f+16>>2]=j;i[f+20>>2]=e;e:{if(!d){b=m>>12;e=n>>12;break e}while(1){j=(((l&2147483647)<<1|k>>>31)&-2)+q|0;b=(k>>>16&65520)+p|0;k=h[b+14>>1];r=h[b+12>>1];s=h[b+10>>1];t=h[b+8>>1];u=h[b+6>>1];v=h[b+4>>1];w=h[b+2>>1];x=h[b>>1];b=0;e=1;while(1){i[(f+8|0)+(b<<2)>>2]=(((((((o(g[(b|-4)+j|0],w)+o(g[(b|-6)+j|0],x)|0)+o(g[(b|-2)+j|0],v)|0)+o(g[b+j|0],u)|0)+o(g[(b|2)+j|0],t)|0)+o(g[(b|4)+j|0],s)|0)+o(g[(b|6)+j|0],r)|0)+o(g[(b|8)+j|0],k)<<8)/32768;l=e;e=0;b=1;if(l){continue}break}b=i[a+32>>2];n=i[a+28>>2]+n|0;e=n>>12;i[c>>2]=i[c>>2]+o(e,i[f+8>>2]);m=b+m|0;b=m>>12;i[c+4>>2]=i[c+4>>2]+o(b,i[f+12>>2]);zb(f+24|0,f+16|0);d=d+ -1|0;if(d){c=c+8|0;k=i[f+24>>2];l=i[f+28>>2];continue}break}k=i[f+24>>2];l=i[f+28>>2]}i[a+40>>2]=m;i[a+20>>2]=e;i[a+36>>2]=n;i[a+24>>2]=b;i[a>>2]=k;i[a+4>>2]=l;Xa=f+32|0}function pma(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,l=0,m=0,n=0,p=0;f=Xa-16|0;Xa=f;i[b+28>>2]=0;i[b+32>>2]=0;a:{b:{c=i[b+88>>2];if(!(c&65536)){g=i[b+676>>2];d=i[b+672>>2];break b}d=i[b+20>>2];h=i[b+672>>2];c:{if((d|0)!=(h|0)){g=i[b+24>>2];l=i[b+676>>2];break c}l=i[b+676>>2];g=i[b+24>>2];if((l|0)==(g|0)){break b}}e=a+24604|0;c=f;h=(h|0)>(d|0);d:{if(!((l|0)<=(g|0)?!h:0)){d=zM(e);break d}d=yM(e)}i[c+12>>2]=d;kb(f,a+1074308|0,4);if(!(!ib(f)|!(i[a+480180>>2]&4))){d=i[a+24620>>2];d=XMa(d,d>>31,5,0)+500|0;c=_a;d=gc(YMa(d,d>>>0<500?c+1|0:c,1e3,0),_a);i[f+12>>2]=d}c=i[b+656>>2];e:{if(!(!c|!(h|(l|0)>(g|0)))){e=d;c=k[c+12>>1];if(c){e=(o(c,i[a+24620>>2])>>>0)/1e5|0}i[f+12>>2]=e;c=(c|0)!=0;break e}e=i[f+12>>2];c=0}if(!e){i[f+12>>2]=1;e=1}l=i[b+676>>2];m=i[b+24>>2];p=l-m<<12;h=i[b+672>>2];n=i[b+20>>2];g=h-n<<12;if(!(j[b+90|0]&32|(!(h|l)|(c|!(m|n))))){i[f+12>>2]=i[a+1074380>>2];Kd(f+12|0,d,2048);l=i[b+676>>2];e=i[f+12>>2];h=i[b+672>>2]}c=(p|0)/(e|0)|0;i[b+32>>2]=c;a=(g|0)/(e|0)|0;i[b+28>>2]=a;g=((o(e,c)|0)/-4096|0)+l|0;i[b+24>>2]=g;d=((o(a,e)|0)/-4096|0)+h|0;i[b+20>>2]=d;if(a|c){i[b+100>>2]=e;e=i[b+88>>2];break a}i[b+24>>2]=l;i[b+20>>2]=h;e=i[b+88>>2]&-65537;i[b+88>>2]=e;g=l;d=h;break a}i[b+24>>2]=g;i[b+20>>2]=d;e=c&-65537;i[b+88>>2]=e}i[b+88>>2]=e&-2097153;i[b+40>>2]=g<<12;i[b+36>>2]=d<<12;Xa=f+16|0}function fwa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,h=0,j=0,k=0,l=0,m=0,n=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;b=Xa-48|0;Xa=b;t=i[a+16>>2];l=i[a+44>>2];i[b+32>>2]=l;f=i[a+48>>2];i[b+36>>2]=f;j=i[a+52>>2];i[b+40>>2]=j;m=i[a+56>>2];i[b+44>>2]=m;u=i[a+24>>2];v=i[a+20>>2];e=i[a+4>>2];k=i[a>>2];i[b+24>>2]=k;i[b+28>>2]=e;h=i[a+12>>2];i[b+16>>2]=i[a+8>>2];i[b+20>>2]=h;if(d){while(1){e=(((e&2147483647)<<1|k>>>31)&-2)+t|0;j=g[e|0]<<8;i[b+8>>2]=j;i[b+12>>2]=g[e+1|0]<<8;f=0;m=1;while(1){h=i[a+60>>2];q=h;k=(b+32|0)+(f<<3)|0;n=i[k>>2];e=Eb(n,-16777216,16776704);s=i[a+64>>2];l=Eb(i[k+4>>2],-16777216,16776704);p=i[a+68>>2];w=p;p=p>>31;i[k+4>>2]=n;n=i[a+72>>2];r=h>>31;j=j<<8;h=j;h=XMa(q,r,h,h>>31);q=_a;r=(b+8|0)+(f<<2)|0;f=h;h=XMa(s,s>>31,e,e>>31);f=f+h|0;e=_a+q|0;e=f>>>0<h>>>0?e+1|0:e;l=XMa(w,p,l,l>>31);f=l+f|0;e=_a+e|0;e=f>>>0<l>>>0?e+1|0:e;f=f+8388608|0;if(f>>>0<8388608){e=e+1|0}e=(e&16777215)<<8|f>>>24;i[r>>2]=(e|0)/256;i[k>>2]=e-(j&n);if(m){f=1;m=0;j=i[b+12>>2];continue}break}i[c>>2]=i[c>>2]+o(i[b+8>>2],v);i[c+4>>2]=i[c+4>>2]+o(i[b+12>>2],u);zb(b+24|0,b+16|0);d=d+ -1|0;if(d){c=c+8|0;k=i[b+24>>2];e=i[b+28>>2];continue}break}k=i[b+24>>2];m=i[b+44>>2];j=i[b+40>>2];l=i[b+32>>2];f=i[b+36>>2];e=i[b+28>>2]}i[a+56>>2]=m;i[a+52>>2]=j;i[a+48>>2]=f;i[a+44>>2]=l;i[a>>2]=k;i[a+4>>2]=e;Xa=b+48|0}function Fta(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,l=0,m=0,n=0,o=0;c=Xa+ -64|0;Xa=c;h[c+62>>1]=b;f=Ti(a);e=Cta(c+48|0,f);a:{b:{if(!f){break b}b=0;while(1){n=$b(e,b),o=b-d|0,h[n>>1]=o;i[114610]=0;l=C(1171,a|0,b|0)|0;m=i[114610];i[114610]=0;if((m|0)==1){break a}d=(k[l>>1]==k[c+62>>1])+d|0;b=b+1|0;if((f|0)!=(b|0)){continue}break}if(!(d&65535)){break b}b=Jb(a);d=Kb(a);i[114610]=0;b=I(1172,b|0,d|0,c+62|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break a}i[c+32>>2]=b;b=Ad(c+40|0,c+32|0);n=c,o=Kb(a),i[n+16>>2]=o;d=i[Ad(c+24|0,c+16|0)>>2];b=i[b>>2];i[114610]=0;I(1173,a|0,b|0,d|0)|0;b=i[114610];i[114610]=0;if((b|0)==1){break a}n=c,o=Jb(a),i[n+32>>2]=o;n=c,o=Kb(a),i[n+16>>2]=o;if(pb(c+32|0,c+16|0)){while(1){b=k[i[c+32>>2]>>1];d=i[a+24>>2];i[114610]=0;d=C(442,d+484344|0,b|0)|0;f=i[114610];i[114610]=0;if((f|0)==1){break a}c:{if(!d){break c}b=Fb(i[a+24>>2]+484344|0,b);n=c,o=Jb(b),i[n+8>>2]=o;n=c,o=Kb(b),i[n>>2]=o;if(!pb(c+8|0,c)){break c}while(1){b=i[c+8>>2];d:{if(j[b+3|0]!=12){break d}d=j[b+5|0];if(Wb(e)>>>0<=d>>>0){break d}n=b,o=j[$b(e,j[b+5|0])|0],g[n+5|0]=o}jk(c+8|0);if(pb(c+8|0,c)){continue}break}}he(c+32|0);if(pb(c+32|0,c+16|0)){continue}break}}b=k[a+28>>1];if(Wb(e)>>>0<=b>>>0){break b}n=a,o=k[$b(e,k[a+28>>1])>>1],h[n+28>>1]=o}df(e);Xa=c- -64|0;return}a=B()|0;A()|0;df(e);E(a|0);x()}function oHa(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;c=Xa-16|0;Xa=c;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{b=j[a+3|0];switch(b+ -14|0){case 2:case 3:case 4:case 5:break b;case 8:break f;case 6:case 7:break g;case 1:break h;case 0:break i;default:break j}}switch(b+ -31|0){case 2:break d;case 0:break e;default:break b}}k:{l:{b=j[a+5|0];if((b|0)!=240){if((b|0)==15){break l}if(b){break k}g[a+3|0]=11;break a}g[a+5|0]=239;break c}g[a+5|0]=254;break c}if(b>>>0>=16){g[a+5|0]=b|15;break c}g[a+5|0]=b|240;break c}g[c+15|0]=j[a+5|0]>>>4;g[c+14|0]=15;e=a,f=j[Xb(c+15|0,c+14|0)|0]|32,g[e+5|0]=f;break c}b=j[a+5|0];if(b>>>0>=16){g[c+13|0]=b>>>4;g[c+12|0]=15;e=a,f=j[Xb(c+13|0,c+12|0)|0]|240,g[e+5|0]=f;break c}g[a+5|0]=b|224;break c}g[a+5|0]=((j[a+5|0]^-1)&254)>>>1;break c}e=a,f=_i(j[a+5|0]<<1),g[e+5|0]=f;break c}b=32;m:{n:{o:{p:{q:{r:{s:{t:{d=j[a+5|0];switch(d>>>4|0){case 3:break m;case 5:break n;case 14:break o;case 12:case 13:break p;case 11:break q;case 10:break r;case 8:break s;case 0:break c;default:break t}}g[a+3|0]=0;break c}b=64;break m}b=176;break m}b=224;break m}if(d){break c}g[a+3|0]=0;break c}g[a+5|0]=119;break c}b=48}g[a+5|0]=d&15|b}b=j[a+3|0]}if(b>>>0>=36){g[a+3|0]=0;break a}g[a+3|0]=j[b+13344|0];if(j[a+2|0]|(b|0)!=12){break a}g[a+2|0]=1;g[a+3|0]=0;b=j[a+5|0];g[a+5|0]=0;g[a+4|0]=b}Xa=c+16|0}function OZ(a,b,c,d,e,f){var g=0,k=0,l=0,m=0,n=0,o=0;i[c>>2]=a;i[f>>2]=d;a:{b:{c:{while(1){d:{d=i[c>>2];if(d>>>0>=b>>>0){break d}k=i[f>>2];if(k>>>0>=e>>>0){break d}m=2;a=j[d|0];if(a>>>0>1114111){break a}o=c;e:{if(a<<24>>24>=0){h[k>>1]=a;a=d+1|0;break e}if(a>>>0<194){break a}if(a>>>0<=223){if((b-d|0)<2){break b}g=j[d+1|0];if((g&192)!=128){break c}a=g&63|a<<6&1984;if(a>>>0>1114111){break c}h[k>>1]=a;a=d+2|0;break e}if(a>>>0<=239){if((b-d|0)<3){break b}l=j[d+2|0];g=j[d+1|0];f:{g:{if((a|0)!=237){if((a|0)!=224){break g}if((g&224)==160){break f}break c}if((g&224)==128){break f}break c}if((g&192)!=128){break c}}if((l&192)!=128){break c}a=l&63|((g&63)<<6|a<<12);if((a&65535)>>>0>1114111){break c}h[k>>1]=a;a=d+3|0;break e}if(a>>>0>244){break a}m=1;if((b-d|0)<4){break c}l=j[d+3|0];g=j[d+2|0];d=j[d+1|0];h:{i:{switch(a+ -240|0){case 0:if((d+112&255)>>>0>=48){break a}break h;case 4:if((d&240)!=128){break a}break h;default:break i}}if((d&192)!=128){break a}}if((g&192)!=128|(l&192)!=128){break a}if((e-k|0)<4){break c}m=2;l=l&63;n=g<<6;a=a&7;if((l|(n&4032|(d<<12&258048|a<<18)))>>>0>1114111){break c}d=d<<2;h[k>>1]=(d&192|a<<8|(g>>>4&3|d&60))+16320|55296;i[f>>2]=k+2;h[k+2>>1]=l|n&960|56320;a=i[c>>2]+4|0}i[o>>2]=a;i[f>>2]=i[f>>2]+2;continue}break}m=d>>>0<b>>>0}return m}return 1}return 2}function E$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;a=Xa-496|0;Xa=a;fc(a+488|0,d);i[114610]=0;m=F(2449,a+488|0)|0;g=i[114610];i[114610]=0;a:{b:{c:{d:{e:{f:{g:{if((g|0)!=1){if(lb(f)){g=i[Ki(f,0)>>2];i[114610]=0;j=C(2475,m|0,45)|0;k=i[114610];i[114610]=0;if((k|0)==1){break g}n=(g|0)==(j|0)}k=Ab(a+456|0);j=Ke(a+440|0);g=Ke(a+424|0);i[114610]=0;$(2503,c|0,n|0,a+488|0,a+480|0,a+476|0,a+472|0,k|0,j|0,g|0,a+420|0);c=i[114610];i[114610]=0;if((c|0)==1){break f}i[a+4>>2]=2420;l=wd(a+8|0,0,a+4|0);h:{if((lb(f)|0)>i[a+420>>2]){c=lb(f);h=i[a+420>>2];h=(lb(g)+(c-h<<1)|0)+1|0;break h}h=lb(g)+2|0}c=a+16|0;h=(lb(j)+h|0)+i[a+420>>2]|0;if(h>>>0<101){break e}de(l,Zc(h<<2));c=i[l>>2];if(c){break e}i[114610]=0;K(2421);b=i[114610];i[114610]=0;if((b|0)==1){break d}x()}f=B()|0;A()|0;break b}f=B()|0;A()|0;break b}f=B()|0;A()|0;break c}h=i[d+4>>2];o=xb(f);p=xb(f);f=lb(f);i[114610]=0;ea(2504,c|0,a+4|0,a|0,h|0,o|0,(f<<2)+p|0,m|0,n|0,a+480|0,i[a+476>>2],i[a+472>>2],k|0,j|0,g|0,i[a+420>>2]);f=i[114610];i[114610]=0;if((f|0)!=1){i[114610]=0;b=Y(2479,b|0,c|0,i[a+4>>2],i[a>>2],d|0,e|0)|0;c=i[114610];i[114610]=0;if((c|0)!=1){break a}}}f=B()|0;A()|0;lc(l)}nc(g);nc(j);eb(k)}ub(a+488|0);E(f|0);x()}lc(l);nc(g);nc(j);eb(k);ub(a+488|0);Xa=a+496|0;return b|0}function QT(a,b){var c=0,d=0,e=0,f=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=Xa-32|0;Xa=d;a:{b:{if((j[a|0]|j[a+1|0]<<8|(j[a+2|0]<<16|j[a+3|0]<<24))!=1229999433){break b}Et(d,3,a+32|0);oc(d+16|0,d);i[114610]=0;C(369,b+492|0,d+16|0)|0;c=i[114610];i[114610]=0;if((c|0)==1){break a}eb(d+16|0);oi(d,1,a+4|0);oc(d+16|0,d);i[114610]=0;C(369,b+524|0,d+16|0)|0;c=i[114610];i[114610]=0;if((c|0)==1){break a}eb(d+16|0);c=a+24|0;c=j[c|0]|j[c+1|0]<<8;i[b+4>>2]=64;i[b+8>>2]=128;i[b>>2]=c<<6;g[b+16|0]=j[a+26|0];g[b+17|0]=j[a+27|0];l=b+108|0;m=b+236|0;c=0;e=a- -64|0;while(1){f=c<<1;k=j[f+e|0];f=j[e+(f|1)|0];p=Mc(m,c),q=f,h[p>>1]=q;p=Nb(l,c),q=(k>>>0<120?k:c)+1|0,g[p|0]=q;c=c+1|0;if((c|0)!=120){continue}break}c=a+17|0;g[b+60|0]=j[b+60|0]&254|g[c|0]&1;g[b+60|0]=j[b+60|0]&253|j[c|0]&2;g[b+60|0]=j[b+60|0]&251|j[c|0]&4;l=b+61|0;g[l|0]=j[a+18|0];m=b+62|0;g[m|0]=j[a+19|0];f=b+63|0;g[f|0]=j[a+20|0];n=b- -64|0;g[n|0]=j[a+21|0];e=b+48|0;Lf(e,25);c=0;while(1){c:{o=c<<1;k=j[(o+a|0)+504|0];p=vb(e,c),q=k,h[p>>1]=q;if((k|0)==255){Lf(e,c);break c}k=j[((o|1)+a|0)+504|0];p=vb(e,c),q=k,g[p+2|0]=q;c=c+1|0;if((c|0)!=25){continue}}break}a=j[Ug(l,m)|0];if(qb(e)>>>0<=a>>>0){g[b+60|0]=j[b+60|0]&253}a=j[Ug(f,n)|0];if(qb(e)>>>0>a>>>0){break b}g[b+60|0]=j[b+60|0]&251}Xa=d+32|0;return}a=B()|0;A()|0;eb(d+16|0);E(a|0);x()}function VMa(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,p=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{g=b;if(g){e=c;if(!e){break j}f=d;if(!f){break i}f=r(f)-r(g)|0;if(f>>>0<=31){break h}break b}if((d|0)==1&c>>>0>=0|d>>>0>1){break b}b=(a>>>0)/(c>>>0)|0;Ya=a-o(b,c)|0;Za=0;_a=0;return b}e=d;if(!a){break g}if(!e){break f}f=e+ -1|0;if(f&e){break f}Ya=a;Za=f&g;a=g>>>WMa(e)|0;_a=0;return a}f=e+ -1|0;if(!(f&e)){break e}j=(r(e)+33|0)-r(g)|0;h=0-j|0;break c}j=f+1|0;h=63-f|0;break c}Ya=0;a=(g>>>0)/(e>>>0)|0;Za=g-o(a,e)|0;_a=0;return a}f=r(e)-r(g)|0;if(f>>>0<31){break d}break b}Ya=a&f;Za=0;if((e|0)==1){break a}c=a;a=WMa(e);d=a&31;if(32<=(a&63)>>>0){f=0;a=b>>>d|0}else{f=b>>>d|0;a=((1<<d)-1&b)<<32-d|c>>>d}_a=f;return a}j=f+1|0;h=63-f|0}e=b;g=a;f=j&63;i=f&31;if(32<=(f&63)>>>0){f=0;l=e>>>i|0}else{f=e>>>i|0;l=((1<<i)-1&e)<<32-i|g>>>i}a=h&63;h=a&31;if(32<=(a&63)>>>0){e=g<<h;a=0}else{e=(1<<h)-1&g>>>32-h|b<<h;a=g<<h}b=e;if(j){g=d+ -1|0;e=c+ -1|0;if((e|0)!=-1){g=g+1|0}h=e;while(1){e=l;f=f<<1|e>>>31;e=e<<1;k=f;f=b>>>31|e;m=k;e=k;k=f;i=g-((h>>>0<f>>>0)+e|0)|0;e=i>>31;i=i>>31;f=c&i;l=k-f|0;f=m-((d&e)+(k>>>0<f>>>0)|0)|0;e=b<<1|a>>>31;a=n|a<<1;b=e|p;e=0;m=e;k=i&1;n=k;j=j+ -1|0;if(j){continue}break}}Ya=l;Za=f;e=b<<1|a>>>31;a=k|a<<1;_a=e|m;return a}Ya=a;Za=b;a=0;b=0}_a=b;return a}function I$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var h=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;a=Xa-192|0;Xa=a;fc(a+184|0,d);i[114610]=0;o=F(21,a+184|0)|0;h=i[114610];i[114610]=0;a:{b:{c:{d:{e:{f:{g:{if((h|0)!=1){if(lb(f)){h=j[Sb(f,0)|0];i[114610]=0;l=C(22,o|0,45)|0;m=i[114610];i[114610]=0;if((m|0)==1){break g}p=(h|0)==(l&255)}m=Ab(a+160|0);l=Ab(a+144|0);h=Ab(a+128|0);i[114610]=0;$(2501,c|0,p|0,a+184|0,a+176|0,a+175|0,a+174|0,m|0,l|0,h|0,a+124|0);c=i[114610];i[114610]=0;if((c|0)==1){break f}i[a+4>>2]=2420;n=wd(a+8|0,0,a+4|0);h:{if((lb(f)|0)>i[a+124>>2]){c=lb(f);k=i[a+124>>2];k=(lb(h)+(c-k<<1)|0)+1|0;break h}k=lb(h)+2|0}c=a+16|0;k=(lb(l)+k|0)+i[a+124>>2]|0;if(k>>>0<101){break e}de(n,Zc(k));c=i[n>>2];if(c){break e}i[114610]=0;K(2421);b=i[114610];i[114610]=0;if((b|0)==1){break d}x()}f=B()|0;A()|0;break b}f=B()|0;A()|0;break b}f=B()|0;A()|0;break c}k=i[d+4>>2];q=xb(f);r=xb(f);f=lb(f);i[114610]=0;ea(2502,c|0,a+4|0,a|0,k|0,q|0,f+r|0,o|0,p|0,a+176|0,g[a+175|0],g[a+174|0],m|0,l|0,h|0,i[a+124>>2]);f=i[114610];i[114610]=0;if((f|0)!=1){i[114610]=0;b=Y(17,b|0,c|0,i[a+4>>2],i[a>>2],d|0,e|0)|0;c=i[114610];i[114610]=0;if((c|0)!=1){break a}}}f=B()|0;A()|0;lc(n)}eb(h);eb(l);eb(m)}ub(a+184|0);E(f|0);x()}lc(n);eb(h);eb(l);eb(m);ub(a+184|0);Xa=a+192|0;return b|0}function Gua(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,h=0,j=0,k=0,l=0,m=0,n=0,p=0,q=0,r=0;e=Xa-48|0;Xa=e;p=i[a+16>>2];f=tf(e+16|0);i[f+8>>2]=a+112;i[f+16>>2]=i[a+128>>2];q=f,r=of(b+327720|0,i[b+20>>2],(i[a+88>>2]&16384)>>>14|0),i[q+12>>2]=r;b=i[f+16>>2];if(b){q=f,r=sf(a+8|0,b),i[q>>2]=r;i[f+4>>2]=_a}l=i[a+40>>2];m=i[a+36>>2];j=i[a+4>>2];h=i[a>>2];i[e+8>>2]=h;i[e+12>>2]=j;b=i[a+12>>2];i[e>>2]=i[a+8>>2];i[e+4>>2]=b;a:{if(!d){b=l>>12;k=m>>12;break a}while(1){b=0;k=b;n=h;i[e+40>>2]=h;i[e+44>>2]=b;j=(((j&2147483647)<<1|h>>>31)&-2)+p|0;b:{b=i[f+16>>2];if((b|0)<=0){break b}while(1){h=(k&2147483647)<<1|n>>>31;fd(i[f+8>>2],g[(h|1)+j|0]+g[j+(h&-2)|0]<<5);ed(i[f+8>>2],4);zb(e+40|0,f);if((b|0)<2){break b}b=b+ -1|0;n=i[e+40>>2];k=i[e+44>>2];continue}}d=d+ -1|0;b=i[f+8>>2];zb(b,b+8|0);b=i[f+8>>2];h=i[b+4>>2];if(h){k=b;b=(i[e+44>>2]&2147483647)<<1|i[e+40>>2]>>>31;fd(k,g[(b|1)+j|0]+g[j+(b&-2)|0]<<5);ed(i[f+8>>2],h);b=i[f+8>>2];h=i[b>>2];i[b>>2]=h;i[b+4>>2]=0}j=nf(b,i[f+12>>2]);b=i[a+32>>2];m=i[a+28>>2]+m|0;k=m>>12;i[c>>2]=i[c>>2]+o(j,k);l=b+l|0;b=l>>12;i[c+4>>2]=i[c+4>>2]+o(j,b);zb(e+8|0,e);if(d){c=c+8|0;h=i[e+8>>2];j=i[e+12>>2];continue}break}h=i[e+8>>2];j=i[e+12>>2]}i[a+40>>2]=l;i[a+20>>2]=k;i[a+36>>2]=m;i[a+24>>2]=b;i[a>>2]=h;i[a+4>>2]=j;Xa=e+48|0}function GDa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,i=0,l=0,m=0,n=0,o=0,p=0,q=0;d=Xa-432|0;Xa=d;pc(b);Gy(b,d+376|0,d+296|0,d+8|0);e=d;if(j[d+408|0]|j[d+409|0]<<8|(j[d+410|0]<<16|j[d+411|0]<<24)){f=j[d+427|0]+1|0}else{f=1}p=e,q=_i(f),g[p+4|0]=q;i=j[Xb(15082,d+4|0)|0];g[d+7|0]=i;h[d+4>>1]=4;a:{b:{if(!i){break b}i=d+291|0;while(1){c:{f=j[d+8|0]|j[d+9|0]<<8;e=f<<8&16711680|f<<24;if(!(e>>16<0|j[i|0]>63)){if(f){e=(e|(f>>>8&65280|f>>>24))>>>16|0;n=e>>>0>1?e:1;f=0;while(1){e=j[d+392|0]|j[d+393|0]<<8|(j[d+394|0]<<16|j[d+395|0]<<24);d:{if(!vc(b,(e<<24|e<<8&16711680|(e>>>8&65280|e>>>24))+(f<<2)|0)){break d}if(!vc(b,Bz(b))){break d}e=d;e:{if(!c){m=id(b);break e}m=pp(b)}h[e+2>>1]=m;p=d,q=k[ri(d+4|0,d+2|0)>>1],h[p+4>>1]=q}f=f+1|0;if((n|0)!=(f|0)){continue}break}}e=j[d+296|0]|j[d+297|0]<<8|(j[d+298|0]<<16|j[d+299|0]<<24);if((e<<24|e<<8&16711680|(e>>>8&65280|e>>>24))>>>0>o>>>0){e=j[d+296|0]|j[d+297|0]<<8|(j[d+298|0]<<16|j[d+299|0]<<24);if(vc(b,e<<24|e<<8&16711680|(e>>>8&65280|e>>>24))){break c}}g[d+7|0]=l+1;break b}hA(a);break a}e=j[d+296|0]|j[d+297|0]<<8|(j[d+298|0]<<16|j[d+299|0]<<24);Gy(b,d+376|0,d+296|0,d+8|0);o=e<<8&16711680|e<<24|(e>>>8&65280|e>>>24);l=l+1|0;if((l&255)>>>0<j[d+7|0]){continue}break}}h[a>>1]=k[d+4>>1];g[a+2|0]=j[d+7|0]}Xa=d+432|0}function h6(a,b,c){var d=0,e=0,f=0,l=0,m=0,n=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;e=j[c+1|0];l=o((e>>>3&1)+(e>>>4&1)|0,3)+(j[c+2|0]>>>2&3)|0;m=l-((l|0)!=0)|0;l=j[c+3|0]>191?1:2;a:{if(e&8){n=zd(a,9);l=l<<1;d=zd(a,l+7|0);break a}n=zd(a,l|8)>>>l|0}e=o(m,40);r=e+42720|0;s=e+43040|0;t=o(m,23)+42528|0;m=0;b:{while(1){e=j[c+3|0];p=zd(a,12);h[b+4>>1]=p;f=zd(a,9);h[b+6>>1]=f;if((f&65535)>>>0>288){break b}e=e>>>0>191?d<<4:d;u=b,v=zd(a,8),g[u+10|0]=v;d=zd(a,j[c+1|0]&8?4:9);g[b+13|0]=22;g[b+14|0]=0;i[b>>2]=t;h[b+8>>1]=d;c:{if(zd(a,1)){d=zd(a,2);g[b+11|0]=d;if(!(d&255)){break b}f=zd(a,1);h[b+18>>1]=65287;g[b+12|0]=f;if(j[b+11|0]==2){d=b;d:{if(!(f&255)){i[b>>2]=r;g[b+18|0]=8;q=39;f=0;break d}i[b>>2]=s;q=30;f=j[c+1|0]&8?8:6}g[d+14|0]=q;g[b+13|0]=f;e=e&3855}d=zd(a,10);u=b,v=zd(a,3),g[u+21|0]=v;u=b,v=zd(a,3),g[u+22|0]=v;u=b,v=zd(a,3),g[u+23|0]=v;d=d<<5;break c}g[b+11|0]=0;g[b+12|0]=0;d=zd(a,15);u=b,v=zd(a,4),g[u+18|0]=v;f=zd(a,3);g[b+20|0]=255;g[b+19|0]=f}g[b+17|0]=d&31;g[b+15|0]=d>>>10;g[b+16|0]=d>>>5&31;m=(p&65535)+m|0;d=b;e:{if(j[c+1|0]&8){f=zd(a,1);break e}f=k[b+8>>1]>499}g[d+24|0]=f;u=b,v=zd(a,1),g[u+25|0]=v;d=zd(a,1);g[b+27|0]=e>>>12&15;g[b+26|0]=d;b=b+28|0;d=e<<4;l=l+ -1|0;if(l){continue}break}return(i[a+4>>2]+m|0)>(i[a+8>>2]+(n<<3)|0)?-1:n}return-1}function JO(a,b){var c=0;a:{b:{c:{d:{if(Hd(a,15613)){break d}if(Hd(a,15640)){break d}if(Hd(a,15645)){break d}if(Hd(a,16137)){break d}if(!Hd(a,16142)){break c}}h[b+8>>1]=4;i[b>>2]=16147;break b}e:{f:{if(Hd(a,15618)){break f}if(Hd(a,15623)){break f}if(!Hd(a,16180)){break e}}g[b+10|0]=1;h[b+8>>1]=4;i[b>>2]=16185;return 1}g:{if(!Hd(a,16198)){if(!Hd(a,16203)){break g}}h[b+8>>1]=8;i[b>>2]=16208;break b}h:{if(!Hd(a,16218)){if(!Hd(a,16223)){break h}}i[b>>2]=16228;h[b+8>>1]=g[a+2|0]+ -48;break b}i:{if(!Hd(a,15603)){if(!Hd(a,15608)){break i}}i[b+4>>2]=1;i[b>>2]=16246;h[b+8>>1]=j[a|0]==56?8:4;return 1}if(!(Xc(a,16277,3)|(j[a+3|0]+ -52&255)>>>0>4)){i[b>>2]=16281;h[b+8>>1]=g[a+3|0]+ -48;break b}j:{if(Xc(a,16297,3)){if(Xc(a,16301,3)){break j}}if((j[a+3|0]+ -52&255)>>>0>5){break j}g[b+13|0]=1;g[b+11|0]=1;i[b>>2]=16305;h[b+8>>1]=g[a+3|0]+ -48;return 1}k:{if((j[a|0]+ -49&255)>>>0>8){break k}if(!Xc(a+1|0,16317,3)){g[b+12|0]=1;i[b>>2]=16321;h[b+8>>1]=g[a|0]+ -48;return 1}if((j[a+1|0]+ -48&255)>>>0>9|((j[a+2|0]|j[a+3|0]<<8)!=20035?(j[a+2|0]|j[a+3|0]<<8)!=18499:0)){break k}g[b+12|0]=1;i[b>>2]=16321;h[b+8>>1]=(g[a+1|0]+o(g[a|0],10)|0)+ -528;return 1}if(Xc(a,16352,3)|(j[a+3|0]+ -52&255)>>>0>5){break a}i[b>>2]=16356;h[b+8>>1]=g[a+3|0]+ -48}c=1}return c}function Kja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;c=Xa-144|0;Xa=c;e=Ek(c+40|0,a);i[114610]=0;d=C(686,c+24|0,32309)|0;a=i[114610];i[114610]=0;a:{b:{c:{d:{if((a|0)!=1){i[114610]=0;i[c+16>>2]=19465472;i[c+20>>2]=0;G(687,e|0,d|0,c+16|0);a=i[114610];i[114610]=0;if((a|0)==1){break d}ob(d);if(!(i[e>>2]&1073741824)){break c}break a}a=B()|0;A()|0;break b}a=B()|0;A()|0;ob(d);break b}a=ke(b);i[114610]=0;h[c+16>>1]=a;h[c+14>>1]=65535;d=C(686,c+24|0,32315)|0;a=i[114610];i[114610]=0;e:{if((a|0)!=1){i[114610]=0;a=I(1184,e|0,c+14|0,d|0)|0;f=i[114610];i[114610]=0;if((f|0)==1){break e}ob(d);if((a|0)!=1){h[c+16>>1]=k[c+14>>1]}Ag(c+16|0,k[i[19847]+10>>1]);f:{if(k[c+16>>1]<=ke(b)>>>0){break f}i[114610]=0;D(401,b|0,k[c+16>>1]);a=i[114610];i[114610]=0;if((a|0)!=1){break f}a=B()|0;A()|0;break b}h[c+12>>1]=0;if(!k[c+16>>1]){break a}a=0;g:{while(1){h:{a=Fb(b,a&65535);i[114610]=0;D(1587,c+24|0,c+12|0);d=i[114610];i[114610]=0;if((d|0)==1){break h}i[114610]=0;N(1569,e|0,a|0,c+24|0,1588)|0;a=i[114610];i[114610]=0;if((a|0)==1){break g}ob(c+24|0);a=k[c+12>>1]+1|0;h[c+12>>1]=a;if((a&65535)>>>0<k[c+16>>1]){continue}break a}break}a=B()|0;A()|0;break b}a=B()|0;A()|0;ob(c+24|0);break b}a=B()|0;A()|0;break b}a=B()|0;A()|0;ob(d)}Yf(e);E(a|0);x()}Yf(e);Xa=c+144|0}function bU(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,h=0,j=0,k=0;f=Xa-1072|0;Xa=f;e=wh(f+16|0);j=Gl(a,e);hb(e);i[a+1060>>2]=0;i[a+1064>>2]=0;i[a+1056>>2]=c;e=a+1068|0;i[e>>2]=0;i[e+4>>2]=0;i[a+1076>>2]=0;g[a+1080|0]=d;a:{b:{if($d(c)){k=a+1060|0;e=0;while(1){i[a+1060>>2]=0;i[a+1064>>2]=0;c:{if(!i[c>>2]){break c}while(1){i[114610]=0;d=C(258,b|0,2)|0;h=i[114610];i[114610]=0;d:{e:{f:{g:{if((h|0)!=1){if(!d){break c}i[114610]=0;d=F(357,b|0)|0;h=i[114610];i[114610]=0;if((h|0)==1){break g}if(!d){break d}i[114610]=0;G(341,f|0,b|0,d|0);d=i[114610];i[114610]=0;if((d|0)==1){break f}d=Gl(f+16|0,f);Cd(j,d);Tb(j+16|0,d+16|0,1040);hb(f+16|0);hb(f);i[a+1072>>2]=0;i[a+1076>>2]=0;h=Kp(i[a+1056>>2]);d=i[a+1056>>2];if(h>>>0>=2){d=i[d+20>>2];i[114610]=0;D(358,a|0,d+(e<<1)|0);d=i[114610];i[114610]=0;if((d|0)!=1){break d}break e}d=i[d+20>>2];i[114610]=0;D(359,a|0,d+e|0);d=i[114610];i[114610]=0;if((d|0)==1){break e}break d}d=B()|0;A()|0;break a}d=B()|0;A()|0;break a}d=B()|0;A()|0;break a}d=H(77024)|0;if((A()|0)!=(U(77024)|0)){break a}M(d|0)|0;i[114610]=0;K(20);d=i[114610];i[114610]=0;if((d|0)==1){break b}}if(l[k>>2]<l[c>>2]){continue}break}}e=e+1|0;if(e>>>0<$d(i[a+1056>>2])>>>0){continue}break}}Xa=f+1072|0;return a|0}d=B()|0;A()|0}hb(a);E(d|0);x()}function QGa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,h=0,k=0,l=0,m=0;c=Xa-32|0;Xa=c;a:{b:{if(!wb(b,9)){break b}k=a+484344|0;l=a+480280|0;while(1){$m(b,c+28|0);d=Cf(b);c:{if(!((j[c+28|0]|j[c+29|0]<<8|(j[c+30|0]<<16|j[c+31|0]<<24))==1229999433|(j[c+28|0]|j[c+29|0]<<8|(j[c+30|0]<<16|j[c+31|0]<<24))==1397771593|((j[c+28|0]|j[c+29|0]<<8|(j[c+30|0]<<16|j[c+31|0]<<24))==1297110104|(j[c+28|0]|j[c+29|0]<<8|(j[c+30|0]<<16|j[c+31|0]<<24))==1297110099))){if(wb(b,d)){break c}}tg(b,8);break b}ad(c+8|0,b,d);d=l;d:{if((j[c+28|0]|j[c+29|0]<<8|(j[c+30|0]<<16|j[c+31|0]<<24))==1481001027){while(1){i[114610]=0;e=F(390,c+8|0)|0;f=i[114610];i[114610]=0;if((f|0)==1){break a}g[d+8|0]=e;d=d+32|0;if((k|0)!=(d|0)){continue}break d}}e:{if(j[c+28|0]!=70){break e}d=j[c+29|0];e=(d|0)==88;if((d+ -48&255)>>>0>9?!e:0){break e}f=j[c+30|0];if((f+ -48&255)>>>0>9){break e}h=j[c+31|0];if((h+ -48&255)>>>0>9){break e}d=(o(f,10)+(e?-16:o(d,100)+48|0)|0)+h&255;if(d>>>0>249){break d}i[114610]=0;D(670,c+8|0,(o(d,160)+a|0)+906300|0);d=i[114610];i[114610]=0;if((d|0)!=1){break d}break a}if((j[c+28|0]|j[c+29|0]<<8|(j[c+30|0]<<16|j[c+31|0]<<24))!=1430540109){break d}i[a+1074304>>2]=0;m=1}hb(c+8|0);if(wb(b,9)){continue}break}}Xa=c+32|0;return m|0}a=B()|0;A()|0;hb(c+8|0);E(a|0);x()}function UKa(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,h=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;l=Xa-32|0;Xa=l;g[l+12|0]=0;o=jS(l+16|0,d,l+12|0);k=i[o>>2];i[l+12>>2]=d;f=d;a:{if(!b|!f){break a}while(1){p=l;h=b+ -1|0;f=j[a|0];b:{c:{if(!(!h|(f|0)!=(e&255))){f=j[a+1|0];i[114610]=0;i[l+8>>2]=f;f=C(33,l+8|0,l+12|0)|0;h=i[114610];i[114610]=0;d:{if((h|0)!=1){n=a+2|0;h=b+ -2|0;if(!h){break d}m=i[f>>2];if(!(m&255)){break d}h=j[n|0];while(1){g[k|0]=h;f=i[l+12>>2]+ -1|0;i[l+12>>2]=f;k=k+1|0;m=m+ -1|0;if(m&255){continue}break}h=b+ -3|0;n=a+3|0;break b}a=B()|0;A()|0;Jp(o);E(a|0);x()}g[k|0]=e;f=i[l+12>>2]+ -1|0;break c}n=a+1|0;g[k|0]=f;f=i[l+12>>2]+ -1|0}i[p+12>>2]=f;k=k+1|0}if(!h){break a}a=n;b=h;if(f){continue}break}}n=i[o>>2];e=d-f|0;e:{if(!e){break e}k=128;h=0;while(1){b=j[n|0];m=0;f=0;while(1){a=c+h|0;p=a;r=j[a|0];a=b&k;g[p|0]=r|(a<<8|a)>>>(f-m&7);a=h+1|0;h=a>>>0<d>>>0?a:0;f=(a>>>0>=d>>>0)+f|0;k=(k<<8|k)>>>1&255;a=m&65535;m=m+1|0;if(a>>>0<7){continue}break}k=(k<<8|k)>>>f&255;n=n+1|0;q=q+1|0;if((q|0)!=(e|0)){continue}break}if(!e){break e}m=0;while(1){d=c;f=d;h=m<<24>>24;b=g[d|0];d=128;f:{if((b|0)==-128){break f}a=b;d=a;if((a|0)>-1){break f}d=0-(b&127)|0}m=h-(d&255)|0;g[f|0]=m;c=c+1|0;e=e+ -1|0;if(e){continue}break}}Jp(o);Xa=l+32|0}function nxa(){var a=0,b=0,c=0,d=0,e=0,f=0,h=0,j=0,k=0,l=0;b=Xa-48|0;Xa=b;f=b+40|0;a=f;i[a>>2]=-1;i[a+4>>2]=-1;ysa();k=b,l=z4(),i[k+8>>2]=l;i[b+12>>2]=_a;a=i[b+12>>2];i[b+16>>2]=i[b+8>>2];i[b+20>>2]=a;a=Xa-16|0;Xa=a;c=usa(b+16|0);Xa=a+16|0;i[b+24>>2]=c;i[b+28>>2]=_a;d=i[b+24>>2];e=d<<8&16711680|d<<24;a=i[b+28>>2];c=a<<24|d>>>8;h=c&65280;c=a<<8|d>>>24;e=c&255|h|e;c=b+32|0;a=((a&255)<<24|d>>>8)&-16777216|((a&16777215)<<8|d>>>24)&16711680|(a>>>8&65280|a>>>24)|j;g[c|0]=a;g[c+1|0]=a>>>8;g[c+2|0]=a>>>16;g[c+3|0]=a>>>24;a=e;g[c+4|0]=a;g[c+5|0]=a>>>8;g[c+6|0]=a>>>16;g[c+7|0]=a>>>24;a=i[b+36>>2];i[b+24>>2]=i[b+32>>2];i[b+28>>2]=a;CM(f,b+24|0,fb(b+24|0));k=b,l=w4(),i[k+8>>2]=l;i[b+12>>2]=_a;a=i[b+12>>2];i[b+16>>2]=i[b+8>>2];i[b+20>>2]=a;a=Xa-16|0;Xa=a;c=osa(b+16|0);Xa=a+16|0;i[b+24>>2]=c;i[b+28>>2]=_a;d=i[b+24>>2];e=d<<8&16711680|d<<24;a=i[b+28>>2];c=a<<24|d>>>8;h=c&65280;c=a<<8|d>>>24;e=c&255|h|e;c=b+32|0;a=((a&255)<<24|d>>>8)&-16777216|((a&16777215)<<8|d>>>24)&16711680|(a>>>8&65280|a>>>24)|j;g[c|0]=a;g[c+1|0]=a>>>8;g[c+2|0]=a>>>16;g[c+3|0]=a>>>24;a=e;g[c+4|0]=a;g[c+5|0]=a>>>8;g[c+6|0]=a>>>16;g[c+7|0]=a>>>24;a=i[b+36>>2];i[b+24>>2]=i[b+32>>2];i[b+28>>2]=a;CM(f,b+24|0,fb(b+24|0));Xa=b+48|0;_a=i[f+4>>2];return i[f>>2]}function Iga(a){a=a|0;var b=0,c=0,d=0,e=0,f=p(0),g=0,h=0;c=Xa-32|0;Xa=c;a:{b=i[a+20>>2];b:{if(!b){break b}i[b+148>>2]=-1;g=c,h=$a[i[i[a>>2]+40>>2]](a)|0,i[g+16>>2]=h;i[c+8>>2]=1073741822;e=i[Nd(c+16|0,c+8|0)>>2];b=e<<2;if(!b){break b}d=i[a+20>>2];i[114610]=0;D(508,d+4|0,b+4|0);b=i[114610];i[114610]=0;c:{d:{e:{f:{if((b|0)!=1){b=i[a+20>>2];i[114610]=0;D(1738,c+8|0,b+4|0);b=i[114610];i[114610]=0;if((b|0)==1){break d}i[114610]=0;i[c>>2]=0;i[c+4>>2]=0;G(1739,c+16|0,c+8|0,c|0);b=i[114610];i[114610]=0;if((b|0)==1){break f}i[114610]=0;C(1740,c+16|0,0)|0;b=i[114610];i[114610]=0;g:{if((b|0)==1){break g}b=i[i[a>>2]+176>>2];i[114610]=0;D(b|0,a|0,-1);b=i[114610];i[114610]=0;if((b|0)==1){break g}if((e|0)>=1){b=0;while(1){d=i[i[a>>2]+48>>2];i[114610]=0;f=p(ba(d|0,a|0,b|0));d=i[114610];i[114610]=0;if((d|0)==1){break e}i[114610]=0;m[c+8>>2]=f;C(1741,c+16|0,c+8|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break e}b=b+1|0;if((e|0)!=(b|0)){continue}break}}b=i[i[a>>2]+180>>2];i[114610]=0;L(b|0,a|0);b=i[114610];i[114610]=0;if((b|0)!=1){break b}}b=H(71348)|0;break c}b=H(71348)|0;break c}b=H(71348)|0;break c}b=H(71348)|0;break c}b=H(71348)|0}if((A()|0)!=(U(71348)|0)){break a}M(b|0)|0;Vr(i[a+20>>2]+4|0);O()}Xa=c+32|0;return}E(b|0);x()}function Bo(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,m=0,n=0;e=Xa-16|0;Xa=e;g=a+1074308|0;kb(e+8|0,g,96);d=b;a:{if(!ib(e+8|0)){f=i[b+660>>2];break a}i[b+660>>2]=0;f=0}i[d+660>>2]=f+c;b:{if(!(j[b+88|0]&2)|(!(i[a+480180>>2]&18)|l[b+84>>2]>c>>>0)){break b}d=i[b+84>>2];if(!d){break b}f=c;c=i[b+80>>2];c=((f-c>>>0)%(d-c>>>0)|0)+c|0}c=c>>>(i[a+480180>>2]==16384?i[b+88>>2]&1:0)|0;c:{if(Jf(b+810|0)){d=i[b+656>>2];if(d){d=k[Mc(d+236|0,j[b+810|0]+ -1|0)>>1];if(!d|d>>>0>k[a+480190>>1]){break c}}if(j[a+480210|0]&32){d=c;c=i[b+660>>2];i[b+660>>2]=d+c}i[b>>2]=0;i[b+4>>2]=c;if(!(j[b+88|0]&2)|l[b+84>>2]>c>>>0?l[b+76>>2]>c>>>0:0){break c}kb(e+8|0,g,57);if(!(h=!ib(e+8|0),m=0,n=i[a+480180>>2]!=16,n?h:m)){i[b+700>>2]=0;i[b+88>>2]=i[b+88>>2]|2097152;break c}if(!(i[a+480180>>2]&1048581)){kb(e+8|0,g,27);if(ib(e+8|0)){if(j[a+480208|0]&4){d=i[b+76>>2];i[b>>2]=0;i[b+4>>2]=d;break c}i[b>>2]=0;i[b+4>>2]=0;break c}d=i[b+80>>2];i[b>>2]=0;i[b+4>>2]=d;if(!(j[a+480208|0]&4)){break c}a=i[b+76>>2];if(a>>>0<5){break c}i[b>>2]=0;i[b+4>>2]=a+ -2;break c}if(!(j[b+88|0]&2)|i[a+480180>>2]!=1){break c}a=i[b+80>>2];i[b>>2]=0;i[b+4>>2]=a;break c}if(!(i[a+480180>>2]&268582928)|c>>>0>=l[b+76>>2]){break c}i[b>>2]=0;i[b+4>>2]=c}Xa=e+16|0}function kIa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,l=0,m=0,n=0;f=Xa-16|0;Xa=f;kd(b,32);e=a+4|0;e=j[e|0]|j[e+1|0]<<8|(j[e+2|0]<<16|j[e+3|0]<<24);i[b>>2]=e<<24|e<<8&16711680|(e>>>8&65280|e>>>24);e=a+10|0;e=j[e|0]|j[e+1|0]<<8|(j[e+2|0]<<16|j[e+3|0]<<24);e=e<<24|e<<8&16711680|(e>>>8&65280|e>>>24);i[b+4>>2]=e;l=e;e=a+14|0;e=j[e|0]|j[e+1|0]<<8|(j[e+2|0]<<16|j[e+3|0]<<24);i[b+8>>2]=l+(e<<24|e<<8&16711680|(e>>>8&65280|e>>>24));e=b;if(!(d?0:c)){c=a+46|0;c=j[c|0]|j[c+1|0]<<8|(j[c+2|0]<<16|j[c+3|0]<<24);c=c<<24|c<<8&16711680|(c>>>8&65280|c>>>24)}i[e+24>>2]=c;c=j[a+8|0]<<28>>24;a:{if((d|0)!=841887798){break a}d=a+42|0;if(!(j[d|0]|j[d+1|0]<<8)|(j[d|0]|j[d+1|0]<<8)==12288){break a}e=c;c=j[d|0]|j[d+1|0]<<8;c=(e-((c<<24|c<<8&16711680)>>>9|0)|0)+6144|0}gs(b,+(c|0)*.0006510416666666666);g[f+15|0]=j[a+9|0];g[f+14|0]=64;m=b,n=j[Xb(f+15|0,f+14|0)|0]<<2,h[m+30>>1]=n;if(g[a+40|0]&1){h[b+34>>1]=k[b+34>>1]|64;i[b>>2]=i[b>>2]>>>1;i[b+4>>2]=i[b+4>>2]>>>1;i[b+8>>2]=i[b+8>>2]>>>1}b:{if(j[a+41|0]<=8){a=i[b+4>>2];c=i[b+8>>2];break b}h[b+34>>1]=k[b+34>>1]|1;i[b>>2]=i[b>>2]>>>1;a=i[b+4>>2]>>>1|0;i[b+4>>2]=a;c=i[b+8>>2]>>>1|0;i[b+8>>2]=c}c:{if(c>>>0>a+1>>>0){h[b+34>>1]=k[b+34>>1]|2;break c}i[b+4>>2]=0;i[b+8>>2]=0}Xa=f+16|0}function ro(a){var b=0,c=0,d=0,e=0,f=0,h=0;c=Xa-16|0;Xa=c;a:{b:{c:{d:{e:{f:{g:{h:{b=i[a+480180>>2];i:{if((b|0)<=2047){if((b|0)<=31){switch(b+ -1|0){case 2:case 4:case 5:case 6:break d;case 7:break g;case 0:case 1:case 3:break i;default:break e}}if((b|0)<=255){if((b|0)==32){break i}if((b|0)==64){break b}break d}if((b|0)==256|(b|0)==512){break b}break d}d=1;if((b|0)<=4194303){if((b|0)<=65535){if((b|0)==2048){break b}if((b|0)!=8192){break d}break b}if((b|0)==65536){break c}if((b|0)!=2097152){break d}break a}if((b|0)>67108863){break h}if((b|0)==4194304){break f}if((b|0)!=16777216){break d}}d=i[a+480180>>2];break a}if((b|0)==67108864|(b|0)==134217728){break a}if((b|0)!=536870912){break d}break a}d=4;if(k[a+480192>>1]){break a}a=a+484344|0;f=c,h=Jb(a),i[f+8>>2]=h;f=c,h=Kb(a),i[f>>2]=h;a=1;j:{if(!pb(c+8|0,c)){break j}while(1){b=i[c+8>>2];if(!(!rh(b)|i[b+12>>2]==64)){a=4;break j}Bx(c+8|0);if(pb(c+8|0,c)){continue}break}}Xa=c+16|0;return a}d=32;if(k[a+480188>>1]>16){break a}if(!k[a+480188>>1]){break b}b=0;while(1){e=(b<<5)+a|0;if(g[e+480281|0]&1|k[e+480286>>1]!=64){break a}b=b+1|0;if(b>>>0<k[a+480188>>1]){continue}break}break b}if((b|0)==16){break b}}d=32;break a}d=16777216;break a}d=2}Xa=c+16|0;return d}function HP(a,b){var c=0,d=0,e=0,f=0;c=Xa-16|0;Xa=c;a:{d=j[a|0];b:{if(d>>>0>21){break b}g[a|0]=j[d+14784|0];c:{switch(d+ -8|0){case 0:g[b|0]=j[b|0]<<1;break b;case 4:g[b|0]=j[b|0]+1>>>1;break b;case 5:a=j[b|0];g[b|0]=o(a>>>4|0,10)+(a&15);break b;case 6:d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{d=j[b|0];switch((d>>>4|0)-1|0){case 10:break e;case 9:break f;case 8:break g;case 6:break h;case 5:break i;case 3:break j;case 1:break k;case 0:break l;case 11:case 12:case 13:break b;case 14:break d;default:break m}}g[a|0]=0;break b}g[a|0]=29;g[c+15|0]=j[b|0]&15;g[c+14|0]=14;e=b,f=j[Xb(c+15|0,c+14|0)|0]<<4|15,g[e|0]=f;break b}g[a|0]=29;g[c+13|0]=j[b|0]&15;g[c+12|0]=14;e=b,f=j[Xb(c+13|0,c+12|0)|0]|240,g[e|0]=f;break b}g[b|0]=d&15|48;break b}g[b|0]=d&15|176;break b}g[b|0]=d&15|64;break b}g[a|0]=15;g[b|0]=j[b|0]&15;break b}g[a|0]=24;g[b|0]=(j[b|0]<<3&120)+8&240;break b}g[a|0]=24;g[b|0]=(j[b|0]&15)+1>>>1;break b}g[a|0]=10;break b;case 8:a=j[b|0];if(a>>>0<=223){g[b|0]=a>>>0>63?-16:a<<2&240;break b}if(a>>>0<=239){g[b|0]=a<<2&48|15;break b}g[b|0]=a<<4|15;break b;case 9:break c;default:break b}}a=j[b|0];if(a>>>0<=223){break a}if(a>>>0>239){break b}g[b|0]=a>>>2&3|240}Xa=c+16|0;return}g[b|0]=a>>>0>63?15:a>>>2|0;Xa=c+16|0}function xva(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,j=0,k=0,l=0,m=0,n=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;j=Xa-16|0;Xa=j;f=i[a+48>>2];p=i[a+40>>2];q=i[a+36>>2];e=i[a+44>>2];t=i[a+16>>2];m=i[a+4>>2];k=i[a>>2];i[j+8>>2]=k;i[j+12>>2]=m;b=i[a+12>>2];i[j>>2]=i[a+8>>2];i[j+4>>2]=b;a:{if(!d){l=p>>12;r=q>>12;break a}while(1){b=m+t|0;l=g[b+2|0];r=g[b+1|0];u=g[b|0];v=g[b+ -1|0];b=i[a+60>>2];w=b;x=b>>31;b=e;e=Eb(e,-16777216,16776704);n=i[a+64>>2];f=Eb(f,-16777216,16776704);y=i[a+72>>2];z=i[a+32>>2];m=c;A=i[c>>2];e=XMa(n,n>>31,e,e>>31);n=_a;B=e;e=i[a+68>>2];s=XMa(e,e>>31,f,f>>31);e=B+s|0;f=_a+n|0;f=e>>>0<s>>>0?f+1|0:f;n=e;e=(k>>>21&2040)+27872|0;k=(((o(u,h[e+2>>1])+o(h[e>>1],v)|0)+o(r,h[e+4>>1])|0)+o(l,h[e+6>>1])<<8)/16384<<8;e=k;l=XMa(w,x,e,e>>31);e=n+l|0;f=_a+f|0;f=e>>>0<l>>>0?f+1|0:f;e=e+8388608|0;if(e>>>0<8388608){f=f+1|0}e=(f&16777215)<<8|e>>>24;f=(e|0)/256|0;q=i[a+28>>2]+q|0;r=q>>12;i[m>>2]=o(f,r)+A;p=p+z|0;l=p>>12;i[c+4>>2]=i[c+4>>2]+o(f,l);e=e-(k&y)|0;zb(j+8|0,j);d=d+ -1|0;if(d){c=c+8|0;k=i[j+8>>2];m=i[j+12>>2];f=b;continue}break}k=i[j+8>>2];m=i[j+12>>2];f=b}i[a+40>>2]=p;i[a+20>>2]=r;i[a+36>>2]=q;i[a+48>>2]=f;i[a+44>>2]=e;i[a+24>>2]=l;i[a>>2]=k;i[a+4>>2]=m;Xa=j+16|0}function Xza(a,b,c,d){var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;f=Xa-16|0;Xa=f;e=$h(c,b);i[f+12>>2]=e;a:{if((e|0)<1){break a}c=i[b+4>>2];b:{if(!c){c=i[d+4>>2];break b}c=32-c|0;i[f+8>>2]=c;e=i[Nd(f+8|0,f+12|0)>>2];i[f+12>>2]=i[f+12>>2]-e;h=i[d+4>>2];j=i[i[b>>2]>>2];k=i[b+4>>2];i[f+8>>2]=e;l=32-h|0;i[f+4>>2]=l;m=rb(f+8|0,f+4|0);g=i[d>>2];j=j&(-1<<k&-1>>>c-e);c=i[d+4>>2];h=i[b+4>>2];k=c>>>0>h>>>0?j<<c-h:j>>>h-c|0;h=i[m>>2];i[g>>2]=k|i[g>>2]&(-1<<c&-1>>>l-h^-1);k=c+h|0;c=k&31;i[d+4>>2]=c;g=g+(k>>>3&536870908)|0;i[d>>2]=g;e=e-h|0;if((e|0)>=1){i[g>>2]=i[g>>2]&(-1>>>32-e^-1)|j>>>h+i[b+4>>2];i[d+4>>2]=e;c=e}i[b>>2]=i[b>>2]+4;e=i[f+12>>2]}h=32-c|0;if((e|0)>=32){j=-1<<c;k=j^-1;g=i[b>>2];while(1){e=i[d>>2];g=i[g>>2];i[e>>2]=k&i[e>>2]|g<<c;i[d>>2]=e+4;i[e+4>>2]=j&i[e+4>>2]|g>>>h;l=i[f+12>>2];e=l+ -32|0;i[f+12>>2]=e;g=i[b>>2]+4|0;i[b>>2]=g;if((l|0)>63){continue}break}}if((e|0)<1){break a}j=i[i[b>>2]>>2];i[f+8>>2]=h;b=Nd(f+12|0,f+8|0);c=i[d>>2];g=i[d+4>>2];b=i[b>>2];k=i[c>>2]&(-1<<g&-1>>>h-b^-1);h=j&-1>>>32-e;i[c>>2]=k|h<<g;e=b+g|0;i[d+4>>2]=e&31;c=c+(e>>>3&536870908)|0;i[d>>2]=c;e=i[f+12>>2]-b|0;i[f+12>>2]=e;if((e|0)<1){break a}i[c>>2]=i[c>>2]&(-1>>>32-e^-1)|h>>>b;i[d+4>>2]=i[f+12>>2]}td(a,d);Xa=f+16|0}function $za(a,b,c,d){var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;f=Xa-16|0;Xa=f;g=$h(c,b);i[f+12>>2]=g;a:{if((g|0)<1){break a}c=i[b+4>>2];b:{if(!c){e=i[d+4>>2];break b}e=32-c|0;i[f+8>>2]=e;c=i[Nd(f+8|0,f+12|0)>>2];i[f+12>>2]=i[f+12>>2]-c;g=i[d+4>>2];h=i[i[b>>2]>>2];k=i[b+4>>2];i[f+8>>2]=c;l=32-g|0;i[f+4>>2]=l;m=rb(f+8|0,f+4|0);j=i[d>>2];k=h&(-1<<k&-1>>>e-c);e=i[d+4>>2];g=i[b+4>>2];h=i[m>>2];i[j>>2]=(e>>>0>g>>>0?k<<e-g:k>>>g-e|0)|i[j>>2]&(-1<<e&-1>>>l-h^-1);l=e+h|0;e=l&31;i[d+4>>2]=e;j=j+(l>>>3&536870908)|0;i[d>>2]=j;c=c-h|0;if((c|0)>=1){i[j>>2]=i[j>>2]&(-1>>>32-c^-1)|k>>>g+h;i[d+4>>2]=c;e=c}i[b>>2]=i[b>>2]+4;g=i[f+12>>2]}j=32-e|0;if((g|0)>=32){l=-1<<e;m=l^-1;h=i[b>>2];c=i[d>>2];k=i[c>>2];while(1){g=i[h>>2];i[c>>2]=k&m|g<<e;k=l&i[c+4>>2]|g>>>j;i[c+4>>2]=k;n=i[f+12>>2];g=n+ -32|0;i[f+12>>2]=g;h=h+4|0;c=c+4|0;if((n|0)>63){continue}break}i[b>>2]=h;i[d>>2]=c}if((g|0)<1){break a}h=i[i[b>>2]>>2];i[f+8>>2]=j;b=Nd(f+12|0,f+8|0);c=i[d>>2];e=i[d+4>>2];b=i[b>>2];g=h&-1>>>32-g;i[c>>2]=i[c>>2]&(-1<<e&-1>>>j-b^-1)|g<<e;e=b+e|0;i[d+4>>2]=e&31;c=c+(e>>>3&536870908)|0;i[d>>2]=c;e=i[f+12>>2]-b|0;i[f+12>>2]=e;if((e|0)<1){break a}i[c>>2]=i[c>>2]&(-1>>>32-e^-1)|g>>>b;i[d+4>>2]=i[f+12>>2]}td(a,d);Xa=f+16|0}function sea(a,b,c){var d=0,e=0,f=0,g=0,j=p(0),n=0,q=p(0),r=0,s=0;e=Xa-144|0;Xa=e;d=i[a+4>>2];if(d>>>0>=29){i[a+4>>2]=0;d=0}d=o(d,44)+82176|0;if(!(b?0:(d|0)==i[a+4112>>2])){i[a+4112>>2]=d;j=p(c>>>0);rea(d,e+8|0,j);i[a+4124>>2]=i[e+40>>2];d=RG(SG(i[e+16>>2]),j);h[a+4190>>1]=d;h[a+4188>>1]=d;d=k[e+24>>1]<<1;h[a+4198>>1]=d;h[a+4196>>1]=d;while(1){d=(g<<4)+a|0;f=(e+8|0)+o(g,12)|0;n=i[f+44>>2];i[d+4204>>2]=n;i[d+4208>>2]=n;h[d+4212>>1]=k[f+36>>1];h[d+4214>>1]=k[f+42>>1];h[d+4216>>1]=k[f+40>>1];h[d+4218>>1]=k[f+38>>1];g=g+1|0;if((g|0)!=8){continue}break}i[a+53996>>2]=i[e+32>>2];f=a+4184|0;d=i[e+12>>2];if((d|0)>-9e3){d=QG(d)}else{d=0}i[f>>2]=d;f=a+54052|0;d=i[e+8>>2];if((d|0)>=-8999){d=QG(d)}else{d=0}i[f>>2]=d;d=i[e+28>>2];f=a+54036|0;i[f>>2]=268464128;i[f+4>>2]=1879052288;d=d>>>0<32512?d:32512;h[a+54010>>1]=d;h[a+54008>>1]=d;h[a+54006>>1]=d;h[a+54004>>1]=d;i[e+4>>2]=i[e+20>>2];Kd(e+4|0,0,32752);d=k[e+4>>1];h[a+54018>>1]=d;f=a+54014|0;h[f>>1]=0;h[f+2>>1]=0;h[a+54012>>1]=d;q=m[e+36>>2];r=e,s=RG(p(q*q),j),i[r>>2]=s;Kd(e,256,32512);d=k[e>>1];h[a+54026>>1]=d;f=a+54022|0;h[f>>1]=0;h[f+2>>1]=0;h[a+54020>>1]=d}if(b){i[a+4120>>2]=0;UG(a)}b=o(c,5);if(l[a+4124>>2]<b>>>0){i[a+4124>>2]=b}Xa=e+144|0}function qva(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;g=Xa-32|0;Xa=g;l=i[a+16>>2];a:{b:{c:{j=i[a+8>>2];e=i[a+12>>2];d:{if((e|0)<1?1:(e|0)<=1?j>>>0<=805306368:0){if((e|0)>-2?1:(e|0)>=-2?j>>>0>=3489660928:0){break c}if((e|0)>-2?1:(e|0)>=-2?j>>>0>2147483647:0){break d}break b}if((e|0)>1?1:(e|0)>=1?j>>>0>2147483648:0){break b}}k=b+196648|0;break a}k=b+131112|0;break a}k=b+262184|0}m=i[a+24>>2];n=i[a+20>>2];b=i[a+4>>2];f=i[a>>2];i[g+24>>2]=f;i[g+28>>2]=b;i[g+16>>2]=j;i[g+20>>2]=e;if(d){while(1){e=((((b&2147483647)<<1|f>>>31)&2147483646)<<1)+l|0;b=(f>>>16&65520)+k|0;p=h[b+14>>1];q=h[b+12>>1];r=h[b+10>>1];s=h[b+8>>1];t=h[b+6>>1];u=h[b+4>>1];v=h[b+2>>1];w=h[b>>1];j=0;b=1;while(1){f=j<<1;i[(g+8|0)+(j<<2)>>2]=(((((((o(h[(f|-8)+e>>1],v)+o(h[(f|-12)+e>>1],w)|0)+o(h[(f|-4)+e>>1],u)|0)+o(h[e+f>>1],t)|0)+o(h[(f|4)+e>>1],s)|0)+o(h[(f|8)+e>>1],r)|0)+o(h[(f|12)+e>>1],q)|0)+o(h[(f|16)+e>>1],p)|0)/32768;f=b;b=0;j=1;if(f){continue}break}i[c>>2]=i[c>>2]+o(i[g+8>>2],n);i[c+4>>2]=i[c+4>>2]+o(i[g+12>>2],m);zb(g+24|0,g+16|0);d=d+ -1|0;if(d){c=c+8|0;f=i[g+24>>2];b=i[g+28>>2];continue}break}f=i[g+24>>2];b=i[g+28>>2]}i[a>>2]=f;i[a+4>>2]=b;Xa=g+32|0}function wva(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;g=Xa-16|0;Xa=g;e=i[a+48>>2];n=i[a+40>>2];p=i[a+36>>2];f=i[a+44>>2];s=i[a+16>>2];m=i[a+4>>2];l=i[a>>2];i[g+8>>2]=l;i[g+12>>2]=m;b=i[a+12>>2];i[g>>2]=i[a+8>>2];i[g+4>>2]=b;a:{if(!d){k=n>>12;j=p>>12;break a}while(1){b=(m<<1)+s|0;j=h[b>>1];t=h[b+ -2>>1];u=h[b+2>>1];v=h[b+4>>1];r=i[a+60>>2];b=f;f=Eb(f,-16777216,16776704);q=i[a+64>>2];k=Eb(e,-16777216,16776704);w=i[a+72>>2];x=i[a+32>>2];m=c;y=i[c>>2];e=XMa(q,q>>31,f,f>>31);q=_a;f=e;e=(l>>>21&2040)+27872|0;l=(((o(h[e+2>>1],j)+o(h[e>>1],t)|0)+o(u,h[e+4>>1])|0)+o(v,h[e+6>>1])|0)/16384<<8;e=l;j=XMa(r,r>>31,e,e>>31);f=f+j|0;e=_a+q|0;e=f>>>0<j>>>0?e+1|0:e;j=f;f=i[a+68>>2];k=XMa(f,f>>31,k,k>>31);f=j+k|0;e=_a+e|0;e=f>>>0<k>>>0?e+1|0:e;f=f+8388608|0;if(f>>>0<8388608){e=e+1|0}f=(e&16777215)<<8|f>>>24;e=(f|0)/256|0;p=i[a+28>>2]+p|0;j=p>>12;i[m>>2]=o(e,j)+y;n=n+x|0;k=n>>12;i[c+4>>2]=i[c+4>>2]+o(e,k);f=f-(l&w)|0;zb(g+8|0,g);d=d+ -1|0;if(d){c=c+8|0;l=i[g+8>>2];m=i[g+12>>2];e=b;continue}break}l=i[g+8>>2];m=i[g+12>>2];e=b}i[a+40>>2]=n;i[a+20>>2]=j;i[a+36>>2]=p;i[a+48>>2]=e;i[a+44>>2]=f;i[a+24>>2]=k;i[a>>2]=l;i[a+4>>2]=m;Xa=g+16|0}function FD(a,b){var c=0,d=0,e=0,f=0;a:{b:{c:{c=i[a+4>>2];d:{if(c>>>0<l[a+104>>2]){i[a+4>>2]=c+1;c=j[c|0];break d}c=Hc(a)}switch(c+ -43|0){case 0:case 2:break b;default:break c}}b=c+ -48|0;break a}f=(c|0)==45;e=!b;b=i[a+4>>2];e:{if(b>>>0<l[a+104>>2]){i[a+4>>2]=b+1;c=j[b|0];break e}c=Hc(a)}b=c+ -48|0;if(!(e|b>>>0<10|!i[a+104>>2])){i[a+4>>2]=i[a+4>>2]+ -1}}f:{if(b>>>0<10){b=0;while(1){d=o(b,10)+c|0;b=i[a+4>>2];g:{if(b>>>0<l[a+104>>2]){i[a+4>>2]=b+1;c=j[b|0];break g}c=Hc(a)}e=c+ -48|0;b=d+ -48|0;if((b|0)<214748364?e>>>0<=9:0){continue}break}d=b;b=b>>31;h:{if(e>>>0>=10){break h}while(1){d=XMa(d,b,10,0);c=d+c|0;b=_a;b=c>>>0<d>>>0?b+1|0:b;c=c+ -48|0;b=b+ -1|0;b=c>>>0<4294967248?b+1|0:b;d=c;c=i[a+4>>2];i:{if(c>>>0<l[a+104>>2]){i[a+4>>2]=c+1;c=j[c|0];break i}c=Hc(a)}e=c+ -48|0;if(e>>>0>9){break h}if((b|0)<21474836?1:(b|0)<=21474836?d>>>0<2061584302:0){continue}break}}if(e>>>0<10){while(1){c=i[a+4>>2];j:{if(c>>>0<l[a+104>>2]){i[a+4>>2]=c+1;c=j[c|0];break j}c=Hc(a)}if(c+ -48>>>0<10){continue}break}}if(i[a+104>>2]){i[a+4>>2]=i[a+4>>2]+ -1}a=d;d=f?0-a|0:a;b=f?0-(b+(0<a>>>0)|0)|0:b;break f}b=-2147483648;if(!i[a+104>>2]){break f}i[a+4>>2]=i[a+4>>2]+ -1;_a=-2147483648;return 0}_a=b;return d}function nja(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,j=0,n=p(0),o=p(0),r=0,s=0,t=0,u=p(0);j=Xa-16|0;Xa=j;a:{if(h[d>>1]>h[d+2>>1]){break a}if(!qb(b)){break a}g=h[e>>1];if((g|0)<h[d>>1]){break a}r=h[d+2>>1];if((r|0)<(g|0)){break a}if((qb(b)+ -1&65535)>>>0>(r-g&65535)>>>0|l[a+36>>2]>65535){break a}b:{if(!qb(b)){break b}while(1){if(!(m[vb(b,f)>>2]<p(0))){f=f+1|0;if(f>>>0<qb(b)>>>0){continue}break b}break}f=0;break a}f=0;if(m[c>>2]<=p(0)){break a}h[a>>1]=1;h[a+28>>1]=k[d>>1];s=a,t=kI(qb(b)),h[s+30>>1]=t;m[a+32>>2]=q(m[c>>2]);g=a+4|0;Tk(g,(h[d+2>>1]-h[d>>1]|0)+1|0);c=Jb(b);b=Kb(b);s=j,t=Jb(g),i[s+8>>2]=t;lja(c,b,Oo(j+8|0,h[e>>1]-h[d>>1]|0));f=h[e>>1];c=h[a+28>>1];c:{if((f|0)<=(c|0)){b=f;break c}while(1){f=f+ -1|0;n=m[vb(g,h[a+30>>1]+(f-c|0)|0)>>2];o=m[a+32>>2];s=vb(g,f-h[a+28>>1]|0),u=p(n/o),m[s>>2]=u;b=h[e>>1];c=h[a+28>>1];if((f|0)<=(c|0)){break c}if((b|0)!=-32768){continue}break}}c=h[a+30>>1];f=c+b|0;d:{if((f|0)>h[d+2>>1]|(32767-c|0)<(b|0)){break d}while(1){n=m[a+32>>2];o=m[vb(g,(f-c|0)-h[a+28>>1]|0)>>2];s=vb(g,f-h[a+28>>1]|0),u=p(o*n),m[s>>2]=u;if((f|0)>=h[d+2>>1]){break d}f=f+1|0;c=h[a+30>>1];if((32767-c|0)>=h[e>>1]){continue}break}}go(a);f=1}Xa=j+16|0;return f|0}function iha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,k=0,l=0,o=0,r=0,s=0;g=Xa-16|0;Xa=g;if(!j[a+4242|0]){ow(a);a:{if(!j[a+4240|0]){break a}e=GJ(i[a+16>>2]);if(e==n[a+4288>>3]){break a}n[a+4288>>3]=e;sr(a)}h=a+4256|0;b:{if(j[a+4244|0]){if(!(n[h>>3]<=1)){n[h>>3]=1}break b}k=(i[a+4232>>2]&-2)!=4;e=n[h>>3];c:{if(q(e)<2147483648){f=~~e;break c}f=-2147483648}if(!(k|(f|0)<1)){mw(a);e=n[a+4256>>3]}n[h>>3]=e- +(f|0)}i[g+8>>2]=0;i[g+12>>2]=0;e=0;f=g;d:{e:{f:{switch(i[a+4232>>2]){case 0:e=Hh(n[a+4256>>3]*6.283185307179586);break e;case 1:e=q(n[a+4256>>3]+ -.5)*-4+1;break e;case 2:e=n[a+4256>>3];e=e+e+ -1;break e;case 3:e=n[a+4256>>3]<.5?-1:1;break e;case 4:e=n[a+4272>>3];break e;case 5:break f;default:break d}}e=n[a+4256>>3];l=e*e*e*((e*6+ -15)*e+10);e=n[a+4272>>3];e=l*(n[a+4280>>3]-e)+e}n[f+8>>3]=e}if(j[a+4241|0]){e=-e;n[g+8>>3]=e}n[g+8>>3]=e*+m[a+4220>>2]+ +m[a+4224>>2];mf(g+8|0,0,1);h=Ji(a);g:{if(!h){break g}f=i[a+4236>>2];if(j[a+4243|0]){r=h,s=f>>>8&15|176|(f&127)<<8|Gs(n[g+8>>3]*127)<<16,o=i[i[h>>2]+68>>2],$a[o](r|0,s|0)|0;break g}$a[i[i[h>>2]+44>>2]](h,f,p(n[g+8>>3]))}n[a+4256>>3]=n[a+4256>>3]+n[a+4264>>3]*+(d>>>0)}f=a;a=a+44|0;Oh(f,b,c,ud(a,0),ud(a,1),d);Xa=g+16|0}function Jua(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,p=0,q=0,r=0;e=Xa-48|0;Xa=e;l=i[a+16>>2];f=tf(e+16|0);i[f+8>>2]=a+112;i[f+16>>2]=i[a+128>>2];q=f,r=of(b+327720|0,i[b+20>>2],(i[a+88>>2]&16384)>>>14|0),i[q+12>>2]=r;b=i[f+16>>2];if(b){q=f,r=sf(a+8|0,b),i[q>>2]=r;i[f+4>>2]=_a}m=i[a+24>>2];n=i[a+20>>2];b=i[a+4>>2];g=i[a>>2];i[e+8>>2]=g;i[e+12>>2]=b;j=i[a+12>>2];i[e>>2]=i[a+8>>2];i[e+4>>2]=j;if(d){while(1){j=0;k=g;i[e+40>>2]=g;i[e+44>>2]=p;g=((((b&2147483647)<<1|g>>>31)&2147483646)<<1)+l|0;a:{b=i[f+16>>2];if((b|0)<=0){break a}while(1){j=(j&2147483647)<<1|k>>>31;fd(i[f+8>>2],(h[(j<<1|2)+g>>1]+h[g+((j&2147483646)<<1)>>1]|0)/8<<16>>16);ed(i[f+8>>2],4);zb(e+40|0,f);if((b|0)<2){break a}b=b+ -1|0;k=i[e+40>>2];j=i[e+44>>2];continue}}d=d+ -1|0;b=i[f+8>>2];zb(b,b+8|0);b=i[f+8>>2];j=i[b+4>>2];if(j){k=b;b=(i[e+44>>2]&2147483647)<<1|i[e+40>>2]>>>31;fd(k,(h[(b<<1|2)+g>>1]+h[g+((b&2147483646)<<1)>>1]|0)/8<<16>>16);ed(i[f+8>>2],j);b=i[f+8>>2];j=i[b>>2];i[b>>2]=j;i[b+4>>2]=0}b=nf(b,i[f+12>>2]);i[c>>2]=i[c>>2]+o(b,n);i[c+4>>2]=i[c+4>>2]+o(b,m);zb(e+8|0,e);if(d){c=c+8|0;g=i[e+8>>2];b=i[e+12>>2];continue}break}g=i[e+8>>2];b=i[e+12>>2]}i[a>>2]=g;i[a+4>>2]=b;Xa=e+48|0}function Z$(a,b,c,d,e,f,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;h=h|0;var k=0,l=0;a=Xa-160|0;Xa=a;i[a+144>>2]=c;i[a+152>>2]=b;i[a+20>>2]=2482;b=wd(a+24|0,a+32|0,a+20|0);i[114610]=0;fc(a+16|0,e);k=i[114610];i[114610]=0;a:{b:{c:{d:{if((k|0)!=1){i[114610]=0;k=F(21,a+16|0)|0;l=i[114610];i[114610]=0;if((l|0)==1){break b}g[a+15|0]=0;e=i[e+4>>2];i[114610]=0;c=fa(2483,a+152|0,c|0,d|0,a+16|0,e|0,f|0,a+15|0,k|0,b|0,a+20|0,a+132|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break b}if(!c){break c}Ce(h);if(!j[a+15|0]){break d}i[114610]=0;c=C(22,k|0,45)|0;d=i[114610];i[114610]=0;if((d|0)==1){break b}i[114610]=0;D(110,h|0,c|0);c=i[114610];i[114610]=0;if((c|0)!=1){break d}break b}e=B()|0;A()|0;break a}i[114610]=0;k=C(22,k|0,48)|0;c=i[114610];i[114610]=0;if((c|0)!=1){e=i[b>>2];l=i[a+20>>2];c=l+ -1|0;d=e>>>0>c>>>0?e:c;k=k&255;while(1){e:{if(e>>>0<c>>>0){if((k|0)==j[e|0]){break e}d=e}i[114610]=0;I(2491,h|0,d|0,l|0)|0;c=i[114610];i[114610]=0;if((c|0)!=1){break c}break b}e=e+1|0;continue}}break b}i[114610]=0;c=C(2423,a+152|0,a+144|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break b}if(c){i[f>>2]=i[f>>2]|2}c=i[a+152>>2];ub(a+16|0);lc(b);Xa=a+160|0;return c|0}e=B()|0;A()|0;ub(a+16|0)}lc(b);E(e|0);x()}function Kpa(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,k=0,l=0,m=0,p=0,r=0,s=0,u=0,v=0,w=0,x=0,y=0,z=0;k=Xa-16|0;Xa=k;x=k,y=o(i[a>>2],$d(a)),i[x+4>>2]=y;kc(k+4|0,c);c=jb(b);m=n[e+8>>3];l=i[k+4>>2];a:{if(!l){break a}e=l;while(1){p=0;f=c;r=j[f+4|0]|j[f+5|0]<<8|(j[f+6|0]<<16|j[f+7|0]<<24);g=j[f|0]|j[f+1|0]<<8|(j[f+2|0]<<16|j[f+3|0]<<24);v=g<<24|g<<8&16711680;s=p;p=r<<24|g>>>8;f=r<<8|g>>>24;s=s|0;p=p&65280|f&255|v;f=r;eNa(0,((f&255)<<24|g>>>8)&-16777216|((f&16777215)<<8|g>>>24)&16711680|(f>>>8&65280|f>>>24)|s);eNa(1,p&2147483647);m=t(+fNa(),m);c=c+8|0;e=e+ -1|0;if(e){continue}break}if(!l|m==0){break a}w=1/m;c=i[a+20>>2];while(1){e=b;a=j[e+4|0]|j[e+5|0]<<8|(j[e+6|0]<<16|j[e+7|0]<<24);g=j[e|0]|j[e+1|0]<<8|(j[e+2|0]<<16|j[e+3|0]<<24);f=g<<24;v=0;r=g<<8&16711680|f;s=a<<24|g>>>8;f=a<<8|g>>>24;e=a;eNa(0,((e&255)<<24|g>>>8)&-16777216|((e&16777215)<<8|g>>>24)&16711680|(e>>>8&65280|e>>>24)|v);eNa(1,r|(s&65280|f&255));x=k,z=+fNa()*w,n[x+8>>3]=z;mf(k+8|0,-1,1);u=n[k+8>>3]*32768;n[k+8>>3]=u;a=c;u=xd(u);b:{if(q(u)<2147483648){e=~~u;break b}e=-2147483648}x=a,y=Bc(e),h[x>>1]=y;b=b+8|0;c=c+2|0;l=l+ -1|0;if(l){continue}break}}if(d){n[d>>3]=m}Xa=k+16|0;return i[k+4>>2]}function sga(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,h=0,k=0,l=0;c=Xa+ -64|0;Xa=c;mga(a);i[114610]=0;l=a;D(1754,a|0,11);b=i[114610];i[114610]=0;a:{if((b|0)!=1){b=80016;b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{while(1){d=hg(44);l:{if(!d){i[c+60>>2]=0;break l}h=i[b>>2];f=i[b+4>>2];i[114610]=0;f=C(85,c+32|0,f|0)|0;e=i[114610];i[114610]=0;if((e|0)==1){break k}i[114610]=0;D(1755,c+48|0,f|0);e=i[114610];i[114610]=0;if((e|0)==1){break j}e=i[b+8>>2];i[114610]=0;e=C(85,c|0,e|0)|0;k=i[114610];i[114610]=0;if((k|0)==1){break i}i[114610]=0;D(1755,c+16|0,e|0);k=i[114610];i[114610]=0;if((k|0)==1){break h}i[114610]=0;S(1756,d|0,h|0,1,c+48|0,c+16|0)|0;h=i[114610];i[114610]=0;if((h|0)==1){break g}ob(c+16|0);eb(e);ob(c+48|0);eb(f);i[114610]=0;i[c+60>>2]=d;D(1757,l|0,c+60|0);d=i[114610];i[114610]=0;if((d|0)==1){break b}d=i[c+60>>2];i[d+32>>2]=i[b+12>>2];i[d+36>>2]=i[b+16>>2];g[d+40|0]=j[b+20|0];g[d+41|0]=j[d+41|0]&253|j[b+21|0]<<1}b=b+24|0;if((b|0)!=80280){continue}break}Xa=c- -64|0;return a|0}b=B()|0;A()|0;break c}b=B()|0;A()|0;break d}b=B()|0;A()|0;break e}b=B()|0;A()|0;break f}b=B()|0;A()|0;ob(c+16|0)}eb(e)}ob(c+48|0)}eb(f)}Cb(d);break a}b=B()|0;A()|0;break a}b=B()|0;A()|0}iw(l);E(b|0);x()}function rva(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,j=0,k=0,l=0,m=0,n=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;e=Xa-32|0;Xa=e;m=i[a+16>>2];a:{b:{c:{f=i[a+8>>2];j=i[a+12>>2];d:{if((j|0)<1?1:(j|0)<=1?f>>>0<=805306368:0){if((j|0)>-2?1:(j|0)>=-2?f>>>0>=3489660928:0){break c}if((j|0)>-2?1:(j|0)>=-2?f>>>0>2147483647:0){break d}break b}if((j|0)>1?1:(j|0)>=1?f>>>0>2147483648:0){break b}}l=b+196648|0;break a}l=b+131112|0;break a}l=b+262184|0}n=i[a+24>>2];p=i[a+20>>2];b=i[a+4>>2];k=i[a>>2];i[e+24>>2]=k;i[e+28>>2]=b;i[e+16>>2]=f;i[e+20>>2]=j;j=a;if(d){while(1){f=(((b&2147483647)<<1|k>>>31)&-2)+m|0;a=(k>>>16&65520)+l|0;q=h[a+14>>1];r=h[a+12>>1];s=h[a+10>>1];t=h[a+8>>1];u=h[a+6>>1];v=h[a+4>>1];w=h[a+2>>1];x=h[a>>1];b=0;a=1;while(1){i[(e+8|0)+(b<<2)>>2]=(((((((o(g[(b|-4)+f|0],w)+o(g[(b|-6)+f|0],x)|0)+o(g[(b|-2)+f|0],v)|0)+o(g[b+f|0],u)|0)+o(g[(b|2)+f|0],t)|0)+o(g[(b|4)+f|0],s)|0)+o(g[(b|6)+f|0],r)|0)+o(g[(b|8)+f|0],q)<<8)/32768;k=a;a=0;b=1;if(k){continue}break}i[c>>2]=i[c>>2]+o(i[e+8>>2],p);i[c+4>>2]=i[c+4>>2]+o(i[e+12>>2],n);zb(e+24|0,e+16|0);d=d+ -1|0;if(d){c=c+8|0;k=i[e+24>>2];b=i[e+28>>2];continue}break}k=i[e+24>>2];b=i[e+28>>2]}i[j>>2]=k;i[j+4>>2]=b;Xa=e+32|0}function gaa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,j=0;b=Xa-2144|0;Xa=b;yb(b+96|0,0,2048);a:{b:{c:{f=i[c+4>>2];if(!f){a=P(8)|0;i[114610]=0;b=C(85,b+80|0,38600)|0;c=i[114610];i[114610]=0;if((c|0)==1){break c}Ub(a,b);i[114610]=0;G(2009,a|0,83568,2017);a=i[114610];i[114610]=0;if((a|0)!=1){break a}c=B()|0;A()|0;eb(b);break b}g=i[c>>2];d=i[c+12>>2];e=i[c+8>>2];i[b+72>>2]=e;i[b+76>>2]=d;c=i[b+76>>2];i[b+24>>2]=i[b+72>>2];i[b+28>>2]=c;i[b+68>>2]=f;i[b+64>>2]=g;c=i[b+68>>2];i[b+16>>2]=i[b+64>>2];i[b+20>>2]=c;c=b;j=b;h=RP(b+16|0);if(h){i[b+48>>2]=e;i[b+52>>2]=d;d=i[b+52>>2];i[b+8>>2]=i[b+48>>2];i[b+12>>2]=d;i[b+44>>2]=f;i[b+40>>2]=g;d=i[b+44>>2];i[b>>2]=i[b+40>>2];i[b+4>>2]=d;d=NP(b)}else{d=0}i[j+56>>2]=d;i[c+60>>2]=0;d=0;c=2048;while(1){if(c){e=$a[f|0](g,(b+96|0)+d|0,c)|0;c=c-e|0;d=d+e|0;if(e){continue}}break}a=Er(a,ml(b+32|0,jb(b+96|0),d),h?b+56|0:0);if(a+1>>>0>=3){a=P(8)|0;i[114610]=0;b=C(85,b+80|0,38585)|0;c=i[114610];i[114610]=0;if((c|0)!=1){Ub(a,b);i[114610]=0;G(2009,a|0,83568,2017);a=i[114610];i[114610]=0;if((a|0)!=1){break a}c=B()|0;A()|0;eb(b);break b}c=B()|0;A()|0;Q(a|0);break b}Xa=b+2144|0;return a|0}c=B()|0;A()|0;Q(a|0)}E(c|0)}x()}function fAa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;d=Xa+ -64|0;Xa=d;t=d,u=cf(a)>>>5|0,h[t+32>>1]=u;h[d+16>>1]=3999;t=c,u=k[ef(d+32|0,d+16|0)>>1],h[t+480190>>1]=u;ky(b,k[c+480190>>1],0);a:{if(k[c+480190>>1]){m=d+62|0;p=d+58|0;q=d+56|0;s=d+52|0;r=d+60|0;n=1;o=1;while(1){f=Uo(c,o&65535);ys(a,d+32|0);kd(f,0);en(d,2,d+32|0);oc(d+16|0,d);i[114610]=0;C(369,((n<<5)+c|0)+946300|0,d+16|0)|0;e=i[114610];i[114610]=0;if((e|0)==1){break a}eb(d+16|0);h[f+32>>1]=64;i[f+24>>2]=8287;e=j[r|0]|j[r+1|0]<<8;h[d+16>>1]=(e<<24|e<<8&16711680)>>>16;h[d>>1]=64;t=f,u=k[ef(d+16|0,d)>>1]<<2,h[t+30>>1]=u;e=s;e=(j[e|0]|j[e+1|0]<<8|(j[e+2|0]<<16|j[e+3|0]<<24))&-16777217;i[f>>2]=e<<24|e<<8&16711680|(e>>>8&65280|e>>>24);e=j[q|0]|j[q+1|0]<<8;g=j[p|0]|j[p+1|0]<<8;g=(g<<24|g<<8&16711680)>>>16|0;b:{if(g>>>0<2){break b}e=(e<<8&16711680|e<<24)>>>16|0;g=e+g<<1;if(g>>>0>l[f>>2]){break b}i[f+16>>2]=g;i[f+12>>2]=e<<1;h[f+34>>1]=k[f+34>>1]|8}if(j[m|0]|j[m+1|0]<<8){e=(j[m|0]|j[m+1|0]<<8)==512}else{e=1}Ld(d+16|0,b,n+ -1|0);Od(d+16|0,e);o=o+1|0;n=o&65535;if(n>>>0<=k[c+480190>>1]){continue}break}}Xa=d- -64|0;return}a=B()|0;A()|0;eb(d+16|0);E(a|0);x()}function R$(a,b,c,d,e,f,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;h=h|0;var k=0,l=0;a=Xa-448|0;Xa=a;i[a+432>>2]=c;i[a+440>>2]=b;i[a+20>>2]=2482;b=wd(a+24|0,a+32|0,a+20|0);i[114610]=0;fc(a+16|0,e);k=i[114610];i[114610]=0;a:{b:{c:{d:{if((k|0)!=1){i[114610]=0;k=F(2449,a+16|0)|0;l=i[114610];i[114610]=0;if((l|0)==1){break b}g[a+15|0]=0;e=i[e+4>>2];i[114610]=0;c=fa(2493,a+440|0,c|0,d|0,a+16|0,e|0,f|0,a+15|0,k|0,b|0,a+20|0,a+432|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break b}if(!c){break c}Q$(h);if(!j[a+15|0]){break d}i[114610]=0;c=C(2475,k|0,45)|0;d=i[114610];i[114610]=0;if((d|0)==1){break b}i[114610]=0;D(112,h|0,c|0);c=i[114610];i[114610]=0;if((c|0)!=1){break d}break b}e=B()|0;A()|0;break a}i[114610]=0;c=C(2475,k|0,48)|0;d=i[114610];i[114610]=0;if((d|0)==1){break b}e=i[b>>2];d=i[a+20>>2];k=d+ -4|0;while(1){if(!((c|0)!=i[e>>2]|e>>>0>=k>>>0)){e=e+4|0;continue}break}i[114610]=0;I(2499,h|0,e|0,d|0)|0;c=i[114610];i[114610]=0;if((c|0)!=1){break c}break b}i[114610]=0;c=C(2455,a+440|0,a+432|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break b}if(c){i[f>>2]=i[f>>2]|2}c=i[a+440>>2];ub(a+16|0);lc(b);Xa=a+448|0;return c|0}e=B()|0;A()|0;ub(a+16|0)}lc(b);E(e|0);x()}function rCa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,l=0,m=0;e=Xa-16|0;Xa=e;kd(b,0);f=j[a|0]|j[a+1|0]<<8|(j[a+2|0]<<16|j[a+3|0]<<24);a:{if(c&34){if(d){i[b+24>>2]=f;break a}l=b,m=Wj(zg(+(f+1408|0)*.0006510416666666666)*8363),i[l+24>>2]=m;break a}g[b+37|0]=(c|0)==16?f:f^128;g[b+36|0]=j[a+4|0]}g[e+15|0]=j[a+5|0];g[e+14|0]=64;l=b,m=j[Xb(e+15|0,e+14|0)|0]<<2,h[l+30>>1]=m;d=a+6|0;if((j[d|0]|j[d+1|0]<<8)>>>0<=256){h[b+28>>1]=j[d|0]|j[d+1|0]<<8;h[b+34>>1]=k[b+34>>1]|32}d=a+8|0;i[b>>2]=j[d|0]|j[d+1|0]<<8|(j[d+2|0]<<16|j[d+3|0]<<24);d=a+12|0;i[b+4>>2]=j[d|0]|j[d+1|0]<<8|(j[d+2|0]<<16|j[d+3|0]<<24);d=a+16|0;i[b+8>>2]=j[d|0]|j[d+1|0]<<8|(j[d+2|0]<<16|j[d+3|0]<<24);d=a+20|0;if(j[d|0]&16){h[b+34>>1]=k[b+34>>1]|2}if(j[d|0]&32){h[b+34>>1]=k[b+34>>1]|4}if(g[d+1|0]&1){h[b+34>>1]=k[b+34>>1]|8}if(j[d+1|0]&2){h[b+34>>1]=k[b+34>>1]|16}g[b+38|0]=j[(j[a+22|0]&7)+27856|0];g[b+39|0]=j[a+23|0];g[b+40|0]=j[a+24|0];g[b+41|0]=j[a+25|0];if((c|0)==32){g[e+13|0]=j[a+26|0];g[e+12|0]=64;l=b,m=j[Xb(e+13|0,e+12|0)|0],h[l+32>>1]=m}c=a+27|0;i[b+12>>2]=j[c|0]|j[c+1|0]<<8|(j[c+2|0]<<16|j[c+3|0]<<24);a=a+31|0;i[b+16>>2]=j[a|0]|j[a+1|0]<<8|(j[a+2|0]<<16|j[a+3|0]<<24);Xa=e+16|0}function lm(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,j=0,l=0;c=Xa-80|0;Xa=c;g=Xv(a);e=b+24|0;a:{b:{if(ph(i[e>>2]+484360|0)){if(ph(i[e>>2]+484360|0)){a=0;while(1){f=i[e>>2];b=BG(FO(c+40|0,1),a&255,0,0);i[114610]=0;d=i[b+12>>2];i[c+8>>2]=i[b+8>>2];i[c+12>>2]=d;d=i[b+20>>2];i[c+16>>2]=i[b+16>>2];i[c+20>>2]=d;d=i[b+4>>2];i[c>>2]=i[b>>2];i[c+4>>2]=d;J(2129,c- -64|0,f|0,0,c|0);b=i[114610];i[114610]=0;c:{d:{if((b|0)!=1){j=c,l=Jb(c- -64|0),i[j+32>>2]=l;j=c,l=Kb(c- -64|0),i[j+24>>2]=l;if(pb(c+32|0,c+24|0)){break d}break c}a=B()|0;A()|0;break b}while(1){e:{b=i[c+32>>2];f=k[b+24>>1];h=n[b>>3];d=i[b+16>>2];b=c+40|0;i[b+16>>2]=a;i[b+12>>2]=f;i[b+8>>2]=d;n[b>>3]=h;i[114610]=0;D(2130,g|0,b|0);b=i[114610];i[114610]=0;if((b|0)==1){break e}Kx(c+32|0);if(pb(c+32|0,c+24|0)){continue}break c}break}a=B()|0;A()|0;hl(c- -64|0);break b}hl(c- -64|0);a=a+1|0;if(a>>>0<ph(i[e>>2]+484360|0)>>>0){continue}break}}Xa=c+80|0;return}b=P(8)|0;i[114610]=0;c=C(85,c+40|0,38538)|0;a=i[114610];i[114610]=0;if((a|0)!=1){Ub(b,c);i[114610]=0;G(2009,b|0,83568,2017);a=i[114610];i[114610]=0;if((a|0)!=1){break a}a=B()|0;A()|0;eb(c);break b}a=B()|0;A()|0;Q(b|0)}We(g);E(a|0)}x()}function QZ(a,b,c,d,e,f){var h=0,j=0;i[c>>2]=a;i[f>>2]=d;h=i[c>>2];a:{b:{while(1){if(h>>>0>=b>>>0){a=0;break a}a=2;d=k[h>>1];if(d>>>0>1114111){break a}c:{d:{if(d>>>0<=127){a=1;h=i[f>>2];if((e-h|0)<1){break a}i[f>>2]=h+1;g[h|0]=d;break d}if(d>>>0<=2047){a=i[f>>2];if((e-a|0)<2){break b}i[f>>2]=a+1;g[a|0]=d>>>6|192;a=i[f>>2];i[f>>2]=a+1;g[a|0]=d&63|128;break d}if(d>>>0<=55295){a=i[f>>2];if((e-a|0)<3){break b}i[f>>2]=a+1;g[a|0]=d>>>12|224;a=i[f>>2];i[f>>2]=a+1;g[a|0]=d>>>6&63|128;a=i[f>>2];i[f>>2]=a+1;g[a|0]=d&63|128;break d}if(d>>>0<=56319){a=1;if((b-h|0)<4){break a}j=k[h+2>>1];if((j&64512)!=56320){break c}if((e-i[f>>2]|0)<4){break a}a=d&960;if((j&1023|(d<<10&64512|a<<10))+65536>>>0>1114111){break c}i[c>>2]=h+2;h=i[f>>2];i[f>>2]=h+1;a=(a>>>6|0)+1|0;g[h|0]=a>>>2|240;h=i[f>>2];i[f>>2]=h+1;g[h|0]=a<<4&48|d>>>2&15|128;a=i[f>>2];i[f>>2]=a+1;g[a|0]=j>>>6&15|d<<4&48|128;a=i[f>>2];i[f>>2]=a+1;g[a|0]=j&63|128;break d}if(d>>>0<57344){break a}a=i[f>>2];if((e-a|0)<3){break b}i[f>>2]=a+1;g[a|0]=d>>>12|224;a=i[f>>2];i[f>>2]=a+1;g[a|0]=d>>>6&63|128;a=i[f>>2];i[f>>2]=a+1;g[a|0]=d&63|128}h=i[c>>2]+2|0;i[c>>2]=h;continue}break}return 2}return 1}return a}function zX(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,k=0,l=0,m=0,n=0;if(Nf(a,i[b+8>>2],e)){qu(b,c,d);return}a:{if(Nf(a,i[b>>2],e)){if(!(i[b+20>>2]!=(c|0)?i[b+16>>2]!=(c|0):0)){if((d|0)!=1){break a}i[b+32>>2]=1;return}i[b+32>>2]=d;if(i[b+44>>2]!=4){f=a+16|0;m=f+(i[a+12>>2]<<3)|0;n=b;b:{c:{while(1){d:{if(f>>>0>=m>>>0){break d}h[b+52>>1]=0;pu(f,b,c,c,1,e);if(j[b+54|0]){break d}e:{if(!j[b+53|0]){break e}if(j[b+52|0]){d=1;if(i[b+24>>2]==1){break c}l=1;k=1;if(j[a+8|0]&2){break e}break c}l=1;d=k;if(!(g[a+8|0]&1)){break c}}f=f+8|0;continue}break}d=k;a=4;if(!l){break b}}a=3}i[n+44>>2]=a;if(d&1){break a}}i[b+20>>2]=c;i[b+40>>2]=i[b+40>>2]+1;if(i[b+36>>2]!=1|i[b+24>>2]!=2){break a}g[b+54|0]=1;return}k=i[a+12>>2];f=a+16|0;eq(f,b,c,d,e);if((k|0)<2){break a}k=f+(k<<3)|0;f=a+24|0;a=i[a+8>>2];if(!(i[b+36>>2]!=1?!(a&2):0)){while(1){if(j[b+54|0]){break a}eq(f,b,c,d,e);f=f+8|0;if(f>>>0<k>>>0){continue}break}break a}if(!(a&1)){while(1){if(j[b+54|0]|i[b+36>>2]==1){break a}eq(f,b,c,d,e);f=f+8|0;if(f>>>0<k>>>0){continue}break a}}while(1){if(j[b+54|0]|(i[b+24>>2]==1?i[b+36>>2]==1:0)){break a}eq(f,b,c,d,e);f=f+8|0;if(f>>>0<k>>>0){continue}break}}}function Hua(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,p=0,q=0;e=Xa-48|0;Xa=e;n=i[a+16>>2];f=tf(e+16|0);i[f+8>>2]=a+112;i[f+16>>2]=i[a+128>>2];p=f,q=of(b+327720|0,i[b+20>>2],(i[a+88>>2]&16384)>>>14|0),i[p+12>>2]=q;b=i[f+16>>2];if(b){p=f,q=sf(a+8|0,b),i[p>>2]=q;i[f+4>>2]=_a}l=i[a+40>>2];m=i[a+36>>2];g=i[a+4>>2];j=i[a>>2];i[e+8>>2]=j;i[e+12>>2]=g;b=i[a+12>>2];i[e>>2]=i[a+8>>2];i[e+4>>2]=b;a:{if(!d){b=l>>12;k=m>>12;break a}while(1){b=0;k=b;i[e+40>>2]=j;i[e+44>>2]=b;g=(g<<1)+n|0;b:{b=i[f+16>>2];if((b|0)<=0){break b}while(1){fd(i[f+8>>2],h[(k<<1)+g>>1]/4<<16>>16);ed(i[f+8>>2],4);zb(e+40|0,f);if((b|0)<2){break b}b=b+ -1|0;k=i[e+44>>2];continue}}d=d+ -1|0;b=i[f+8>>2];zb(b,b+8|0);b=i[f+8>>2];j=i[b+4>>2];if(j){fd(b,h[g+(i[e+44>>2]<<1)>>1]/4<<16>>16);ed(i[f+8>>2],j);b=i[f+8>>2];j=i[b>>2];i[b>>2]=j;i[b+4>>2]=0}g=nf(b,i[f+12>>2]);b=i[a+32>>2];m=i[a+28>>2]+m|0;k=m>>12;i[c>>2]=i[c>>2]+o(g,k);l=b+l|0;b=l>>12;i[c+4>>2]=i[c+4>>2]+o(g,b);zb(e+8|0,e);if(d){c=c+8|0;j=i[e+8>>2];g=i[e+12>>2];continue}break}j=i[e+8>>2];g=i[e+12>>2]}i[a+40>>2]=l;i[a+20>>2]=k;i[a+36>>2]=m;i[a+24>>2]=b;i[a>>2]=j;i[a+4>>2]=g;Xa=e+48|0}function nv(a,b,c,d){var e=0,f=0,g=0,h=0,j=0,k=0,l=0;g=Xa-32|0;Xa=g;e=d&2147483647;j=e;e=e+ -1006698496|0;h=c;f=c;if(c>>>0<0){e=e+1|0}k=f;f=e;e=j+ -1140785152|0;l=h;if(h>>>0<0){e=e+1|0}a:{if((e|0)==(f|0)&k>>>0<l>>>0|f>>>0<e>>>0){e=d<<4|c>>>28;c=c<<4|b>>>28;b=b&268435455;h=b;if((b|0)==134217728&a>>>0>=1|b>>>0>134217728){e=e+1073741824|0;a=c+1|0;if(a>>>0<1){e=e+1|0}f=a;break a}f=c;e=e-((c>>>0<0)+ -1073741824|0)|0;if(a|h^134217728){break a}a=f+(f&1)|0;if(a>>>0<f>>>0){e=e+1|0}f=a;break a}if(!(!h&(j|0)==2147418112?!(a|b):(j|0)==2147418112&h>>>0<0|j>>>0<2147418112)){e=d<<4|c>>>28;f=c<<4|b>>>28;e=e&524287|2146959360;break a}f=0;e=2146435072;if(j>>>0>1140785151){break a}e=0;h=j>>>16|0;if(h>>>0<15249){break a}e=d&65535|65536;kf(g+16|0,a,b,c,e,h+ -15233|0);cm(g,a,b,c,e,15361-h|0);c=i[g+4>>2];a=i[g+8>>2];e=i[g+12>>2]<<4|a>>>28;f=a<<4|c>>>28;a=c&268435455;c=a;b=i[g>>2]|((i[g+16>>2]|i[g+24>>2])!=0|(i[g+20>>2]|i[g+28>>2])!=0);if((a|0)==134217728&b>>>0>=1|a>>>0>134217728){a=f+1|0;if(a>>>0<1){e=e+1|0}f=a;break a}if(b|c^134217728){break a}a=f+(f&1)|0;if(a>>>0<f>>>0){e=e+1|0}f=a}Xa=g+32|0;eNa(0,f|0);eNa(1,d&-2147483648|e);return+fNa()}function tga(a,b,c){var d=0,e=0,f=0,g=0,h=0,k=0,l=0,m=0,n=0;d=Xa-80|0;Xa=d;f=Bb(d+48|0,KJ(b));i[114610]=0;D(1603,d- -64|0,f|0);e=i[114610];i[114610]=0;a:{b:{c:{if((e|0)!=1){eb(f);m=d,n=Jb(a),i[m+40>>2]=n;m=d,n=Kb(a),i[m+32>>2]=n;if(!pb(d+40|0,d+32|0)){a=0;break a}k=b+20|0;l=b+16|0;f=0;while(1){a=0;g=i[d+40>>2];e=l;if(i[i[g>>2]+32>>2]==(j[e|0]|j[e+1|0]<<8|(j[e+2|0]<<16|j[e+3|0]<<24))){a=k;a=i[i[g>>2]+36>>2]==(j[a|0]|j[a+1|0]<<8|(j[a+2|0]<<16|j[a+3|0]<<24))}e=i[g>>2];i[114610]=0;D(1753,d|0,e+8|0);e=i[114610];i[114610]=0;d:{e:{f:{g:{if((e|0)!=1){i[114610]=0;D(1603,d+16|0,d|0);e=i[114610];i[114610]=0;if((e|0)==1){break g}e=Xe(d+16|0,d- -64|0);eb(d+16|0);eb(d);if((a&e)!=1){break e}f=i[g>>2];h=3;break d}a=B()|0;A()|0;break f}a=B()|0;A()|0;eb(d)}f=d- -64|0;break b}if(!(a^1|(h|0)>1)){f=i[g>>2];h=2;break d}a=e&(h|0)<1;f=a?i[g>>2]:f;h=a?1:h}Gd(d+40|0);if(pb(d+40|0,d+32|0)){continue}break}break c}a=B()|0;A()|0;break b}a=0;if(!f){break a}e=i[f+4>>2];if(!e){break a}i[114610]=0;a=I(e|0,f|0,c|0,b|0)|0;b=i[114610];i[114610]=0;if((b|0)!=1){a=(a|0)!=0;break a}a=B()|0;f=d- -64|0;A()|0}eb(f);E(a|0);x()}eb(d- -64|0);Xa=d+80|0;return a}function _5(a,b,c,d,e,f){var h=0,i=0,l=0,n=0,q=0,r=0,s=0,t=0,u=0,v=p(0),w=0,x=p(0);l=Xa-48|0;Xa=l;q=!j[d+13|0]+(j[d+14|0]!=0)|0;r=j[d+25|0];s=l;t=b;u=l+44|0;a:{if(j[a+1|0]&8){f=j[d+27|0];h=j[k[d+8>>1]+43456|0];i=h&3;g[l+47|0]=i;g[l+46|0]=i;i=h>>>2|0;g[l+45|0]=i;g[l+44|0]=i;b=o(q,28)+43360|0;break a}f=(j[a+3|0]&16)>>>4&(f|0)!=0;b=f?12:0;h=k[d+8>>1]>>>f|0;while(1){n=1;f=3;while(1){i=f;f=j[(f+b|0)+43472|0];g[i+(l+44|0)|0]=((h|0)/(n|0)|0)%(f|0);n=o(f,n);f=i+ -1|0;if(i){continue}break}b=b+4|0;h=h-n|0;if((h|0)>-1){continue}break}f=-16;b=(o(q,28)+43360|0)+b|0}P5(s,t,u,b,c,f);i=j[d+14|0];b:{if(i){b=2-r|0;q=j[d+23|0]<<b;f=j[d+22|0]<<b;c=j[d+21|0]<<b;b=j[d+13|0];n=0;while(1){h=(b+n|0)+l|0;g[h|0]=c+j[h|0];g[h+1|0]=f+j[h+1|0];g[h+2|0]=q+j[h+2|0];n=n+3|0;if(n>>>0<i>>>0){continue}break}break b}if(!j[d+24|0]){break b}f=0;while(1){b=f+l|0;g[b+11|0]=j[b+11|0]+j[f+43496|0];f=f+1|0;if((f|0)!=10){continue}break}}v=Cv(p(2048),((((j[a+3|0]&224)==96)<<1)-j[d+10|0]|0)+258|0);f=0;if((i|0)!=(0-j[d+13|0]|0)){a=r+1|0;while(1){w=(f<<2)+e|0,x=Cv(v,j[f+l|0]<<a),m[w>>2]=x;f=f+1|0;if(f>>>0<j[d+14|0]+j[d+13|0]>>>0){continue}break}}Xa=l+48|0}function Kua(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,h=0,j=0,k=0,l=0,m=0,n=0,p=0,q=0,r=0;e=Xa-48|0;Xa=e;l=i[a+16>>2];f=tf(e+16|0);i[f+8>>2]=a+112;i[f+16>>2]=i[a+128>>2];q=f,r=of(b+327720|0,i[b+20>>2],(i[a+88>>2]&16384)>>>14|0),i[q+12>>2]=r;b=i[f+16>>2];if(b){q=f,r=sf(a+8|0,b),i[q>>2]=r;i[f+4>>2]=_a}m=i[a+24>>2];n=i[a+20>>2];b=i[a+4>>2];h=i[a>>2];i[e+8>>2]=h;i[e+12>>2]=b;j=i[a+12>>2];i[e>>2]=i[a+8>>2];i[e+4>>2]=j;if(d){while(1){j=0;k=h;i[e+40>>2]=h;i[e+44>>2]=p;h=(((b&2147483647)<<1|h>>>31)&-2)+l|0;a:{b=i[f+16>>2];if((b|0)<=0){break a}while(1){j=(j&2147483647)<<1|k>>>31;fd(i[f+8>>2],g[(j|1)+h|0]+g[h+(j&-2)|0]<<5);ed(i[f+8>>2],4);zb(e+40|0,f);if((b|0)<2){break a}b=b+ -1|0;k=i[e+40>>2];j=i[e+44>>2];continue}}d=d+ -1|0;b=i[f+8>>2];zb(b,b+8|0);b=i[f+8>>2];j=i[b+4>>2];if(j){k=b;b=(i[e+44>>2]&2147483647)<<1|i[e+40>>2]>>>31;fd(k,g[(b|1)+h|0]+g[h+(b&-2)|0]<<5);ed(i[f+8>>2],j);b=i[f+8>>2];j=i[b>>2];i[b>>2]=j;i[b+4>>2]=0}b=nf(b,i[f+12>>2]);i[c>>2]=i[c>>2]+o(b,n);i[c+4>>2]=i[c+4>>2]+o(b,m);zb(e+8|0,e);if(d){c=c+8|0;h=i[e+8>>2];b=i[e+12>>2];continue}break}h=i[e+8>>2];b=i[e+12>>2]}i[a>>2]=h;i[a+4>>2]=b;Xa=e+48|0}function go(a){a=a|0;var b=0,c=0,d=0,e=0,f=p(0),g=0,j=p(0),n=0,q=0,r=0,s=p(0);c=i[a+36>>2];if(!c){Sh(a+16|0);return}a:{b:{c:{switch(k[a>>1]){case 3:d=a+16|0;if(c>>>0>=1001){Sh(d);return}Tk(d,c);c=k[a+28>>1];b=a+4|0;qb(b);f=Uk(a,(c<<16)+65536>>16);c=h[a+28>>1];qb(b);b=1;f=Wd(p(f/Uk(a,c)),p(p(1)/p(i[a+36>>2]+1>>>0)));if(!i[a+36>>2]){break b}while(1){j=Wd(f,p(b>>>0));r=vb(d,b+ -1|0),s=j,m[r>>2]=s;b=b+1|0;if(b>>>0<=l[a+36>>2]){continue}break}break b;case 1:d=a+16|0;g=k[a+30>>1];if(1e3/(c>>>0)>>>0<g>>>0){Sh(d);return}Tk(d,o(c,g));c=h[a+28>>1];qb(a+4|0);b=k[a+30>>1];if((c|0)>=0){c=(c|0)%(b|0)|0}else{c=((c^-1)%(b|0)^-1)+b|0}if(!g){break b}while(1){b=b&65535;e=c+n<<16>>16;d:{if((e|0)>=0){b=(e|0)%(b|0)|0;break d}b=b+((e^-1)%(b|0)^-1)|0}e=1;b=b<<16;q=b>>16;f=Wd(p(Uk(a,b+65536>>16)/Uk(a,q)),p(p(1)/p(i[a+36>>2]+1>>>0)));b=1;if(i[a+36>>2]){while(1){j=Wd(f,p((b&65535)>>>0));r=vb(d,(o(i[a+36>>2],q)+e|0)+ -1|0),s=j,m[r>>2]=s;b=b+1|0;e=b&65535;if(l[a+36>>2]>=e>>>0){continue}break}}n=n+1|0;if((n&65535)>>>0>=g>>>0){break b}b=k[a+30>>1];continue};case 0:break a;default:break c}}Sh(a+16|0);i[a+36>>2]=0}return}Sh(a+16|0)}function Tpa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,k=0,l=0,m=0,o=0,p=0,r=0,s=0;f=Xa-16|0;Xa=f;i[f+8>>2]=c>>>4;i[f+4>>2]=i[a>>2];d=i[rb(f+8|0,f+4|0)>>2];b=jb(b);if(d){a=i[a+20>>2];c=d;while(1){e=b;g=j[e+4|0]|j[e+5|0]<<8|(j[e+6|0]<<16|j[e+7|0]<<24);k=j[e|0]|j[e+1|0]<<8|(j[e+2|0]<<16|j[e+3|0]<<24);e=g;m=k<<8&16711680|k<<24;o=e<<24|k>>>8;g=e<<8|k>>>24;m=o&65280|g&255|m;i[f+8>>2]=((e&255)<<24|k>>>8)&-16777216|((e&16777215)<<8|k>>>24)&16711680|(e>>>8&65280|e>>>24)|p;i[f+12>>2]=m;mf(f+8|0,-1,1);l=n[f+8>>3]*32768;n[f+8>>3]=l;e=a;l=xd(l);a:{if(q(l)<2147483648){g=~~l;break a}g=-2147483648}r=e,s=Bc(g),h[r>>1]=s;e=b;g=j[e+12|0]|j[e+13|0]<<8|(j[e+14|0]<<16|j[e+15|0]<<24);k=j[e+8|0]|j[e+9|0]<<8|(j[e+10|0]<<16|j[e+11|0]<<24);e=g;m=k<<8&16711680|k<<24;o=e<<24|k>>>8;g=e<<8|k>>>24;m=o&65280|g&255|m;i[f+8>>2]=((e&255)<<24|k>>>8)&-16777216|((e&16777215)<<8|k>>>24)&16711680|(e>>>8&65280|e>>>24)|p;i[f+12>>2]=m;mf(f+8|0,-1,1);l=n[f+8>>3]*32768;n[f+8>>3]=l;e=a;l=xd(l);b:{if(q(l)<2147483648){g=~~l;break b}g=-2147483648}r=e,s=Bc(g),h[r+2>>1]=s;a=a+4|0;b=b+16|0;c=c+ -1|0;if(c){continue}break}}Xa=f+16|0;return d<<4}function Ova(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;g=Xa-16|0;Xa=g;f=i[a+48>>2];n=i[a+40>>2];p=i[a+36>>2];e=i[a+44>>2];s=i[a+16>>2];l=i[a+4>>2];k=i[a>>2];i[g+8>>2]=k;i[g+12>>2]=l;b=i[a+12>>2];i[g>>2]=i[a+8>>2];i[g+4>>2]=b;a:{if(!d){j=n>>12;q=p>>12;break a}while(1){b=(l<<1)+s|0;q=h[b+2>>1];j=h[b>>1];b=i[a+60>>2];t=b;u=b>>31;b=e;e=Eb(e,-16777216,16776704);m=i[a+64>>2];f=Eb(f,-16777216,16776704);v=i[a+72>>2];w=i[a+32>>2];l=c;x=i[c>>2];e=XMa(m,m>>31,e,e>>31);m=_a;y=e;e=i[a+68>>2];r=XMa(e,e>>31,f,f>>31);e=y+r|0;f=_a+m|0;f=e>>>0<r>>>0?f+1|0:f;m=e;k=j+((o(q-j|0,k>>>18|0)|0)/16384|0)<<8;e=k;j=XMa(t,u,e,e>>31);e=m+j|0;f=_a+f|0;f=e>>>0<j>>>0?f+1|0:f;e=e+8388608|0;if(e>>>0<8388608){f=f+1|0}e=(f&16777215)<<8|e>>>24;f=(e|0)/256|0;p=i[a+28>>2]+p|0;q=p>>12;i[l>>2]=o(f,q)+x;n=n+w|0;j=n>>12;i[c+4>>2]=i[c+4>>2]+o(f,j);e=e-(k&v)|0;zb(g+8|0,g);d=d+ -1|0;if(d){c=c+8|0;k=i[g+8>>2];l=i[g+12>>2];f=b;continue}break}k=i[g+8>>2];l=i[g+12>>2];f=b}i[a+40>>2]=n;i[a+20>>2]=q;i[a+36>>2]=p;i[a+48>>2]=f;i[a+44>>2]=e;i[a+24>>2]=j;i[a>>2]=k;i[a+4>>2]=l;Xa=g+16|0}function Pva(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,h=0,j=0,k=0,l=0,m=0,n=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;h=Xa-16|0;Xa=h;f=i[a+48>>2];n=i[a+40>>2];p=i[a+36>>2];e=i[a+44>>2];s=i[a+16>>2];l=i[a+4>>2];k=i[a>>2];i[h+8>>2]=k;i[h+12>>2]=l;b=i[a+12>>2];i[h>>2]=i[a+8>>2];i[h+4>>2]=b;a:{if(!d){j=n>>12;q=p>>12;break a}while(1){b=l+s|0;q=g[b+1|0];j=g[b|0];b=i[a+60>>2];t=b;u=b>>31;b=e;e=Eb(e,-16777216,16776704);m=i[a+64>>2];f=Eb(f,-16777216,16776704);v=i[a+72>>2];w=i[a+32>>2];l=c;x=i[c>>2];e=XMa(m,m>>31,e,e>>31);m=_a;y=e;e=i[a+68>>2];r=XMa(e,e>>31,f,f>>31);e=y+r|0;f=_a+m|0;f=e>>>0<r>>>0?f+1|0:f;m=e;k=((o(q-j|0,k>>>18|0)<<8)/16384|0)+(j<<8)<<8;e=k;j=XMa(t,u,e,e>>31);e=m+j|0;f=_a+f|0;f=e>>>0<j>>>0?f+1|0:f;e=e+8388608|0;if(e>>>0<8388608){f=f+1|0}e=(f&16777215)<<8|e>>>24;f=(e|0)/256|0;p=i[a+28>>2]+p|0;q=p>>12;i[l>>2]=o(f,q)+x;n=n+w|0;j=n>>12;i[c+4>>2]=i[c+4>>2]+o(f,j);e=e-(k&v)|0;zb(h+8|0,h);d=d+ -1|0;if(d){c=c+8|0;k=i[h+8>>2];l=i[h+12>>2];f=b;continue}break}k=i[h+8>>2];l=i[h+12>>2];f=b}i[a+40>>2]=n;i[a+20>>2]=q;i[a+36>>2]=p;i[a+48>>2]=f;i[a+44>>2]=e;i[a+24>>2]=j;i[a>>2]=k;i[a+4>>2]=l;Xa=h+16|0}function Tb(a,b,c){var d=0,e=0,f=0;if(c>>>0>=512){Ba(a|0,b|0,c|0)|0;return a}e=a+c|0;a:{if(!((a^b)&3)){b:{if((c|0)<1){c=a;break b}if(!(a&3)){c=a;break b}c=a;while(1){g[c|0]=j[b|0];b=b+1|0;c=c+1|0;if(c>>>0>=e>>>0){break b}if(c&3){continue}break}}d=e&-4;c:{if(d>>>0<64){break c}f=d+ -64|0;if(c>>>0>f>>>0){break c}while(1){i[c>>2]=i[b>>2];i[c+4>>2]=i[b+4>>2];i[c+8>>2]=i[b+8>>2];i[c+12>>2]=i[b+12>>2];i[c+16>>2]=i[b+16>>2];i[c+20>>2]=i[b+20>>2];i[c+24>>2]=i[b+24>>2];i[c+28>>2]=i[b+28>>2];i[c+32>>2]=i[b+32>>2];i[c+36>>2]=i[b+36>>2];i[c+40>>2]=i[b+40>>2];i[c+44>>2]=i[b+44>>2];i[c+48>>2]=i[b+48>>2];i[c+52>>2]=i[b+52>>2];i[c+56>>2]=i[b+56>>2];i[c+60>>2]=i[b+60>>2];b=b- -64|0;c=c- -64|0;if(c>>>0<=f>>>0){continue}break}}if(c>>>0>=d>>>0){break a}while(1){i[c>>2]=i[b>>2];b=b+4|0;c=c+4|0;if(c>>>0<d>>>0){continue}break}break a}if(e>>>0<4){c=a;break a}d=e+ -4|0;if(d>>>0<a>>>0){c=a;break a}c=a;while(1){g[c|0]=j[b|0];g[c+1|0]=j[b+1|0];g[c+2|0]=j[b+2|0];g[c+3|0]=j[b+3|0];b=b+4|0;c=c+4|0;if(c>>>0<=d>>>0){continue}break}}if(c>>>0<e>>>0){while(1){g[c|0]=j[b|0];b=b+1|0;c=c+1|0;if((e|0)!=(c|0)){continue}break}}return a}function IZ(a,b,c,d,e,f){var h=0,k=0,l=0,m=0,n=0,o=0;i[c>>2]=a;i[f>>2]=d;a:{b:{while(1){c:{h=i[c>>2];if(h>>>0>=b>>>0){break c}m=i[f>>2];if(m>>>0>=e>>>0){break c}a=g[h|0];d=a&255;d:{if((a|0)>=0){if(d>>>0<=1114111){a=1;break d}return 2}n=2;if(d>>>0<194){break b}if(d>>>0<=223){if((b-h|0)<2){break a}k=j[h+1|0];if((k&192)!=128){break b}a=2;d=k&63|d<<6&1984;if(d>>>0<=1114111){break d}break b}if(d>>>0<=239){if((b-h|0)<3){break a}l=j[h+2|0];k=j[h+1|0];e:{f:{if((d|0)!=237){if((d|0)!=224){break f}if((k&224)==160){break e}break b}if((k&224)==128){break e}break b}if((k&192)!=128){break b}}if((l&192)!=128){break b}a=3;d=l&63|(d<<12&61440|(k&63)<<6);if(d>>>0<=1114111){break d}break b}if(d>>>0>244){break b}if((b-h|0)<4){break a}l=j[h+3|0];o=j[h+2|0];k=j[h+1|0];g:{h:{switch(d+ -240|0){case 0:if((k+112&255)>>>0<48){break g}break b;case 4:if((k&240)==128){break g}break b;default:break h}}if((k&192)!=128){break b}}if((o&192)!=128|(l&192)!=128){break b}a=4;d=l&63|(o<<6&4032|(d<<18&1835008|(k&63)<<12));if(d>>>0>1114111){break b}}i[m>>2]=d;i[c>>2]=a+h;i[f>>2]=i[f>>2]+4;continue}break}n=h>>>0<b>>>0}return n}return 1}function Hk(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;f=Xa-16|0;Xa=f;i[a+4>>2]=0;if(j[Gi(f+8|0,a,1)|0]){a:{b:{c:{if((b|0)==2147483647){while(1){b=i[i[a>>2]+ -12>>2];i[114610]=0;b=i[(a+b|0)+24>>2];d=i[114610];i[114610]=0;if((d|0)==1){break c}i[114610]=0;b=F(2323,b|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break c}if(ae(b,-1)){break b}i[a+4>>2]=i[a+4>>2]+1;if(!ae(b,c)){continue}break}d=0;break a}while(1){if(i[a+4>>2]>=(b|0)){break a}e=i[i[a>>2]+ -12>>2];i[114610]=0;e=i[(a+e|0)+24>>2];g=i[114610];i[114610]=0;d:{if((g|0)==1){break d}i[114610]=0;e=F(2323,e|0)|0;g=i[114610];i[114610]=0;if((g|0)==1){break d}if(ae(e,-1)){break b}i[a+4>>2]=i[a+4>>2]+1;if(!ae(e,c)){continue}break a}break}}b=H(0)|0;A()|0;M(b|0)|0;Ei(i[i[a>>2]+ -12>>2]+a|0,1);b=i[i[a>>2]+ -12>>2];i[114610]=0;b=i[(a+b|0)+20>>2];c=i[114610];i[114610]=0;e:{f:{g:{if((c|0)!=1){if(!(b&1)){break g}i[114610]=0;K(81);a=i[114610];i[114610]=0;if((a|0)!=1){break e}}a=B()|0;A()|0;i[114610]=0;K(20);b=i[114610];i[114610]=0;if((b|0)==1){break f}E(a|0);x()}O();d=1;break a}a=H(0)|0;A()|0;gb(a)}x()}d=2}ag(i[i[a>>2]+ -12>>2]+a|0,d)}Xa=f+16|0;return a|0}function Iua(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,h=0,j=0,k=0,l=0,m=0,n=0,p=0,q=0;e=Xa-48|0;Xa=e;n=i[a+16>>2];f=tf(e+16|0);i[f+8>>2]=a+112;i[f+16>>2]=i[a+128>>2];p=f,q=of(b+327720|0,i[b+20>>2],(i[a+88>>2]&16384)>>>14|0),i[p+12>>2]=q;b=i[f+16>>2];if(b){p=f,q=sf(a+8|0,b),i[p>>2]=q;i[f+4>>2]=_a}l=i[a+40>>2];m=i[a+36>>2];h=i[a+4>>2];j=i[a>>2];i[e+8>>2]=j;i[e+12>>2]=h;b=i[a+12>>2];i[e>>2]=i[a+8>>2];i[e+4>>2]=b;a:{if(!d){b=l>>12;k=m>>12;break a}while(1){b=0;k=b;i[e+40>>2]=j;i[e+44>>2]=b;h=h+n|0;b:{b=i[f+16>>2];if((b|0)<=0){break b}while(1){fd(i[f+8>>2],g[h+k|0]<<6);ed(i[f+8>>2],4);zb(e+40|0,f);if((b|0)<2){break b}b=b+ -1|0;k=i[e+44>>2];continue}}d=d+ -1|0;b=i[f+8>>2];zb(b,b+8|0);b=i[f+8>>2];j=i[b+4>>2];if(j){fd(b,g[h+i[e+44>>2]|0]<<6);ed(i[f+8>>2],j);b=i[f+8>>2];j=i[b>>2];i[b>>2]=j;i[b+4>>2]=0}h=nf(b,i[f+12>>2]);b=i[a+32>>2];m=i[a+28>>2]+m|0;k=m>>12;i[c>>2]=i[c>>2]+o(h,k);l=b+l|0;b=l>>12;i[c+4>>2]=i[c+4>>2]+o(h,b);zb(e+8|0,e);if(d){c=c+8|0;j=i[e+8>>2];h=i[e+12>>2];continue}break}j=i[e+8>>2];h=i[e+12>>2]}i[a+40>>2]=l;i[a+20>>2]=k;i[a+36>>2]=m;i[a+24>>2]=b;i[a>>2]=j;i[a+4>>2]=h;Xa=e+48|0}function Tfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=p(0),g=p(0),h=0,j=0,k=0,l=0,n=0,o=0,r=0,s=0,u=0,v=p(0),w=0,x=0,y=0,z=p(0);a:{if(!i[a+4272>>2]){break a}h=a+44|0;if(!Wg(h)){break a}l=ud(h,0);n=ud(h,1);o=Pc(h,0);r=Pc(h,1);if(d){k=a+4256|0;e=i[a+4268>>2];s=d;while(1){f=m[n>>2];g=m[l>>2];y=vb(k,e<<1),z=g,m[y>>2]=z;y=vb(k,i[a+4268>>2]<<1|1),z=f,m[y>>2]=z;f=p(q(iH(p(p(p(q(g))+p(q(f)))*p(536870912)),31,5)));g=m[a+4276>>2];f=p(f*p(4.656612873077393e-10));f=p(p(p(g-f)*m[(g>f?4240:4236)+a>>2])+f);m[a+4276>>2]=f;u=o;v=p(m[a+4232>>2]*p(4.656612873077393e-10));g=m[a+4244>>2];f=p(p(p(m[a+4248>>2]*p(2147483648))*p(g-p(t(f,g))))+p(2147483392));b:{if(f<p(4294967296)&f>=p(0)){j=~~f>>>0;break b}j=0}e=j<<5;w=e|-2147483648;x=e;e=j>>>26|0;f=p(v*p((e?w:x)>>>(e?32-e|0:31)>>>0));e=i[a+4272>>2];e=(((e+(i[a+4252>>2]+(i[a+4268>>2]<<12)|0)|0)+ -1|0)/4096|0)%(e|0)<<1;y=u,z=p(f*m[vb(k,e)>>2]),m[y>>2]=z;y=r,z=p(f*m[vb(k,e|1)>>2]),m[y>>2]=z;j=i[a+4268>>2];e=j+ -1|0;i[a+4268>>2]=e;if(!j){e=i[a+4272>>2]+e|0;i[a+4268>>2]=e}r=r+4|0;o=o+4|0;n=n+4|0;l=l+4|0;s=s+ -1|0;if(s){continue}break}}Oh(a,b,c,Pc(h,0),Pc(h,1),d)}}function ova(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,p=0;f=Xa-16|0;Xa=f;p=i[a+16>>2];a:{b:{c:{g=i[a+8>>2];e=i[a+12>>2];d:{if((e|0)<1?1:(e|0)<=1?g>>>0<=805306368:0){if((e|0)>-2?1:(e|0)>=-2?g>>>0>=3489660928:0){break c}if((e|0)>-2?1:(e|0)>=-2?g>>>0>2147483647:0){break d}break b}if((e|0)>1?1:(e|0)>=1?g>>>0>2147483648:0){break b}}n=b+196648|0;break a}n=b+131112|0;break a}n=b+262184|0}k=i[a+40>>2];l=i[a+36>>2];b=i[a+4>>2];m=i[a>>2];i[f+8>>2]=m;i[f+12>>2]=b;i[f>>2]=g;i[f+4>>2]=e;e:{if(!d){g=k>>12;e=l>>12;break e}while(1){g=i[a+32>>2];l=i[a+28>>2]+l|0;e=l>>12;j=(b<<1)+p|0;b=(m>>>16&65520)+n|0;b=(((((((o(h[j+ -4>>1],h[b+2>>1])+o(h[j+ -6>>1],h[b>>1])|0)+o(h[j+ -2>>1],h[b+4>>1])|0)+o(h[j>>1],h[b+6>>1])|0)+o(h[j+2>>1],h[b+8>>1])|0)+o(h[j+4>>1],h[b+10>>1])|0)+o(h[j+6>>1],h[b+12>>1])|0)+o(h[j+8>>1],h[b+14>>1])|0)/32768|0;i[c>>2]=i[c>>2]+o(e,b);k=g+k|0;g=k>>12;i[c+4>>2]=i[c+4>>2]+o(b,g);zb(f+8|0,f);d=d+ -1|0;if(d){c=c+8|0;m=i[f+8>>2];b=i[f+12>>2];continue}break}m=i[f+8>>2];b=i[f+12>>2]}i[a+40>>2]=k;i[a+20>>2]=e;i[a+36>>2]=l;i[a+24>>2]=g;i[a>>2]=m;i[a+4>>2]=b;Xa=f+16|0}function r5(a,b,c){var d=0,e=0,f=0,h=0,k=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;a:{if(j[a+23|0]){d=i[a+2092>>2];if((d|0)<1){break a}while(1){f=e<<2;s=f+i[a+2084>>2]|0,t=Mk(i[f+i[a+32>>2]>>2]),i[s>>2]=t;e=e+1|0;d=i[a+2092>>2];if((e|0)<(d|0)){continue}break}break a}if(i[a+4>>2]>=1){while(1){if(NE(a,j[b+e|0])){s=i[a+2084>>2]+(d<<2)|0,t=Mk(i[i[a+32>>2]+(e<<2)>>2]),i[s>>2]=t;d=d+1|0}e=e+1|0;if((e|0)<i[a+4>>2]){continue}break}}if(i[a+2092>>2]==(d|0)){break a}V(52065,50448,1185,52088);x()}AE(i[a+2084>>2],d,2302);i[i[a+2084>>2]+(i[a+2092>>2]<<2)>>2]=-1;b:{c:{d=j[a+23|0];m=i[(d?2092:4)+a>>2];if((m|0)<1){break c}f=0;while(1){e=f;h=a;if(d&255){e=i[(f<<2)+c>>2]}n=j[b+e|0];d:{if(!NE(h,n)){break d}o=f<<2;h=Mk(i[o+i[a+32>>2]>>2]);p=i[a+2084>>2];e=0;d=i[a+2092>>2];if((d|0)>=2){while(1){k=d>>>1|0;q=k+e|0;r=l[(q<<2)+p>>2]>h>>>0;e=r?e:q;d=r?k:d-k|0;if((d|0)>1){continue}break}}d=h;h=e<<2;if((d|0)!=i[h+p>>2]){break b}if(j[a+23|0]){i[h+i[a+2088>>2]>>2]=i[c+o>>2];g[i[a+8>>2]+e|0]=n;break d}i[h+i[a+2088>>2]>>2]=f}f=f+1|0;if((m|0)==(f|0)){break c}d=j[a+23|0];continue}}return}V(52111,50448,1215,52088);x()}function Hw(a,b,c){var d=0,e=0,f=0,l=0,m=0,n=0,o=0,p=0,q=0;e=Xa-16|0;Xa=e;d=a+2|0;if(!(j[d|0]==255|!j[d|0])){i[e+12>>2]=j[d|0]+1;i[e+8>>2]=10;Lf(b,i[Nd(e+12|0,e+8|0)>>2]);d=j[a+3|0];g[b+15|0]=d;g[b+16|0]=d;g[b+13|0]=j[a+4|0];g[b+14|0]=j[a+5|0];d=0;f=511;a:{b:{switch(c+ -1|0){case 1:d=4096;f=128;break a;case 0:break b;default:break a}}d=32768;f=1024}if(qb(b)){n=f>>>1|d;d=0;while(1){l=(d<<2)+a|0;c=l+6|0;c=j[c|0]|j[c+1|0]<<8;p=vb(b,d),q=c>>>4|0,h[p>>1]=q;o=b;c:{d:{if(!d){m=0;c=0;break d}c=d+ -1|0;if(k[vb(b,d)>>1]>=k[vb(b,c)>>1]){break c}m=d;c=k[vb(b,c)>>1]+1|0}p=vb(o,m),q=c,h[p>>1]=q}c=l+8|0;i[e+12>>2]=(((j[c|0]|j[c+1|0]<<8)<<16>>16)+n|0)/(f|0);i[e+8>>2]=0;i[e+4>>2]=64;c=i[_r(e+12|0,e+8|0,e+4|0)>>2];p=vb(b,d),q=c,g[p+2|0]=q;d=d+1|0;if(d>>>0<qb(b)>>>0){continue}break}}g[b+12|0]=j[b+12|0]&254|g[a|0]&1;c=b;e:{f:{if(!(j[a|0]&2)){break f}d=j[b+15|0];if(qb(b)>>>0<d>>>0){break f}d=j[b+12|0]|4;break e}d=j[b+12|0]&-5}g[c+12|0]=d;c=b;g:{h:{if(!(j[a|0]&4)){break h}a=j[b+13|0];if(a>>>0>j[b+14|0]){break h}if(qb(b)>>>0<a>>>0){break h}a=j[b+12|0]|2;break g}a=j[b+12|0]&-3}g[c+12|0]=a}Xa=e+16|0}function J9(a,b){a=a|0;b=+b;var c=0,d=0,e=0,f=0,g=0,l=0,m=0;d=Xa-80|0;Xa=d;a:{b:{c:{d:{e:{f:{g:{if(Mh(a)){bo(d+72|0);break g}lm(d+32|0,a);i[114610]=0;D(2175,d+72|0,d+32|0);c=i[114610];i[114610]=0;if((c|0)==1){break f}We(d+32|0)}c=a+36|0;h:{if(Mh(a)){break h}c=i[d+72>>2]}e=i[a+8>>2];if((e|0)!=-1){break c}f=fy(c);if(nd(c)){break e}break d}e=B()|0;A()|0;We(d+32|0);break a}e=0;while(1){if(!(n[wc(c,e)>>3]+g<=b)){f=wc(c,e);break d}g=n[f>>3]+g;e=e+1|0;if(e>>>0<nd(c)>>>0){continue}break}}b=b-g;break b}f=wc(c,e)}e=a+24|0;l=i[e>>2];m=j[a+64|0];c=BG(EO(d+32|0,b),j[f+16|0],k[f+12>>1],i[f+8>>2]);i[114610]=0;f=i[c+12>>2];i[d+16>>2]=i[c+8>>2];i[d+20>>2]=f;f=i[c+20>>2];i[d+24>>2]=i[c+16>>2];i[d+28>>2]=f;f=i[c+4>>2];i[d+8>>2]=i[c>>2];i[d+12>>2]=f;J(2129,d+56|0,l|0,(m?7:1)|0,d+8|0);c=i[114610];i[114610]=0;if((c|0)!=1){i:{c=wg(d+56|0);f=i[c+8>>2];b=n[c>>3];c=k[c+20>>1];hl(d+56|0);h[i[e>>2]+1074438>>1]=c;l=i[e>>2];i[114610]=0;D(2178,l|0,c|0);c=i[114610];i[114610]=0;if((c|0)==1){break i}i[i[e>>2]+1074428>>2]=f;b=b+g;n[a+16>>3]=b;Ej(d+72|0);Xa=d+80|0;return+b}}e=B()|0;A()|0;Ej(d+72|0)}E(e|0);x()}function Wua(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;f=Xa-32|0;Xa=f;m=i[a+40>>2];n=i[a+36>>2];p=i[a+16>>2];e=i[a+4>>2];g=e;j=i[a>>2];i[f+24>>2]=j;i[f+28>>2]=e;e=i[a+12>>2];i[f+16>>2]=i[a+8>>2];i[f+20>>2]=e;a:{if(!d){e=m>>12;l=n>>12;break a}while(1){k=((((g&2147483647)<<1|j>>>31)&2147483646)<<1)+p|0;e=(((j>>>16|0)+4&131064)<<1)+b|0;j=h[e+38>>1];q=h[e+36>>1];r=h[e+34>>1];s=h[e+32>>1];t=h[e+30>>1];u=h[e+28>>1];v=h[e+26>>1];w=h[e+24>>1];l=0;e=1;while(1){g=l<<1;i[(f+8|0)+(l<<2)>>2]=(((((o(h[(g|8)+k>>1],r)+o(h[(g|4)+k>>1],s)|0)+o(h[(g|12)+k>>1],q)|0)+o(h[(g|16)+k>>1],j)|0)/2|0)+((((o(h[(g|-8)+k>>1],v)+o(h[(g|-12)+k>>1],w)|0)+o(h[(g|-4)+k>>1],u)|0)+o(h[g+k>>1],t)|0)/2|0)|0)/16384;g=e;e=0;l=1;if(g){continue}break}e=i[a+32>>2];n=i[a+28>>2]+n|0;l=n>>12;i[c>>2]=i[c>>2]+o(l,i[f+8>>2]);m=e+m|0;e=m>>12;i[c+4>>2]=i[c+4>>2]+o(e,i[f+12>>2]);zb(f+24|0,f+16|0);d=d+ -1|0;if(d){c=c+8|0;j=i[f+24>>2];g=i[f+28>>2];continue}break}j=i[f+24>>2];g=i[f+28>>2]}i[a+40>>2]=m;i[a+20>>2]=l;i[a+36>>2]=n;i[a+24>>2]=e;i[a>>2]=j;i[a+4>>2]=g;Xa=f+32|0}function pva(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,j=0,k=0,l=0,m=0,n=0,p=0,q=0;f=Xa-16|0;Xa=f;q=i[a+16>>2];a:{b:{c:{j=i[a+8>>2];e=i[a+12>>2];d:{if((e|0)<1?1:(e|0)<=1?j>>>0<=805306368:0){if((e|0)>-2?1:(e|0)>=-2?j>>>0>=3489660928:0){break c}if((e|0)>-2?1:(e|0)>=-2?j>>>0>2147483647:0){break d}break b}if((e|0)>1?1:(e|0)>=1?j>>>0>2147483648:0){break b}}p=b+196648|0;break a}p=b+131112|0;break a}p=b+262184|0}l=i[a+40>>2];m=i[a+36>>2];b=i[a+4>>2];n=i[a>>2];i[f+8>>2]=n;i[f+12>>2]=b;i[f>>2]=j;i[f+4>>2]=e;e:{if(!d){j=l>>12;e=m>>12;break e}while(1){j=i[a+32>>2];m=i[a+28>>2]+m|0;e=m>>12;k=b+q|0;b=(n>>>16&65520)+p|0;b=(((((((o(g[k+ -2|0],h[b+2>>1])+o(g[k+ -3|0],h[b>>1])|0)+o(g[k+ -1|0],h[b+4>>1])|0)+o(g[k|0],h[b+6>>1])|0)+o(g[k+1|0],h[b+8>>1])|0)+o(g[k+2|0],h[b+10>>1])|0)+o(g[k+3|0],h[b+12>>1])|0)+o(g[k+4|0],h[b+14>>1])<<8)/32768|0;i[c>>2]=i[c>>2]+o(e,b);l=j+l|0;j=l>>12;i[c+4>>2]=i[c+4>>2]+o(b,j);zb(f+8|0,f);d=d+ -1|0;if(d){c=c+8|0;n=i[f+8>>2];b=i[f+12>>2];continue}break}n=i[f+8>>2];b=i[f+12>>2]}i[a+40>>2]=l;i[a+20>>2]=e;i[a+36>>2]=m;i[a+24>>2]=j;i[a>>2]=n;i[a+4>>2]=b;Xa=f+16|0}function SE(a,b,c,d,e,f,g,k){var l=0,n=0,q=0,r=0,s=0,t=p(0),u=0,v=0;a:{if(j[b+21|0]){r=i[f>>2];n=i[e>>2];u=1;b:{if((k|0)>=1){s=i[b>>2];v=o(d,g);while(1){if(i[a+1396>>2]<=9){Bj(a)}q=i[a+1392>>2];g=h[(((q&1023)<<1)+b|0)+36>>1];c:{if((g|0)>=0){l=q;q=j[g+i[b+8>>2]|0];i[a+1392>>2]=l>>>q;l=i[a+1396>>2]-q|0;q=(l|0)<0;i[a+1396>>2]=q?0:l;g=q?-1:g;break c}g=Nk(a,b)}if((g|0)>=i[b+2092>>2]?j[b+23|0]:0){break a}if((g|0)<=-1){if(!j[a+1376|0]){u=0;if(i[a+1384>>2]){break b}}Lb(a,21);return 0}q=o(d,r);s=((q+s|0)+n|0)>(v|0)?(v-q|0)+n|0:s;q=o(g,i[b>>2]);d:{if(j[b+22|0]){g=0;t=p(0);if((s|0)<=0){break d}while(1){t=p(m[i[b+28>>2]+(g+q<<2)>>2]+t);l=i[(n<<2)+c>>2];if(l){l=l+(r<<2)|0;m[l>>2]=m[l>>2]+t}n=n+1|0;l=(n|0)==(d|0);n=l?0:n;r=l+r|0;g=g+1|0;if((s|0)!=(g|0)){continue}break}break d}g=0;if((s|0)<=0){break d}while(1){l=i[(n<<2)+c>>2];if(l){l=l+(r<<2)|0;m[l>>2]=m[l>>2]+m[i[b+28>>2]+(g+q<<2)>>2]}n=n+1|0;l=(n|0)==(d|0);n=l?0:n;r=l+r|0;g=g+1|0;if((s|0)!=(g|0)){continue}break}}k=k-s|0;if((k|0)>0){continue}break}}i[e>>2]=n;i[f>>2]=r}return u}Lb(a,21);return 0}V(50704,50448,1872,50740);x()}function Cva(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,j=0,k=0,l=0,m=0,n=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;j=Xa-16|0;Xa=j;f=i[a+48>>2];p=i[a+24>>2];q=i[a+20>>2];b=i[a+44>>2];r=i[a+16>>2];k=i[a+4>>2];l=i[a>>2];i[j+8>>2]=l;i[j+12>>2]=k;e=i[a+12>>2];i[j>>2]=i[a+8>>2];i[j+4>>2]=e;a:{if(!d){e=b;b=f;break a}while(1){e=k+r|0;k=g[e+2|0];s=g[e+1|0];t=g[e|0];u=g[e+ -1|0];e=i[a+60>>2];v=e;w=e>>31;e=Eb(b,-16777216,16776704);m=i[a+64>>2];f=Eb(f,-16777216,16776704);x=i[a+72>>2];y=i[c>>2];e=XMa(m,m>>31,e,e>>31);m=_a;z=e;e=i[a+68>>2];n=XMa(e,e>>31,f,f>>31);e=z+n|0;f=_a+m|0;f=e>>>0<n>>>0?f+1|0:f;m=e;e=(l>>>21&2040)+27872|0;k=(((o(h[e+2>>1],t)+o(u,h[e>>1])|0)+o(h[e+4>>1],s)|0)+o(k,h[e+6>>1])<<8)/16384<<8;e=k;l=XMa(v,w,e,e>>31);e=m+l|0;f=_a+f|0;f=e>>>0<l>>>0?f+1|0:f;e=e+8388608|0;if(e>>>0<8388608){f=f+1|0}f=(f&16777215)<<8|e>>>24;e=(f|0)/256|0;i[c>>2]=o(e,q)+y;i[c+4>>2]=i[c+4>>2]+o(e,p);e=f-(k&x)|0;zb(j+8|0,j);d=d+ -1|0;if(d){c=c+8|0;l=i[j+8>>2];k=i[j+12>>2];f=b;b=e;continue}break}l=i[j+8>>2];k=i[j+12>>2]}i[a+48>>2]=b;i[a+44>>2]=e;i[a>>2]=l;i[a+4>>2]=k;Xa=j+16|0}function Bva(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;g=Xa-16|0;Xa=g;f=i[a+48>>2];p=i[a+24>>2];q=i[a+20>>2];b=i[a+44>>2];r=i[a+16>>2];j=i[a+4>>2];k=i[a>>2];i[g+8>>2]=k;i[g+12>>2]=j;e=i[a+12>>2];i[g>>2]=i[a+8>>2];i[g+4>>2]=e;a:{if(!d){e=b;b=f;break a}while(1){e=(j<<1)+r|0;l=h[e>>1];s=h[e+ -2>>1];t=h[e+2>>1];u=h[e+4>>1];n=i[a+60>>2];e=Eb(b,-16777216,16776704);m=i[a+64>>2];j=Eb(f,-16777216,16776704);v=i[a+72>>2];f=i[c>>2];e=XMa(m,m>>31,e,e>>31);m=_a;w=c;x=f;f=(k>>>21&2040)+27872|0;k=(((o(l,h[f+2>>1])+o(h[f>>1],s)|0)+o(h[f+4>>1],t)|0)+o(u,h[f+6>>1])|0)/16384<<8;f=k;l=XMa(n,n>>31,f,f>>31);e=l+e|0;f=_a+m|0;f=e>>>0<l>>>0?f+1|0:f;l=e;e=i[a+68>>2];j=XMa(e,e>>31,j,j>>31);e=l+j|0;f=_a+f|0;f=e>>>0<j>>>0?f+1|0:f;e=e+8388608|0;if(e>>>0<8388608){f=f+1|0}f=(f&16777215)<<8|e>>>24;e=(f|0)/256|0;i[w>>2]=x+o(e,q);i[c+4>>2]=i[c+4>>2]+o(e,p);e=f-(k&v)|0;zb(g+8|0,g);d=d+ -1|0;if(d){c=c+8|0;k=i[g+8>>2];j=i[g+12>>2];f=b;b=e;continue}break}k=i[g+8>>2];j=i[g+12>>2]}i[a+48>>2]=b;i[a+44>>2]=e;i[a>>2]=k;i[a+4>>2]=j;Xa=g+16|0}function uka(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0;e=Xa+ -64|0;Xa=e;g=sm(a);a:{if(b+ -1>>>0>1023){break a}f=i[a+12>>2];if((f|0)==(b|0)){break a}if(c){c=i[g+8>>2];if(l[c+40>>2]<b>>>0|l[c+36>>2]>b>>>0){break a}f=i[a+12>>2]}f=o(Hj(a),f>>>0<b>>>0?b-f|0:f-b|0);b:{c:{if(l[a+12>>2]<b>>>0){c=e;d:{if(d){d=Kb(a);break d}d=Jb(a)}i[c+48>>2]=d;c=Ad(e+56|0,e+48|0);Tg(e+40|0);c=i[c>>2];i[114610]=0;N(1563,a|0,c|0,f|0,e+40|0)|0;c=i[114610];i[114610]=0;if((c|0)!=1){break b}a=H(71348)|0;break c}if(d){j=e,k=Kb(a),i[j+48>>2]=k;j=e,k=DI(e+48|0,0-f|0),i[j+40>>2]=k;c=Ad(e+32|0,e+40|0);j=e,k=Kb(a),i[j+16>>2]=k;d=i[Ad(e+24|0,e+16|0)>>2];c=i[c>>2];i[114610]=0;I(1564,a|0,c|0,d|0)|0;c=i[114610];i[114610]=0;if((c|0)!=1){break b}a=H(71348)|0;break c}j=e,k=Jb(a),i[j+40>>2]=k;c=Ad(e+8|0,e+40|0);j=e,k=Jb(a),i[j+16>>2]=k;j=e,k=DI(e+16|0,f),i[j+48>>2]=k;d=i[Ad(e,e+48|0)>>2];c=i[c>>2];i[114610]=0;I(1564,a|0,c|0,d|0)|0;c=i[114610];i[114610]=0;if((c|0)!=1){break b}a=H(71348)|0}if((A()|0)==(U(71348)|0)){M(a|0)|0;O();break a}E(a|0);x()}i[a+12>>2]=b;h=1}Xa=e- -64|0;return h|0}function RE(a,b,c,d,e){var f=p(0),g=p(0),h=0,i=p(0),j=p(0),k=0;if(!(a&3)){if((a|0)>=4){k=a>>>2|0;a=(c<<2)+b|0;d=a+(d<<2)|0;while(1){b=d+ -4|0;g=m[b>>2];i=m[d>>2];j=m[a>>2];m[a>>2]=i+j;c=a+ -4|0;f=m[c>>2];m[c>>2]=m[b>>2]+f;i=p(j-i);f=p(f-g);m[d>>2]=p(m[e>>2]*i)-p(m[e+4>>2]*f);m[b>>2]=p(m[e+4>>2]*i)+p(m[e>>2]*f);b=d+ -12|0;i=m[b>>2];c=a+ -8|0;f=m[c>>2];h=c;c=d+ -8|0;j=m[c>>2];m[h>>2]=j+f;h=a+ -12|0;g=m[h>>2];m[h>>2]=m[b>>2]+g;f=p(f-j);g=p(g-i);m[c>>2]=p(m[e+32>>2]*f)-p(m[e+36>>2]*g);m[b>>2]=p(m[e+36>>2]*f)+p(m[e+32>>2]*g);b=d+ -20|0;i=m[b>>2];c=a+ -16|0;f=m[c>>2];h=c;c=d+ -16|0;j=m[c>>2];m[h>>2]=j+f;h=a+ -20|0;g=m[h>>2];m[h>>2]=m[b>>2]+g;f=p(f-j);g=p(g-i);m[c>>2]=p(m[e+64>>2]*f)-p(m[e+68>>2]*g);m[b>>2]=p(m[e+68>>2]*f)+p(m[e+64>>2]*g);b=d+ -28|0;i=m[b>>2];c=a+ -24|0;f=m[c>>2];h=c;c=d+ -24|0;j=m[c>>2];m[h>>2]=j+f;h=a+ -28|0;g=m[h>>2];m[h>>2]=m[b>>2]+g;f=p(f-j);g=p(g-i);m[c>>2]=p(m[e+96>>2]*f)-p(m[e+100>>2]*g);m[b>>2]=p(m[e+100>>2]*f)+p(m[e+96>>2]*g);d=d+ -32|0;a=a+ -32|0;e=e+128|0;b=(k|0)>1;k=k+ -1|0;if(b){continue}break}}return}V(51856,50448,2408,51869);x()}function Xua(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,j=0,k=0,l=0,m=0,n=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;f=Xa-32|0;Xa=f;n=i[a+40>>2];p=i[a+36>>2];q=i[a+16>>2];e=i[a+4>>2];k=e;l=i[a>>2];i[f+24>>2]=l;i[f+28>>2]=e;e=i[a+12>>2];i[f+16>>2]=i[a+8>>2];i[f+20>>2]=e;a:{if(!d){j=n>>12;e=p>>12;break a}while(1){m=(((k&2147483647)<<1|l>>>31)&-2)+q|0;e=(((l>>>16|0)+4&131064)<<1)+b|0;l=h[e+38>>1];r=h[e+36>>1];s=h[e+34>>1];t=h[e+32>>1];u=h[e+30>>1];v=h[e+28>>1];w=h[e+26>>1];x=h[e+24>>1];j=0;e=1;while(1){i[(f+8|0)+(j<<2)>>2]=(((((o(g[(j|4)+m|0],s)+o(g[(j|2)+m|0],t)|0)+o(g[(j|6)+m|0],r)|0)+o(g[(j|8)+m|0],l)<<8)/2|0)+((((o(g[(j|-4)+m|0],w)+o(g[(j|-6)+m|0],x)|0)+o(g[(j|-2)+m|0],v)|0)+o(g[j+m|0],u)<<8)/2|0)|0)/16384;k=e;e=0;j=1;if(k){continue}break}k=i[a+32>>2];p=i[a+28>>2]+p|0;e=p>>12;i[c>>2]=i[c>>2]+o(e,i[f+8>>2]);n=k+n|0;j=n>>12;i[c+4>>2]=i[c+4>>2]+o(j,i[f+12>>2]);zb(f+24|0,f+16|0);d=d+ -1|0;if(d){c=c+8|0;l=i[f+24>>2];k=i[f+28>>2];continue}break}l=i[f+24>>2];k=i[f+28>>2]}i[a+40>>2]=n;i[a+20>>2]=e;i[a+36>>2]=p;i[a+24>>2]=j;i[a>>2]=l;i[a+4>>2]=k;Xa=f+32|0}function K3(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,k=0,l=0,m=0;c=Xa-32|0;Xa=c;i[114610]=0;h=C(15,c+24|0,a|0)|0;d=i[114610];i[114610]=0;a:{b:{c:{if((d|0)!=1){d:{if(!j[h|0]){break d}d=i[(i[i[a>>2]+ -12>>2]+a|0)+4>>2];fc(c+16|0,i[i[a>>2]+ -12>>2]+a|0);i[114610]=0;f=F(2331,c+16|0)|0;e=i[114610];i[114610]=0;e:{f:{if((e|0)!=1){ub(c+16|0);e=sk(c+8|0,a);g=i[i[a>>2]+ -12>>2];i[114610]=0;g=a+g|0;l=F(16,g|0)|0;k=i[114610];i[114610]=0;if((k|0)==1){break f}e=i[e>>2];i[114610]=0;k=f;f=b&65535;m=b;b=d&74;b=S(2332,k|0,e|0,g|0,l|0,((b|0)==64?f:(b|0)==8?f:m)|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break f}i[c+16>>2]=b;if(!rk(c+16|0)){break d}b=i[i[a>>2]+ -12>>2];i[114610]=0;D(18,a+b|0,5);b=i[114610];i[114610]=0;if((b|0)!=1){break d}b=H(0)|0;A()|0;break e}b=H(0)|0;A()|0;ub(c+16|0);break e}b=H(0)|0;A()|0}jf(h);break c}jf(h);break b}b=H(0)|0;A()|0}M(b|0)|0;b=i[i[a>>2]+ -12>>2];i[114610]=0;L(19,a+b|0);a=i[114610];i[114610]=0;if((a|0)==1){break a}O()}Xa=c+32|0;return}a=B()|0;A()|0;i[114610]=0;K(20);b=i[114610];i[114610]=0;if((b|0)!=1){E(a|0);x()}a=H(0)|0;A()|0;gb(a);x()}function d5(a,b,c,d,e,f,g){var h=p(0),i=p(0),j=p(0),k=p(0),l=0,n=p(0),q=0,r=p(0),s=p(0),t=p(0),u=p(0),v=p(0),w=p(0),x=p(0);if((a|0)>=1){l=o(f,12)+e|0;n=m[l>>2];q=f<<3;r=m[q+e>>2];f=(f<<2)+e|0;s=m[f>>2];t=m[l+4>>2];u=m[(q|4)+e>>2];v=m[f+4>>2];w=m[e+4>>2];x=m[e>>2];e=(c<<2)+b|0;f=e+(d<<2)|0;b=0-g<<2;while(1){c=f+ -4|0;i=m[c>>2];k=m[f>>2];j=m[e>>2];m[e>>2]=k+j;d=e+ -4|0;h=m[d>>2];m[d>>2]=m[c>>2]+h;h=p(h-i);i=p(j-k);m[c>>2]=p(h*x)+p(i*w);m[f>>2]=p(i*x)-p(h*w);c=f+ -12|0;k=m[c>>2];d=e+ -8|0;h=m[d>>2];g=d;d=f+ -8|0;j=m[d>>2];m[g>>2]=j+h;g=e+ -12|0;i=m[g>>2];m[g>>2]=m[c>>2]+i;i=p(i-k);h=p(h-j);m[c>>2]=p(i*s)+p(h*v);m[d>>2]=p(h*s)-p(i*v);c=f+ -20|0;k=m[c>>2];d=e+ -16|0;h=m[d>>2];g=d;d=f+ -16|0;j=m[d>>2];m[g>>2]=j+h;g=e+ -20|0;i=m[g>>2];m[g>>2]=m[c>>2]+i;i=p(i-k);h=p(h-j);m[c>>2]=p(i*r)+p(h*u);m[d>>2]=p(h*r)-p(i*u);c=f+ -28|0;k=m[c>>2];d=e+ -24|0;h=m[d>>2];g=d;d=f+ -24|0;j=m[d>>2];m[g>>2]=j+h;g=e+ -28|0;i=m[g>>2];m[g>>2]=m[c>>2]+i;i=p(i-k);h=p(h-j);m[c>>2]=p(i*n)+p(h*t);m[d>>2]=p(h*n)-p(i*t);f=b+f|0;e=b+e|0;c=(a|0)>1;a=a+ -1|0;if(c){continue}break}}}function DH(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,h=p(0);c=Xa+ -64|0;Xa=c;d=Dn(c+48|0,td(c+40|0,b));i[114610]=0;b=F(548,d|0)|0;e=i[114610];i[114610]=0;a:{if((e|0)==1){break a}i[114610]=0;b=I(1701,d|0,c|0,b|0)|0;e=i[114610];i[114610]=0;if((e|0)==1){break a}b:{if(!b|i[c>>2]!=542066252){break b}b=c|4;if(j[b|0]|j[b+1|0]<<8|(j[b+2|0]<<16|j[b+3|0]<<24)){break b}b=c+8|0;f=a,h=Fm((eNa(2,j[b|0]|j[b+1|0]<<8|(j[b+2|0]<<16|j[b+3|0]<<24)),iNa()),p(0),p(1)),m[f+4220>>2]=h;b=c+12|0;f=a,h=Fm((eNa(2,j[b|0]|j[b+1|0]<<8|(j[b+2|0]<<16|j[b+3|0]<<24)),iNa()),p(0),p(1)),m[f+4224>>2]=h;b=c+16|0;f=a,h=Fm((eNa(2,j[b|0]|j[b+1|0]<<8|(j[b+2|0]<<16|j[b+3|0]<<24)),iNa()),p(0),p(1)),m[f+4228>>2]=h;b=c+20|0;if((j[b|0]|j[b+1|0]<<8|(j[b+2|0]<<16|j[b+3|0]<<24))>>>0<=5){i[a+4232>>2]=j[b|0]|j[b+1|0]<<8|(j[b+2|0]<<16|j[b+3|0]<<24)}b=c+24|0;i[a+4236>>2]=j[b|0]|j[b+1|0]<<8|(j[b+2|0]<<16|j[b+3|0]<<24);g[a+4240|0]=j[c+28|0]!=0;g[a+4241|0]=j[c+29|0]!=0;g[a+4242|0]=j[c+30|0]!=0;g[a+4243|0]=j[c+31|0]!=0;g[a+4244|0]=j[c+32|0]!=0}hb(d);Xa=c- -64|0;return}a=B()|0;A()|0;hb(d);E(a|0);x()}function z5(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=Xa-32|0;Xa=d;a=uv(a);a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{if((Qq(b,c,0)|0)!=-1){while(1){f=Qq(b,c,e);i[114610]=0;J(199,d|0,b|0,e|0,f-e|0);f=i[114610];i[114610]=0;if((f|0)==1){break j}i[114610]=0;D(200,d+16|0,d|0);f=i[114610];i[114610]=0;if((f|0)==1){break i}i[114610]=0;D(201,a|0,d+16|0);f=i[114610];i[114610]=0;if((f|0)==1){break h}eb(d+16|0);eb(d);e=Qq(b,c,e)+lb(c)|0;if((Qq(b,c,e)|0)!=-1){continue}break}}k:{if(Uc(a)){i[114610]=0;J(199,d+16|0,b|0,e|0,-1);c=i[114610];i[114610]=0;if((c|0)==1){break f}c=lb(d+16|0);eb(d+16|0);if(!c){break k}}i[114610]=0;J(199,d|0,b|0,e|0,-1);b=i[114610];i[114610]=0;if((b|0)==1){break e}i[114610]=0;D(200,d+16|0,d|0);b=i[114610];i[114610]=0;if((b|0)==1){break d}i[114610]=0;D(201,a|0,d+16|0);b=i[114610];i[114610]=0;if((b|0)==1){break c}eb(d+16|0);eb(d)}Xa=d+32|0;return}e=B()|0;A()|0;break a}e=B()|0;A()|0;break g}e=B()|0;A()|0;eb(d+16|0)}eb(d);break a}e=B()|0;A()|0;break a}e=B()|0;A()|0;break a}e=B()|0;A()|0;break b}e=B()|0;A()|0;eb(d+16|0)}eb(d)}Ok(a);E(e|0);x()}function t5(a,b,c,d){var e=0,f=0,g=0,h=0,k=0,l=0,m=0,n=0;e=Xa-128|0;Xa=e;l=yb(e,0,128);a:{b:{c:{d:{if((c|0)<1){break d}while(1){if(j[b+h|0]!=255){break d}h=h+1|0;if((h|0)!=(c|0)){continue}break}break c}if((c|0)!=(h|0)){break b}}f=1;if(!i[a+2092>>2]){break a}V(51962,50448,1088,51985);x()}e=b+h|0;OE(a,0,h,0,j[e|0],d);e=j[e|0];if(e){g=e>>>0>1?e:1;f=1;while(1){i[(f<<2)+l>>2]=1<<32-f;e=(f|0)==(g|0);f=f+1|0;if(!e){continue}break}}m=1;k=h+1|0;if((k|0)>=(c|0)){f=1;break a}e:{f:{g:{while(1){h:{h=b+k|0;e=j[h|0];i:{if((e|0)==255){break i}f=e;if(!e){break e}while(1){g=(f<<2)+l|0;n=i[g>>2];if(!n){g=(f|0)>1;f=f+ -1|0;if(g){continue}break e}break}if(f>>>0>=32){break h}i[g>>2]=0;OE(a,Mk(n),k,m,e,d);m=m+1|0;g=j[h|0];if((g|0)==(f|0)){break i}if(g>>>0>31){break g}if((f|0)>=(g|0)){break i}while(1){e=(g<<2)+l|0;if(i[e>>2]){break f}i[e>>2]=(1<<32-g)+n;g=g+ -1|0;if((g|0)>(f|0)){continue}break}}f=1;k=k+1|0;if((k|0)!=(c|0)){continue}break a}break}V(52003,50448,1111,51985);x()}V(52020,50448,1116,51985);x()}V(52047,50448,1118,51985);x()}f=0}Xa=l+128|0;return f}function a_(a,b,c,d,e,f,h,k){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;h=h|0;k=k|0;var l=0,m=0,n=0,o=0;n=Xa-16|0;Xa=n;l=c;while(1){a:{if((d|0)==(l|0)){l=d;break a}if(!i[l>>2]){break a}l=l+4|0;continue}break}i[k>>2]=f;i[e>>2]=c;while(1){b:{c:{if(!((f|0)==(h|0)|(c|0)==(d|0))){m=i[b+4>>2];i[n+8>>2]=i[b>>2];i[n+12>>2]=m;m=1;d:{e:{f:{g:{h:{o=$Z(f,e,l-c>>2,h-f|0,b,i[a+8>>2]);switch(o+1|0){case 0:break h;case 1:break c;default:break g}}i[k>>2]=f;while(1){i:{if(i[e>>2]==(c|0)){break i}b=Fu(f,i[c>>2],n+8|0,i[a+8>>2]);if((b|0)==-1){break i}f=b+i[k>>2]|0;i[k>>2]=f;c=c+4|0;continue}break}i[e>>2]=c;break f}f=i[k>>2]+o|0;i[k>>2]=f;if((f|0)==(h|0)){break d}if((d|0)==(l|0)){c=i[e>>2];l=d;continue}l=Fu(n+4|0,0,b,i[a+8>>2]);if((l|0)!=-1){break e}}m=2;break c}c=n+4|0;if(l>>>0>h-i[k>>2]>>>0){break c}while(1){if(l){f=j[c|0];m=i[k>>2];i[k>>2]=m+1;g[m|0]=f;l=l+ -1|0;c=c+1|0;continue}break}c=i[e>>2]+4|0;i[e>>2]=c;l=c;while(1){if((d|0)==(l|0)){l=d;break b}if(!i[l>>2]){break b}l=l+4|0;continue}}c=i[e>>2]}m=(c|0)!=(d|0)}Xa=n+16|0;return m|0}f=i[k>>2];continue}}function pea(a,b,c){var d=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0;a:{if(!i[a+4116>>2]){if(!i[a+4120>>2]){break a}Rm(a+8|0,c,a+4104|0,a+4108|0)}f=i[a>>2];g=i[a+4184>>2];d=o(f,g)>>>4|0;d=d>>>0<32767?d:32767;h[a+4202>>1]=d;h[a+4200>>1]=d;e=i[a+54052>>2];d=o(e,f)>>>4|0;d=d>>>0<65536?d:65536;l=d+127>>>3|0;h[a+54050>>1]=l;d=d+255>>>4|0;h[a+54048>>1]=d;h[a+54046>>1]=d;h[a+54044>>1]=l;d=a+8|0;g=(g|0)>(e|0)?g:e;f=36-f>>>1|0;f=f>>>0>8?f:8;oea(b,d,16-(o((g|0)<32768?g:32768,(f|0)<16?16-f|0:0)>>15)|0,c);l=a+4172|0;c=nea(a,d,c);b:{if(!c){k=i[l>>2];break b}n=a+53996|0;mea(l,d,c);j=i[a+4180>>2];m=a+37612|0;f=d;g=c;while(1){k=j&4095;j=j-i[a+53996>>2]&4095;e=4096-(j>>>0<k>>>0?k:j)|0;e=g>>>0>e>>>0?e:g;e=e>>>0<64?e:64;lea(l,(k<<2)+m|0,f,e);kea(n,(j<<2)+m|0,f,e);j=e+i[a+4180>>2]&4095;i[a+4180>>2]=j;k=e+i[a+4172>>2]&8191;i[a+4172>>2]=k;f=(e<<3)+f|0;g=g-e|0;if(g){continue}break}}i[a+4172>>2]=k&8191;jea(a,d,b,c);c:{if(i[a+4116>>2]){i[a+4120>>2]=i[a+4124>>2];break c}b=i[a+4120>>2];if(b>>>0>c>>>0){i[a+4120>>2]=b-c;break c}UG(a);i[a+4120>>2]=0}i[a+4116>>2]=0}}function rwa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,h=0,i=0,k=0,l=0,m=0;i=jb(b);a:{b:{c:{d:{e:{while(1){b=c;if(!c){break e}c=b+ -1|0;if(!j[i+c|0]){continue}break}if((d|0)!=4){break c}d=0;c=0;while(1){f:{g:{h:{e=j[c+i|0];switch(e+ -10|0){case 3:break h;case 0:break g;default:break f}}f=f+1|0;break f}h=h+1|0}k=((d&255)==13&(c|0)!=0&(e|0)==10)+k|0;d=e;c=c+1|0;if((c|0)!=(b|0)){continue}break}break d}b=0;if((d|0)!=4){break b}}i:{if((f|0)==(h|0)){d=2;if((f|0)==(k|0)){break i}}if(f){d=0;if(!h){break i}}d=f?3:h?1:3}if(!b){break b}}c=0;f=(d|0)!=2;e=0;while(1){e=(f|j[c+i|0]!=10)+e|0;c=c+1|0;if((c|0)!=(b|0)){continue}break}mm(a,e);f=(d|0)==1?32:13;h=(d|0)==2;k=d&-3;c=0;e=0;while(1){j:{k:{l:{m:{n:{o:{d=g[c+i|0];switch(d+ -10|0){case 1:case 2:break l;case 0:break n;case 3:break o;default:break m}}l=Ll(a,e),m=f,g[l|0]=m;c=c+h|0;break j}d=Ll(a,e);if(k){g[d|0]=13;break j}g[d|0]=32;break j}if(!d){break k}}l=Ll(a,e),m=d,g[l|0]=m;break j}l=Ll(a,e),m=32,g[l|0]=m}e=e+1|0;c=c+1|0;if(c>>>0<b>>>0){continue}break}break a}mm(a,0)}return 1}function cS(a){var b=0,c=0,d=0,e=0,f=0,h=0,i=0;a:{if((j[a|0]+ -1&255)>>>0>14){break a}h=a+1954|0;d=a+1698|0;while(1){if(g[d|0]<=-2){break a}d=d+1|0;if((h|0)!=(d|0)){continue}break}d=0;while(1){h=f;f=0;c=o(d,13)+a|0;if(j[c+14|0]){break a}e=(d<<4)+a|0;b=e+418|0;if(j[b|0]|j[b+1|0]<<8|(j[b+2|0]<<16|j[b+3|0]<<24)){break a}b=e+422|0;if(j[c+942|0]|(j[b|0]|j[b+1|0]<<8|(j[b+2|0]<<16|j[b+3|0]<<24))>>>0>1048575){break a}c=o(d,11)+a|0;i=c+1346|0;if(j[i|0]>15|j[c+1351|0]>3|j[c+1356|0]>3){break a}b:{if(!(j[b|0]|j[b+1|0]<<8|(j[b+2|0]<<16|j[b+3|0]<<24))){break b}c=e+430|0;if((j[c|0]|j[c+1|0]<<8|(j[c+2|0]<<16|j[c+3|0]<<24))>>>0>1048574){break b}if((j[c|0]|j[c+1|0]<<8|(j[c+2|0]<<16|j[c+3|0]<<24))>>>0>(j[b|0]|j[b+1|0]<<8|(j[b+2|0]<<16|j[b+3|0]<<24))>>>0){break a}e=e+426|0;if((j[e|0]|j[e+1|0]<<8|(j[e+2|0]<<16|j[e+3|0]<<24))>>>0>(j[c|0]|j[c+1|0]<<8|(j[c+2|0]<<16|j[c+3|0]<<24))>>>0){break a}}f=1;c:{if(h&1|(j[b|0]|j[b+1|0]<<8|(j[b+2|0]<<16|j[b+3|0]<<24))){break c}if(Xc(i,12323,11)){break c}f=0}d=d+1|0;if((d|0)!=32){continue}break}}return f}function Zn(a,b,c,d,e,f){var g=p(0),h=p(0),i=0,j=p(0),k=p(0),l=0;if((a|0)>=4){l=a>>>2|0;a=(c<<2)+b|0;d=a+(d<<2)|0;b=f<<2;while(1){c=d+ -4|0;h=m[c>>2];j=m[d>>2];k=m[a>>2];m[a>>2]=j+k;f=a+ -4|0;g=m[f>>2];m[f>>2]=m[c>>2]+g;j=p(k-j);g=p(g-h);m[d>>2]=p(m[e>>2]*j)-p(m[e+4>>2]*g);m[c>>2]=p(m[e+4>>2]*j)+p(m[e>>2]*g);f=d+ -12|0;j=m[f>>2];c=a+ -8|0;g=m[c>>2];i=c;c=d+ -8|0;k=m[c>>2];m[i>>2]=k+g;i=a+ -12|0;h=m[i>>2];m[i>>2]=m[f>>2]+h;i=c;c=b+e|0;g=p(g-k);h=p(h-j);m[i>>2]=p(m[c>>2]*g)-p(m[c+4>>2]*h);m[f>>2]=p(m[c+4>>2]*g)+p(m[c>>2]*h);e=d+ -20|0;j=m[e>>2];f=a+ -16|0;g=m[f>>2];i=f;f=d+ -16|0;k=m[f>>2];m[i>>2]=k+g;i=a+ -20|0;h=m[i>>2];m[i>>2]=m[e>>2]+h;c=b+c|0;g=p(g-k);h=p(h-j);m[f>>2]=p(m[c>>2]*g)-p(m[c+4>>2]*h);m[e>>2]=p(m[c+4>>2]*g)+p(m[c>>2]*h);e=d+ -28|0;j=m[e>>2];f=a+ -24|0;g=m[f>>2];i=f;f=d+ -24|0;k=m[f>>2];m[i>>2]=k+g;i=a+ -28|0;h=m[i>>2];m[i>>2]=m[e>>2]+h;c=b+c|0;g=p(g-k);h=p(h-j);m[f>>2]=p(m[c>>2]*g)-p(m[c+4>>2]*h);m[e>>2]=p(m[c+4>>2]*g)+p(m[c>>2]*h);e=b+c|0;d=d+ -32|0;a=a+ -32|0;c=(l|0)>1;l=l+ -1|0;if(c){continue}break}}}function CG(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,h=0,j=0,k=p(0);d=Xa-48|0;Xa=d;a:{b:{c:{d:{e:{switch(b+ -1|0){case 1:b=(c<<7)/100|0;a=a+24|0;if((b|0)==i[i[a>>2]+24604>>2]){break d}Tb(d+8|0,i[a>>2]+24604|0,40);i[d+8>>2]=b;Ww(i[a>>2],d+8|0);break d;case 2:b=a+24|0;a=i[b>>2];e=a+24664|0;f=i[e+4>>2];i[d+24>>2]=i[e>>2];i[d+28>>2]=f;e=a+24656|0;f=i[e+4>>2];i[d+16>>2]=i[e>>2];i[d+20>>2]=f;e=i[a+24652>>2];i[d+8>>2]=i[a+24648>>2];i[d+12>>2]=e;h=d,j=Uaa(c),g[h+8|0]=j;if(!Yv(d+8|0,i[b>>2]+24648|0)){break d}Vw(i[b>>2],d+8|0);break d;case 3:a=a+24|0;Tb(d+8|0,i[a>>2]+24604|0,40);Taa(d+8|0,c);if(i[i[a>>2]+24640>>2]==i[d+44>>2]?i[i[a>>2]+24636>>2]==i[d+40>>2]:0){break d}Ww(i[a>>2],d+8|0);break d;default:a=P(8)|0;i[114610]=0;c=C(85,d+8|0,38621)|0;b=i[114610];i[114610]=0;if((b|0)==1){break c}Ub(a,c);i[114610]=0;G(2009,a|0,83568,2017);a=i[114610];i[114610]=0;if((a|0)!=1){break a}b=B()|0;A()|0;eb(c);break b;case 0:break e}}h=a,k=Wd(p(10),p(p(c|0)*p(.0005000000237487257))),m[h+48>>2]=k}Xa=d+48|0;return}b=B()|0;A()|0;Q(a|0)}E(b|0)}x()}function hya(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;b=Xa-48|0;Xa=b;a:{b:{c:{f=a+24|0;d:{if($c(f)){break d}d=a+4|0;c=lb(d);a=nxa();e=_a;if(c){c=Sm(b+32|0);i[114610]=0;i[b+16>>2]=e;D(87,c|0,b+16|0);e=i[114610];i[114610]=0;e:{f:{g:{if((e|0)!=1){i[114610]=0;i[b+16>>2]=a;D(87,c|0,b+16|0);a=i[114610];i[114610]=0;if((a|0)==1){break g}if(lb(d)){a=0;while(1){e=j[Sb(d,a)|0];i[114610]=0;i[b+16>>2]=e;D(87,c|0,b+16|0);e=i[114610];i[114610]=0;if((e|0)==1){break b}a=a+1|0;if(a>>>0<lb(d)>>>0){continue}break}}a=Jb(c);d=Kb(c);i[114610]=0;d=I(88,b+16|0,a|0,d|0)|0;a=i[114610];i[114610]=0;if((a|0)==1){break f}i[114610]=0;D(89,b+8|0,d|0);a=i[114610];i[114610]=0;if((a|0)==1){break e}ks(f,b+8|0);$e(b+8|0);Sd(d);Sd(c);break d}a=B()|0;A()|0;break a}a=B()|0;A()|0;break a}a=B()|0;A()|0;break a}a=B()|0;A()|0;Sd(d);break a}_a=a;i[b+16>>2]=e;i[b+20>>2]=_a;c=mwa(b+32|0,b+16|0,b+24|0);i[114610]=0;D(89,b+8|0,c|0);a=i[114610];i[114610]=0;if((a|0)==1){break c}ks(f,b+8|0);$e(b+8|0);Sd(c)}Xa=b+48|0;return}a=B()|0;A()|0;break a}a=B()|0;A()|0}Sd(c);E(a|0);x()}function cwa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;j=Xa-16|0;Xa=j;e=i[a+48>>2];n=i[a+40>>2];p=i[a+36>>2];f=i[a+44>>2];s=i[a+16>>2];l=i[a+4>>2];k=i[a>>2];i[j+8>>2]=k;i[j+12>>2]=l;b=i[a+12>>2];i[j>>2]=i[a+8>>2];i[j+4>>2]=b;a:{if(!d){m=n>>12;g=p>>12;break a}while(1){m=h[(l<<1)+s>>1];g=i[a+60>>2];b=f;f=Eb(f,-16777216,16776704);q=i[a+64>>2];k=Eb(e,-16777216,16776704);t=i[a+72>>2];u=i[a+32>>2];l=c;v=i[c>>2];r=m<<8;e=r;e=XMa(g,g>>31,e,e>>31);m=_a;g=XMa(q,q>>31,f,f>>31);f=g+e|0;e=_a+m|0;e=f>>>0<g>>>0?e+1|0:e;g=f;f=i[a+68>>2];k=XMa(f,f>>31,k,k>>31);f=g+k|0;e=_a+e|0;e=f>>>0<k>>>0?e+1|0:e;f=f+8388608|0;if(f>>>0<8388608){e=e+1|0}f=(e&16777215)<<8|f>>>24;e=(f|0)/256|0;p=i[a+28>>2]+p|0;g=p>>12;i[l>>2]=o(e,g)+v;n=n+u|0;m=n>>12;i[c+4>>2]=i[c+4>>2]+o(e,m);f=f-(r&t)|0;zb(j+8|0,j);d=d+ -1|0;if(d){c=c+8|0;l=i[j+12>>2];e=b;continue}break}k=i[j+8>>2];l=i[j+12>>2];e=b}i[a+40>>2]=n;i[a+20>>2]=g;i[a+36>>2]=p;i[a+48>>2]=e;i[a+44>>2]=f;i[a+24>>2]=m;i[a>>2]=k;i[a+4>>2]=l;Xa=j+16|0}function N1(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var h=0;h=Xa-32|0;Xa=h;i[h+24>>2]=b;a:{b:{if(!(i[d+4>>2]&1)){i[h>>2]=-1;b=$a[i[i[a>>2]+16>>2]](a,b,c,d,e,h)|0;i[h+24>>2]=b;c:{switch(i[h>>2]){case 1:g[f|0]=1;break a;case 0:break b;default:break c}}g[f|0]=1;i[e>>2]=4;break a}fc(h,d);i[114610]=0;b=F(2449,h|0)|0;a=i[114610];i[114610]=0;d:{e:{f:{g:{if((a|0)!=1){ub(h);fc(h,d);i[114610]=0;a=F(2450,h|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break g}ub(h);i[114610]=0;D(2451,h|0,a|0);d=i[114610];i[114610]=0;if((d|0)==1){b=B()|0;A()|0;break d}i[114610]=0;D(2452,h|12,a|0);a=i[114610];i[114610]=0;if((a|0)==1){break f}i[114610]=0;d=h+24|0;a=ga(2453,h+24|0,c|0,h|0,d|0,b|0,e|0,1)|0;b=i[114610];i[114610]=0;if((b|0)==1){break e}g[f|0]=(a|0)==(h|0);b=i[h+24>>2];while(1){d=nc(d+ -12|0);if((h|0)!=(d|0)){continue}break}break a}b=B()|0;A()|0;ub(h);break d}b=B()|0;A()|0;ub(h);break d}b=B()|0;A()|0;nc(h);break d}b=B()|0;A()|0;while(1){d=nc(d+ -12|0);if((h|0)!=(d|0)){continue}break}}E(b|0);x()}g[f|0]=0}Xa=h+32|0;return b|0}function qq(a,b,c,d,e,f,h,k,l,m,n,o){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;h=h|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;var p=0;p=Xa-16|0;Xa=p;i[p+12>>2]=a;a:{b:{if((a|0)==(f|0)){if(!j[b|0]){break b}a=0;g[b|0]=0;b=i[e>>2];i[e>>2]=b+1;g[b|0]=46;if(!lb(k)){break a}b=i[m>>2];if((b-l|0)>159){break a}c=i[n>>2];i[m>>2]=b+4;i[b>>2]=c;break a}c:{if((a|0)!=(h|0)){break c}if(!lb(k)){break c}if(!j[b|0]){break b}a=0;b=i[m>>2];if((b-l|0)>159){break a}a=i[n>>2];i[m>>2]=b+4;i[b>>2]=a;a=0;i[n>>2]=0;break a}a=-1;f=Ju(o,o+128|0,p+12|0)-o|0;if((f|0)>124){break a}h=j[(f>>2)+62112|0];d:{e:{switch(aNa(f+ -88|0,30)|0){case 2:case 3:b=i[e>>2];if((j[b+ -1|0]&95)!=(j[c|0]&127)?(b|0)!=(d|0):0){break a}i[e>>2]=b+1;g[b|0]=h;a=0;break a;case 0:case 1:g[c|0]=80;break d;default:break e}}a=g[c|0];if((a|0)!=(h&95)){break d}g[c|0]=a|128;if(!j[b|0]){break d}g[b|0]=0;if(!lb(k)){break d}a=i[m>>2];if((a-l|0)>159){break d}b=i[n>>2];i[m>>2]=a+4;i[a>>2]=b}a=i[e>>2];i[e>>2]=a+1;g[a|0]=h;a=0;if((f|0)>84){break a}i[n>>2]=i[n>>2]+1;break a}a=-1}Xa=p+16|0;return a|0}function AJ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=Xa-16|0;Xa=d;a:{b:{switch(i[a+480224>>2]+ -1|0){default:c=i[a+24620>>2];i[d+12>>2]=1;i[d+8>>2]=i[b+44>>2]<<1;c=XMa(c,c>>31,5e4,0);f=_a;b=i[Jc(d+12|0,d+8|0)>>2];c=gc(YMa(c,f,b,b>>31),_a);break a;case 0:c=i[a+24620>>2];i[d+12>>2]=1;i[d+8>>2]=i[b+44>>2];c=XMa(c,c>>31,1e4,0);f=_a;b=i[Jc(d+12|0,d+8|0)>>2];c=gc(YMa(c,f,b,b>>31),_a);break a;case 1:break b}}e=+l[a+24620>>2]*60/(+l[b+44>>2]*1e-4*(+(XMa(i[b+32>>2],0,i[b+40>>2],0)>>>0)+ +(_a>>>0)*4294967296));c:{d:{c=a+484344|0;if(!pg(c,k[b+60>>1])){break d}if(!(Uc(Fb(c,k[b+60>>1])+24|0)^1)){break d}c=Fb(c,k[b+60>>1])+24|0;break c}c=a+480248|0}if(!Uc(c)){e=e*5.960464477539063e-8*+l[vb(c,l[b+48>>2]%(qb(c)>>>0)|0)>>2]}e:{if(q(e)<2147483648){c=~~e;break e}c=-2147483648}e=e- +(c>>>0)+n[b+8>>3];n[b+8>>3]=e;if(!(e<1)){n[b+8>>3]=e+ -1;c=c+1|0;break a}if(n[a+1074384>>3]>-1){break a}n[b+8>>3]=e+1;c=c+ -1|0}b=XMa(i[a+480244>>2],0,c,0)+32768|0;a=_a;a=b>>>0<32768?a+1|0:a;a=Vc((a&65535)<<16|b>>>16,a>>>16|0);Xa=d+16|0;return(a?a:1)|0}function p2(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var h=0;h=Xa-32|0;Xa=h;i[h+24>>2]=b;a:{b:{if(!(i[d+4>>2]&1)){i[h>>2]=-1;b=$a[i[i[a>>2]+16>>2]](a,b,c,d,e,h)|0;i[h+24>>2]=b;c:{switch(i[h>>2]){case 1:g[f|0]=1;break a;case 0:break b;default:break c}}g[f|0]=1;i[e>>2]=4;break a}fc(h,d);i[114610]=0;b=F(21,h|0)|0;a=i[114610];i[114610]=0;d:{e:{f:{g:{if((a|0)!=1){ub(h);fc(h,d);i[114610]=0;a=F(2416,h|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break g}ub(h);i[114610]=0;D(2417,h|0,a|0);d=i[114610];i[114610]=0;if((d|0)==1){b=B()|0;A()|0;break d}i[114610]=0;D(2418,h|12,a|0);a=i[114610];i[114610]=0;if((a|0)==1){break f}i[114610]=0;d=h+24|0;a=ga(2419,h+24|0,c|0,h|0,d|0,b|0,e|0,1)|0;b=i[114610];i[114610]=0;if((b|0)==1){break e}g[f|0]=(a|0)==(h|0);b=i[h+24>>2];while(1){d=eb(d+ -12|0);if((h|0)!=(d|0)){continue}break}break a}b=B()|0;A()|0;ub(h);break d}b=B()|0;A()|0;ub(h);break d}b=B()|0;A()|0;eb(h);break d}b=B()|0;A()|0;while(1){d=eb(d+ -12|0);if((h|0)!=(d|0)){continue}break}}E(b|0);x()}g[f|0]=0}Xa=h+32|0;return b|0}function dwa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,h=0,j=0,k=0,l=0,m=0,n=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;j=Xa-16|0;Xa=j;e=i[a+48>>2];n=i[a+40>>2];p=i[a+36>>2];f=i[a+44>>2];s=i[a+16>>2];l=i[a+4>>2];k=i[a>>2];i[j+8>>2]=k;i[j+12>>2]=l;b=i[a+12>>2];i[j>>2]=i[a+8>>2];i[j+4>>2]=b;a:{if(!d){m=n>>12;h=p>>12;break a}while(1){m=g[l+s|0];h=i[a+60>>2];b=f;f=Eb(f,-16777216,16776704);q=i[a+64>>2];k=Eb(e,-16777216,16776704);t=i[a+72>>2];u=i[a+32>>2];l=c;v=i[c>>2];r=m<<16;e=r;e=XMa(h,h>>31,e,e>>31);m=_a;h=XMa(q,q>>31,f,f>>31);f=h+e|0;e=_a+m|0;e=f>>>0<h>>>0?e+1|0:e;h=f;f=i[a+68>>2];k=XMa(f,f>>31,k,k>>31);f=h+k|0;e=_a+e|0;e=f>>>0<k>>>0?e+1|0:e;f=f+8388608|0;if(f>>>0<8388608){e=e+1|0}f=(e&16777215)<<8|f>>>24;e=(f|0)/256|0;p=i[a+28>>2]+p|0;h=p>>12;i[l>>2]=o(e,h)+v;n=n+u|0;m=n>>12;i[c+4>>2]=i[c+4>>2]+o(e,m);f=f-(r&t)|0;zb(j+8|0,j);d=d+ -1|0;if(d){c=c+8|0;l=i[j+12>>2];e=b;continue}break}k=i[j+8>>2];l=i[j+12>>2];e=b}i[a+40>>2]=n;i[a+20>>2]=h;i[a+36>>2]=p;i[a+48>>2]=e;i[a+44>>2]=f;i[a+24>>2]=m;i[a>>2]=k;i[a+4>>2]=l;Xa=j+16|0}function hH(a){var b=p(0),c=0,d=0,e=0,f=0,h=p(0),k=p(0),l=0,n=p(0);c=Xa-16|0;Xa=c;l=c,n=p(fw(m[a+4216>>2])/p(we(i[a+16>>2])>>>0)),m[l+12>>2]=n;i[c+8>>2]=1056964608;b=p(w(p(p(Yn(p(m[Sk(c+12|0,c+8|0)>>2]*p(6.2831854820251465)))*p(.4000000059604645))+p(.6000000238418579))));m[a+4236>>2]=b;m[a+4240>>2]=w(p(p(1)-p(b*b)));f=a;b=p(p(m[a+4212>>2]*p(29))+p(2));a:{if(b<p(4294967296)&b>=p(0)){d=~~b>>>0;break a}d=0}g[f+4272|0]=d;f=a;e=2;b:{if(d>>>0<4){break b}e=3;if(d>>>0<8){break b}e=d>>>0<16?4:5}g[f+4273|0]=e;h=Wd(p(10),p(p(p(m[a+4208>>2]*p(60))+p(-60))*p(.05000000074505806)));l=c,n=p(fw(m[a+4220>>2])/p(we(i[a+16>>2])>>>0)),m[l+12>>2]=n;i[c+8>>2]=1056964608;k=m[Sk(c+12|0,c+8|0)>>2];l=c,n=p(fw(m[a+4224>>2])/p(we(i[a+16>>2])>>>0)),m[l+12>>2]=n;i[c+8>>2]=1056964608;b=O4(p(m[Sk(c+12|0,c+8|0)>>2]*p(3.1415927410125732)));m[a+4268>>2]=p(p(1)-b)/p(b+p(1));b=Yn(p(k*p(6.2831854820251465)));m[a+4264>>2]=-b;h=p(h*p(w(p(p(1)-p(b*b)))));b=m[a+4268>>2];m[a+4260>>2]=p(h*p(w(p(p(1)-p(b*b)))))*m[(j[a+4272|0]<<2)+33328>>2];Xa=c+16|0}function DD(a,b,c,d){var e=0,f=0,g=0,h=0,j=0,k=0,l=0;h=Xa-32|0;Xa=h;f=d&2147483647;g=f;e=f+ -1065418752|0;f=c;j=f;if(f>>>0<0){e=e+1|0}l=j;k=g+ -1082064896|0;j=f;if(f>>>0<0){k=k+1|0}a:{if((e|0)==(k|0)&l>>>0<j>>>0|e>>>0<k>>>0){g=(d&33554431)<<7|c>>>25;f=0;k=f;j=c&33554431;if(!(!f&(j|0)==16777216?!(a|b):!f&j>>>0<16777216|f>>>0<0)){e=g+1073741825|0;break a}e=g+1073741824|0;if(j^16777216|a|(b|k)){break a}e=(e&1)+e|0;break a}if(!(!f&(g|0)==2147418112?!(a|b):(g|0)==2147418112&f>>>0<0|g>>>0<2147418112)){e=((d&33554431)<<7|c>>>25)&4194303|2143289344;break a}e=2139095040;if(g>>>0>1082064895){break a}e=0;g=g>>>16|0;if(g>>>0<16145){break a}e=d&65535|65536;kf(h+16|0,a,b,c,e,g+ -16129|0);cm(h,a,b,f,e,16257-g|0);b=i[h+8>>2];e=(i[h+12>>2]&33554431)<<7|b>>>25;f=i[h+4>>2];g=f;a=0;j=a;k=i[h>>2]|((i[h+16>>2]|i[h+24>>2])!=0|(i[h+20>>2]|i[h+28>>2])!=0);b=b&33554431;if(!(!a&(b|0)==16777216?!(f|k):!a&b>>>0<16777216|a>>>0<0)){e=e+1|0;break a}if(b^16777216|k|(g|j)){break a}e=(e&1)+e|0}Xa=h+32|0;return eNa(2,d&-2147483648|e),iNa()}function X3(a,b){var c=0,d=0,e=0,f=0,g=0;c=Xa-32|0;Xa=c;i[c+28>>2]=0;a:{b:{if(j[Gi(c+24|0,a,0)|0]){fc(c+16|0,i[i[a>>2]+ -12>>2]+a|0);i[114610]=0;d=F(2316,c+16|0)|0;e=i[114610];i[114610]=0;c:{d:{e:{f:{g:{if((e|0)==1){break g}e=am(c+8|0,a);f=ak(c);g=i[i[a>>2]+ -12>>2];f=i[f>>2];e=i[e>>2];i[114610]=0;Y(2319,d|0,e|0,f|0,a+g|0,c+28|0,c+20|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break g}ub(c+16|0);if(i[c+20>>2]>=-2147483648){break f}i[c+28>>2]=i[c+28>>2]|4;d=-2147483648;break e}b=H(0)|0;A()|0;ub(c+16|0);M(b|0)|0;b=i[c+28>>2]|1;i[c+28>>2]=b;Ei(i[i[a>>2]+ -12>>2]+a|0,b);b=i[i[a>>2]+ -12>>2];i[114610]=0;b=i[(a+b|0)+20>>2];d=i[114610];i[114610]=0;if((d|0)!=1){if(!(b&1)){break d}i[114610]=0;K(81);a=i[114610];i[114610]=0;if((a|0)!=1){break a}}a=B()|0;A()|0;i[114610]=0;K(20);b=i[114610];i[114610]=0;if((b|0)==1){break b}E(a|0);x()}if(i[c+20>>2]>2147483647){i[c+28>>2]=i[c+28>>2]|4;d=2147483647;break e}d=i[c+20>>2]}i[b>>2]=d;break c}O()}ag(i[i[a>>2]+ -12>>2]+a|0,i[c+28>>2])}Xa=c+32|0;return a}a=H(0)|0;A()|0;gb(a)}x()}function OO(a,b,c,d,e){var f=0,i=0;f=Xa-16|0;Xa=f;i=k[c>>1];a:{if(j[d|0]<=4){while(1){d=i<<1;h[c>>1]=d;g[b|0]=(d&65534)>>>0>255;d=j[c|0];h[c>>1]=d;if(!d){if(!pe(a,f+15|0)){break a}d=j[f+15|0];h[c>>1]=d<<1|1;g[b|0]=d>>>7;h[c>>1]=j[c|0]}h[e>>1]=g[b|0]+(k[e>>1]<<1);d=k[c>>1]<<1;h[c>>1]=d;g[b|0]=(d&65534)>>>0>255;d=j[c|0];h[c>>1]=d;if(!d){if(!pe(a,f+14|0)){break a}d=j[f+14|0];h[c>>1]=d<<1|1;g[b|0]=d>>>7;h[c>>1]=j[c|0]}h[e>>1]=g[b|0]+(k[e>>1]<<1);d=k[c>>1]<<1;h[c>>1]=d;g[b|0]=(d&65534)>>>0>255;i=j[c|0];h[c>>1]=i;if(!i){if(!pe(a,f+13|0)){break a}d=j[f+13|0];h[c>>1]=d<<1|1;g[b|0]=d>>>7;i=j[c|0];h[c>>1]=i}if(j[b|0]){continue}break a}}while(1){d=i<<1;h[c>>1]=d;g[b|0]=(d&65534)>>>0>255;d=j[c|0];h[c>>1]=d;if(!d){if(!pe(a,f+12|0)){break a}d=j[f+12|0];h[c>>1]=d<<1|1;g[b|0]=d>>>7;h[c>>1]=j[c|0]}h[e>>1]=g[b|0]+(k[e>>1]<<1);d=k[c>>1]<<1;h[c>>1]=d;g[b|0]=(d&65534)>>>0>255;i=j[c|0];h[c>>1]=i;if(!i){if(!pe(a,f+11|0)){break a}d=j[f+11|0];h[c>>1]=d<<1|1;g[b|0]=d>>>7;i=j[c|0];h[c>>1]=i}if(j[b|0]){continue}break}}Xa=f+16|0}function sq(a,b,c,d,e,f,h,k,l,m,n,o){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;h=h|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;var p=0;p=Xa-16|0;Xa=p;g[p+15|0]=a;a:{b:{if((a|0)==(f|0)){if(!j[b|0]){break b}a=0;g[b|0]=0;b=i[e>>2];i[e>>2]=b+1;g[b|0]=46;if(!lb(k)){break a}b=i[m>>2];if((b-l|0)>159){break a}c=i[n>>2];i[m>>2]=b+4;i[b>>2]=c;break a}c:{if((a|0)!=(h|0)){break c}if(!lb(k)){break c}if(!j[b|0]){break b}a=0;b=i[m>>2];if((b-l|0)>159){break a}a=i[n>>2];i[m>>2]=b+4;i[b>>2]=a;a=0;i[n>>2]=0;break a}a=-1;f=um(o,o+32|0,p+15|0)-o|0;if((f|0)>31){break a}h=j[f+62112|0];d:{e:{switch(f+ -22|0){case 2:case 3:b=i[e>>2];if((j[b+ -1|0]&95)!=(j[c|0]&127)?(b|0)!=(d|0):0){break a}i[e>>2]=b+1;g[b|0]=h;a=0;break a;case 0:case 1:g[c|0]=80;break d;default:break e}}a=g[c|0];if((a|0)!=(h&95)){break d}g[c|0]=a|128;if(!j[b|0]){break d}g[b|0]=0;if(!lb(k)){break d}a=i[m>>2];if((a-l|0)>159){break d}b=i[n>>2];i[m>>2]=a+4;i[a>>2]=b}a=i[e>>2];i[e>>2]=a+1;g[a|0]=h;a=0;if((f|0)>21){break a}i[n>>2]=i[n>>2]+1;break a}a=-1}Xa=p+16|0;return a|0}function pKa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;l=Xa-144|0;Xa=l;p=pp(a);if(p){u=l+8|4;v=l+8|6;w=l+8|5;n=l+8|2;q=l+8|3;while(1){XJa(a,l+8|0);e=j[l+8|0]|j[l+9|0]<<8;a:{if(!e){break a}e=(e<<24|e<<8)>>>16|0;if(e>>>0>k[c+480192>>1]){break a}e=i[((e<<2)+c|0)+900380>>2];if(!e){break a}e=xt(e,b);b:{if(!j[q|0]){break b}if(g[n|0]&1){g[e+12|0]=j[e+12|0]|1}if(j[n|0]&2){g[e+12|0]=j[e+12|0]|4}if(!(j[n|0]&4)){break b}g[e+12|0]=j[e+12|0]|2}g[l+4|0]=j[q|0];g[l+7|0]=31;f=j[Xb(l+4|0,l+7|0)|0]+1|0;o=f&255;Lf(e,o);g[e+13|0]=j[w|0];g[e+14|0]=j[v|0];m=j[u|0];g[e+15|0]=m;g[e+16|0]=m;m=0;if((f|0)!=(o|0)){break a}while(1){r=l+16|0;s=m<<2;f=r+s|0;f=j[f|0]|j[f+1|0]<<8;x=vb(e,m),y=(f<<8&16711680|f<<24)>>>16|0,h[x>>1]=y;f=(s|2)+r|0;f=j[f|0]|j[f+1|0]<<8;f=(f<<24|f<<8&16711680)>>>16|0;h[l+4>>1]=d?f+128>>>2|0:f;Ag(l+4|0,64);f=j[l+4|0];x=vb(e,m),y=f,g[x+2|0]=y;m=m+1|0;if((o|0)!=(m|0)){continue}break}}t=t+1|0;if((t&65535)>>>0<p>>>0){continue}break}}Xa=l+144|0}function Lua(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,p=0,q=0;e=Xa-48|0;Xa=e;k=i[a+16>>2];f=tf(e+16|0);i[f+8>>2]=a+112;i[f+16>>2]=i[a+128>>2];p=f,q=of(b+327720|0,i[b+20>>2],(i[a+88>>2]&16384)>>>14|0),i[p+12>>2]=q;b=i[f+16>>2];if(b){p=f,q=sf(a+8|0,b),i[p>>2]=q;i[f+4>>2]=_a}l=i[a+24>>2];m=i[a+20>>2];b=i[a+4>>2];j=i[a>>2];i[e+8>>2]=j;i[e+12>>2]=b;g=i[a+12>>2];i[e>>2]=i[a+8>>2];i[e+4>>2]=g;if(d){while(1){g=0;i[e+40>>2]=j;i[e+44>>2]=n;j=(b<<1)+k|0;a:{b=i[f+16>>2];if((b|0)<=0){break a}while(1){fd(i[f+8>>2],h[(g<<1)+j>>1]/4<<16>>16);ed(i[f+8>>2],4);zb(e+40|0,f);if((b|0)<2){break a}b=b+ -1|0;g=i[e+44>>2];continue}}d=d+ -1|0;b=i[f+8>>2];zb(b,b+8|0);b=i[f+8>>2];g=i[b+4>>2];if(g){fd(b,h[j+(i[e+44>>2]<<1)>>1]/4<<16>>16);ed(i[f+8>>2],g);b=i[f+8>>2];g=i[b>>2];i[b>>2]=g;i[b+4>>2]=0}b=nf(b,i[f+12>>2]);i[c>>2]=i[c>>2]+o(b,m);i[c+4>>2]=i[c+4>>2]+o(b,l);zb(e+8|0,e);if(d){c=c+8|0;j=i[e+8>>2];b=i[e+12>>2];continue}break}j=i[e+8>>2];b=i[e+12>>2]}i[a>>2]=j;i[a+4>>2]=b;Xa=e+48|0}function qW(a){a=a|0;var b=0,c=0,d=0,e=0;c=Xa+ -64|0;Xa=c;a=Oc(a);i[114610]=0;b=R(228)|0;d=i[114610];i[114610]=0;a:{b:{if((d|0)==1){break b}c:{d:{if(!b){break d}i[114610]=0;d=C(2,c+32|0,10984)|0;b=i[114610];i[114610]=0;if((b|0)==1){break c}i[114610]=0;b=R(228)|0;e=i[114610];i[114610]=0;e:{f:{g:{h:{if((e|0)==1){break h}i[114610]=0;i[c+12>>2]=b;D(234,c+16|0,c+12|0);b=i[114610];i[114610]=0;if((b|0)==1){break h}i[114610]=0;G(3,c+48|0,d|0,c+16|0);b=i[114610];i[114610]=0;if((b|0)==1){break g}mb(a,c+48|0);eb(c+48|0);eb(c+16|0);eb(d);i[114610]=0;b=R(230)|0;d=i[114610];i[114610]=0;if((d|0)==1){break b}if(!b){break e}i[114610]=0;C(235,a|0,10987)|0;b=i[114610];i[114610]=0;if((b|0)!=1){break e}break b}b=B()|0;A()|0;break f}b=B()|0;A()|0;eb(c+16|0)}eb(d);break a}i[114610]=0;b=R(229)|0;d=i[114610];i[114610]=0;if((d|0)==1){break b}if(!b){break d}i[114610]=0;C(235,a|0,10989)|0;b=i[114610];i[114610]=0;if((b|0)==1){break b}}Xa=c- -64|0;return}b=B()|0;A()|0;break a}b=B()|0;A()|0}eb(a);E(b|0);x()}function gG(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=Xa-32|0;Xa=d;a:{b:{c:{d:{e:{f:{g:{if(Mh(a)){bo(d+24|0);break g}lm(d+8|0,a);i[114610]=0;D(2175,d+24|0,d+8|0);c=i[114610];i[114610]=0;if((c|0)==1){break f}We(d+8|0)}c=a+36|0;h:{if(Mh(a)){break h}c=i[d+24>>2]}if((b|0)==-1){e=4194304;break d}if((b|0)>=0){f=b;if((nd(c)|0)>(b|0)){break d}}b=P(8)|0;i[114610]=0;c=C(85,d+8|0,38655)|0;a=i[114610];i[114610]=0;if((a|0)==1){break e}Ub(b,c);i[114610]=0;G(2009,b|0,83568,2017);a=i[114610];i[114610]=0;if((a|0)!=1){break a}a=B()|0;A()|0;eb(c);break c}a=B()|0;A()|0;We(d+8|0);break b}a=B()|0;A()|0;Q(b|0);break c}i[a+8>>2]=b;b=a+24|0;g=i[b>>2];i[g+480208>>2]=i[g+480208>>2]&-4194305|e;b=i[b>>2];e=j[wc(c,f)+16|0];i[114610]=0;D(489,b+484360|0,e|0);b=i[114610];i[114610]=0;i:{if((b|0)==1){break i}b=i[wc(c,f)+12>>2];c=i[wc(c,f)+8>>2];i[114610]=0;+aa(2025,a|0,b|0,c|0);b=i[114610];i[114610]=0;if((b|0)==1){break i}i[a+16>>2]=0;i[a+20>>2]=0;Ej(d+24|0);Xa=d+32|0;return}a=B()|0;A()|0}Ej(d+24|0)}E(a|0)}x()}function xK(a,b,c,d){var e=0,f=0,h=0,k=0,l=0,m=0;e=Xa-16|0;Xa=e;h=o(b,896)+a|0;a:{if(c){kb(e+8|0,a+1074308|0,90);if(!ib(e+8|0)){g[(o(b,896)+a|0)+1075815|0]=c}g[(o(b,896)+a|0)+1075816|0]=c;break a}c=j[h+1075816|0]}f=h+1074984|0;k=c&255;m=0-k|0;l=d?l:!(i[a+480180>>2]&204473357);sK(a,b,m,l);b:{c:{if(i[a+480180>>2]!=16777216){break c}h=i[(o(b,896)+a|0)+1075640>>2];if(!h|!i[h+44>>2]){break c}b=c&255;if(!(b>>>0<240|d)){rK(a,f,240-k|0);break b}if(!(b>>>0<224|d)){pK(f,224-k|0);break b}oK(f,m);break b}if(i[a+480180>>2]==268435456){i[(o(b,896)+a|0)+1075692>>2]=65535}if(!(l^1|(c&255)>>>0<224)){d:{d=k&15;if(!d){break d}c=c&240;if((c|0)!=224){if((c|0)!=240){break d}lK(a,f,d);break b}if(i[a+480180>>2]==524288){break d}uK(a,f,d);break b}if(i[a+480180>>2]!=524288){break b}}e:{if(!(g[(o(b,896)+a|0)+1075856|0]&1)){break e}if(i[a+1074416>>2]==1){kb(e+8|0,a+1074308|0,6);if(ib(e+8|0)){break e}}if(i[a+480180>>2]==64){break e}if(!(i[a+480208>>2]&2)|i[a+480180>>2]!=8){break b}}mK(a,f,k<<2)}Xa=e+16|0}function Fsa(a,b,c){var d=0,e=0,f=0,g=0,l=0,m=0;if(!j[a+40|0]){h[c>>1]=0;h[b>>1]=0;return}f=i[a+16>>2];e=k[f+3840>>1];d=0;a:{if(!(e&3)){break a}d=(k[a+20>>1]>>>7&7)>>>(j[f+3844|0]^1)>>>(e&1)|0;d=(e&4?0-d|0:d)<<16>>16}d=d<<k[a+22>>1];l=b;e=i[a+36>>2];b:{if(e){m=k[e+32>>1];g=k[a+32>>1];e=qf(i[a>>2],i[a+24>>2],d<<16>>16,0,h[a+30>>1]);f=i[a+24>>2];b=i[a+4>>2];if(!m){if(!g){d=d<<16>>16;e=qf(b,f,d,e,0);e=qf(i[a+8>>2],i[a+24>>2],d,e,0);d=qf(i[a+12>>2],i[a+24>>2],d,e,0);break b}d=d<<16>>16;f=qf(b,f,d,0,0);f=qf(i[a+8>>2],i[a+24>>2],d,f,0);d=qf(i[a+12>>2],i[a+24>>2],d,f,0)+e|0;break b}if(!g){d=d<<16>>16;e=qf(b,f,d,e,0);f=qf(i[a+8>>2],i[a+24>>2],d,0,0);d=qf(i[a+12>>2],i[a+24>>2],d,f,0)+e|0;break b}d=d<<16>>16;f=qf(b,f,d,0,0);d=(qf(i[a+8>>2],i[a+24>>2],d,f,0)+e|0)+qf(i[a+12>>2],i[a+24>>2],d,0,0)|0;break b}g=k[a+32>>1];d=d<<16>>16;e=qf(i[a>>2],i[a+24>>2],d,0,h[a+30>>1]);f=i[a+24>>2];b=i[a+4>>2];if(!g){d=qf(b,f,d,e,0);break b}d=qf(b,f,d,0,0)+e|0}h[l>>1]=j[a+41|0]?d:0;h[c>>1]=j[a+42|0]?d:0}function YIa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,k=0,l=0,m=0,n=0,p=0;f=Xa-2608|0;Xa=f;d=f+8|0;Gl(d,a);i[d+1056>>2]=0;i[d+1060>>2]=0;yb(d+1064|0,0,1536);i[114610]=0;L(566,d|0);a=i[114610];i[114610]=0;a:{b:{c:{d:{e:{if((a|0)!=1){if(!c){break d}f:{while(1){i[114610]=0;n=C(260,d|0,1)|0;a=i[114610];i[114610]=0;if((a|0)==1){break f}a=0;g:{while(1){i[114610]=0;e=C(260,d|0,1)|0;p=i[114610];i[114610]=0;if((p|0)==1){break g}a=o(a,6)+d|0;a=h[(e?a+1066|0:a+1064|0)>>1];h:{if((a|0)>255){break h}e=o(a,6)+d|0;k=j[e+1068|0];if(h[e+1064>>1]<0){break h}if(h[e+1066>>1]>-1){continue}}break}k=(n?-1:0)^k;m=(m&255)+(k&255)|0;g[b+l|0]=m;l=l+1|0;if((l|0)!=(c|0)){continue}break d}break}b=H(77024)|0;break e}b=H(77024)|0;break e}b=H(77024)|0}if((A()|0)!=(U(77024)|0)){break a}M(b|0)|0;i[114610]=0;K(20);a=i[114610];i[114610]=0;if((a|0)==1){break c}}i[114610]=0;a=F(567,d|0)|0;b=i[114610];i[114610]=0;if((b|0)==1){break b}hb(d);Xa=f+2608|0;return a|0}b=B()|0;A()|0;break a}b=B()|0;A()|0}hb(d);E(b|0);x()}function GZ(a,b,c){var d=0,e=0,f=0,h=0,i=0,k=0,l=0;d=a;while(1){a:{if(k>>>0>=c>>>0|d>>>0>=b>>>0){break a}h=g[d|0];f=h&255;b:{if((h|0)>=0){h=1;if(f>>>0<=1114111){break b}break a}if(f>>>0<194){break a}if(f>>>0<=223){if((b-d|0)<2){break a}e=j[d+1|0];if((e&192)!=128){break a}h=2;if((e&63|f<<6&1984)>>>0<=1114111){break b}break a}c:{d:{if(f>>>0<=239){if((b-d|0)<3){break a}i=j[d+2|0];e=j[d+1|0];if((f|0)==237){break d}if((f|0)==224){if((e&224)==160){break c}break a}if((e&192)!=128){break a}break c}if((b-d|0)<4|f>>>0>244){break a}i=j[d+3|0];l=j[d+2|0];e=j[d+1|0];e:{f:{switch(f+ -240|0){case 0:if((e+112&255)>>>0<48){break e}break a;case 4:if((e&240)==128){break e}break a;default:break f}}if((e&192)!=128){break a}}if((l&192)!=128|(i&192)!=128){break a}h=4;if((i&63|(l<<6&4032|(f<<18&1835008|(e&63)<<12)))>>>0>1114111){break a}break b}if((e&224)!=128){break a}}if((i&192)!=128){break a}h=3;if((i&63|(f<<12&61440|(e&63)<<6))>>>0>1114111){break a}}k=k+1|0;d=d+h|0;continue}break}return d-a|0}function lxa(a,b){var c=0,d=0,e=0,f=0,g=0;d=Xa-32|0;Xa=d;kd(b,0);bk(d,2,a+32|0);oc(d+16|0,d);i[114610]=0;C(370,b+43|0,d+16|0)|0;c=i[114610];i[114610]=0;if((c|0)!=1){eb(d+16|0);e=a+56|0;c=a+52|0;a:{if((j[e|0]|j[e+1|0]<<8|(j[e+2|0]<<16|j[e+3|0]<<24))>>>0<=(j[c|0]|j[c+1|0]<<8|(j[c+2|0]<<16|j[c+3|0]<<24))>>>0){break a}i[b>>2]=(j[e|0]|j[e+1|0]<<8|(j[e+2|0]<<16|j[e+3|0]<<24))-(j[c|0]|j[c+1|0]<<8|(j[c+2|0]<<16|j[c+3|0]<<24));c=a+44|0;i[b+12>>2]=j[c|0]|j[c+1|0]<<8|(j[c+2|0]<<16|j[c+3|0]<<24);c=a+48|0;i[d+16>>2]=j[c|0]|j[c+1|0]<<8|(j[c+2|0]<<16|j[c+3|0]<<24);f=b,g=i[rb(d+16|0,b)>>2],i[f+16>>2]=g;h[b+30>>1]=j[a+60|0];c=a+62|0;i[b+24>>2]=j[c|0]|j[c+1|0]<<8;c=a- -64|0;if(j[c|0]|j[c+1|0]<<8){gs(b,+((j[c|0]|j[c+1|0]<<8)<<16>>16)*25431315104166665e-22)}a=a+61|0;if(j[a|0]&8){h[b+34>>1]=k[b+34>>1]|8}if(j[a|0]&16){h[b+34>>1]=k[b+34>>1]|16}if(!(j[a|0]&4)){break a}h[b+34>>1]=k[b+34>>1]|1;i[b+12>>2]=i[b+12>>2]>>>1;i[b+16>>2]=i[b+16>>2]>>>1}Xa=d+32|0;return}a=B()|0;A()|0;eb(d+16|0);E(a|0);x()}function yK(a,b,c,d){var e=0,f=0,h=0,k=0,l=0;e=Xa-16|0;Xa=e;k=o(b,896)+a|0;a:{if(c){kb(e+8|0,a+1074308|0,90);if(!ib(e+8|0)){g[(o(b,896)+a|0)+1075816|0]=c}g[(o(b,896)+a|0)+1075815|0]=c;break a}c=j[k+1075815|0]}f=k+1074984|0;h=c&255;l=d?l:!(i[a+480180>>2]&204473357);sK(a,b,h,l);b:{c:{if(i[a+480180>>2]!=16777216){break c}k=i[(o(b,896)+a|0)+1075640>>2];if(!k|!i[k+44>>2]){break c}b=c&255;if(!(b>>>0<240|d)){rK(a,f,h+ -240|0);break b}if(!(b>>>0<224|d)){pK(f,h+ -224|0);break b}oK(f,h);break b}if(i[a+480180>>2]==268435456){i[(o(b,896)+a|0)+1075692>>2]=1}if(!(l^1|(c&255)>>>0<224)){d:{d=h&15;if(!d){break d}c=c&240;if((c|0)!=224){if((c|0)!=240){break d}nK(a,f,d);break b}if(i[a+480180>>2]==524288){break d}tK(a,f,d);break b}if(i[a+480180>>2]!=524288){break b}}e:{if(!(g[(o(b,896)+a|0)+1075856|0]&1)){break e}if(i[a+1074416>>2]==1){kb(e+8|0,a+1074308|0,6);if(ib(e+8|0)){break e}}if(i[a+480180>>2]==64){break e}if(!(i[a+480208>>2]&2)|i[a+480180>>2]!=8){break b}}mK(a,f,0-(h<<2)|0)}Xa=e+16|0}function Sva(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;j=Xa-16|0;Xa=j;g=i[a+48>>2];p=i[a+24>>2];q=i[a+20>>2];b=i[a+44>>2];r=i[a+16>>2];f=i[a+4>>2];k=i[a>>2];i[j+8>>2]=k;i[j+12>>2]=f;e=i[a+12>>2];i[j>>2]=i[a+8>>2];i[j+4>>2]=e;a:{if(!d){e=b;b=g;break a}while(1){e=(f<<1)+r|0;s=h[e+2>>1];e=h[e>>1];f=i[a+60>>2];t=f;u=f>>31;f=Eb(b,-16777216,16776704);l=i[a+64>>2];g=Eb(g,-16777216,16776704);v=i[a+72>>2];w=i[c>>2];f=XMa(l,l>>31,f,f>>31);l=_a;m=f;f=i[a+68>>2];n=XMa(f,f>>31,g,g>>31);f=m+n|0;g=_a+l|0;g=f>>>0<n>>>0?g+1|0:g;m=f;f=e+((o(s-e|0,k>>>18|0)|0)/16384|0)<<8;e=f;k=XMa(t,u,e,e>>31);e=m+k|0;g=_a+g|0;g=e>>>0<k>>>0?g+1|0:g;e=e+8388608|0;if(e>>>0<8388608){g=g+1|0}g=(g&16777215)<<8|e>>>24;e=(g|0)/256|0;i[c>>2]=o(e,q)+w;i[c+4>>2]=i[c+4>>2]+o(e,p);e=g-(f&v)|0;zb(j+8|0,j);d=d+ -1|0;if(d){c=c+8|0;k=i[j+8>>2];f=i[j+12>>2];g=b;b=e;continue}break}k=i[j+8>>2];f=i[j+12>>2]}i[a+48>>2]=b;i[a+44>>2]=e;i[a>>2]=k;i[a+4>>2]=f;Xa=j+16|0}function Tva(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,h=0,j=0,k=0,l=0,m=0,n=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;j=Xa-16|0;Xa=j;h=i[a+48>>2];p=i[a+24>>2];q=i[a+20>>2];b=i[a+44>>2];r=i[a+16>>2];f=i[a+4>>2];k=i[a>>2];i[j+8>>2]=k;i[j+12>>2]=f;e=i[a+12>>2];i[j>>2]=i[a+8>>2];i[j+4>>2]=e;a:{if(!d){e=b;b=h;break a}while(1){e=f+r|0;s=g[e+1|0];e=g[e|0];f=i[a+60>>2];t=f;u=f>>31;f=Eb(b,-16777216,16776704);l=i[a+64>>2];h=Eb(h,-16777216,16776704);v=i[a+72>>2];w=i[c>>2];f=XMa(l,l>>31,f,f>>31);l=_a;m=f;f=i[a+68>>2];n=XMa(f,f>>31,h,h>>31);f=m+n|0;h=_a+l|0;h=f>>>0<n>>>0?h+1|0:h;m=f;f=((o(s-e|0,k>>>18|0)<<8)/16384|0)+(e<<8)<<8;e=f;k=XMa(t,u,e,e>>31);e=m+k|0;h=_a+h|0;h=e>>>0<k>>>0?h+1|0:h;e=e+8388608|0;if(e>>>0<8388608){h=h+1|0}h=(h&16777215)<<8|e>>>24;e=(h|0)/256|0;i[c>>2]=o(e,q)+w;i[c+4>>2]=i[c+4>>2]+o(e,p);e=h-(f&v)|0;zb(j+8|0,j);d=d+ -1|0;if(d){c=c+8|0;k=i[j+8>>2];f=i[j+12>>2];h=b;b=e;continue}break}k=i[j+8>>2];f=i[j+12>>2]}i[a+48>>2]=b;i[a+44>>2]=e;i[a>>2]=k;i[a+4>>2]=f;Xa=j+16|0}function AE(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=Xa-208|0;Xa=d;i[d+8>>2]=1;i[d+12>>2]=0;a:{h=b<<2;if(!h){break a}i[d+16>>2]=4;i[d+20>>2]=4;b=4;g=4;e=2;while(1){f=b;b=(g+4|0)+b|0;i[(d+16|0)+(e<<2)>>2]=b;e=e+1|0;g=f;if(b>>>0<h>>>0){continue}break}f=(a+h|0)+ -4|0;b:{if(f>>>0<=a>>>0){e=1;b=1;break b}e=1;b=1;while(1){c:{if((e&3)==3){pv(a,c,b,d+16|0);Mq(d+8|0,2);b=b+2|0;break c}g=b+ -1|0;d:{if(l[(d+16|0)+(g<<2)>>2]>=f-a>>>0){Lq(a,c,d+8|0,b,0,d+16|0);break d}pv(a,c,b,d+16|0)}if((b|0)==1){Kq(d+8|0,1);b=0;break c}Kq(d+8|0,g);b=1}e=i[d+8>>2]|1;i[d+8>>2]=e;a=a+4|0;if(a>>>0<f>>>0){continue}break}}Lq(a,c,d+8|0,b,0,d+16|0);while(1){e:{f:{g:{if(!((b|0)!=1|(e|0)!=1)){if(i[d+12>>2]){break g}break a}if((b|0)>1){break f}}f=zE(d+8|0);Mq(d+8|0,f);e=i[d+8>>2];b=b+f|0;break e}Kq(d+8|0,2);i[d+8>>2]=i[d+8>>2]^7;Mq(d+8|0,1);g=a+ -4|0;f=b+ -2|0;Lq(g-i[(d+16|0)+(f<<2)>>2]|0,c,d+8|0,b+ -1|0,1,d+16|0);Kq(d+8|0,1);e=i[d+8>>2]|1;i[d+8>>2]=e;Lq(g,c,d+8|0,f,1,d+16|0);b=f}a=a+ -4|0;continue}}Xa=d+208|0}function ij(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,j=0,m=0;d=Xa-80|0;Xa=d;c=i[a+28>>2];jn(i[i[c>>2]+ -12>>2]+c|0,0);if(!dd(a,4)){Bu(a)}a:{if(!i[a+4>>2]){break a}if(dd(a,6)){break a}if(dd(a,7)){break a}h=i[a+28>>2];c=d- -64|0;e=i[a+84>>2];f=o(i[a+20>>2],i[a+4>>2]);g=f+i[a+80>>2]|0;if(g>>>0<f>>>0){e=e+1|0}e=og(c,g,e);f=i[e+12>>2];i[d+24>>2]=i[e+8>>2];i[d+28>>2]=f;c=i[e+4>>2];i[d+16>>2]=i[e>>2];i[d+20>>2]=c;Di(h,d+16|0)}c=0;b:{if(!dd(a,5)){break b}e=a+44|0;f=Wc(e);if(!f){break b}g=a+32|0;while(1){c:{h=(i[a+96>>2]+c>>>0)%(f>>>0)|0;if(l[_b(e,h)>>2]>=rc(g)>>>0){break c}j=Ol(d+48|0,dc(g,i[_b(e,h)>>2]),k[_b(e,h)+12>>1]);m=Eu(b,j);ob(j);if(!m){break c}i[a+96>>2]=(h+1>>>0)%(f>>>0);if(i[_b(e,h)+4>>2]){f=i[a+28>>2];b=d+32|0;c=i[a+12>>2];g=i[a+8>>2];a=i[_b(e,h)+4>>2];g=g+a|0;if(g>>>0<a>>>0){c=c+1|0}a=og(b,g,c);c=i[a+12>>2];i[d+8>>2]=i[a+8>>2];i[d+12>>2]=c;b=i[a+4>>2];i[d>>2]=i[a>>2];i[d+4>>2]=b;Di(f,d)}c=_b(e,h);break b}c=c+1|0;if((f|0)!=(c|0)){continue}break}c=0}Xa=d+80|0;return c}function _Z(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var k=0,l=0,m=0;l=Xa-16|0;Xa=l;k=c;while(1){a:{if((d|0)==(k|0)){k=d;break a}if(!j[k|0]){break a}k=k+1|0;continue}break}i[h>>2]=f;i[e>>2]=c;while(1){b:{c:{d:{if((f|0)==(g|0)|(c|0)==(d|0)){break d}m=i[b+4>>2];i[l+8>>2]=i[b>>2];i[l+12>>2]=m;e:{f:{g:{m=ZZ(f,e,k-c|0,g-f>>2,b,i[a+8>>2]);h:{if((m|0)==-1){while(1){i:{i[h>>2]=f;if(i[e>>2]==(c|0)){break i}g=1;j:{k:{l:{b=qC(f,c,k-c|0,l+8|0,i[a+8>>2]);switch(b+2|0){case 2:break j;case 1:break l;case 0:break f;default:break k}}i[e>>2]=c;break h}g=b}c=c+g|0;f=i[h>>2]+4|0;continue}break}i[e>>2]=c;break d}f=i[h>>2]+(m<<2)|0;i[h>>2]=f;if((f|0)==(g|0)){break e}c=i[e>>2];if((d|0)==(k|0)){k=d;continue}if(!qC(f,c,1,b,i[a+8>>2])){break g}}a=2;break c}i[h>>2]=i[h>>2]+4;c=i[e>>2]+1|0;i[e>>2]=c;k=c;while(1){if((d|0)==(k|0)){k=d;break b}if(!j[k|0]){break b}k=k+1|0;continue}}i[e>>2]=c;a=1;break c}c=i[e>>2]}a=(c|0)!=(d|0)}Xa=l+16|0;return a|0}f=i[h>>2];continue}}function G3(a,b,c){var d=0,e=0,f=0,g=0,h=0,k=0,l=0;d=Xa-32|0;Xa=d;i[114610]=0;g=C(15,d+24|0,a|0)|0;h=i[114610];i[114610]=0;a:{b:{c:{if((h|0)!=1){d:{if(!j[g|0]){break d}fc(d+16|0,i[i[a>>2]+ -12>>2]+a|0);i[114610]=0;h=F(2331,d+16|0)|0;e=i[114610];i[114610]=0;e:{f:{if((e|0)!=1){ub(d+16|0);e=sk(d+8|0,a);f=i[i[a>>2]+ -12>>2];i[114610]=0;f=a+f|0;k=F(16,f|0)|0;l=i[114610];i[114610]=0;if((l|0)==1){break f}e=i[e>>2];i[114610]=0;b=pa(2334,h|0,e|0,f|0,k|0,b|0,c|0)|0;c=i[114610];i[114610]=0;if((c|0)==1){break f}i[d+16>>2]=b;if(!rk(d+16|0)){break d}b=i[i[a>>2]+ -12>>2];i[114610]=0;D(18,a+b|0,5);b=i[114610];i[114610]=0;if((b|0)!=1){break d}b=H(0)|0;A()|0;break e}b=H(0)|0;A()|0;ub(d+16|0);break e}b=H(0)|0;A()|0}jf(g);break c}jf(g);break b}b=H(0)|0;A()|0}M(b|0)|0;b=i[i[a>>2]+ -12>>2];i[114610]=0;L(19,a+b|0);a=i[114610];i[114610]=0;if((a|0)==1){break a}O()}Xa=d+32|0;return}a=B()|0;A()|0;i[114610]=0;K(20);b=i[114610];i[114610]=0;if((b|0)!=1){E(a|0);x()}a=H(0)|0;A()|0;gb(a);x()}function MZ(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;e=a;while(1){a:{if(g>>>0>=c>>>0|e>>>0>=b>>>0){break a}f=j[e|0];if(f>>>0>1114111){break a}d=e+1|0;b:{if(f<<24>>24>=0){break b}if(f>>>0<194){break a}if(f>>>0<=223){if((b-e|0)<2){break a}d=j[e+1|0];if((d&192)!=128|(d&63|f<<6&1984)>>>0>1114111){break a}d=e+2|0;break b}c:{d:{if(f>>>0<=239){if((b-e|0)<3){break a}h=j[e+2|0];d=j[e+1|0];if((f|0)==237){break d}if((f|0)==224){if((d&224)==160){break c}break a}if((d&192)!=128){break a}break c}if(c-g>>>0<2|f>>>0>244|(b-e|0)<4){break a}h=j[e+3|0];i=j[e+2|0];d=j[e+1|0];e:{f:{switch(f+ -240|0){case 0:if((d+112&255)>>>0<48){break e}break a;case 4:if((d&240)==128){break e}break a;default:break f}}if((d&192)!=128){break a}}if((i&192)!=128|(h&192)!=128|(h&63|(i<<6&4032|(f<<18&1835008|(d&63)<<12)))>>>0>1114111){break a}g=g+1|0;d=e+4|0;break b}if((d&224)!=128){break a}}if((h&192)!=128|(h&63|(f<<12&61440|(d&63)<<6))>>>0>1114111){break a}d=e+3|0}e=d;g=g+1|0;continue}break}return e-a|0}function Uka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,l=0;e=Xa-16|0;Xa=e;kd(c,0);d=a+36|0;h[e+14>>1]=j[d|0]|j[d+1|0]<<8;h[e+12>>1]=32767;f=c,l=(k[ef(e+14|0,e+12|0)>>1]<<8>>>0)/32767|0,h[f+28>>1]=l;d=a+38|0;h[e+10>>1]=j[d|0]|j[d+1|0]<<8;h[e+8>>1]=32767;f=c,l=(k[ef(e+10|0,e+8|0)>>1]<<8>>>0)/32767|0,h[f+30>>1]=l;h[c+32>>1]=64;d=a+44|0;i[c>>2]=j[d|0]|j[d+1|0]<<8|(j[d+2|0]<<16|j[d+3|0]<<24);d=a+48|0;i[c+4>>2]=j[d|0]|j[d+1|0]<<8|(j[d+2|0]<<16|j[d+3|0]<<24);d=a+52|0;i[c+8>>2]=j[d|0]|j[d+1|0]<<8|(j[d+2|0]<<16|j[d+3|0]<<24);d=a+56|0;i[c+24>>2]=j[d|0]|j[d+1|0]<<8|(j[d+2|0]<<16|j[d+3|0]<<24);d=b+166|0;if(j[d|0]<=4){g[c+38|0]=j[j[d|0]+31834|0]}g[c+39|0]=j[b+167|0];d=b+171|0;g[c+41|0]=(j[d|0]|j[d+1|0]<<8)>>>4;b=b+169|0;b=(j[b|0]|j[b+1|0]<<8)>>>2|0;g[c+40|0]=b;if(j[c+41|0]|b&255){g[c+39|0]=j[c+39|0]^-1}a=a+40|0;if(j[a|0]&4){h[c+34>>1]=k[c+34>>1]|1}if(j[a|0]&8){h[c+34>>1]=k[c+34>>1]|2}if(j[a|0]&16){h[c+34>>1]=k[c+34>>1]|4}if(j[a|0]&32){h[c+34>>1]=k[c+34>>1]|32}Xa=e+16|0}function cv(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,k=0;c=Xa-32|0;Xa=c;i[114610]=0;g=C(15,c+24|0,a|0)|0;d=i[114610];i[114610]=0;a:{b:{c:{if((d|0)!=1){d:{if(!j[g|0]){break d}fc(c+16|0,i[i[a>>2]+ -12>>2]+a|0);i[114610]=0;d=F(2331,c+16|0)|0;e=i[114610];i[114610]=0;e:{f:{if((e|0)!=1){ub(c+16|0);e=sk(c+8|0,a);f=i[i[a>>2]+ -12>>2];i[114610]=0;f=a+f|0;h=F(16,f|0)|0;k=i[114610];i[114610]=0;if((k|0)==1){break f}e=i[e>>2];i[114610]=0;b=S(2333,d|0,e|0,f|0,h|0,b|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break f}i[c+16>>2]=b;if(!rk(c+16|0)){break d}b=i[i[a>>2]+ -12>>2];i[114610]=0;D(18,a+b|0,5);b=i[114610];i[114610]=0;if((b|0)!=1){break d}b=H(0)|0;A()|0;break e}b=H(0)|0;A()|0;ub(c+16|0);break e}b=H(0)|0;A()|0}jf(g);break c}jf(g);break b}b=H(0)|0;A()|0}M(b|0)|0;b=i[i[a>>2]+ -12>>2];i[114610]=0;L(19,a+b|0);a=i[114610];i[114610]=0;if((a|0)==1){break a}O()}Xa=c+32|0;return}a=B()|0;A()|0;i[114610]=0;K(20);b=i[114610];i[114610]=0;if((b|0)!=1){E(a|0);x()}a=H(0)|0;A()|0;gb(a);x()}function Mua(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,h=0,j=0,k=0,l=0,m=0,n=0,p=0,q=0;e=Xa-48|0;Xa=e;k=i[a+16>>2];f=tf(e+16|0);i[f+8>>2]=a+112;i[f+16>>2]=i[a+128>>2];p=f,q=of(b+327720|0,i[b+20>>2],(i[a+88>>2]&16384)>>>14|0),i[p+12>>2]=q;b=i[f+16>>2];if(b){p=f,q=sf(a+8|0,b),i[p>>2]=q;i[f+4>>2]=_a}l=i[a+24>>2];m=i[a+20>>2];b=i[a+4>>2];j=i[a>>2];i[e+8>>2]=j;i[e+12>>2]=b;h=i[a+12>>2];i[e>>2]=i[a+8>>2];i[e+4>>2]=h;if(d){while(1){h=0;i[e+40>>2]=j;i[e+44>>2]=n;j=b+k|0;a:{b=i[f+16>>2];if((b|0)<=0){break a}while(1){fd(i[f+8>>2],g[j+h|0]<<6);ed(i[f+8>>2],4);zb(e+40|0,f);if((b|0)<2){break a}b=b+ -1|0;h=i[e+44>>2];continue}}d=d+ -1|0;b=i[f+8>>2];zb(b,b+8|0);b=i[f+8>>2];h=i[b+4>>2];if(h){fd(b,g[j+i[e+44>>2]|0]<<6);ed(i[f+8>>2],h);b=i[f+8>>2];h=i[b>>2];i[b>>2]=h;i[b+4>>2]=0}b=nf(b,i[f+12>>2]);i[c>>2]=i[c>>2]+o(b,m);i[c+4>>2]=i[c+4>>2]+o(b,l);zb(e+8|0,e);if(d){c=c+8|0;j=i[e+8>>2];b=i[e+12>>2];continue}break}j=i[e+8>>2];b=i[e+12>>2]}i[a>>2]=j;i[a+4>>2]=b;Xa=e+48|0}function H3(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,k=0;c=Xa-32|0;Xa=c;i[114610]=0;g=C(15,c+24|0,a|0)|0;d=i[114610];i[114610]=0;a:{b:{c:{if((d|0)!=1){d:{if(!j[g|0]){break d}fc(c+16|0,i[i[a>>2]+ -12>>2]+a|0);i[114610]=0;d=F(2331,c+16|0)|0;e=i[114610];i[114610]=0;e:{f:{if((e|0)!=1){ub(c+16|0);e=sk(c+8|0,a);f=i[i[a>>2]+ -12>>2];i[114610]=0;f=a+f|0;h=F(16,f|0)|0;k=i[114610];i[114610]=0;if((k|0)==1){break f}e=i[e>>2];i[114610]=0;b=S(2332,d|0,e|0,f|0,h|0,b|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break f}i[c+16>>2]=b;if(!rk(c+16|0)){break d}b=i[i[a>>2]+ -12>>2];i[114610]=0;D(18,a+b|0,5);b=i[114610];i[114610]=0;if((b|0)!=1){break d}b=H(0)|0;A()|0;break e}b=H(0)|0;A()|0;ub(c+16|0);break e}b=H(0)|0;A()|0}jf(g);break c}jf(g);break b}b=H(0)|0;A()|0}M(b|0)|0;b=i[i[a>>2]+ -12>>2];i[114610]=0;L(19,a+b|0);a=i[114610];i[114610]=0;if((a|0)==1){break a}O()}Xa=c+32|0;return}a=B()|0;A()|0;i[114610]=0;K(20);b=i[114610];i[114610]=0;if((b|0)!=1){E(a|0);x()}a=H(0)|0;A()|0;gb(a);x()}function D3(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,k=0;d=Xa-32|0;Xa=d;i[114610]=0;g=C(15,d+24|0,a|0)|0;c=i[114610];i[114610]=0;a:{b:{c:{if((c|0)!=1){d:{if(!j[g|0]){break d}fc(d+16|0,i[i[a>>2]+ -12>>2]+a|0);i[114610]=0;c=F(2331,d+16|0)|0;e=i[114610];i[114610]=0;e:{f:{if((e|0)!=1){ub(d+16|0);e=sk(d+8|0,a);f=i[i[a>>2]+ -12>>2];i[114610]=0;f=a+f|0;h=F(16,f|0)|0;k=i[114610];i[114610]=0;if((k|0)==1){break f}e=i[e>>2];i[114610]=0;c=Ja(2335,c|0,e|0,f|0,h|0,+b)|0;e=i[114610];i[114610]=0;if((e|0)==1){break f}i[d+16>>2]=c;if(!rk(d+16|0)){break d}c=i[i[a>>2]+ -12>>2];i[114610]=0;D(18,a+c|0,5);c=i[114610];i[114610]=0;if((c|0)!=1){break d}c=H(0)|0;A()|0;break e}c=H(0)|0;A()|0;ub(d+16|0);break e}c=H(0)|0;A()|0}jf(g);break c}jf(g);break b}c=H(0)|0;A()|0}M(c|0)|0;c=i[i[a>>2]+ -12>>2];i[114610]=0;L(19,a+c|0);a=i[114610];i[114610]=0;if((a|0)==1){break a}O()}Xa=d+32|0;return}a=B()|0;A()|0;i[114610]=0;K(20);d=i[114610];i[114610]=0;if((d|0)!=1){E(a|0);x()}a=H(0)|0;A()|0;gb(a);x()}function Bi(a,b,c,d,e,f,g,h){var j=0,k=0,l=0,m=0,n=0;j=Xa-32|0;Xa=j;i[j+16>>2]=c;i[j+24>>2]=b;fc(j+8|0,d);i[114610]=0;k=F(2449,j+8|0)|0;b=i[114610];i[114610]=0;if((b|0)!=1){ub(j+8|0);i[e>>2]=0;c=0;a:{while(1){if((g|0)==(h|0)|c){break a}b:{if(wj(j+24|0,j+16|0)){break b}c:{if((Rl(k,i[g>>2])|0)==37){c=g+4|0;if((h|0)==(c|0)){break b}l=0;b=Rl(k,i[c>>2]);d:{if(!((b|0)==69|(b&255)==48)){c=g;break d}if((g+8|0)==(h|0)){break b}l=b;b=Rl(k,i[g+8>>2])}m=j,n=$a[i[i[a>>2]+36>>2]](a,i[j+24>>2],i[j+16>>2],d,e,f,b,l)|0,i[m+24>>2]=n;g=c+8|0;break c}if(xj(k,8192,i[g>>2])){while(1){e:{g=g+4|0;if((h|0)==(g|0)){g=h;break e}if(xj(k,8192,i[g>>2])){continue}}break}while(1){if(!Dq(j+24|0,j+16|0)){break c}if(!xj(k,8192,Gk(j+24|0))){break c}_l(j+24|0);continue}}if((qk(k,Gk(j+24|0))|0)==(qk(k,i[g>>2])|0)){g=g+4|0;_l(j+24|0);break c}i[e>>2]=4}c=i[e>>2];continue}break}i[e>>2]=4}if(wj(j+24|0,j+16|0)){i[e>>2]=i[e>>2]|2}Xa=j+32|0;return i[j+24>>2]}a=B()|0;A()|0;ub(j+8|0);E(a|0);x()}function sva(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0;f=Xa-16|0;Xa=f;l=i[a+16>>2];a:{b:{c:{j=i[a+8>>2];g=i[a+12>>2];d:{if((g|0)<1?1:(g|0)<=1?j>>>0<=805306368:0){if((g|0)>-2?1:(g|0)>=-2?j>>>0>=3489660928:0){break c}if((g|0)>-2?1:(g|0)>=-2?j>>>0>2147483647:0){break d}break b}if((g|0)>1?1:(g|0)>=1?j>>>0>2147483648:0){break b}}k=b+196648|0;break a}k=b+131112|0;break a}k=b+262184|0}m=i[a+24>>2];n=i[a+20>>2];b=i[a+4>>2];e=i[a>>2];i[f+8>>2]=e;i[f+12>>2]=b;i[f>>2]=j;i[f+4>>2]=g;if(d){while(1){b=(b<<1)+l|0;e=(e>>>16&65520)+k|0;b=(((((((o(h[b+ -4>>1],h[e+2>>1])+o(h[b+ -6>>1],h[e>>1])|0)+o(h[b+ -2>>1],h[e+4>>1])|0)+o(h[b>>1],h[e+6>>1])|0)+o(h[b+2>>1],h[e+8>>1])|0)+o(h[b+4>>1],h[e+10>>1])|0)+o(h[b+6>>1],h[e+12>>1])|0)+o(h[b+8>>1],h[e+14>>1])|0)/32768|0;i[c>>2]=i[c>>2]+o(b,n);i[c+4>>2]=i[c+4>>2]+o(b,m);zb(f+8|0,f);d=d+ -1|0;if(d){c=c+8|0;e=i[f+8>>2];b=i[f+12>>2];continue}break}e=i[f+8>>2];b=i[f+12>>2]}i[a>>2]=e;i[a+4>>2]=b;Xa=f+16|0}function _ua(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;f=Xa-32|0;Xa=f;l=i[a+24>>2];m=i[a+20>>2];n=i[a+16>>2];k=i[a+4>>2];e=k;g=i[a>>2];i[f+24>>2]=g;i[f+28>>2]=e;k=i[a+12>>2];i[f+16>>2]=i[a+8>>2];i[f+20>>2]=k;k=a;if(d){while(1){j=((((e&2147483647)<<1|g>>>31)&2147483646)<<1)+n|0;a=(((g>>>16|0)+4&131064)<<1)+b|0;p=h[a+38>>1];q=h[a+36>>1];r=h[a+34>>1];s=h[a+32>>1];t=h[a+30>>1];u=h[a+28>>1];v=h[a+26>>1];w=h[a+24>>1];g=0;a=1;while(1){e=g<<1;i[(f+8|0)+(g<<2)>>2]=(((((o(h[(e|8)+j>>1],r)+o(h[(e|4)+j>>1],s)|0)+o(h[(e|12)+j>>1],q)|0)+o(h[(e|16)+j>>1],p)|0)/2|0)+((((o(h[(e|-8)+j>>1],v)+o(h[(e|-12)+j>>1],w)|0)+o(h[(e|-4)+j>>1],u)|0)+o(h[e+j>>1],t)|0)/2|0)|0)/16384;e=a;a=0;g=1;if(e){continue}break}i[c>>2]=i[c>>2]+o(i[f+8>>2],m);i[c+4>>2]=i[c+4>>2]+o(i[f+12>>2],l);zb(f+24|0,f+16|0);d=d+ -1|0;if(d){c=c+8|0;g=i[f+24>>2];e=i[f+28>>2];continue}break}g=i[f+24>>2];e=i[f+28>>2]}i[k>>2]=g;i[k+4>>2]=e;Xa=f+32|0}function ay(a,b){a=a|0;b=b|0;a:{b:{switch((j[a+3|0]|64)+ -64|0){case 0:g[a+3|0]=j[a+5|0]?42:0;return;case 1:g[a+3|0]=16;return;case 2:g[a+3|0]=12;return;case 3:g[a+3|0]=14;if(b){break a}b=a;a=j[a+5|0];g[b+5|0]=o(a>>>4|0,10)+(a&15);return;case 4:g[a+3|0]=11;return;case 5:g[a+3|0]=3;return;case 6:g[a+3|0]=2;return;case 7:g[a+3|0]=4;return;case 8:g[a+3|0]=5;return;case 9:g[a+3|0]=18;return;case 10:g[a+3|0]=1;return;case 11:g[a+3|0]=7;return;case 12:g[a+3|0]=6;return;case 13:g[a+3|0]=21;return;case 14:g[a+3|0]=22;return;case 15:g[a+3|0]=10;return;case 16:g[a+3|0]=29;return;case 17:g[a+3|0]=15;return;case 18:g[a+3|0]=8;return;case 19:g[a+3|0]=20;return;case 20:g[a+3|0]=17;return;case 21:g[a+3|0]=26;return;case 22:g[a+3|0]=23;return;case 23:g[a+3|0]=24;return;case 24:g[a+3|0]=9;return;case 25:g[a+3|0]=27;return;case 26:g[a+3|0]=31;return;case 28:g[a+3|0]=b?32:31;return;case 29:g[a+3|0]=33;return;case 27:g[a+3|0]=34;return;default:break b}}g[a+3|0]=0}}function nCa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,l=0,m=0,n=0,p=0,q=0,r=0,s=0,t=0;e=Xa-16|0;Xa=e;g[e+15|0]=8;h[e+12>>1]=0;i[e+8>>2]=0;h[e+6>>1]=0;if(d){q=o(c,d);while(1){if((q|0)>=1){m=(p<<1)+b|0;t=m+(q<<1)|0;while(1){h[e+6>>1]=0;OO(a,e+14|0,e+12|0,e+15|0,e+6|0);a:{b:{l=j[e+15|0];if(!l){break b}c=k[e+12>>1];while(1){f=c<<1;c=f&254;h[e+12>>1]=c;f=(f&65534)>>>0>255;g[e+14|0]=f;if(!c){if(!pe(a,e+5|0)){break b}c=j[e+5|0];f=c>>>7|0;g[e+14|0]=f;c=c<<1&254|1;h[e+12>>1]=c}n=k[e+6>>1]<<1|f;h[e+6>>1]=n;l=l+ -1|0;if(l&255){continue}break}break a}n=k[e+6>>1]}c=1;l=n&65535;c:{if(l>>>0<4){break c}f=15;while(1){c=f;r=c&255;if(r>>>0<2){break c}f=c+ -1|0;if(!(l&1<<r)){continue}break}}g[e+15|0]=(j[e+15|0]+c&254)>>>1;c=n&1;g[e+14|0]=c;c=c+ -1^(n&65534)>>>1;f=c+k[e+8>>1]|0;h[e+6>>1]=f;h[m>>1]=f;c=(c>>1)-s|0;s=h[e+6>>1];i[e+8>>2]=c+(s<<1);Kd(e+8|0,-32768,32767);m=(d<<1)+m|0;if(m>>>0<t>>>0){continue}break}}p=p+1|0;if((p|0)!=(d|0)){continue}break}}Xa=e+16|0}function Ci(a,b,c,d,e,f,h,j){var k=0,l=0,m=0,n=0,o=0;k=Xa-32|0;Xa=k;i[k+16>>2]=c;i[k+24>>2]=b;fc(k+8|0,d);i[114610]=0;l=F(21,k+8|0)|0;b=i[114610];i[114610]=0;if((b|0)!=1){ub(k+8|0);i[e>>2]=0;c=0;a:{while(1){if((h|0)==(j|0)|c){break a}b:{if(Fi(k+24|0,k+16|0)){break b}c:{if((Sl(l,g[h|0])|0)==37){c=h+1|0;if((j|0)==(c|0)){break b}m=0;b=Sl(l,g[c|0]);d:{if(!((b|0)==69|(b&255)==48)){c=h;break d}if((h+2|0)==(j|0)){break b}m=b;b=Sl(l,g[h+2|0])}n=k,o=$a[i[i[a>>2]+36>>2]](a,i[k+24>>2],i[k+16>>2],d,e,f,b,m)|0,i[n+24>>2]=o;h=c+2|0;break c}if(jg(l,8192,g[h|0])){while(1){e:{h=h+1|0;if((j|0)==(h|0)){h=j;break e}if(jg(l,8192,g[h|0])){continue}}break}while(1){if(!Tn(k+24|0,k+16|0)){break c}if(!jg(l,8192,zj(k+24|0))){break c}Jk(k+24|0);continue}}if((Nu(l,zj(k+24|0))|0)==(Nu(l,g[h|0])|0)){h=h+1|0;Jk(k+24|0);break c}i[e>>2]=4}c=i[e>>2];continue}break}i[e>>2]=4}if(Fi(k+24|0,k+16|0)){i[e>>2]=i[e>>2]|2}Xa=k+32|0;return i[k+24>>2]}a=B()|0;A()|0;ub(k+8|0);E(a|0);x()}function tva(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,j=0,k=0,l=0,m=0,n=0,p=0;f=Xa-16|0;Xa=f;m=i[a+16>>2];a:{b:{c:{k=i[a+8>>2];j=i[a+12>>2];d:{if((j|0)<1?1:(j|0)<=1?k>>>0<=805306368:0){if((j|0)>-2?1:(j|0)>=-2?k>>>0>=3489660928:0){break c}if((j|0)>-2?1:(j|0)>=-2?k>>>0>2147483647:0){break d}break b}if((j|0)>1?1:(j|0)>=1?k>>>0>2147483648:0){break b}}l=b+196648|0;break a}l=b+131112|0;break a}l=b+262184|0}n=i[a+24>>2];p=i[a+20>>2];b=i[a+4>>2];e=i[a>>2];i[f+8>>2]=e;i[f+12>>2]=b;i[f>>2]=k;i[f+4>>2]=j;if(d){while(1){b=b+m|0;e=(e>>>16&65520)+l|0;b=(((((((o(g[b+ -2|0],h[e+2>>1])+o(g[b+ -3|0],h[e>>1])|0)+o(g[b+ -1|0],h[e+4>>1])|0)+o(g[b|0],h[e+6>>1])|0)+o(g[b+1|0],h[e+8>>1])|0)+o(g[b+2|0],h[e+10>>1])|0)+o(g[b+3|0],h[e+12>>1])|0)+o(g[b+4|0],h[e+14>>1])<<8)/32768|0;i[c>>2]=i[c>>2]+o(b,p);i[c+4>>2]=i[c+4>>2]+o(b,n);zb(f+8|0,f);d=d+ -1|0;if(d){c=c+8|0;e=i[f+8>>2];b=i[f+12>>2];continue}break}e=i[f+8>>2];b=i[f+12>>2]}i[a>>2]=e;i[a+4>>2]=b;Xa=f+16|0}function Xi(a){a=a|0;var b=0;a:{b:{switch(j[a+3|0]){case 0:if(!j[a+5|0]){break a}g[a+3|0]=1;return;case 1:g[a+3|0]=2;return;case 2:g[a+3|0]=3;return;case 3:g[a+3|0]=4;return;case 4:g[a+3|0]=5;return;case 5:g[a+3|0]=6;return;case 6:g[a+3|0]=7;return;case 7:g[a+3|0]=8;return;case 8:g[a+3|0]=9;return;case 9:g[a+3|0]=10;return;case 10:g[a+3|0]=11;return;case 11:g[a+3|0]=12;return;case 12:g[a+3|0]=13;return;case 13:g[a+3|0]=14;b=a;a=j[a+5|0];g[b+5|0]=o(a>>>4|0,10)+(a&15);return;case 14:g[a+3|0]=19;return;case 15:if(j[a+5|0]<=31){g[a+3|0]=16;return}g[a+3|0]=17;return;case 16:g[a+3|0]=23;return;case 17:g[a+3|0]=24;return;case 20:g[a+3|0]=25;return;case 21:g[a+3|0]=30;return;case 25:g[a+3|0]=29;return;case 27:g[a+3|0]=15;return;case 29:g[a+3|0]=18;return;case 32:g[a+3|0]=42;return;case 33:g[a+3|0]=28;return;case 34:g[a+3|0]=27;return;case 35:g[a+3|0]=31;return;case 36:g[a+3|0]=32;return;case 38:g[a+3|0]=34;return;default:break b}}g[a+3|0]=0}}function pU(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=Xa-80|0;Xa=d;pc(b);Yp(a);a:{if(!Qt(b,d+40|0)){break a}if(!GA(d+40|0)){break a}b:{if(!c){break b}c=d+40|4;e=j[c|0]|j[c+1|0]<<8|(j[c+2|0]<<16|j[c+3|0]<<24);if(!wb(b,(e<<24|e<<8&16711680|(e>>>8&65280|e>>>24))+ -28|0)){break a}ju(a);iu(d+24|0);hu(wg(a)+28|0,d+24|0);Xp(d+24|0);e=i[wg(a)+28>>2];i[114610]=0;f=F(350,b|0)|0;b=i[114610];i[114610]=0;c:{if((b|0)==1){break c}c=j[c|0]|j[c+1|0]<<8|(j[c+2|0]<<16|j[c+3|0]<<24);b=j[d+52|0]|j[d+53|0]<<8|(j[d+54|0]<<16|j[d+55|0]<<24);i[114610]=0;c=N(351,f|0,(c<<8&16711680|c<<24|(c>>>8&65280|c>>>24))+ -28|0,e|0,b<<8&16711680|b<<24|(b>>>8&65280|b>>>24))|0;b=i[114610];i[114610]=0;if((b|0)==1){break c}f=0;if(!c){break a}ui(d+8|0,e);eu(d+16|0,d+8|0);b=Dn(d+24|0,d+16|0);Cd(wg(a)+12|0,b);hb(b);break b}b=oa(71348,77368)|0;a=A()|0;d:{if((U(71348)|0)==(a|0)){break d}if((U(77368)|0)==(a|0)){break d}E(b|0);x()}M(b|0)|0;O();f=0;break a}f=1}Xa=d+80|0;return f|0}function Pm(a,b,c){var d=0,e=0;e=Xa-16|0;Xa=e;g[a+861|0]=0;i[a+708>>2]=0;i[a+656>>2]=0;i[a+104>>2]=0;g[a+819|0]=0;i[a+804>>2]=0;i[a+824>>2]=0;i[a+696>>2]=0;i[a+668>>2]=0;i[a+88>>2]=i[a+88>>2]|6144;kb(e+8|0,b+1074308|0,23);if(ib(e+8|0)){h[a+798>>1]=65536;h[a+800>>1]=1}g[a+866|0]=0;g[a+859|0]=0;g[a+871|0]=255;i[a+660>>2]=0;g[a+872|0]=j[a+872|0]&252;vs(a+810|0);i[a+84>>2]=0;i[a+76>>2]=0;i[a+80>>2]=0;i[a+700>>2]=0;i[a+656>>2]=0;i[a+104>>2]=0;i[a+92>>2]=0;i[a+96>>2]=0;i[a>>2]=0;i[a+4>>2]=0;g[a+865|0]=0;g[a+858|0]=0;i[a+688>>2]=0;i[a+672>>2]=0;i[a+676>>2]=0;h[a+840>>1]=0;g[a+839|0]=0;h[a+856>>1]=32512;h[a+862>>1]=0;i[a+20>>2]=0;i[a+24>>2]=0;i[a+8>>2]=0;i[a+12>>2]=0;i[a+28>>2]=0;i[a+32>>2]=0;i[a+876>>2]=0;i[a+880>>2]=0;g[a+872|0]=j[a+872|0]&243;a:{if(c>>>0>126){c=64;b=128;d=0;break a}d=(c<<5)+b|0;c=k[d+480286>>1];b=k[d+480284>>1];d=i[d+480280>>2]}h[a+796>>1]=0;i[a+760>>2]=c;i[a+692>>2]=b;i[a+88>>2]=d;g[a+817|0]=0;g[a+818|0]=0;Xa=e+16|0}function ZE(a){var b=0,c=0,d=0,e=0,f=0,h=0,k=0,m=0;b=i[a+32>>2];a:{b:{c:{c=i[a+1380>>2];d:{if((c|0)==-1){k=1;c=-1;break d}d=i[a+1116>>2];e:{if((c|0)>=(d|0)){break e}while(1){e=j[(a+c|0)+1120|0];b=e+b|0;if((e|0)!=255){break e}c=c+1|0;if((c|0)<(d|0)){continue}break}}if(b>>>0>l[a+40>>2]){break c}c=(c|0)==(d|0)?-1:c}while(1){if((c|0)!=-1){return 1}h=i[a+40>>2];if(b+26>>>0>=h>>>0){Lb(a,1);break a}if((j[b|0]|j[b+1|0]<<8|(j[b+2|0]<<16|j[b+3|0]<<24))!=(j[84608]|j[84609]<<8|(j[84610]<<16|j[84611]<<24))){Lb(a,21);break a}if(j[b+4|0]){Lb(a,21);break a}f:{if(k){if(!i[a+992>>2]|!(g[b+5|0]&1)){break f}Lb(a,21);break a}if(g[b+5|0]&1){break f}Lb(a,21);break a}d=b+27|0;e=j[b+26|0];b=d+e|0;if(b>>>0>h>>>0){break b}k=0;c=0;f=0;g:{if(!e){break g}while(1){m=j[c+d|0];b=m+b|0;f=c;if((m|0)!=255){break g}c=c+1|0;if((e|0)!=(c|0)){continue}break}f=e}d=f;c=(d|0)==(e|0)?-1:d;if(b>>>0<=h>>>0){continue}break}Lb(a,1);break a}Lb(a,1);break a}Lb(a,1)}return 0}function kL(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,m=0,n=0,o=0,p=0;e=Xa-96|0;Xa=e;g[e+95|0]=d;d=0;n=Fo(a);o=Ti(n);h[b>>1]=0;a:{if(o){while(1){p=k[$b(n,d&65535)>>1];b:{if(!pg(i[a+24>>2]+484344|0,p)){break b}d=k[b>>1];if(cc(a)>>>0<=d>>>0){i[c>>2]=0;a=1;break a}f=Yc(a,k[b>>1]);Wi(e+72|0,f);Uj(e- -64|0,f);d=i[e+76>>2];i[e+32>>2]=i[e+72>>2];i[e+36>>2]=d;d=i[e+68>>2];i[e+24>>2]=i[e+64>>2];i[e+28>>2]=d;wra(e+80|0,e+32|0,e+24|0,e+95|0);d=c;c:{if(j[e+95|0]){Uj(e+56|0,f);m=0;if(jL(e+80|0,e+56|0)){break c}if(j[e+95|0]){break b}}Uj(e+56|0,f);if(jL(e+80|0,e+56|0)^1){Wi(e+48|0,f);a=i[e+84>>2];b=i[e+80>>2];i[e+40>>2]=b;i[e+44>>2]=a;c=i[e+52>>2];i[e+16>>2]=i[e+48>>2];i[e+20>>2]=c;i[e+8>>2]=b;i[e+12>>2]=a;m=uN(e+16|0,e+8|0);break c}if(l[f+4>>2]>=l[Fb(i[a+24>>2]+484344|0,p)+12>>2]){break b}m=i[f+4>>2]}i[d>>2]=m;a=1;break a}d=k[b>>1]+1|0;h[b>>1]=d;if((d&65535)>>>0<o>>>0){continue}break}}h[b>>1]=65535;i[c>>2]=-1;a=0}Xa=e+96|0;return a|0}function Di(a,b){var c=0,d=0,e=0,f=0;c=Xa+ -64|0;Xa=c;d=i[(i[i[a>>2]+ -12>>2]+a|0)+16>>2]&-3;jn(i[i[a>>2]+ -12>>2]+a|0,d);a:{b:{if(j[Gi(c+56|0,a,1)|0]){e=i[i[a>>2]+ -12>>2];i[114610]=0;e=i[(a+e|0)+24>>2];f=i[114610];i[114610]=0;c:{d:{if((f|0)==1){break d}i[114610]=0;f=i[b+12>>2];i[c+16>>2]=i[b+8>>2];i[c+20>>2]=f;f=i[b+4>>2];i[c+8>>2]=i[b>>2];i[c+12>>2]=f;J(2326,c+40|0,e|0,c+8|0,8);b=i[114610];i[114610]=0;if((b|0)==1){break d}b=og(c+24|0,-1,-1);i[114610]=0;b=WR(c+40|0,b);e=i[114610];i[114610]=0;if((e|0)==1){break d}b=b?d|4:d;break c}b=H(0)|0;A()|0;M(b|0)|0;b=d|1;Ei(i[i[a>>2]+ -12>>2]+a|0,b);d=i[i[a>>2]+ -12>>2];i[114610]=0;d=i[(a+d|0)+20>>2];e=i[114610];i[114610]=0;e:{if((e|0)!=1){if(!(d&1)){break e}i[114610]=0;K(81);a=i[114610];i[114610]=0;if((a|0)!=1){break a}}a=B()|0;A()|0;i[114610]=0;K(20);b=i[114610];i[114610]=0;if((b|0)==1){break b}E(a|0);x()}O()}ag(i[i[a>>2]+ -12>>2]+a|0,b)}Xa=c- -64|0;return}a=H(0)|0;A()|0;gb(a)}x()}function qia(a,b,c,d){var e=0,f=0,g=0,j=0,k=0;e=Xa-48|0;Xa=e;i[e+44>>2]=0;di(b,e+44|0);a:{b:{if(i[e+44>>2]!=(mk(32529)|0)){break b}i[e+40>>2]=0;di(b,e+40|0);k=-1;f=i[e+40>>2];if(f+ -1>>>0>1){break b}c:{d:{e:{if((f|0)<=1){f=Ab(e+24|0);i[114610]=0;g=I(724,b|0,f|0,256)|0;j=i[114610];i[114610]=0;if((j|0)==1){break a}if(!g){break d}i[114610]=0;G(13,e+8|0,d|0,f|0);g=i[114610];i[114610]=0;if((g|0)!=1){break e}break a}f=Ab(e+24|0);i[114610]=0;g=I(726,b|0,f|0,255)|0;j=i[114610];i[114610]=0;if((j|0)==1){break a}if(!g){break c}i[114610]=0;G(13,e+8|0,d|0,f|0);g=i[114610];i[114610]=0;if((g|0)==1){break a}}mb(c,e+8|0);eb(e+8|0);eb(f);c=0;h[e+8>>1]=0;af(b,e+8|0);i[e+24>>2]=0;di(b,e+24|0);f=i[e+24>>2];if(f>>>0>50){break b}if(f){while(1){if(!ZH(a,b,d)){break b}c=c+1|0;if(c>>>0<l[e+24>>2]){continue}break}}i[e+24>>2]=0;di(b,e+24|0);k=i[e+24>>2]==(mk(32534)|0)?1:-1;break b}eb(f);break b}eb(f)}Xa=e+48|0;return k}a=B()|0;A()|0;eb(f);E(a|0);x()}function $ua(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,j=0,k=0,l=0,m=0,n=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;f=Xa-32|0;Xa=f;m=i[a+24>>2];n=i[a+20>>2];p=i[a+16>>2];k=i[a+4>>2];l=k;e=i[a>>2];i[f+24>>2]=e;i[f+28>>2]=k;k=i[a+12>>2];i[f+16>>2]=i[a+8>>2];i[f+20>>2]=k;k=a;if(d){while(1){j=(((l&2147483647)<<1|e>>>31)&-2)+p|0;a=(((e>>>16|0)+4&131064)<<1)+b|0;q=h[a+38>>1];r=h[a+36>>1];s=h[a+34>>1];t=h[a+32>>1];u=h[a+30>>1];v=h[a+28>>1];w=h[a+26>>1];x=h[a+24>>1];e=0;a=1;while(1){i[(f+8|0)+(e<<2)>>2]=(((((o(g[(e|4)+j|0],s)+o(g[(e|2)+j|0],t)|0)+o(g[(e|6)+j|0],r)|0)+o(g[(e|8)+j|0],q)<<8)/2|0)+((((o(g[(e|-4)+j|0],w)+o(g[(e|-6)+j|0],x)|0)+o(g[(e|-2)+j|0],v)|0)+o(g[e+j|0],u)<<8)/2|0)|0)/16384;l=a;a=0;e=1;if(l){continue}break}i[c>>2]=i[c>>2]+o(i[f+8>>2],n);i[c+4>>2]=i[c+4>>2]+o(i[f+12>>2],m);zb(f+24|0,f+16|0);d=d+ -1|0;if(d){c=c+8|0;e=i[f+24>>2];l=i[f+28>>2];continue}break}e=i[f+24>>2];l=i[f+28>>2]}i[k>>2]=e;i[k+4>>2]=l;Xa=f+32|0}function Sea(a){var b=p(0),c=p(0),d=p(0),e=0,f=p(0),h=p(0),j=p(0),k=p(0),l=p(0),n=p(0),o=p(0),q=0,r=p(0);e=Xa-16|0;Xa=e;c=mg(a,5);f=mg(a,11);d=p(c*mg(a,4));k=p(p(d*p(.03999999910593033))+p(c*p(.02250000089406967)));c=p(f*mg(a,10));f=p(p(c*p(.03999999910593033))+p(f*p(.02250000089406967)));if(g[a+4264|0]&1){b=mg(a,3);h=mg(a,9);b=p(b*d);d=p(mg(a,2)*b);k=p(p(p(b*p(.12250000238418579))+k)+p(d*p(.1444000005722046)));b=p(h*c);c=p(mg(a,8)*b);f=p(p(p(b*p(.12250000238418579))+f)+p(c*p(.1444000005722046)))}mg(a,12);b=m[a+4496>>2];h=mg(a,1);j=mg(a,7);n=mg(a,0);o=mg(a,6);q=e,r=Wd(p(10),p(p(aH(a)+p(p(m[a+4236>>2]*p(12e3))+p(-1e4)))*p(.0005000000237487257))),m[q+12>>2]=r;i[e+8>>2]=1065353216;l=m[Sk(e+12|0,e+8|0)>>2];b=p(b*b);c=p(j*p(b*c));j=p(o*c);d=p(h*p(b*d));b=p(n*d);h=p(p(p(j+b)*p(-.5))+p(1));m[a+4284>>2]=l*p(w(p(h/p(p(p(b+c)*p(.1444000005722046))+k))));m[a+4288>>2]=l*p(w(p(h/p(p(p(j+d)*p(.1444000005722046))+f))));Xa=e+16|0}function Sha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=p(0),h=0,j=0,k=0,l=0,n=0,o=0,r=p(0),s=p(0),t=p(0),u=p(0),v=p(0),w=p(0),x=p(0),y=p(0),z=0,A=0,B=p(0);if(i[a+4220>>2]){f=a+44|0;j=ud(f,0);k=ud(f,1);l=Pc(f,0);n=Pc(f,1);if(d){h=a+4208|0;e=i[a+4224>>2];o=d;while(1){r=m[k>>2];s=m[j>>2];z=h;e=e-i[a+4228>>2]|0;if((e|0)<=-1){e=e+i[a+4220>>2]|0}e=e<<1;t=m[vb(z,e)>>2];e=vb(h,e|1);v=m[a+4248>>2];w=m[a+4256>>2];x=m[a+4252>>2];y=m[a+4244>>2];u=m[e>>2];g=p(p(p(p(r*v)+p(s*w))+p(t*x))+p(y*u));A=vb(h,i[a+4224>>2]<<1),B=p(q(g))<p(1.0000000195414814e-24)?p(0):g,m[A>>2]=B;g=p(p(p(p(v*s)+p(w*r))+p(x*u))+p(y*t));A=vb(h,i[a+4224>>2]<<1|1),B=p(q(g))<p(1.0000000195414814e-24)?p(0):g,m[A>>2]=B;e=i[a+4224>>2]+1|0;e=(e|0)==i[a+4220>>2]?0:e;i[a+4224>>2]=e;m[l>>2]=p(t*m[a+4236>>2])+p(s*m[a+4240>>2]);m[n>>2]=p(u*m[a+4236>>2])+p(r*m[a+4240>>2]);n=n+4|0;l=l+4|0;k=k+4|0;j=j+4|0;o=o+ -1|0;if(o){continue}break}}Oh(a,b,c,Pc(f,0),Pc(f,1),d)}}function mCa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,l=0,m=0,n=0,p=0,q=0,r=0,s=0,t=0,u=0;e=Xa-16|0;Xa=e;g[e+15|0]=4;h[e+12>>1]=0;i[e+8>>2]=0;g[e+7|0]=0;if(d){q=o(c,d);t=(q|0)<1;while(1){if(!t){m=b+p|0;u=q+m|0;while(1){g[e+7|0]=0;NO(a,e+14|0,e+12|0,e+7|0);a:{b:{l=j[e+15|0];if(!l){break b}c=k[e+12>>1];while(1){f=c<<1;c=f&254;h[e+12>>1]=c;f=(f&65534)>>>0>255;g[e+14|0]=f;if(!c){if(!pe(a,e+6|0)){break b}c=j[e+6|0];f=c>>>7|0;g[e+14|0]=f;c=c<<1&254|1;h[e+12>>1]=c}n=j[e+7|0]<<1|f;g[e+7|0]=n;l=l+ -1|0;if(l&255){continue}break}break a}n=j[e+7|0]}c=1;l=n&255;c:{if(l>>>0<4){break c}f=7;while(1){c=f;r=c&255;if(r>>>0<2){break c}f=c+ -1|0;if(!(l&1<<r)){continue}break}}g[e+15|0]=(j[e+15|0]+c&254)>>>1;c=n&1;g[e+14|0]=c;c=c+ -1^(n&254)>>>1;f=c+j[e+8|0]|0;g[e+7|0]=f;g[m|0]=f;c=(c>>1)-s|0;s=g[e+7|0];i[e+8>>2]=c+(s<<1);Kd(e+8|0,-128,127);m=d+m|0;if(m>>>0<u>>>0){continue}break}}p=p+1|0;if((p|0)!=(d|0)){continue}break}}Xa=e+16|0}function yca(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;b=Xa-48|0;Xa=b;i[114610]=0;L(2015,a|0);c=i[114610];i[114610]=0;a:{b:{c:{d:{e:{f:{g:{h:{if((c|0)!=1){d=Ab(b+32|0);c=i[a+24>>2];i[114610]=0;D(2075,b+16|0,c|0);c=i[114610];i[114610]=0;if((c|0)==1){break h}e=b,f=Jb(b+16|0),i[e+8>>2]=f;e=b,f=Kb(b+16|0),i[e>>2]=f;if(!pb(b+8|0,b)){break f}break g}c=H(0)|0;A()|0;break c}c=H(0)|0;A()|0;break d}while(1){c=i[b+8>>2];i[114610]=0;C(1251,d|0,c|0)|0;c=i[114610];i[114610]=0;if((c|0)==1){break e}_m(b+8|0);e=b,f=Kb(b+16|0),i[e>>2]=f;if(!pb(b+8|0,b)){break f}i[114610]=0;C(1995,d|0,34153)|0;c=i[114610];i[114610]=0;if((c|0)!=1){continue}break}break e}c=Ed(xb(d));Sc(b+16|0);eb(d);break b}c=H(0)|0;A()|0;Sc(b+16|0)}eb(d)}M(c|0)|0;c=0;i[114610]=0;J(1989,36857,a|0,0,0);a=i[114610];i[114610]=0;if((a|0)==1){break a}O()}Xa=b+48|0;return c|0}a=B()|0;A()|0;i[114610]=0;K(20);b=i[114610];i[114610]=0;if((b|0)!=1){E(a|0);x()}a=H(0)|0;A()|0;gb(a);x()}function fda(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;b=Xa-48|0;Xa=b;i[114610]=0;L(2015,a|0);c=i[114610];i[114610]=0;a:{b:{c:{d:{e:{f:{g:{h:{if((c|0)!=1){d=Ab(b+32|0);c=i[a+24>>2];i[114610]=0;D(2040,b+16|0,c|0);c=i[114610];i[114610]=0;if((c|0)==1){break h}e=b,f=Jb(b+16|0),i[e+8>>2]=f;e=b,f=Kb(b+16|0),i[e>>2]=f;if(!pb(b+8|0,b)){break f}break g}c=H(0)|0;A()|0;break c}c=H(0)|0;A()|0;break d}while(1){c=i[b+8>>2];i[114610]=0;C(1251,d|0,c|0)|0;c=i[114610];i[114610]=0;if((c|0)==1){break e}_m(b+8|0);e=b,f=Kb(b+16|0),i[e>>2]=f;if(!pb(b+8|0,b)){break f}i[114610]=0;C(1995,d|0,34153)|0;c=i[114610];i[114610]=0;if((c|0)!=1){continue}break}break e}c=Ed(xb(d));Sc(b+16|0);eb(d);break b}c=H(0)|0;A()|0;Sc(b+16|0)}eb(d)}M(c|0)|0;c=0;i[114610]=0;J(1989,35614,a|0,0,0);a=i[114610];i[114610]=0;if((a|0)==1){break a}O()}Xa=b+48|0;return c|0}a=B()|0;A()|0;i[114610]=0;K(20);b=i[114610];i[114610]=0;if((b|0)!=1){E(a|0);x()}a=H(0)|0;A()|0;gb(a);x()}function gwa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,p=0,q=0,r=0,s=0,t=0,u=0;j=Xa-16|0;Xa=j;f=i[a+48>>2];q=i[a+24>>2];r=i[a+20>>2];b=i[a+44>>2];s=i[a+16>>2];k=i[a+4>>2];l=i[a>>2];i[j+8>>2]=l;i[j+12>>2]=k;e=i[a+12>>2];i[j>>2]=i[a+8>>2];i[j+4>>2]=e;a:{if(!d){e=b;b=f;break a}while(1){l=h[(k<<1)+s>>1];g=i[a+60>>2];m=g;e=Eb(b,-16777216,16776704);p=i[a+64>>2];k=Eb(f,-16777216,16776704);t=i[a+72>>2];f=i[c>>2];n=g>>31;l=l<<8;g=l;g=XMa(m,n,g,g>>31);m=_a;n=c;u=f;f=g;g=XMa(p,p>>31,e,e>>31);e=f+g|0;f=_a+m|0;f=e>>>0<g>>>0?f+1|0:f;g=e;e=i[a+68>>2];k=XMa(e,e>>31,k,k>>31);e=g+k|0;f=_a+f|0;f=e>>>0<k>>>0?f+1|0:f;e=e+8388608|0;if(e>>>0<8388608){f=f+1|0}f=(f&16777215)<<8|e>>>24;e=(f|0)/256|0;i[n>>2]=u+o(e,r);i[c+4>>2]=i[c+4>>2]+o(e,q);e=f-(l&t)|0;zb(j+8|0,j);d=d+ -1|0;if(d){c=c+8|0;k=i[j+12>>2];f=b;b=e;continue}break}l=i[j+8>>2];k=i[j+12>>2]}i[a+48>>2]=b;i[a+44>>2]=e;i[a>>2]=l;i[a+4>>2]=k;Xa=j+16|0}function Cla(a,b,c){var d=0,e=0,f=0,g=0,h=0;f=Xa-16|0;Xa=f;g=Mg(a);a=c+16|0;a=j[a|0]|j[a+1|0]<<8|(j[a+2|0]<<16|j[a+3|0]<<24);i[114610]=0;a=C(256,b|0,a|0)|0;d=i[114610];i[114610]=0;a:{b:{c:{if((d|0)==1){break c}d:{e:{f:{if(!a){break f}a=c+12|0;d=j[a|0]|j[a+1|0]<<8|(j[a+2|0]<<16|j[a+3|0]<<24);i[114610]=0;D(1532,g|0,d|0);d=i[114610];i[114610]=0;if((d|0)==1){break c}if(!(j[a|0]|j[a+1|0]<<8|(j[a+2|0]<<16|j[a+3|0]<<24))){break f}d=c+4|0;c=0;while(1){i[114610]=0;e=C(258,b|0,4)|0;h=i[114610];i[114610]=0;if((h|0)==1){break b}if(!e){break f}e=j[d|0]|j[d+1|0]<<8;i[114610]=0;G(1533,f|0,b|0,e|0);e=i[114610];i[114610]=0;if((e|0)==1){break e}i[114610]=0;D(1534,g|0,f|0);e=i[114610];i[114610]=0;if((e|0)==1){break d}eb(f);c=c+1|0;if(c>>>0<(j[a|0]|j[a+1|0]<<8|(j[a+2|0]<<16|j[a+3|0]<<24))>>>0){continue}break}}Xa=f+16|0;return}a=B()|0;A()|0;break a}a=B()|0;A()|0;eb(f);break a}a=B()|0;A()|0;break a}a=B()|0;A()|0}Sc(g);E(a|0);x()}function hwa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,h=0,j=0,k=0,l=0,m=0,n=0,p=0,q=0,r=0,s=0,t=0,u=0;j=Xa-16|0;Xa=j;f=i[a+48>>2];q=i[a+24>>2];r=i[a+20>>2];b=i[a+44>>2];s=i[a+16>>2];k=i[a+4>>2];l=i[a>>2];i[j+8>>2]=l;i[j+12>>2]=k;e=i[a+12>>2];i[j>>2]=i[a+8>>2];i[j+4>>2]=e;a:{if(!d){e=b;b=f;break a}while(1){l=g[k+s|0];h=i[a+60>>2];m=h;e=Eb(b,-16777216,16776704);p=i[a+64>>2];k=Eb(f,-16777216,16776704);t=i[a+72>>2];f=i[c>>2];n=h>>31;l=l<<16;h=l;h=XMa(m,n,h,h>>31);m=_a;n=c;u=f;f=h;h=XMa(p,p>>31,e,e>>31);e=f+h|0;f=_a+m|0;f=e>>>0<h>>>0?f+1|0:f;h=e;e=i[a+68>>2];k=XMa(e,e>>31,k,k>>31);e=h+k|0;f=_a+f|0;f=e>>>0<k>>>0?f+1|0:f;e=e+8388608|0;if(e>>>0<8388608){f=f+1|0}f=(f&16777215)<<8|e>>>24;e=(f|0)/256|0;i[n>>2]=u+o(e,r);i[c+4>>2]=i[c+4>>2]+o(e,q);e=f-(l&t)|0;zb(j+8|0,j);d=d+ -1|0;if(d){c=c+8|0;k=i[j+12>>2];f=b;b=e;continue}break}l=i[j+8>>2];k=i[j+12>>2]}i[a+48>>2]=b;i[a+44>>2]=e;i[a>>2]=l;i[a+4>>2]=k;Xa=j+16|0}function L6(a,b,c,d){var e=0,f=0,g=0,h=0,j=0,k=0;h=a;k=a>>31;a=XMa(a,k,1e4,0)+14780|0;e=_a;j=a;e=a>>>0<14780?e+1|0:e;f=e;a=h;g=YMa(j,e,-14609700,-1)+a|0;e=k+_a|0;e=g>>>0<a>>>0?e+1|0:e;a=YMa(j,f,365242500,0);g=a+g|0;e=_a+e|0;e=g>>>0<a>>>0?e+1|0:e;a=YMa(j,f,-146097e4,-1);g=a+g|0;e=_a+e|0;e=g>>>0<a>>>0?e+1|0:e;a=YMa(j,f,3652425,0);f=_a;j=f;f=XMa(a,f,-365,-1);g=f+g|0;e=_a+e|0;e=g>>>0<f>>>0?e+1|0:e;f=e;if(!((e|0)>0?1:(e|0)>=0?g>>>0>=0:0)){e=j+ -1|0;a=a+ -1|0;if((a|0)!=-1){e=e+1|0}f=XMa(a,e,-365,-1)+h|0;e=k+_a|0;e=f>>>0<h>>>0?e+1|0:e;h=f;f=(a|0)/-4|0;g=h+f|0;e=(f>>31)+e|0;e=g>>>0<f>>>0?e+1|0:e;f=(a|0)/100|0;g=f+g|0;e=(f>>31)+e|0;e=g>>>0<f>>>0?e+1|0:e;f=(a|0)/-400|0;g=f+g|0;e=(f>>31)+e|0;e=g>>>0<f>>>0?e+1|0:e;f=e}j=b;k=a;a=XMa(g,f,100,0)+52|0;e=_a;h=YMa(a,a>>>0<52?e+1|0:e,3060,0);b=h+2|0;a=(b|0)/12|0;i[j>>2]=k+a;i[c>>2]=(b-o(a,12)|0)+1;a=XMa(h,_a,306,0)+5|0;e=_a;b=YMa(a,a>>>0<5?e+1|0:e,-10,-1)+g|0;i[d>>2]=b+1}function SI(a,b,c,d,e,f,i,l){var m=0,n=0,o=0,p=0,q=0,r=0,s=0;o=Xa-16|0;Xa=o;g[o+15|0]=c;g[o+14|0]=12;Lf(b,j[Xb(o+15|0,o+14|0)|0]);if(qb(b)){c=0;p=a+96|0;a=a+144|0;while(1){a:{b:{c:{switch(l|0){case 0:m=c<<2;n=m+p|0;n=j[n|0]|j[n+1|0]<<8;r=vb(b,c),s=n,h[r>>1]=s;m=(m|2)+p|0;break b;case 1:break c;default:break a}}m=c<<2;n=m+a|0;n=j[n|0]|j[n+1|0]<<8;r=vb(b,c),s=n,h[r>>1]=s;m=a+(m|2)|0}m=j[m|0];r=vb(b,c),s=m,g[r+2|0]=s}d:{if(!c){break d}m=c+ -1|0;if(k[vb(b,c)>>1]>=k[vb(b,m)>>1]){break d}if(k[vb(b,c)>>1]>255){break d}n=j[vb(b,m)+1|0];q=vb(b,c);h[q>>1]=k[q>>1]|n<<8;if(k[vb(b,c)>>1]>=k[vb(b,m)>>1]){break d}m=vb(b,c);h[m>>1]=k[m>>1]+256}c=c+1|0;if(c>>>0<qb(b)>>>0){continue}break}}g[b+12|0]=0;e:{if(!(d&1)){break e}if(Uc(b)){break e}g[b+12|0]=j[b+12|0]|1}if(e>>>0<=11){if(d&2){g[b+12|0]=j[b+12|0]|4}g[b+15|0]=e;g[b+16|0]=e}if(!(i>>>0<f>>>0|i>>>0>11)){if(d&4){g[b+12|0]=j[b+12|0]|2}g[b+14|0]=i;g[b+13|0]=f}Xa=o+16|0}function gK(a,b,c,d){var e=0,f=0;e=Xa-16|0;Xa=e;i[e+12>>2]=b;f=0;a:{if(!b){break a}if(i[a+480180>>2]&20){b=a+1074308|0;kb(e,b,73);if(ib(e)){i[e+12>>2]=k[e+12>>1]}if(j[a+480208|0]&16){kb(e,b,73);b=ib(e);a=i[e+12>>2];c=i[((a>>>0)%768<<2)+22096>>2]<<6;if(b){a=14-((9983-a>>>0)/768|0)&31}else{a=((a>>>0)/768|0)+2|0}f=c>>>a|0;break a}a=i[e+12>>2];if(!a){i[e+12>>2]=1;a=1}f=229079296/(a>>>0)|0;break a}f=227001280/(b>>>0)|0;if(Ts(a)){break a}f=(b+c<<4)+ -133808|0;if(i[a+480180>>2]==64){break a}b=i[a+480180>>2];kc(e+12|0,16777215);if(b&17408){f=Vc(_Ma(XMa(c?c:8363,0,3506176,0),_a,(i[e+12>>2]<<8)+d|0,0),_a);break a}if(j[a+480208|0]&16){kb(e,a+1074308|0,7);if(ib(e)){c=d>>31;b=d;a=i[e+12>>2];d=a>>>24|0;f=a<<8;b=b+f|0;a=c+d|0;a=b>>>0<f>>>0?a+1|0:a;f=(a&15)<<28|b>>>4;break a}f=Vc(_Ma(XMa(c?c:8363,0,7012352,0),_a,(i[e+12>>2]<<8)+d|0,0),_a);break a}f=Vc(_Ma(-1485242368,13,(i[e+12>>2]<<8)+d|0,0),_a)}Xa=e+16|0;return f}function TM(a,b,c){var d=0;d=j[a|0]&15;g[a|0]=j[d+17504|0];a:{b:{c:{switch(d|0){case 0:if(j[b|0]?c>>>0>=51:0){break b}g[a|0]=0;return;case 5:d=j[b|0];if(!((d&240)!=32?(d&15)!=2:0)){g[a|0]=20;g[b|0]=159;d=159}if(!((d&15)==12|(d&240)==192)|c>>>0<51){break b}g[a|0]=25;g[b|0]=0;return;case 7:if(c>>>0>51){break b}g[a|0]=0;return;case 10:a=j[b|0]&240;if(!a){break b}g[b|0]=a;return;case 11:g[b|0]=o(j[b|0]&15,17);return;case 12:g[b|0]=j[b|0]>>>2;return;case 13:a=j[b|0];g[b|0]=o(a>>>4|0,10)+(a&15);return;case 14:d:{switch((j[b|0]>>>4|0)+ -1|0){case 0:g[a|0]=2;break a;case 1:g[a|0]=3;break a;case 7:if(c>>>0<52){break b}g[a|0]=20;g[b|0]=j[b|0]&15|96;return;case 8:g[a|0]=15;g[b|0]=j[b|0]&15;return;case 9:g[a|0]=11;g[b|0]=j[b|0]<<4|15;return;case 10:g[a|0]=11;break a;case 11:case 12:break d;default:break b}}g[a|0]=20;return;case 15:break c;default:break b}}if(j[b|0]<48){break b}g[a|0]=17}return}g[b|0]=j[b|0]|240}function Vxa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,j=0,l=0,m=0,n=0;m=Xa-112|0;Xa=m;a:{b:{if(!ie(a)){break b}if(cc(b)>>>0<2){break b}f=Yx(m+8|0,a);i[f+20>>2]=0;i[f>>2]=0;c:{d=cc(b);if(d){d:{while(1){c=Yc(b,g);e=i[a>>2];j=i[c>>2];if(e>>>0<=j>>>0){break d}c=i[c+4>>2];if(e-j>>>0<c>>>0){break d}e=i[f>>2];if(e>>>0>268435456-c>>>0){break d}i[f>>2]=c+e;g=g+1|0;if((d|0)!=(g|0)){continue}break}g=d}if(!Mo(f)){break b}if(!g){break c}d=0;c=0;while(1){e=Yc(b,d);j=i[f+20>>2];i[114610]=0;j=F(466,j|0)|0;l=i[114610];i[114610]=0;if((l|0)==1){break a}l=i[a+20>>2];i[114610]=0;l=F(466,l|0)|0;n=i[114610];i[114610]=0;if((n|0)==1){break a}Tb(c+j|0,l+i[e>>2]|0,i[e+4>>2]);i[e>>2]=c;if(!(!d|d>>>0>9)){i[((d<<2)+f|0)- -64>>2]=c}c=i[e+4>>2]+c|0;d=d+1|0;if((g|0)!=(d|0)){continue}break}break c}if(Mo(f)){break c}break b}Om(a);Yx(a,f);i[a+4>>2]=0;i[a+8>>2]=i[a>>2];h[a+34>>1]=k[a+34>>1]|2}Xa=m+112|0;return}a=H(0)|0;A()|0;gb(a);x()}function G5(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;g=Xa-16|0;Xa=g;a:{if(i[a+1420>>2]>=0){i[f>>2]=0;a=E5(a,b,c);break a}i[a+100>>2]=0;i[a+32>>2]=b;i[a+40>>2]=b+c;if(!ZE(a)){i[f>>2]=0;a=0;break a}if(!D5(a,g+12|0,g+4|0,g+8|0)){b:{c:{d:{c=i[a+100>>2];switch(c+ -32|0){case 0:break c;case 3:break d;default:break b}}i[a+100>>2]=0;while(1){if(m=0,n=(lg(a)|0)!=-1,o=i[a+96>>2],o?m:n){continue}break}i[f>>2]=0;a=i[a+32>>2]-b|0;break a}if(i[a+992>>2]){break b}i[a+100>>2]=0;while(1){if(m=0,n=(lg(a)|0)!=-1,o=i[a+96>>2],o?m:n){continue}break}i[f>>2]=0;a=i[a+32>>2]-b|0;break a}H5(a);i[a+100>>2]=c;i[f>>2]=0;a=1;break a}j=i[g+4>>2];k=C5(a,i[g+12>>2],j,i[g+8>>2]);i[g+12>>2]=k;h=i[a+4>>2];if((h|0)>=1){c=0;while(1){l=(c<<2)+a|0;i[l+864>>2]=i[l+800>>2]+(j<<2);c=c+1|0;if((h|0)!=(c|0)){continue}break}}if(d){i[d>>2]=h}i[f>>2]=k;i[e>>2]=a+864;a=i[a+32>>2]-b|0}Xa=g+16|0;return a|0}function xoa(a,b){var c=0,d=0,e=0,f=0,h=0,k=0,l=0;d=Xa-16|0;Xa=d;f=Ab(a);a:{if(lb(b)){while(1){e=i[Ki(b,l)>>2];b:{if(e>>>0>=2097152){i[114610]=0;D(110,f|0,63);a=i[114610];i[114610]=0;if((a|0)!=1){break b}break a}a=0;c:{d:{while(1){k=e&63;g[(d+10|0)+a|0]=k;c=a+1|0;e=e>>>6|0;if(!e){break d}a=c;if((a|0)!=6){continue}break}c=7;a=6;break c}e:{if(!a){i[114610]=0;D(110,f|0,g[d+10|0]);break e}if((c|0)!=2){break c}a=1;c=2;if((k|0)!=1){break c}i[114610]=0;D(110,f|0,g[d+10|0]|64)}a=i[114610];i[114610]=0;if((a|0)!=1){break b}break a}e=(-1<<c^-1)<<7-a;k=c+d|0;a=c;while(1){f:{if((a|0)==(c|0)){h=j[k+9|0];i[114610]=0;D(110,f|0,(e|h)<<24>>24);h=i[114610];i[114610]=0;if((h|0)==1){break a}a=a+ -1|0;break f}i[114610]=0;a=a+ -1|0;D(110,f|0,g[a+(d+10|0)|0]|-128);h=i[114610];i[114610]=0;if((h|0)==1){break a}}if(a){continue}break}}l=l+1|0;if(l>>>0<lb(b)>>>0){continue}break}}Xa=d+16|0;return}a=B()|0;A()|0;eb(f);E(a|0);x()}function Ila(a,b){var c=0,d=0,e=0,f=0,h=0,k=0,l=0;d=Xa-16|0;Xa=d;f=Oc(a);a:{if(lb(b)){while(1){e=i[Ki(b,l)>>2];b:{if(e>>>0>=2097152){i[114610]=0;D(118,f|0,63);a=i[114610];i[114610]=0;if((a|0)!=1){break b}break a}a=0;c:{d:{while(1){k=e&63;g[(d+10|0)+a|0]=k;c=a+1|0;e=e>>>6|0;if(!e){break d}a=c;if((a|0)!=6){continue}break}c=7;a=6;break c}e:{if(!a){i[114610]=0;D(118,f|0,g[d+10|0]);break e}if((c|0)!=2){break c}a=1;c=2;if((k|0)!=1){break c}i[114610]=0;D(118,f|0,g[d+10|0]|64)}a=i[114610];i[114610]=0;if((a|0)!=1){break b}break a}e=(-1<<c^-1)<<7-a;k=c+d|0;a=c;while(1){f:{if((a|0)==(c|0)){h=j[k+9|0];i[114610]=0;D(118,f|0,(e|h)<<24>>24);h=i[114610];i[114610]=0;if((h|0)==1){break a}a=a+ -1|0;break f}i[114610]=0;a=a+ -1|0;D(118,f|0,g[a+(d+10|0)|0]|-128);h=i[114610];i[114610]=0;if((h|0)==1){break a}}if(a){continue}break}}l=l+1|0;if(l>>>0<lb(b)>>>0){continue}break}}Xa=d+16|0;return}a=B()|0;A()|0;eb(f);E(a|0);x()}function md(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=Xa+ -64|0;Xa=c;i[a+480180>>2]=b;b=ro(a);LJ(c,b);e=i[c+12>>2];d=a+1074316|0;i[d>>2]=i[c+8>>2];i[d+4>>2]=e;d=i[c+4>>2];i[a+1074308>>2]=i[c>>2];i[a+1074312>>2]=d;Fr(a+8|0,b);d=k[a+480192>>1];if(d){b=1;while(1){e=(((b&65535)<<2)+a|0)+900380|0;f=i[e>>2];if(f){Cb(Is(f));d=k[a+480192>>1]}i[e>>2]=0;b=b+1|0;if((b&65535)>>>0<=d>>>0){continue}break}}i[a+480184>>2]=0;i[a+480188>>2]=0;i[a+480236>>2]=65536;i[a+480228>>2]=48;i[a+480232>>2]=48;g[a+480268|0]=5;i[a+480260>>2]=16;i[a+480264>>2]=32767;i[a+480204>>2]=125e4;i[a+480208>>2]=0;i[a+480196>>2]=6;i[a+480200>>2]=256;i[a+1074300>>2]=0;i[a+1074304>>2]=0;h[a+480192>>1]=0;dx(a,4);Vja(a+484344|0);cM(a+484360|0);Ce(a+1304400|0);Ce(a+1304412|0);Ce(a+1304424|0);b=yb(c,0,64);c=UJ(b);Pna(a+1304436|0,c);Ir(c);wz(a+1304500|0);$r(a+480248|0);if(i[a+480180>>2]&738230281){i[a+480208>>2]=i[a+480208>>2]|8388608}Xa=b- -64|0}function ica(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;i[114610]=0;L(2088,a|0);e=i[114610];i[114610]=0;a:{b:{c:{d:{e:{if((e|0)==1){break e}i[114610]=0;L(2041,b|0);e=i[114610];i[114610]=0;if((e|0)==1){break e}e=0;i[114610]=0;L(2089,c|0);f=i[114610];i[114610]=0;if((f|0)==1){break e}a=yb(c,0,d);if(!j[b|0]){break b}if(Ih(b,37302)|(d|0)!=8){break d}i[a+4>>2]=2090;i[a>>2]=2091;break c}b=H(0)|0;A()|0;M(b|0)|0;i[114610]=0;J(1989,37326,a|0,0,0);a=i[114610];i[114610]=0;if((a|0)==1){break a}O();return 0}if(Ih(b,37314)|(d|0)!=64){break b}i[a+60>>2]=2092;i[a+56>>2]=2093;i[a+52>>2]=2094;i[a+48>>2]=2095;i[a+44>>2]=2096;i[a+40>>2]=2097;i[a+36>>2]=2098;i[a+32>>2]=2099;i[a+28>>2]=2100;i[a+24>>2]=2101;i[a+20>>2]=2102;i[a+16>>2]=2103;i[a+12>>2]=2104;i[a+8>>2]=2105;i[a+4>>2]=2106;i[a>>2]=2107}e=1}return e|0}a=B()|0;A()|0;i[114610]=0;K(20);b=i[114610];i[114610]=0;if((b|0)!=1){E(a|0);x()}a=H(0)|0;A()|0;gb(a);x()}function lea(a,b,c,d){var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,p=0,q=0,r=0;l=Xa-32|0;Xa=l;g=i[a>>2];while(1){i[(e<<2)+l>>2]=g+(i[((e<<4)+a|0)+32>>2]^-1);e=e+1|0;if((e|0)!=7){continue}break}if(d){q=h[a+28>>1]/8<<16>>16;while(1){g=0;f=0;e=0;while(1){j=(e<<2)+l|0;k=i[j>>2]+1&8191;i[j>>2]=k;p=f;f=(k<<2)+a|0;k=h[f+160>>1];j=(e<<4)+a|0;n=h[f+162>>1];f=(p+o(k,h[j+44>>1])|0)+o(n,h[j+46>>1])|0;g=(o(k,h[j+40>>1])+g|0)+o(n,h[j+42>>1])|0;e=e+1|0;if((e|0)!=4){continue}break}j=0;e=4;k=Bc((g|0)/32768|0);n=Bc((f|0)/32768|0);g=0;while(1){m=(e<<2)+l|0;f=i[m>>2]+1&8191;i[m>>2]=f;p=g;g=(f<<2)+a|0;m=h[g+160>>1];f=(e<<4)+a|0;r=h[g+162>>1];g=(p+o(m,h[f+44>>1])|0)+o(r,h[f+46>>1])|0;j=(o(h[f+40>>1],m)+j|0)+o(h[f+42>>1],r)|0;e=e+1|0;if((e|0)!=7){continue}break}e=Bc(k+((j|0)/32768|0)|0);h[b>>1]=e;i[c>>2]=o(e,q);e=Bc(n+((g|0)/32768|0)|0);h[b+2>>1]=e;i[c+4>>2]=o(e,q);c=c+8|0;b=b+4|0;d=d+ -1|0;if(d){continue}break}}Xa=l+32|0}function OD(a,b){var c=0,d=0,e=0,f=0,h=0,k=0,l=0,m=0,n=0;c=Xa-32|0;Xa=c;a:{if(j[a+52|0]){d=i[a+48>>2];if(!b){break a}g[a+52|0]=0;i[a+48>>2]=-1;break a}i[c+24>>2]=1;e=i[wf(c+24|0,a+44|0)>>2];k=(e|0)>0?e:0;b:{while(1){if((d|0)!=(k|0)){f=yq(i[a+32>>2]);if((f|0)==-1){break b}g[(c+24|0)+d|0]=f;d=d+1|0;continue}break}c:{if(j[a+53|0]){g[c+23|0]=j[c+24|0];break c}k=c+24|0;while(1){d:{d=i[a+40>>2];f=i[d>>2];l=i[d+4>>2];e:{h=d;d=(c+24|0)+e|0;switch(ND(i[a+36>>2],h,c+24|0,d,c+16|0,c+23|0,k,c+12|0)+ -1|0){case 0:break e;case 1:break b;case 2:break d;default:break c}}h=i[a+40>>2];i[h>>2]=f;i[h+4>>2]=l;if((e|0)==8){break b}f=yq(i[a+32>>2]);if((f|0)==-1){break b}g[d|0]=f;e=e+1|0;continue}break}g[c+23|0]=j[c+24|0]}f:{if(!b){while(1){if((e|0)<1){break f}e=e+ -1|0;if((zq(cg(g[e+(c+24|0)|0]),i[a+32>>2])|0)!=-1){continue}break b}}m=a,n=cg(g[c+23|0]),i[m+48>>2]=n}d=cg(g[c+23|0]);break a}d=-1}Xa=c+32|0;return d}function yfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,k=0,l=0,n=0,o=p(0),r=0,s=0,t=0,u=0,v=0,w=p(0),x=p(0),y=p(0),z=0,A=0,B=p(0);f=Xa-16|0;Xa=f;a:{if(!i[a+4240>>2]){break a}g=a+44|0;if(!Wg(g)){break a}y=m[a+4220>>2];z=f,A=ud(g,0),i[z+8>>2]=A;z=f,A=ud(g,1),i[z+12>>2]=A;z=f,A=Pc(g,0),i[z>>2]=A;z=f,A=Pc(g,1),i[z+4>>2]=A;if(d){r=a+4208|0;l=d;while(1){h=0;k=1;n=0;while(1){s=(j[a+4264|0]?1-n|0:h)&255;e=i[a+4244>>2]-i[((s<<2)+a|0)+4248>>2]|0;if((e|0)<=-1){e=i[a+4240>>2]+e|0}t=h<<2;u=t+(f+8|0)|0;v=i[u>>2];i[u>>2]=v+4;o=m[v>>2];w=m[vb(r,(e<<1)+s|0)>>2];x=p(p(m[a+4224>>2]*w)+p(o*m[a+4260>>2]));z=vb(r,i[a+4244>>2]<<1|h),B=p(q(x))<p(1.0000000195414814e-24)?p(0):x,m[z>>2]=B;h=f+t|0;e=i[h>>2];i[h>>2]=e+4;m[e>>2]=o+p(p(w-o)*y);n=n+1|0;e=k;k=0;h=1;if(e){continue}break}k=i[a+4244>>2]+1|0;i[a+4244>>2]=(k|0)==i[a+4240>>2]?0:k;l=l+ -1|0;if(l){continue}break}}Oh(a,b,c,Pc(g,0),Pc(g,1),d)}Xa=f+16|0}function OG(a,b,c,d,e,f,g,h,j){var k=0,l=0,m=0,n=0;k=Xa-48|0;Xa=k;i[k+44>>2]=0;if(!(j?0:!(d|g|h))){l=Qba(g?k+44|0:0)}if(d){m=$a[d|0](l,e)|0}else{m=3}if(!(!(m&2)|!g)){i[g+16>>2]=l;n=g;g=i[k+44>>2];a:{if(g){g=Ed(g);break a}g=Ed(34133)}i[n+20>>2]=g}if(h){i[h>>2]=l}if(j){g=i[k+44>>2];b:{if(g){g=Ed(g);break b}g=Ed(34133)}i[j>>2]=g}g=i[k+44>>2];if(g){Cb(g);i[k+44>>2]=0}c:{if(!(m&1)){break c}i[114610]=0;D(1990,k+32|0,a|0);g=i[114610];i[114610]=0;d:{e:{if((g|0)!=1){f:{if(f){i[114610]=0;D(1991,f|0,k+32|0);g=i[114610];i[114610]=0;if((g|0)!=1){break f}break e}g=xb(k+32|0);if(b){i[114610]=0;D(b|0,g|0,c|0);g=i[114610];i[114610]=0;if((g|0)==1){break e}break f}hr(g,k)}eb(k+32|0);break c}g=H(0)|0;A()|0;break d}g=H(0)|0;A()|0;eb(k+32|0)}M(g|0)|0;i[k+28>>2]=f;i[k+24>>2]=e;i[k+20>>2]=d;i[k+16>>2]=c;i[k+12>>2]=b;i[k+4>>2]=248;i[k>>2]=37489;i[k+8>>2]=a?a:34133;a=i[13910];BE(a,37359,k);Nq(a);O()}Xa=k+48|0}function RJ(a,b){var c=0,d=0,e=0,f=0,g=0;d=Xa-16|0;Xa=d;e=Ke(a);f=d,g=ld(b),i[f+8>>2]=g;f=d,g=Ye(b),i[f>>2]=g;a:{b:{if(!pb(d+8|0,d)){break b}a=0;b=0;while(1){c=j[i[d+8>>2]];c:{if(!a){if(!(c&128)){a=0;i[114610]=0;D(112,e|0,c|0);c=i[114610];i[114610]=0;if((c|0)!=1){break c}break a}if((c&224)==192){b=c&31;a=1;break c}if((c&240)==224){b=c&15;a=2;break c}if((c&248)==240){b=c&7;a=3;break c}b=0;i[114610]=0;D(112,e|0,65533);c=i[114610];i[114610]=0;a=0;if((c|0)==1){break a}break c}if((c&192)!=128){i[114610]=0;D(112,e|0,65533);a=i[114610];i[114610]=0;if((a|0)==1){break a}b=c&63;a=-1;break c}c=c&63|b<<6;a=a+ -1|0;if(a){b=c;break c}b=0;i[114610]=0;D(112,e|0,c|0);c=i[114610];i[114610]=0;a=0;if((c|0)==1){break a}}Tf(d+8|0);if(pb(d+8|0,d)){continue}break}if(!a){break b}i[114610]=0;D(112,e|0,65533);a=i[114610];i[114610]=0;if((a|0)!=1){break b}break a}Xa=d+16|0;return}a=B()|0;A()|0;nc(e);E(a|0);x()}function Dva(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,p=0,q=0,r=0;e=Xa-32|0;Xa=e;k=i[a+40>>2];l=i[a+36>>2];n=i[a+16>>2];b=i[a+4>>2];f=b;g=i[a>>2];i[e+24>>2]=g;i[e+28>>2]=b;b=i[a+12>>2];i[e+16>>2]=i[a+8>>2];i[e+20>>2]=b;a:{if(!d){b=k>>12;j=l>>12;break a}while(1){m=((((f&2147483647)<<1|g>>>31)&2147483646)<<1)+n|0;b=(g>>>21&2040)+27872|0;g=h[b+6>>1];p=h[b+4>>1];q=h[b+2>>1];r=h[b>>1];j=0;b=1;while(1){f=j<<1;i[(e+8|0)+(j<<2)>>2]=(((o(h[f+m>>1],q)+o(h[(f|-4)+m>>1],r)|0)+o(h[(f|4)+m>>1],p)|0)+o(h[(f|8)+m>>1],g)|0)/16384;f=b;b=0;j=1;if(f){continue}break}b=i[a+32>>2];l=i[a+28>>2]+l|0;j=l>>12;i[c>>2]=i[c>>2]+o(j,i[e+8>>2]);k=b+k|0;b=k>>12;i[c+4>>2]=i[c+4>>2]+o(b,i[e+12>>2]);zb(e+24|0,e+16|0);d=d+ -1|0;if(d){c=c+8|0;g=i[e+24>>2];f=i[e+28>>2];continue}break}g=i[e+24>>2];f=i[e+28>>2]}i[a+40>>2]=k;i[a+20>>2]=j;i[a+36>>2]=l;i[a+24>>2]=b;i[a>>2]=g;i[a+4>>2]=f;Xa=e+32|0}function sM(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;g[a+15|0]=0;g[a+16|0]=0;g[a+17|0]=0;g[a+18|0]=0;g[a+19|0]=0;g[a+20|0]=0;g[a+21|0]=0;g[a+22|0]=0;g[a+14|0]=5;h[a+12>>1]=0;i[a+8>>2]=128;i[a>>2]=256;i[a+4>>2]=64;i[a+28>>2]=0;g[a+27|0]=60;i[a+40>>2]=0;i[a+44>>2]=0;g[a+33|0]=33554434;g[a+34|0]=131072;g[a+35|0]=512;g[a+36|0]=2;g[a+23|0]=16711680;g[a+24|0]=65280;g[a+25|0]=255;g[a+26|0]=0;g[a+32|0]=0;d=Nx(a+48|0);e=Nx(a+68|0);f=Nx(a+88|0);i[114610]=0;F(1163,a+492|0)|0;c=i[114610];i[114610]=0;a:{if((c|0)==1){break a}i[114610]=0;F(1163,a+524|0)|0;c=i[114610];i[114610]=0;if((c|0)==1){break a}i[114610]=0;G(910,a|0,0,0);c=i[114610];i[114610]=0;if((c|0)==1){break a}i[114610]=0;G(911,a|0,0,0);c=i[114610];i[114610]=0;if((c|0)==1){break a}i[a+40>>2]=0;i[a+44>>2]=0;i[114610]=0;D(780,a|0,b|0);b=i[114610];i[114610]=0;if((b|0)==1){break a}dua(a);return a|0}a=B()|0;A()|0;Um(f);Um(e);Um(d);E(a|0);x()}function pCa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,i=0,l=0,m=0,n=0,p=0,q=0,r=0,s=0;e=Xa-16|0;Xa=e;g[e+15|0]=8;g[e+14|0]=0;h[e+12>>1]=0;if(d){p=o(c,d);while(1){if((p|0)>=1){l=(n<<1)+b|0;r=l+(p<<1)|0;while(1){h[e+10>>1]=0;OO(a,e+14|0,e+12|0,e+15|0,e+10|0);a:{b:{i=j[e+15|0];if(!i){break b}c=k[e+12>>1];while(1){f=c<<1;c=f&254;h[e+12>>1]=c;f=(f&65534)>>>0>255;g[e+14|0]=f;if(!c){if(!pe(a,e+9|0)){break b}c=j[e+9|0];f=c>>>7|0;g[e+14|0]=f;c=c<<1&254|1;h[e+12>>1]=c}m=k[e+10>>1]<<1|f;h[e+10>>1]=m;i=i+ -1|0;if(i&255){continue}break}break a}m=k[e+10>>1]}c=1;i=m&65535;c:{if(i>>>0<4){break c}f=15;while(1){c=f;q=c&255;if(q>>>0<2){break c}f=c+ -1|0;if(!(i&1<<q)){continue}break}}g[e+15|0]=(j[e+15|0]+c&254)>>>1;c=m&1;g[e+14|0]=c;c=(c+ -1^(m&65534)>>>1)+s|0;h[e+10>>1]=c;h[l>>1]=c;s=k[e+10>>1];l=(d<<1)+l|0;if(l>>>0<r>>>0){continue}break}}n=n+1|0;if((n|0)!=(d|0)){continue}break}}Xa=e+16|0}function FW(){var a=0,b=0,c=0,d=0;c=Xa-32|0;Xa=c;a:{a=Bb(c+16|0,10940);if(!lb(a)){break a}b:{if((Ef(a,10946)|0)!=-1){b=Ef(a,10946);i[114610]=0;J(232,c|0,a|0,b+1|0,-1);b=i[114610];i[114610]=0;if((b|0)==1){break b}mb(a,c);eb(c)}if((Ef(a,10948)|0)!=-1){b=Ef(a,10948);i[114610]=0;J(232,c|0,a|0,b+1|0,-1);b=i[114610];i[114610]=0;if((b|0)==1){break b}mb(a,c);eb(c)}if((Ef(a,10950)|0)!=-1){b=Ef(a,10950);i[114610]=0;J(232,c|0,a|0,0,b|0);b=i[114610];i[114610]=0;if((b|0)==1){break b}mb(a,c);eb(c)}if((Ef(a,10952)|0)!=-1){b=Ef(a,10952);i[114610]=0;J(232,c|0,a|0,0,b|0);b=i[114610];i[114610]=0;if((b|0)==1){break b}mb(a,c);eb(c)}if((Ef(a,10954)|0)!=-1){b=Ef(a,10954);i[114610]=0;J(232,c|0,a|0,0,b|0);b=i[114610];i[114610]=0;if((b|0)==1){break b}mb(a,c);eb(c)}i[114610]=0;b=F(233,a|0)|0;d=i[114610];i[114610]=0;if((d|0)!=1){break a}}c=B()|0;A()|0;eb(a);E(c|0);x()}eb(a);Xa=c+32|0;return b|0}function LD(a,b){var c=0,d=0,e=0,f=0,h=0,k=0,l=0;c=Xa-32|0;Xa=c;a:{if(j[a+52|0]){d=i[a+48>>2];if(!b){break a}g[a+52|0]=0;i[a+48>>2]=-1;break a}i[c+24>>2]=1;e=i[wf(c+24|0,a+44|0)>>2];k=(e|0)>0?e:0;b:{while(1){if((d|0)!=(k|0)){f=yq(i[a+32>>2]);if((f|0)==-1){break b}g[(c+24|0)+d|0]=f;d=d+1|0;continue}break}c:{if(j[a+53|0]){i[c+20>>2]=g[c+24|0];break c}k=c+24|0;while(1){d:{d=i[a+40>>2];f=i[d>>2];l=i[d+4>>2];e:{h=d;d=(c+24|0)+e|0;switch(ND(i[a+36>>2],h,c+24|0,d,c+16|0,c+20|0,k,c+12|0)+ -1|0){case 0:break e;case 1:break b;case 2:break d;default:break c}}h=i[a+40>>2];i[h>>2]=f;i[h+4>>2]=l;if((e|0)==8){break b}f=yq(i[a+32>>2]);if((f|0)==-1){break b}g[d|0]=f;e=e+1|0;continue}break}i[c+20>>2]=g[c+24|0]}f:{if(!b){while(1){if((e|0)<1){break f}e=e+ -1|0;if((zq(g[e+(c+24|0)|0],i[a+32>>2])|0)!=-1){continue}break b}}i[a+48>>2]=i[c+20>>2]}d=i[c+20>>2];break a}d=-1}Xa=c+32|0;return d}function $Ha(a,b,c){var d=0,e=0,f=0,h=0,j=0,k=0;d=Xa-80|0;Xa=d;Ce(b);a:{if(wb(a,1)){b:{c:{d:{e:{f:{g:{while(1){i[114610]=0;e=I(605,a|0,d+16|0,64)|0;f=i[114610];i[114610]=0;if((f|0)==1){break d}i[d+8>>2]=e;e=lb(b);i[114610]=0;i[d+4>>2]=c-e;e=C(33,d+8|0,d+4|0)|0;f=i[114610];i[114610]=0;if((f|0)==1){break g}e=i[e>>2];if(!e){break b}g[d+8|0]=0;f=e+(d+16|0)|0;e=um(d+16|0,f,d+8|0);j=d,k=Ye(b),i[j+8>>2]=k;Ad(d,d+8|0);i[114610]=0;N(606,b|0,i[d>>2],d+16|0,e|0)|0;h=i[114610];i[114610]=0;if((h|0)==1){break f}i[114610]=0;C(338,a|0,e-(d+16|0)|0)|0;h=i[114610];i[114610]=0;if((h|0)==1){break e}if(e>>>0>=f>>>0){continue}break}i[114610]=0;C(338,a|0,1)|0;a=i[114610];i[114610]=0;if((a|0)!=1){break b}a=H(71348)|0;break c}a=H(71348)|0;break c}a=H(71348)|0;break c}a=H(71348)|0;break c}a=H(71348)|0}if((A()|0)!=(U(71348)|0)){break a}M(a|0)|0;O()}e=(lb(b)|0)!=0}Xa=d+80|0;return e}E(a|0);x()}function Nk(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,k=0,m=0;Bj(a);a:{b:{c:{g=i[b+32>>2];d:{if(!g){d=i[b+2084>>2];if(d){break d}break b}f=i[b+4>>2];if((f|0)<9){break c}d=i[b+2084>>2];if(!d){break c}}h=i[a+1392>>2];m=Mk(h);e=i[b+2092>>2];if((e|0)>=2){while(1){f=e>>>1|0;k=f+c|0;g=l[(k<<2)+d>>2]>m>>>0;c=g?c:k;e=g?f:e-f|0;if((e|0)>1){continue}break}}e=a;d=i[a+1396>>2];c=j[b+23|0]?c:i[i[b+2088>>2]+(c<<2)>>2];b=j[c+i[b+8>>2]|0];e:{if((d|0)<(b|0)){c=-1;a=0;break e}i[a+1392>>2]=h>>>b;a=d-b|0}i[e+1396>>2]=a;return c}if(j[b+23|0]){break a}if((f|0)>=1){d=i[b+8>>2];while(1){f:{e=j[c+d|0];if((e|0)==255){break f}h=i[a+1392>>2];if(i[g+(c<<2)>>2]!=(h&(-1<<e^-1))){break f}d=i[a+1396>>2];if((d|0)>=(e|0)){i[a+1392>>2]=h>>>e;i[a+1396>>2]=d-j[i[b+8>>2]+c|0];return c}i[a+1396>>2]=0;break b}c=c+1|0;if((f|0)!=(c|0)){continue}break}}Lb(a,21);i[a+1396>>2]=0}return-1}V(50666,50448,1690,50677);x()}function Eva(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,j=0,k=0,l=0,m=0,n=0,p=0,q=0,r=0,s=0;e=Xa-32|0;Xa=e;l=i[a+40>>2];m=i[a+36>>2];p=i[a+16>>2];b=i[a+4>>2];j=b;k=i[a>>2];i[e+24>>2]=k;i[e+28>>2]=b;b=i[a+12>>2];i[e+16>>2]=i[a+8>>2];i[e+20>>2]=b;a:{if(!d){f=l>>12;b=m>>12;break a}while(1){n=(((j&2147483647)<<1|k>>>31)&-2)+p|0;b=(k>>>21&2040)+27872|0;k=h[b+6>>1];q=h[b+4>>1];r=h[b+2>>1];s=h[b>>1];f=0;b=1;while(1){i[(e+8|0)+(f<<2)>>2]=(((o(g[f+n|0],r)+o(g[(f|-2)+n|0],s)|0)+o(g[(f|2)+n|0],q)|0)+o(g[(f|4)+n|0],k)<<8)/16384;j=b;b=0;f=1;if(j){continue}break}j=i[a+32>>2];m=i[a+28>>2]+m|0;b=m>>12;i[c>>2]=i[c>>2]+o(b,i[e+8>>2]);l=j+l|0;f=l>>12;i[c+4>>2]=i[c+4>>2]+o(f,i[e+12>>2]);zb(e+24|0,e+16|0);d=d+ -1|0;if(d){c=c+8|0;k=i[e+24>>2];j=i[e+28>>2];continue}break}k=i[e+24>>2];j=i[e+28>>2]}i[a+40>>2]=l;i[a+20>>2]=b;i[a+36>>2]=m;i[a+24>>2]=f;i[a>>2]=k;i[a+4>>2]=j;Xa=e+32|0}function Eq(a){a=a|0;var b=0,c=0,d=0,e=0;d=Xa-16|0;Xa=d;c=i[i[a>>2]+ -12>>2];i[114610]=0;c=i[(a+c|0)+24>>2];b=i[114610];i[114610]=0;a:{b:{c:{d:{e:{if((b|0)!=1){if(!c){break b}i[114610]=0;c=C(15,d+8|0,a|0)|0;b=i[114610];i[114610]=0;if((b|0)==1){break d}if(!j[c|0]){break e}b=i[i[a>>2]+ -12>>2];i[114610]=0;b=i[(a+b|0)+24>>2];e=i[114610];i[114610]=0;f:{if((e|0)==1){break f}i[114610]=0;b=F(2315,b|0)|0;e=i[114610];i[114610]=0;if((e|0)==1){break f}if((b|0)!=-1){break e}b=i[i[a>>2]+ -12>>2];i[114610]=0;D(18,a+b|0,1);b=i[114610];i[114610]=0;if((b|0)!=1){break e}}b=H(0)|0;A()|0;jf(c);break c}b=H(0)|0;A()|0;break c}jf(c);break b}b=H(0)|0;A()|0}M(b|0)|0;c=i[i[a>>2]+ -12>>2];i[114610]=0;L(19,a+c|0);c=i[114610];i[114610]=0;if((c|0)==1){break a}O()}Xa=d+16|0;return a|0}a=B()|0;A()|0;i[114610]=0;K(20);c=i[114610];i[114610]=0;if((c|0)!=1){E(a|0);x()}a=H(0)|0;A()|0;gb(a);x()}function wka(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,j=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;n=Xa-16|0;Xa=n;if(ie(a)){d=k[a+34>>1];o=i[a+4>>2];h=i[a+8>>2];m=i[a>>2];r=!(d&2)|(o>>>0>=h>>>0|h>>>0>m>>>0);p=i[a+12>>2];j=i[a+16>>2];s=!(d&8)|(p>>>0>=j>>>0|j>>>0>m>>>0);t=b+1304360|0;b=b+1074984|0;u=d&4;v=d&16;while(1){a:{if(i[b+104>>2]!=(a|0)){break a}d=i[b+76>>2];if(!d){break a}b:{c:{d:{e=b;e:{f:{if(s){break f}c=i[b+88>>2];if(c&2048){break f}i[b+84>>2]=j;i[b+80>>2]=p;g=v;d=j;break e}if(r){break d}i[b+84>>2]=h;i[b+80>>2]=o;c=i[b+88>>2];g=u;d=h}i[e+76>>2]=d;f=c|2;i[b+88>>2]=f;q=b+88|0;e=1;if(!g){break c}c=c|6;e=1;g=1;break b}f=i[b+88>>2]&-3;i[b+88>>2]=f;q=b+88|0;e=0}c=f&-5;g=0}i[b+88>>2]=c;if(d>>>0<l[b+4>>2]){c=c&-129;i[b+88>>2]=c;f=i[b+80>>2];i[b>>2]=0;i[b+4>>2]=f}if(!g){i[q>>2]=c&-129}if(e){break a}i[b+76>>2]=m}b=b+896|0;if((t|0)!=(b|0)){continue}break}}Xa=n+16|0}function lI(a,b,c){var d=0,e=0,f=0,g=0,h=0,k=0,l=0;d=Xa-32|0;Xa=d;i[114610]=0;g=C(15,d+24|0,a|0)|0;e=i[114610];i[114610]=0;a:{b:{c:{if((e|0)!=1){d:{e:{if(!j[g|0]){break e}e=sk(d+8|0,a);h=i[(i[i[a>>2]+ -12>>2]+a|0)+4>>2];f=i[i[a>>2]+ -12>>2];i[114610]=0;f=a+f|0;k=F(16,f|0)|0;l=i[114610];i[114610]=0;if((l|0)==1){break d}e=i[e>>2];i[114610]=0;c=b+c|0;b=Y(17,e|0,b|0,((h&176)==32?c:b)|0,c|0,f|0,k|0)|0;c=i[114610];i[114610]=0;if((c|0)==1){break d}i[d+16>>2]=b;if(!rk(d+16|0)){break e}b=i[i[a>>2]+ -12>>2];i[114610]=0;D(18,a+b|0,5);b=i[114610];i[114610]=0;if((b|0)!=1){break e}break d}jf(g);break b}b=H(0)|0;A()|0;jf(g);break c}b=H(0)|0;A()|0}M(b|0)|0;b=i[i[a>>2]+ -12>>2];i[114610]=0;L(19,a+b|0);b=i[114610];i[114610]=0;if((b|0)==1){break a}O()}Xa=d+32|0;return a}a=B()|0;A()|0;i[114610]=0;K(20);b=i[114610];i[114610]=0;if((b|0)==1){a=H(0)|0;A()|0;gb(a);x()}E(a|0);x()}function Qba(a){var b=0,c=0,d=0,e=0;a:{if(!a){break a}c=i[a>>2];if(!c){break a}Cb(c);i[a>>2]=0}i[114610]=0;K(81);c=i[114610];i[114610]=0;e=a;b:{c:{d:{if((c|0)==1){d=Oa(71348,83452,83464,83568,71504,71608,71556,71448,71436,71752,71720,71688,71676,71324,0)|0;a=277;b=A()|0;if((b|0)==(U(71348)|0)){break d}a=358;if((U(83452)|0)==(b|0)){break d}a=359;if((U(83464)|0)==(b|0)){break d}a=357;if((U(83568)|0)==(b|0)){break d}a=300;if((U(71504)|0)==(b|0)){break d}a=299;if((U(71608)|0)==(b|0)){break d}a=298;if((U(71556)|0)==(b|0)){break d}a=297;if((U(71448)|0)==(b|0)){break d}a=296;if((U(71436)|0)==(b|0)){break d}a=289;if((U(71752)|0)==(b|0)){break d}a=288;if((U(71720)|0)==(b|0)){break d}a=287;if((U(71688)|0)==(b|0)){break d}a=286;if((U(71676)|0)==(b|0)){break d}c=257;a=267;b=(U(71324)|0)==(b|0);d=M(d|0)|0;if(b){break c}break b}x()}d=M(d|0)|0}Oba(e,d);c=a}O();return c}function EK(a,b){var c=0,d=0,e=0,f=0,g=0;d=k[a+480188>>1];a:{if(d>>>0<=255){f=a+1304392|0;while(1){e=o(d,896)+a|0;c=e+1075060|0;b:{if(i[c>>2]){break b}if(!Pi(e+1074984|0)){break a}if(i[c>>2]){break b}if(j[e+1075073|0]&24){break a}}if(j[e+1075073|0]&2){if(!$c(f)){break a}if(!DK(i[f>>2],d&65535)){break a}}d=d+1|0;if((d&65535)!=256){continue}break}}g=8388608;if(b>>>0<=255){b=o(b,896)+a|0;if(!i[b+1075680>>2]){d=65535;if(i[b+1075060>>2]){break a}}g=i[b+1075672>>2]|i[b+1075664>>2]<<9}d=65535;b=k[a+480188>>1];if(b>>>0>255){break a}e=0;while(1){c=o(b,896)+a|0;if(!(i[c+1075680>>2]?0:i[c+1075060>>2])){f=(i[c+1075672>>2]|i[c+1075664>>2]<<9)>>>(i[c+1075072>>2]>>>1&1)|0;c:{d:{if(f>>>0<g>>>0){c=i[c+1075712>>2];break d}if((f|0)!=(g|0)){break c}c=i[c+1075712>>2];if(c>>>0<=e>>>0){break c}}g=f;d=b;e=c}b=b+1|0;if((b&65535)!=256){continue}break a}break}d=b}return d&65535}function oCa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,i=0,l=0,m=0,n=0,p=0,q=0,r=0,s=0,t=0;e=Xa-16|0;Xa=e;g[e+15|0]=4;g[e+14|0]=0;h[e+12>>1]=0;if(d){p=o(c,d);r=(p|0)<1;while(1){if(!r){l=b+n|0;s=p+l|0;while(1){g[e+11|0]=0;NO(a,e+14|0,e+12|0,e+11|0);a:{b:{i=j[e+15|0];if(!i){break b}c=k[e+12>>1];while(1){f=c<<1;c=f&254;h[e+12>>1]=c;f=(f&65534)>>>0>255;g[e+14|0]=f;if(!c){if(!pe(a,e+10|0)){break b}c=j[e+10|0];f=c>>>7|0;g[e+14|0]=f;c=c<<1&254|1;h[e+12>>1]=c}m=j[e+11|0]<<1|f;g[e+11|0]=m;i=i+ -1|0;if(i&255){continue}break}break a}m=j[e+11|0]}c=1;i=m&255;c:{if(i>>>0<4){break c}f=7;while(1){c=f;q=c&255;if(q>>>0<2){break c}f=c+ -1|0;if(!(i&1<<q)){continue}break}}g[e+15|0]=(j[e+15|0]+c&254)>>>1;c=m&1;g[e+14|0]=c;c=(c+ -1^(m&254)>>>1)+t|0;g[e+11|0]=c;g[l|0]=c;t=j[e+11|0];l=d+l|0;if(l>>>0<s>>>0){continue}break}}n=n+1|0;if((n|0)!=(d|0)){continue}break}}Xa=e+16|0}function kxa(a,b,c){var d=0,e=0,f=0,h=0,i=0,k=0;d=Xa-16|0;Xa=d;h=1;f=a;e=id(b);if((e|0)==252){h=id(b);e=id(b)}g[f|0]=(e+ -1&255)>>>0<60?e+36|0:0;nn(d+8|0,b);b=Nc(d+8|0);f=yf(d+8|0);e=li(d+8|0);g[a+1|0]=j[d+8|0];g[d+7|0]=j[b|0]&15;g[d+6|0]=j[b|0]>>>4;g[d+5|0]=j[f|0];g[d+4|0]=j[e|0];TM(d+7|0,d+5|0,c);TM(d+6|0,d+4|0,c);a:{b:{c:{d:{e=j[d+7|0];c=(e|0)!=10;b=j[d+6|0];if(!(c|(b|0)!=10)){g[d+7|0]=0;i=d,k=Vm((j[d+4|0]|j[d+5|0]<<8)>>>6|0),g[i+5|0]=k;break d}if(!c){i=d,k=Vm(j[d+5|0]<<2),g[i+5|0]=k;break d}if((b|0)==10){i=d,k=Vm(j[d+4|0]<<2),g[i+4|0]=k;break d}if((b|0)!=(e|0)){break d}g[d+6|0]=0;break c}b=j[d+6|0];if((b|0)==13){break b}if(b){break a}e=j[d+7|0]}if((e&255)==13){break a}}Sg(d+7|0,d+6|0);Sg(d+5|0,d+4|0)}Dw(d+6|0,d+4|0,d+7|0,d+5|0);Cw(d,d+7|0,d+5|0,d+6|0,d+4|0);g[a+2|0]=j[d+7|0];g[a+4|0]=j[d+5|0];g[a+3|0]=j[d+6|0];g[a+5|0]=j[d+4|0];Xa=d+16|0;return h}function tv(a){var b=0,c=0,d=0,e=0,f=0,g=0;gNa(+a);e=dNa(1)|0;dNa(0)|0;b=e;e=b>>>31|0;a:{b:{c:{d:{d=a;e:{f:{b=b&2147483647;g:{if(b>>>0>=1082532651){gNa(+a);b=dNa(1)|0;b=b&2147483647;if((b|0)==2146435072&dNa(0)>>>0>0|b>>>0>2146435072){return a}if(!(a>709.782712893384^1)){return a*8.98846567431158e+307}if(!(a<-745.1332191019411)|a<-708.3964185322641^1){break g}break b}if(b>>>0<1071001155){break d}if(b>>>0<1072734898){break f}}a=a*1.4426950408889634+n[(e<<3)+52208>>3];if(q(a)<2147483648){b=~~a;break e}b=-2147483648;break e}b=(e^1)-e|0}c=+(b|0);a=d+c*-.6931471803691238;f=c*1.9082149292705877e-10;d=a-f;break c}if(b>>>0<=1043333120){break a}b=0;d=a}c=d;g=a;c=c*c;a=d-c*(c*(c*(c*(c*4.1381367970572385e-8+ -16533902205465252e-22)+6613756321437934e-20)+ -.0027777777777015593)+.16666666666666602);c=g+(d*a/(2-a)-f)+1;if(!b){break b}c=yh(c,b)}return c}return a+1}function sca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=Xa-32|0;Xa=e;i[114610]=0;L(2015,a|0);d=i[114610];i[114610]=0;a:{b:{c:{d:{e:{f:{g:{if((d|0)==1){break g}i[114610]=0;L(2041,b|0);d=i[114610];i[114610]=0;if((d|0)==1){break g}i[114610]=0;L(2041,c|0);d=i[114610];i[114610]=0;if((d|0)==1){break g}d=i[a+24>>2];i[114610]=0;b=C(85,e+16|0,b|0)|0;f=i[114610];i[114610]=0;if((f|0)==1){break g}i[114610]=0;c=C(85,e|0,c|0)|0;f=i[114610];i[114610]=0;if((f|0)==1){break f}i[114610]=0;J(2081,d|0,b|0,c|0,1);d=i[114610];i[114610]=0;if((d|0)==1){break e}eb(c);eb(b);b=1;break b}d=H(0)|0;A()|0;break c}d=H(0)|0;A()|0;break d}d=H(0)|0;A()|0;eb(c)}eb(b)}M(d|0)|0;b=0;i[114610]=0;J(1989,37031,a|0,0,0);a=i[114610];i[114610]=0;if((a|0)==1){break a}O()}Xa=e+32|0;return b|0}a=B()|0;A()|0;i[114610]=0;K(20);b=i[114610];i[114610]=0;if((b|0)!=1){E(a|0);x()}a=H(0)|0;A()|0;gb(a);x()}function Mca(a,b){a=a|0;b=b|0;var c=0,d=0;d=Xa-16|0;Xa=d;i[114610]=0;L(2015,a|0);c=i[114610];i[114610]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{if((c|0)!=1){c=i[a+24>>2];i[114610]=0;D(2061,d|0,c|0);c=i[114610];i[114610]=0;if((c|0)==1){break i}if(cc(d)>>>0<2147483647){break h}c=P(8)|0;i[114610]=0;C(2062,c|0,36344)|0;b=i[114610];i[114610]=0;if((b|0)==1){break g}i[114610]=0;G(2009,c|0,71676,265);b=i[114610];i[114610]=0;if((b|0)!=1){break b}b=H(0)|0;A()|0;break f}b=H(0)|0;A()|0;break e}b=H(0)|0;A()|0;break e}a=34133;j:{if((b|0)<0){break j}a=34133;if((cc(d)|0)<=(b|0)){break j}a=xb(Yc(d,b))}b=Ed(a);Sc(d);break d}b=H(0)|0;A()|0;Q(c|0)}Sc(d)}M(b|0)|0;b=0;i[114610]=0;J(1989,36359,a|0,0,0);a=i[114610];i[114610]=0;if((a|0)==1){break c}O()}Xa=d+16|0;return b|0}a=B()|0;A()|0;i[114610]=0;K(20);b=i[114610];i[114610]=0;if((b|0)!=1){break a}a=H(0)|0;A()|0;gb(a)}x()}E(a|0);x()}function Lca(a,b){a=a|0;b=b|0;var c=0,d=0;d=Xa-16|0;Xa=d;i[114610]=0;L(2015,a|0);c=i[114610];i[114610]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{if((c|0)!=1){c=i[a+24>>2];i[114610]=0;D(2063,d|0,c|0);c=i[114610];i[114610]=0;if((c|0)==1){break i}if(cc(d)>>>0<2147483647){break h}c=P(8)|0;i[114610]=0;C(2062,c|0,36344)|0;b=i[114610];i[114610]=0;if((b|0)==1){break g}i[114610]=0;G(2009,c|0,71676,265);b=i[114610];i[114610]=0;if((b|0)!=1){break b}b=H(0)|0;A()|0;break f}b=H(0)|0;A()|0;break e}b=H(0)|0;A()|0;break e}a=34133;j:{if((b|0)<0){break j}a=34133;if((cc(d)|0)<=(b|0)){break j}a=xb(Yc(d,b))}b=Ed(a);Sc(d);break d}b=H(0)|0;A()|0;Q(c|0)}Sc(d)}M(b|0)|0;b=0;i[114610]=0;J(1989,36391,a|0,0,0);a=i[114610];i[114610]=0;if((a|0)==1){break c}O()}Xa=d+16|0;return b|0}a=B()|0;A()|0;i[114610]=0;K(20);b=i[114610];i[114610]=0;if((b|0)!=1){break a}a=H(0)|0;A()|0;gb(a)}x()}E(a|0);x()}function Kca(a,b){a=a|0;b=b|0;var c=0,d=0;d=Xa-16|0;Xa=d;i[114610]=0;L(2015,a|0);c=i[114610];i[114610]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{if((c|0)!=1){c=i[a+24>>2];i[114610]=0;D(2064,d|0,c|0);c=i[114610];i[114610]=0;if((c|0)==1){break i}if(cc(d)>>>0<2147483647){break h}c=P(8)|0;i[114610]=0;C(2062,c|0,36344)|0;b=i[114610];i[114610]=0;if((b|0)==1){break g}i[114610]=0;G(2009,c|0,71676,265);b=i[114610];i[114610]=0;if((b|0)!=1){break b}b=H(0)|0;A()|0;break f}b=H(0)|0;A()|0;break e}b=H(0)|0;A()|0;break e}a=34133;j:{if((b|0)<0){break j}a=34133;if((cc(d)|0)<=(b|0)){break j}a=xb(Yc(d,b))}b=Ed(a);Sc(d);break d}b=H(0)|0;A()|0;Q(c|0)}Sc(d)}M(b|0)|0;b=0;i[114610]=0;J(1989,36423,a|0,0,0);a=i[114610];i[114610]=0;if((a|0)==1){break c}O()}Xa=d+16|0;return b|0}a=B()|0;A()|0;i[114610]=0;K(20);b=i[114610];i[114610]=0;if((b|0)!=1){break a}a=H(0)|0;A()|0;gb(a)}x()}E(a|0);x()}function Jca(a,b){a=a|0;b=b|0;var c=0,d=0;d=Xa-16|0;Xa=d;i[114610]=0;L(2015,a|0);c=i[114610];i[114610]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{if((c|0)!=1){c=i[a+24>>2];i[114610]=0;D(2065,d|0,c|0);c=i[114610];i[114610]=0;if((c|0)==1){break i}if(cc(d)>>>0<2147483647){break h}c=P(8)|0;i[114610]=0;C(2062,c|0,36344)|0;b=i[114610];i[114610]=0;if((b|0)==1){break g}i[114610]=0;G(2009,c|0,71676,265);b=i[114610];i[114610]=0;if((b|0)!=1){break b}b=H(0)|0;A()|0;break f}b=H(0)|0;A()|0;break e}b=H(0)|0;A()|0;break e}a=34133;j:{if((b|0)<0){break j}a=34133;if((cc(d)|0)<=(b|0)){break j}a=xb(Yc(d,b))}b=Ed(a);Sc(d);break d}b=H(0)|0;A()|0;Q(c|0)}Sc(d)}M(b|0)|0;b=0;i[114610]=0;J(1989,36453,a|0,0,0);a=i[114610];i[114610]=0;if((a|0)==1){break c}O()}Xa=d+16|0;return b|0}a=B()|0;A()|0;i[114610]=0;K(20);b=i[114610];i[114610]=0;if((b|0)!=1){break a}a=H(0)|0;A()|0;gb(a)}x()}E(a|0);x()}function Ica(a,b){a=a|0;b=b|0;var c=0,d=0;d=Xa-16|0;Xa=d;i[114610]=0;L(2015,a|0);c=i[114610];i[114610]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{if((c|0)!=1){c=i[a+24>>2];i[114610]=0;D(2066,d|0,c|0);c=i[114610];i[114610]=0;if((c|0)==1){break i}if(cc(d)>>>0<2147483647){break h}c=P(8)|0;i[114610]=0;C(2062,c|0,36344)|0;b=i[114610];i[114610]=0;if((b|0)==1){break g}i[114610]=0;G(2009,c|0,71676,265);b=i[114610];i[114610]=0;if((b|0)!=1){break b}b=H(0)|0;A()|0;break f}b=H(0)|0;A()|0;break e}b=H(0)|0;A()|0;break e}a=34133;j:{if((b|0)<0){break j}a=34133;if((cc(d)|0)<=(b|0)){break j}a=xb(Yc(d,b))}b=Ed(a);Sc(d);break d}b=H(0)|0;A()|0;Q(c|0)}Sc(d)}M(b|0)|0;b=0;i[114610]=0;J(1989,36485,a|0,0,0);a=i[114610];i[114610]=0;if((a|0)==1){break c}O()}Xa=d+16|0;return b|0}a=B()|0;A()|0;i[114610]=0;K(20);b=i[114610];i[114610]=0;if((b|0)!=1){break a}a=H(0)|0;A()|0;gb(a)}x()}E(a|0);x()}function Hca(a,b){a=a|0;b=b|0;var c=0,d=0;d=Xa-16|0;Xa=d;i[114610]=0;L(2015,a|0);c=i[114610];i[114610]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{if((c|0)!=1){c=i[a+24>>2];i[114610]=0;D(2067,d|0,c|0);c=i[114610];i[114610]=0;if((c|0)==1){break i}if(cc(d)>>>0<2147483647){break h}c=P(8)|0;i[114610]=0;C(2062,c|0,36344)|0;b=i[114610];i[114610]=0;if((b|0)==1){break g}i[114610]=0;G(2009,c|0,71676,265);b=i[114610];i[114610]=0;if((b|0)!=1){break b}b=H(0)|0;A()|0;break f}b=H(0)|0;A()|0;break e}b=H(0)|0;A()|0;break e}a=34133;j:{if((b|0)<0){break j}a=34133;if((cc(d)|0)<=(b|0)){break j}a=xb(Yc(d,b))}b=Ed(a);Sc(d);break d}b=H(0)|0;A()|0;Q(c|0)}Sc(d)}M(b|0)|0;b=0;i[114610]=0;J(1989,36520,a|0,0,0);a=i[114610];i[114610]=0;if((a|0)==1){break c}O()}Xa=d+16|0;return b|0}a=B()|0;A()|0;i[114610]=0;K(20);b=i[114610];i[114610]=0;if((b|0)!=1){break a}a=H(0)|0;A()|0;gb(a)}x()}E(a|0);x()}function cF(a,b,c,d){var e=0,f=0,g=0,h=p(0),i=0,j=p(0),k=0,l=p(0),n=p(0),o=p(0),q=0;e=Xa-96|0;Xa=e;if((d|0)>=1){while(1){m[e+48>>2]=-m[a>>2];m[e>>2]=m[a+68>>2];f=0;while(1){g=f<<3;i=f<<4;j=m[(i|8)+a>>2];h=m[(i|4)+a>>2];m[(e+48|0)+(g|4)>>2]=j+h;k=f<<1;m[(8-k<<2)+e>>2]=h-j;j=m[(a+i|0)+16>>2];h=m[(i|12)+a>>2];m[(7-k<<2)+e>>2]=j-h;m[(e+g|0)+56>>2]=-p(h+j);f=f+1|0;if((f|0)!=4){continue}break}bF(e+48|0);bF(e);m[e+4>>2]=-m[e+4>>2];m[e+12>>2]=-m[e+12>>2];m[e+20>>2]=-m[e+20>>2];m[e+28>>2]=-m[e+28>>2];i=0;while(1){f=i<<2;g=f+b|0;j=m[g>>2];k=g;h=m[f+48880>>2];l=m[f+(e+48|0)>>2];n=m[e+f>>2];g=f+36|0;o=m[g+48880>>2];m[k>>2]=p(h*l)-p(n*o);k=a+f|0;f=c+f|0;g=c+g|0;h=p(p(h*n)+p(o*l));m[k>>2]=p(j*m[f>>2])-p(m[g>>2]*h);m[(17-i<<2)+a>>2]=p(m[f>>2]*h)+p(j*m[g>>2]);i=i+1|0;if((i|0)!=9){continue}break}b=b+36|0;a=a+72|0;q=q+1|0;if((q|0)!=(d|0)){continue}break}}Xa=e+96|0}function KU(a,b,c,d){var e=0,f=0,h=0,k=0,m=0,n=0,o=0,p=0;e=Xa-32|0;Xa=e;g[e+24|0]=j[a|0];g[e+25|0]=j[a+1|0];g[e+26|0]=j[a+2|0];g[e+27|0]=j[a+3|0];f=MA(e+8|0);b=a+b|0;i[f+12>>2]=b+ -4;i[f+8>>2]=a;si(f,j[b+ -1|0]);a:{if(!d){break a}a=d;while(1){if(!si(f,1)){i[e+4>>2]=1;while(1){b=si(f,2);i[e+4>>2]=b+i[e+4>>2];if((b|0)==3){continue}break}kc(e+4|0,a);b=0;if(i[e+4>>2]){while(1){a=a+ -1|0;o=c+a|0,p=si(f,8),g[o|0]=p;b=b+1|0;if(b>>>0<l[e+4>>2]){continue}break}}if(!a){break a}}b=si(f,2);i[e+4>>2]=b+2;b:{if((b|0)==3){b=f;k=b;h=7;c:{if(!si(b,1)){break c}h=j[Nb(e+24|0,3)|0]}h=si(k,h);while(1){b=si(f,3);i[e+4>>2]=b+i[e+4>>2];if((b|0)==7){continue}break}break b}h=si(f,j[Nb(e+24|0,b)|0])}kc(e+4|0,a);k=0;m=i[e+4>>2];if(m){while(1){b=0;n=a+h|0;if(n>>>0<d>>>0){b=j[c+n|0]}a=a+ -1|0;g[c+a|0]=b;k=k+1|0;if((m|0)!=(k|0)){continue}break}}if(a){continue}break}}Xa=e+32|0}function vH(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=p(0);b=Xa-32|0;Xa=b;e=i[a+20>>2];a:{if(!e){break a}if(rc(e+4|0)>>>0<4){break a}ui(b+8|0,i[a+20>>2]+4|0);e=Ega(b+16|0,b+8|0);i[114610]=0;d=F(390,e|0)|0;c=i[114610];i[114610]=0;b:{if((c|0)!=1){if(d){break b}d=i[i[a>>2]+40>>2];i[114610]=0;d=F(d|0,a|0)|0;c=i[114610];i[114610]=0;c:{if((c|0)==1){break c}if(rc(i[a+20>>2]+4|0)+ -4>>>0<d<<2>>>0){break b}c=i[i[a>>2]+168>>2];i[114610]=0;D(c|0,a|0,-1);c=i[114610];i[114610]=0;if((c|0)==1){break c}if(d){c=0;while(1){i[114610]=0;g=p(ma(703,e|0));f=i[114610];i[114610]=0;if((f|0)==1){break c}f=i[i[a>>2]+44>>2];i[114610]=0;ka(f|0,a|0,c|0,p(g));f=i[114610];i[114610]=0;if((f|0)==1){break c}c=c+1|0;if((d|0)!=(c|0)){continue}break}}d=i[i[a>>2]+172>>2];i[114610]=0;L(d|0,a|0);a=i[114610];i[114610]=0;if((a|0)!=1){break b}}}a=B()|0;A()|0;hb(e);E(a|0);x()}hb(e)}Xa=b+32|0}function yla(a,b,c,d){var e=0;e=Xa-48|0;Xa=e;a=Ab(a);a:{b:{b=b+ -1|0;switch(b|0){case 0:case 3:break b;default:break a}}d=d?d+ -1|0:0}c:{d:{e:{f:{g:{h:{i:{j:{switch(b|0){case 0:case 1:g[e+32|0]=0;b=um(c,c+d|0,e+32|0);i[114610]=0;I(119,a|0,c|0,b|0)|0;b=i[114610];i[114610]=0;if((b|0)!=1){break i}b=B()|0;A()|0;break c;case 2:case 3:break j;default:break i}}i[114610]=0;I(119,a|0,c|0,c+d|0)|0;b=i[114610];i[114610]=0;if((b|0)==1){break h}Zka(ld(a),Ye(a),ld(a));i[114610]=0;c=C(120,e+16|0,a|0)|0;b=i[114610];i[114610]=0;if((b|0)==1){break g}i[114610]=0;d=C(85,e|0,6640)|0;b=i[114610];i[114610]=0;if((b|0)==1){break f}i[114610]=0;G(121,e+32|0,c|0,d|0);b=i[114610];i[114610]=0;if((b|0)==1){break e}mb(a,e+32|0);eb(e+32|0);eb(d);eb(c)}Xa=e+48|0;return}b=B()|0;A()|0;break c}b=B()|0;A()|0;break c}b=B()|0;A()|0;break d}b=B()|0;A()|0;eb(d)}eb(c)}eb(a);E(b|0);x()}function nK(a,b,c){var d=0,e=0,f=0;e=Xa-16|0;Xa=e;a:{if(i[a+480180>>2]==4){d=j[b+833|0];if(c){g[b+833|0]=d&15|c<<4;break a}c=(d&240)>>>4|0;break a}if(i[a+480180>>2]!=1048576){break a}if(c){g[b+833|0]=c;break a}c=j[b+833|0]}b:{if(!(g[b+872|0]&1)|!(c&255)){break b}d=i[b+700>>2];if(!d){break b}c:{if(!(j[a+480208|0]&16)){break c}d=i[b+700>>2];if(i[a+480180>>2]==4){break c}c=kx(a,c&15);f=XMa(c,c>>31,d,d>>31)+32768|0;c=_a;c=gc(YMa(f,f>>>0<32768?c+1|0:c,65536,0),_a);i[b+700>>2]=c;if((c|0)!=(d|0)){break b}a=a+1074308|0;kb(e+8|0,a,7);if(!(!ib(e+8|0)|i[b+700>>2]>=2147483647)){i[b+700>>2]=i[b+700>>2]+1;break b}kb(e+8|0,a,7);if(ib(e+8|0)){break b}a=i[b+700>>2];if((a|0)<2){break b}i[b+700>>2]=a+ -1;break b}c=d-((c&255)<<2)|0;i[b+700>>2]=c;if((c|0)>0){break b}i[b+700>>2]=1;if(i[a+480180>>2]!=2){break b}i[b+696>>2]=0;i[b+88>>2]=i[b+88>>2]|2101248}Xa=e+16|0}function Yua(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0;g=Xa-16|0;Xa=g;k=i[a+40>>2];l=i[a+36>>2];n=i[a+16>>2];j=i[a+4>>2];e=j;f=i[a>>2];i[g+8>>2]=f;i[g+12>>2]=e;j=i[a+12>>2];i[g>>2]=i[a+8>>2];i[g+4>>2]=j;a:{if(!d){j=k>>12;m=l>>12;break a}while(1){j=i[a+32>>2];l=i[a+28>>2]+l|0;m=l>>12;e=(e<<1)+n|0;f=(((f>>>16|0)+4&131064)<<1)+b|0;e=(((((o(h[e+4>>1],h[f+34>>1])+o(h[e+2>>1],h[f+32>>1])|0)+o(h[e+6>>1],h[f+36>>1])|0)+o(h[e+8>>1],h[f+38>>1])|0)/2|0)+((((o(h[e+ -4>>1],h[f+26>>1])+o(h[e+ -6>>1],h[f+24>>1])|0)+o(h[e+ -2>>1],h[f+28>>1])|0)+o(h[e>>1],h[f+30>>1])|0)/2|0)|0)/16384|0;i[c>>2]=i[c>>2]+o(m,e);k=j+k|0;j=k>>12;i[c+4>>2]=i[c+4>>2]+o(e,j);zb(g+8|0,g);d=d+ -1|0;if(d){c=c+8|0;f=i[g+8>>2];e=i[g+12>>2];continue}break}f=i[g+8>>2];e=i[g+12>>2]}i[a+40>>2]=k;i[a+20>>2]=m;i[a+36>>2]=l;i[a+24>>2]=j;i[a>>2]=f;i[a+4>>2]=e;Xa=g+16|0}function LJ(a,b){var c=0;c=Xa-16|0;Xa=c;a=gx(a);a:{b:{c:{switch(b+ -1|0){default:if((b|0)!=16777216){break b}tb(a,7,1);tb(a,9,1);tb(a,10,1);tb(a,13,1);tb(a,15,1);tb(a,16,1);tb(a,17,1);tb(a,18,1);tb(a,20,1);tb(a,21,1);tb(a,24,1);tb(a,25,1);tb(a,26,1);tb(a,28,1);tb(a,30,1);tb(a,31,1);tb(a,33,1);tb(a,34,1);tb(a,39,1);tb(a,41,1);tb(a,44,1);tb(a,46,1);tb(a,45,1);tb(a,47,1);tb(a,48,1);tb(a,50,1);tb(a,99,1);tb(a,102,1);tb(a,104,1);tb(a,105,1);tb(a,108,1);break a;case 1:cx(c,2);b=i[c+12>>2];i[a+8>>2]=i[c+8>>2];i[a+12>>2]=b;b=i[c+4>>2];i[a>>2]=i[c>>2];i[a+4>>2]=b;ng(a,107);break a;case 3:cx(c,4);b=i[c+12>>2];i[a+8>>2]=i[c+8>>2];i[a+12>>2]=b;b=i[c+4>>2];i[a>>2]=i[c>>2];i[a+4>>2]=b;ng(a,4);break a;case 2:break b;case 0:break c}}tb(a,88,1);break a}cx(c,b);b=i[c+12>>2];i[a+8>>2]=i[c+8>>2];i[a+12>>2]=b;b=i[c+4>>2];i[a>>2]=i[c>>2];i[a+4>>2]=b}Xa=c+16|0}function Zua(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,j=0,k=0,l=0,m=0,n=0,p=0;j=Xa-16|0;Xa=j;l=i[a+40>>2];m=i[a+36>>2];p=i[a+16>>2];k=i[a+4>>2];e=k;f=i[a>>2];i[j+8>>2]=f;i[j+12>>2]=e;k=i[a+12>>2];i[j>>2]=i[a+8>>2];i[j+4>>2]=k;a:{if(!d){k=l>>12;n=m>>12;break a}while(1){k=i[a+32>>2];m=i[a+28>>2]+m|0;n=m>>12;e=e+p|0;f=(((f>>>16|0)+4&131064)<<1)+b|0;e=(((((o(g[e+2|0],h[f+34>>1])+o(g[e+1|0],h[f+32>>1])|0)+o(g[e+3|0],h[f+36>>1])|0)+o(g[e+4|0],h[f+38>>1])<<8)/2|0)+((((o(g[e+ -2|0],h[f+26>>1])+o(g[e+ -3|0],h[f+24>>1])|0)+o(g[e+ -1|0],h[f+28>>1])|0)+o(g[e|0],h[f+30>>1])<<8)/2|0)|0)/16384|0;i[c>>2]=i[c>>2]+o(n,e);l=k+l|0;k=l>>12;i[c+4>>2]=i[c+4>>2]+o(e,k);zb(j+8|0,j);d=d+ -1|0;if(d){c=c+8|0;f=i[j+8>>2];e=i[j+12>>2];continue}break}f=i[j+8>>2];e=i[j+12>>2]}i[a+40>>2]=l;i[a+20>>2]=n;i[a+36>>2]=m;i[a+24>>2]=k;i[a>>2]=f;i[a+4>>2]=e;Xa=j+16|0}function ky(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=Xa-80|0;Xa=d;a:{b:{e=i[a+4>>2];if(e>>>0<b>>>0){h=tf(d+72|0);g=us(a);f=b-e|0;if(!(g>>>0<f>>>0|e>>>0>g-f>>>0)){Uj(d+56|0,a);b=i[d+60>>2];i[d+72>>2]=i[d+56>>2];i[d+76>>2]=b;i[a+4>>2]=i[a+4>>2]+f;break b}fb(a);b=jy(d+56|0);e=i[a+4>>2];i[114610]=0;e=C(933,a|0,e+f|0)|0;g=i[114610];i[114610]=0;c:{if((g|0)==1){break c}i[114610]=0;D(934,b|0,e|0);e=i[114610];i[114610]=0;if((e|0)==1){break c}i[b+4>>2]=i[a+4>>2]+f;Wi(d+40|0,a);Uj(d+32|0,a);Wi(d+24|0,b);i[114610]=0;e=i[d+44>>2];i[d+8>>2]=i[d+40>>2];i[d+12>>2]=e;e=i[d+36>>2];i[d>>2]=i[d+32>>2];i[d+4>>2]=e;J(935,d+48|0,d+8|0,d|0,d+24|0);e=i[114610];i[114610]=0;if((e|0)==1){break c}e=i[d+52>>2];i[d+72>>2]=i[d+48>>2];i[d+76>>2]=e;iy(a,b);Td(b);break b}a=B()|0;A()|0;Td(b);E(a|0);x()}i[a+4>>2]=b;break a}Bp(td(d+16|0,h),f,c)}Xa=d+80|0}function QR(a,b){var c=0,d=0;d=j[a|0];if(d>>>0>=36){g[a|0]=0;return}c=j[d+12560|0];g[a|0]=c;a:{b:{c:{d:{e:{f:{if(c>>>0<=16){if(c+ -6>>>0>=2){if((c|0)==1){break f}if((c|0)!=11){break a}}c=j[b|0];a=c&240;if(!a|(a|0)==240|(c&15)==15){break a}g[b|0]=a;return}switch(c+ -17|0){case 1:case 3:case 4:case 5:break a;case 0:break c;case 2:break d;case 6:break e;default:break b}}if(j[b|0]){break a}g[a|0]=0;return}a=j[b|0];if(a>>>0<=64){g[b|0]=a<<1;return}g[b|0]=128;return}g:{h:{i:{j:{c=j[b|0];switch((c&240)+ -48>>>4|0){case 4:break g;case 2:break h;case 1:break i;case 0:break j;default:break a}}g[a|0]=20;g[b|0]=159;return}g[a|0]=20;g[b|0]=192;return}if(c&14){break a}g[a|0]=21;g[b|0]=(j[b|0]!=80)<<6;return}g[a|0]=20;g[b|0]=j[b|0]&15|160;return}if(j[b|0]>31){break a}g[a|0]=16;return}if((c|0)!=31){break a}g[b|0]=(d<<5|j[b|0]<<24>>>27)^128}}function LG(a,b,c,d,e,f,g,h,j){a=a|0;b=b|0;c=+c;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0;k=Xa+ -64|0;Xa=k;i[k+60>>2]=e;e=i[a+4>>2];l=i[a>>2];a=i[a+8>>2];i[114610]=0;i[k+40>>2]=b;i[k+52>>2]=a;i[k+44>>2]=l;i[k+48>>2]=e;i[k+20>>2]=d?d:1997;G(1998,k+24|0,k+20|0,k+60|0);a=i[114610];i[114610]=0;a:{b:{c:{d:{if((a|0)!=1){b=eo(k+32|0,k+24|0);i[114610]=0;a=i[k+52>>2];i[k+8>>2]=i[k+48>>2];i[k+12>>2]=a;a=i[k+44>>2];i[k>>2]=i[k+40>>2];i[k+4>>2]=a;c=+ja(1999,k|0,+c,b|0);a=i[114610];i[114610]=0;if((a|0)==1){break d}Ec(b);Ec(k+24|0);break b}a=H(0)|0;A()|0;break c}a=H(0)|0;A()|0;Ec(b);Ec(k+24|0)}M(a|0)|0;i[114610]=0;X(2e3,34488,d|0,i[k+60>>2],f|0,g|0,h|0,j|0);a=i[114610];i[114610]=0;if((a|0)==1){break a}O();c=0}Xa=k- -64|0;return+c}a=B()|0;A()|0;i[114610]=0;K(20);b=i[114610];i[114610]=0;if((b|0)!=1){E(a|0);x()}a=H(0)|0;A()|0;gb(a);x()}function i9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=Xa-32|0;Xa=d;e=Mg(a);f=b+24|0;a=i[f>>2];i[114610]=0;a=F(2194,a+484344|0)|0;c=i[114610];i[114610]=0;a:{b:{c:{if((c|0)==1){break c}i[114610]=0;D(1532,e|0,a|0);a=i[114610];i[114610]=0;if((a|0)==1){break c}a=0;d:{e:{f:{g:{while(1){c=i[f>>2];i[114610]=0;c=F(2194,c+484344|0)|0;g=i[114610];i[114610]=0;if((g|0)==1){break b}if(a>>>0>=c>>>0){break d}c=Fb(i[f>>2]+484344|0,a);i[114610]=0;D(2191,d|0,c|0);c=i[114610];i[114610]=0;if((c|0)!=1){i[114610]=0;G(2185,d+16|0,b|0,d|0);c=i[114610];i[114610]=0;if((c|0)==1){break g}i[114610]=0;D(1534,e|0,d+16|0);c=i[114610];i[114610]=0;if((c|0)==1){break f}a=a+1|0;eb(d+16|0);eb(d);continue}break}a=B()|0;A()|0;break a}a=B()|0;A()|0;break e}a=B()|0;A()|0;eb(d+16|0)}eb(d);break a}Xa=d+32|0;return}a=B()|0;A()|0;break a}a=B()|0;A()|0}Sc(e);E(a|0);x()}function Gea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,n=p(0),o=0,q=p(0),r=p(0),s=p(0),t=p(0),u=p(0),v=p(0),w=p(0),x=p(0),y=p(0);j=Xa-16|0;Xa=j;k=a+44|0;if(Wg(k)){h=ud(k,0);i[j+8>>2]=h;l=ud(k,1);i[j+12>>2]=l;e=Pc(k,0);i[j>>2]=e;f=Pc(k,1);i[j+4>>2]=f;a:{if(m[a+4216>>2]!=p(.5)){if(!d){break a}h=d;while(1){f=0;l=1;while(1){f=f<<2;e=f+(j+8|0)|0;g=i[e>>2];i[e>>2]=g+4;e=a+f|0;o=e+4248|0;s=m[o>>2];n=m[g>>2];t=m[a+4228>>2];u=m[a+4224>>2];v=m[a+4220>>2];w=m[a+4236>>2];x=m[a+4232>>2];g=e+4240|0;q=m[g>>2];m[o>>2]=q;m[g>>2]=n;g=e+4264|0;y=m[g>>2];e=e+4256|0;r=m[e>>2];m[g>>2]=r;n=p(p(p(p(q*u)+p(v*n))+p(s*t))-p(p(y*w)+p(r*x)));m[e>>2]=n;f=f+j|0;e=i[f>>2];i[f>>2]=e+4;m[e>>2]=n;e=l;l=0;f=1;if(e){continue}break}h=h+ -1|0;if(h){continue}break}break a}g=h;h=d<<2;Tb(e,g,h);Tb(f,l,h)}Oh(a,b,c,Pc(k,0),Pc(k,1),d)}Xa=j+16|0}function _3(a,b){var c=0,d=0,e=0,f=0,g=0;c=Xa-32|0;Xa=c;i[c+28>>2]=0;a:{b:{if(j[Gi(c+24|0,a,0)|0]){fc(c+16|0,i[i[a>>2]+ -12>>2]+a|0);i[114610]=0;e=F(2316,c+16|0)|0;d=i[114610];i[114610]=0;c:{d:{if((d|0)==1){break d}d=am(c+8|0,a);f=ak(c);g=i[i[a>>2]+ -12>>2];f=i[f>>2];d=i[d>>2];i[114610]=0;Y(2317,e|0,d|0,f|0,a+g|0,c+28|0,b|0)|0;b=i[114610];i[114610]=0;if((b|0)==1){break d}ub(c+16|0);break c}b=H(0)|0;A()|0;ub(c+16|0);M(b|0)|0;b=i[c+28>>2]|1;i[c+28>>2]=b;Ei(i[i[a>>2]+ -12>>2]+a|0,b);b=i[i[a>>2]+ -12>>2];i[114610]=0;b=i[(a+b|0)+20>>2];e=i[114610];i[114610]=0;e:{if((e|0)!=1){if(!(b&1)){break e}i[114610]=0;K(81);a=i[114610];i[114610]=0;if((a|0)!=1){break a}}a=B()|0;A()|0;i[114610]=0;K(20);b=i[114610];i[114610]=0;if((b|0)==1){break b}E(a|0);x()}O()}ag(i[i[a>>2]+ -12>>2]+a|0,i[c+28>>2])}Xa=c+32|0;return a}a=H(0)|0;A()|0;gb(a)}x()}function V3(a,b){var c=0,d=0,e=0,f=0,g=0;c=Xa-32|0;Xa=c;i[c+28>>2]=0;a:{b:{if(j[Gi(c+24|0,a,0)|0]){fc(c+16|0,i[i[a>>2]+ -12>>2]+a|0);i[114610]=0;e=F(2316,c+16|0)|0;d=i[114610];i[114610]=0;c:{d:{if((d|0)==1){break d}d=am(c+8|0,a);f=ak(c);g=i[i[a>>2]+ -12>>2];f=i[f>>2];d=i[d>>2];i[114610]=0;Y(2320,e|0,d|0,f|0,a+g|0,c+28|0,b|0)|0;b=i[114610];i[114610]=0;if((b|0)==1){break d}ub(c+16|0);break c}b=H(0)|0;A()|0;ub(c+16|0);M(b|0)|0;b=i[c+28>>2]|1;i[c+28>>2]=b;Ei(i[i[a>>2]+ -12>>2]+a|0,b);b=i[i[a>>2]+ -12>>2];i[114610]=0;b=i[(a+b|0)+20>>2];e=i[114610];i[114610]=0;e:{if((e|0)!=1){if(!(b&1)){break e}i[114610]=0;K(81);a=i[114610];i[114610]=0;if((a|0)!=1){break a}}a=B()|0;A()|0;i[114610]=0;K(20);b=i[114610];i[114610]=0;if((b|0)==1){break b}E(a|0);x()}O()}ag(i[i[a>>2]+ -12>>2]+a|0,i[c+28>>2])}Xa=c+32|0;return a}a=H(0)|0;A()|0;gb(a)}x()}function S3(a,b){var c=0,d=0,e=0,f=0,g=0;c=Xa-32|0;Xa=c;i[c+28>>2]=0;a:{b:{if(j[Gi(c+24|0,a,0)|0]){fc(c+16|0,i[i[a>>2]+ -12>>2]+a|0);i[114610]=0;e=F(2316,c+16|0)|0;d=i[114610];i[114610]=0;c:{d:{if((d|0)==1){break d}d=am(c+8|0,a);f=ak(c);g=i[i[a>>2]+ -12>>2];f=i[f>>2];d=i[d>>2];i[114610]=0;Y(2321,e|0,d|0,f|0,a+g|0,c+28|0,b|0)|0;b=i[114610];i[114610]=0;if((b|0)==1){break d}ub(c+16|0);break c}b=H(0)|0;A()|0;ub(c+16|0);M(b|0)|0;b=i[c+28>>2]|1;i[c+28>>2]=b;Ei(i[i[a>>2]+ -12>>2]+a|0,b);b=i[i[a>>2]+ -12>>2];i[114610]=0;b=i[(a+b|0)+20>>2];e=i[114610];i[114610]=0;e:{if((e|0)!=1){if(!(b&1)){break e}i[114610]=0;K(81);a=i[114610];i[114610]=0;if((a|0)!=1){break a}}a=B()|0;A()|0;i[114610]=0;K(20);b=i[114610];i[114610]=0;if((b|0)==1){break b}E(a|0);x()}O()}ag(i[i[a>>2]+ -12>>2]+a|0,i[c+28>>2])}Xa=c+32|0;return a}a=H(0)|0;A()|0;gb(a)}x()}function Q3(a,b){var c=0,d=0,e=0,f=0,g=0;c=Xa-32|0;Xa=c;i[c+28>>2]=0;a:{b:{if(j[Gi(c+24|0,a,0)|0]){fc(c+16|0,i[i[a>>2]+ -12>>2]+a|0);i[114610]=0;e=F(2316,c+16|0)|0;d=i[114610];i[114610]=0;c:{d:{if((d|0)==1){break d}d=am(c+8|0,a);f=ak(c);g=i[i[a>>2]+ -12>>2];f=i[f>>2];d=i[d>>2];i[114610]=0;Y(2322,e|0,d|0,f|0,a+g|0,c+28|0,b|0)|0;b=i[114610];i[114610]=0;if((b|0)==1){break d}ub(c+16|0);break c}b=H(0)|0;A()|0;ub(c+16|0);M(b|0)|0;b=i[c+28>>2]|1;i[c+28>>2]=b;Ei(i[i[a>>2]+ -12>>2]+a|0,b);b=i[i[a>>2]+ -12>>2];i[114610]=0;b=i[(a+b|0)+20>>2];e=i[114610];i[114610]=0;e:{if((e|0)!=1){if(!(b&1)){break e}i[114610]=0;K(81);a=i[114610];i[114610]=0;if((a|0)!=1){break a}}a=B()|0;A()|0;i[114610]=0;K(20);b=i[114610];i[114610]=0;if((b|0)==1){break b}E(a|0);x()}O()}ag(i[i[a>>2]+ -12>>2]+a|0,i[c+28>>2])}Xa=c+32|0;return a}a=H(0)|0;A()|0;gb(a)}x()}function xma(a,b,c){var d=0,e=0,f=0,h=0,k=0;d=Xa-16|0;Xa=d;a:{if(!(j[b+90|0]&4)|(i[a+480208>>2]&2101248)==2101248){break a}b:{if(i[c>>2]<=0){kb(d+8|0,a+1074308|0,21);if(!ib(d+8|0)){break b}}h=5;if(!(i[a+480180>>2]&5)){kb(d+8|0,a+1074308|0,21);h=ib(d+8|0)?5:6}f=Tw(a,j[b+845|0],j[b+840|0]);c:{if((j[b+845|0]&3)!=1){break c}kb(d+8|0,a+1074308|0,89);if(!ib(d+8|0)){break c}f=j[b+839|0];k=j[b+840|0];e=k<<2&124;e=(!(j[b+90|0]&2)|j[a+480209|0]&16?f:j[b+843|0]+f|0)&32?e^127:e;f=k&32?0-e|0:e}e=c;if(i[a+480180>>2]!=131072){c=i[c>>2]+((o(j[b+847|0],f)|0)/(1<<h)|0)|0}else{c=i[c>>2];c=((o(j[b+847|0],o(c,64-f|0))|0)/-8192|0)+c|0}i[e>>2]=c}if(!(i[a+480180>>2]&16777248)|j[a+480208|0]&4?j[a+480209|0]&16:0){break a}kb(d+8|0,a+1074308|0,21);c=ib(d+8|0);a=j[b+846|0];if(c){g[b+840|0]=j[b+840|0]+(a<<2);break a}g[b+840|0]=a+j[b+840|0]}Xa=d+16|0}function C2(a,b,c){var d=0,e=0,f=0,h=0,j=0;j=Xa-16|0;Xa=j;a:{b:{c:{d:{if(a){if(c>>>0>=4){break d}d=c;break c}c=0;a=i[b>>2];d=i[a>>2];if(!d){break a}while(1){f=1;if(d>>>0>=128){h=-1;f=Aj(j+12|0,d,0);if((f|0)==-1){break a}}d=i[a+4>>2];a=a+4|0;c=c+f|0;h=c;if(d){continue}break}break a}f=i[b>>2];d=c;while(1){e=i[f>>2];e:{if(e+ -1>>>0>=127){if(!e){g[a|0]=0;i[b>>2]=0;break b}h=-1;e=Aj(a,e,0);if((e|0)==-1){break a}d=d-e|0;a=a+e|0;break e}g[a|0]=e;d=d+ -1|0;f=i[b>>2];a=a+1|0}f=f+4|0;i[b>>2]=f;if(d>>>0>3){continue}break}}if(d){f=i[b>>2];while(1){e=i[f>>2];f:{if(e+ -1>>>0>=127){if(!e){g[a|0]=0;i[b>>2]=0;break b}h=-1;e=Aj(j+12|0,e,0);if((e|0)==-1){break a}if(d>>>0<e>>>0){break b}Aj(a,i[f>>2],0);d=d-e|0;a=a+e|0;break f}g[a|0]=e;d=d+ -1|0;f=i[b>>2];a=a+1|0}f=f+4|0;i[b>>2]=f;if(d){continue}break}}h=c;break a}h=c-d|0}Xa=j+16|0;return h}function Wha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0;a:{b:{if((Re(a)|0)==(b|0)){if((Re(a+12|0)|0)==(c|0)){break b}}i[114610]=0;D(1641,a|0,b|0);d=i[114610];i[114610]=0;c:{d:{if((d|0)==1){break d}i[114610]=0;e=a+12|0;D(1641,e|0,c|0);d=i[114610];i[114610]=0;if((d|0)==1){break d}i[114610]=0;f=a+24|0;D(1642,f|0,b|0);d=i[114610];i[114610]=0;if((d|0)==1){break d}i[114610]=0;g=a+36|0;D(1642,g|0,c|0);d=i[114610];i[114610]=0;if((d|0)==1){break d}if(b){d=0;while(1){h=ul(a,d);j=vb(f,d),k=h,i[j>>2]=k;d=d+1|0;if((d|0)!=(b|0)){continue}break}}if(c){break c}return 1}b=H(71348)|0;if((A()|0)!=(U(71348)|0)){break a}M(b|0)|0;VH(a);UH(a);b=a+12|0;VH(b);UH(b);b=a+24|0;TH(b);SH(b);a=a+36|0;TH(a);SH(a);O();return 0}a=0;while(1){b=ul(e,a);j=vb(g,a),k=b,i[j>>2]=k;a=a+1|0;if((c|0)!=(a|0)){continue}break}}return 1}E(b|0);x()}function HM(a){a=a|0;var b=0;yb(a,0,288);Tx(a+288|0);Ro(a+800|0);g[a+2|0]=j[18162];b=j[18160]|j[18161]<<8;g[a|0]=b;g[a+1|0]=b>>>8;g[a+34|0]=j[18165];b=j[18163]|j[18164]<<8;g[a+32|0]=b;g[a+33|0]=b>>>8;b=j[18169]|j[18170]<<8|(j[18171]<<16|j[18172]<<24);g[a+99|0]=b;g[a+100|0]=b>>>8;g[a+101|0]=b>>>16;g[a+102|0]=b>>>24;b=j[18166]|j[18167]<<8|(j[18168]<<16|j[18169]<<24);g[a+96|0]=b;g[a+97|0]=b>>>8;g[a+98|0]=b>>>16;g[a+99|0]=b>>>24;b=j[18173]|j[18174]<<8|(j[18175]<<16|j[18176]<<24);g[a+128|0]=b;g[a+129|0]=b>>>8;g[a+130|0]=b>>>16;g[a+131|0]=b>>>24;b=j[18176]|j[18177]<<8|(j[18178]<<16|j[18179]<<24);g[a+131|0]=b;g[a+132|0]=b>>>8;g[a+133|0]=b>>>16;g[a+134|0]=b>>>24;g[a+260|0]=j[18184];b=j[18180]|j[18181]<<8|(j[18182]<<16|j[18183]<<24);g[a+256|0]=b;g[a+257|0]=b>>>8;g[a+258|0]=b>>>16;g[a+259|0]=b>>>24;Cwa(a+288|0);Bwa(a+800|0)}function uD(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0;g=Xa-1040|0;Xa=g;h=i[b>>2];i[g+12>>2]=h;k=a?a:g+16|0;a:{b:{c:{d=a?d:256;if(!d|!h){break c}f=c>>>2|0;l=f>>>0<d>>>0;if(f>>>0<d>>>0?c>>>0<=131:0){break b}while(1){f=l?f:d;c=c-f|0;f=Su(k,g+12|0,f,e);if((f|0)==-1){d=0;h=i[g+12>>2];j=-1;break c}h=(g+16|0)==(k|0);k=h?k:(f<<2)+k|0;j=f+j|0;d=d-(h?0:f)|0;h=i[g+12>>2];if(!d|!h){break c}f=c>>>2|0;l=f>>>0<d>>>0;if(c>>>0>131|f>>>0>=d>>>0){continue}break}break b}if(!h){break a}}if(!d|!c){break a}f=j;while(1){d:{j=Qn(k,h,c,e);e:{if(j+2>>>0<=2){f:{switch(j+1|0){case 1:i[g+12>>2]=0;break e;case 0:break a;default:break f}}i[e>>2]=0;break e}h=i[g+12>>2]+j|0;i[g+12>>2]=h;f=f+1|0;d=d+ -1|0;if(d){break d}}j=f;break a}k=k+4|0;c=c-j|0;j=f;if(c){continue}break}}if(a){i[b>>2]=i[g+12>>2]}Xa=g+1040|0;return j|0}function uM(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,l=0,m=0;e=Xa-32|0;Xa=e;d=c&4;a:{if(!(b&4)){if(!d){break a}g[a+15|0]=j[a+16|0];b=j[a+12|0];g[a+12|0]=b&247;if(!(b&2)){break a}b=j[a+14|0];if(b>>>0<=j[a+13|0]){break a}if(qb(a)>>>0<=b>>>0){break a}while(1){d=hc(a,b);h[d>>1]=k[d>>1]+1;b=b+1|0;if(b>>>0<qb(a)>>>0){continue}break}break a}if(d){break a}b=j[a+14|0];b:{if(j[a+15|0]<=b>>>0){break b}d=j[a+12|0];if(!(d&2)){break b}g[a+12|0]=d&251}if(!(j[a+12|0]&2)|b>>>0<=j[a+13|0]){break a}if(qb(a)>>>0<=b>>>0){break a}d=k[hc(a,j[a+14|0])>>1];f=hc(a,j[a+14|0]+ -1|0);b=j[a+14|0];if((d+ -1|0)>k[f>>1]){b=k[hc(a,b)>>1]+ -1&65535;d=Po(a,b,64,64);l=e,m=Jb(a),i[l+8>>2]=m;l=e,m=Oo(e+8|0,j[a+14|0]),i[l+16>>2]=m;f=Ad(e+24|0,e+16|0);b=ap(e,b,d&255);hua(a,i[f>>2],b);break a}g[a+14|0]=b+ -1}if((c|0)!=16777216){g[a+17|0]=255}Xa=e+32|0}function FJ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;e=Xa-16|0;Xa=e;a:{b:{d=a+484360|0;if(Wb(Db(d))>>>0<=b>>>0){break b}if(Lo(Db(d),b)){break b}while(1){b=b+1|0;c=b&65535;if(Wb(Db(d))>>>0<=c>>>0){break a}if(!Lo(Db(d),b&65535)){continue}break}break a}c=b}if(Wb(Db(d))>>>0>c>>>0){d=a+1074308|0;f=a+1304360|0;c=a+1074984|0;while(1){g[c+819|0]=0;i[c+700>>2]=0;g[c+861|0]=0;g[c+827|0]=0;i[c+708>>2]=0;g[c+841|0]=0;i[c+804>>2]=0;g[c+839|0]=0;g[c+840|0]=0;kb(e+8|0,d,23);if(ib(e+8|0)){h[c+798>>1]=65536;h[c+800>>1]=1}g[c+859|0]=0;c=c+896|0;if((f|0)!=(c|0)){continue}break}EJ(a);c:{if(!(b&65535)){yna(a);break c}h[a+1074440>>1]=b;h[a+1074436>>1]=0;b=a+1074424|0;i[b>>2]=0;i[b+4>>2]=0;i[a+1074432>>2]=0;b=a+1074396|0;i[b>>2]=0;i[b+4>>2]=0;i[a+1074380>>2]=0;i[a+1074392>>2]=i[a+1074416>>2]}i[a+480208>>2]=i[a+480208>>2]&-769}Xa=e+16|0}function Bya(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,m=0;d=Xa-32|0;Xa=d;kd(c,2);g[d+16|0]=j[b+13|0];g[d|0]=64;f=c,m=j[Xb(d+16|0,d)|0]<<2,h[f+30>>1]=m;e=b+14|0;i[c+24>>2]=(j[e|0]|j[e+1|0]<<8)<<1;bk(d,2,b+1|0);oc(d+16|0,d);i[114610]=0;C(370,c+43|0,d+16|0)|0;e=i[114610];i[114610]=0;if((e|0)!=1){eb(d+16|0);e=Ic(a,8,1,0,2);a:{if((j[b|0]&3)!=1){break a}a=b+22|0;i[c>>2]=j[a|0]|j[a+1|0]<<8|(j[a+2|0]<<16|j[a+3|0]<<24);a=b+26|0;i[c+4>>2]=j[a|0]|j[a+1|0]<<8|(j[a+2|0]<<16|j[a+3|0]<<24);a=b+30|0;a=j[a|0]|j[a+1|0]<<8|(j[a+2|0]<<16|j[a+3|0]<<24);i[c+8>>2]=a;if(a>>>0>l[c+4>>2]){i[c+8>>2]=a+ -1}if(j[b|0]&4){h[c+34>>1]=k[c+34>>1]|2}if(j[b|0]&8){h[c+34>>1]=k[c+34>>1]|4}if(!(j[b|0]&16)){break a}mz(e);cj(e,9);i[c>>2]=i[c>>2]>>>1;i[c+4>>2]=i[c+4>>2]>>>1;i[c+8>>2]=i[c+8>>2]>>>1}Xa=d+32|0;return}a=B()|0;A()|0;eb(d+16|0);E(a|0);x()}function ZKa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=Xa-16|0;Xa=d;kd(b,0);i[b>>2]=j[a|0]|j[a+1|0]<<8|(j[a+2|0]<<16|j[a+3|0]<<24);c=ot(a+4|0,a);i[b+4>>2]=j[c|0]|j[c+1|0]<<8|(j[c+2|0]<<16|j[c+3|0]<<24);c=ot(a+8|0,a);i[b+8>>2]=j[c|0]|j[c+1|0]<<8|(j[c+2|0]<<16|j[c+3|0]<<24);c=a+15|0;i[b+24>>2]=(j[c|0]|j[c+1|0]<<8)<<1;if(!(j[c|0]|j[c+1|0]<<8)){i[b+24>>2]=16726}c=a+14|0;e=b,f=(o(hs(g[a+17|0],j[c|0]<<28>>24),i[b+24>>2])>>>0)/8363|0,i[e+24>>2]=f;g[d+15|0]=j[a+18|0];g[d+14|0]=127;e=b,f=(((j[Xb(d+15|0,d+14|0)|0]<<8|64)&65344)>>>0)/127|0,h[e+30>>1]=f;if(j[c|0]>=16){c=j[c|0];h[b+34>>1]=32;h[b+28>>1]=c&240}a=a+19|0;if(j[a|0]&4){h[b+34>>1]=k[b+34>>1]|1}a:{if(!(j[a|0]&8)|l[b+4>>2]>=l[b+8>>2]){break a}h[b+34>>1]=k[b+34>>1]|2;if(j[a|0]&16){h[b+34>>1]=k[b+34>>1]|4}if(!(j[a|0]&64)){break a}h[b+34>>1]=k[b+34>>1]|128}Xa=d+16|0}function Lpa(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,k=0,l=0,m=0,p=0,r=0,s=0,u=0;f=Xa-16|0;Xa=f;r=f,s=o(i[a>>2],$d(a)),i[r+4>>2]=s;kc(f+4|0,c);c=jb(b);k=n[e+8>>3];g=i[f+4>>2];a:{if(!g){break a}e=g;while(1){m=(j[c+4|0]|j[c+5|0]<<8|(j[c+6|0]<<16|j[c+7|0]<<24))&2147483647;eNa(0,j[c|0]|j[c+1|0]<<8|(j[c+2|0]<<16|j[c+3|0]<<24));eNa(1,m|0);k=t(+fNa(),k);c=c+8|0;e=e+ -1|0;if(e){continue}break}if(!g|k==0){break a}p=1/k;c=i[a+20>>2];while(1){a=b;e=j[a+4|0]|j[a+5|0]<<8|(j[a+6|0]<<16|j[a+7|0]<<24);eNa(0,j[a|0]|j[a+1|0]<<8|(j[a+2|0]<<16|j[a+3|0]<<24));eNa(1,e|0);r=f,u=+fNa()*p,n[r+8>>3]=u;mf(f+8|0,-1,1);l=n[f+8>>3]*32768;n[f+8>>3]=l;a=c;l=xd(l);b:{if(q(l)<2147483648){e=~~l;break b}e=-2147483648}r=a,s=Bc(e),h[r>>1]=s;b=b+8|0;c=c+2|0;g=g+ -1|0;if(g){continue}break}}if(d){n[d>>3]=k}Xa=f+16|0;return i[f+4>>2]}function Npa(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,k=p(0),l=p(0),n=p(0),r=0,s=0;f=Xa-16|0;Xa=f;r=f,s=o(i[a>>2],$d(a)),i[r+8>>2]=s;kc(f+8|0,c);c=jb(b);k=m[e+4>>2];e=i[f+8>>2];if(e){while(1){g=j[c|0]|j[c+1|0]<<8|(j[c+2|0]<<16|j[c+3|0]<<24);k=p(t(p(q((eNa(2,g<<24|g<<8&16711680|(g>>>8&65280|g>>>24)),iNa()))),k));c=c+4|0;e=e+ -1|0;if(e){continue}break}}c=k==p(0);a:{if(c){break a}e=i[f+8>>2];if(!e){break a}n=c?p(1):p(p(1)/k);c=i[a+20>>2];while(1){a=j[b|0]|j[b+1|0]<<8|(j[b+2|0]<<16|j[b+3|0]<<24);m[f+12>>2]=n*(eNa(2,a<<24|a<<8&16711680|(a>>>8&65280|a>>>24)),iNa());Id(f+12|0,p(-1));l=p(m[f+12>>2]*p(32768));m[f+12>>2]=l;a=c;l=Qd(l);b:{if(p(q(l))<p(2147483648)){g=~~l;break b}g=-2147483648}r=a,s=Bc(g),h[r>>1]=s;b=b+4|0;c=c+2|0;e=e+ -1|0;if(e){continue}break}}if(d){m[d>>2]=k}Xa=f+16|0;return i[f+8>>2]}function kta(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,j=0,l=0;c=Xa+ -64|0;Xa=c;af(a,c+62|0);a:{b:{c:{d:{e:{f:{g:{e=i[19847];if(k[c+62>>1]>k[e+12>>1]){f=i[b+12>>2];Dz(c+16|0,18517);i[114610]=0;J(1182,c+32|0,c+16|0,c+62|0,e+12|0);d=i[114610];i[114610]=0;if((d|0)==1){break g}i[114610]=0;d=C(653,c+48|0,c+32|0)|0;g=i[114610];i[114610]=0;if((g|0)==1){break f}i[114610]=0;D(627,f|0,d|0);f=i[114610];i[114610]=0;if((f|0)==1){break e}eb(d);eb(c+32|0);ob(c+16|0);h[c+62>>1]=k[e+12>>1]}Zf(bi(b,0),k[c+62>>1]);b=bi(b,0);j=c,l=Jb(b),i[j+48>>2]=l;j=c,l=Kb(b),i[j+16>>2]=l;if(pb(c+48|0,c+16|0)){break b}break a}b=B()|0;A()|0;break c}b=B()|0;A()|0;break d}b=B()|0;A()|0;eb(d)}eb(c+32|0)}ob(c+16|0);E(b|0);x()}while(1){b=i[c+48>>2];af(a,c+14|0);h[b>>1]=k[c+14>>1];he(c+48|0);if(pb(c+48|0,c+16|0)){continue}break}}Xa=c- -64|0}function oX(a){var b=0,c=p(0),d=p(0),e=p(0),f=p(0),g=0,h=p(0),i=p(0);b=(hNa(a),dNa(2));a:{b:{if(!((b|0)>-1?b>>>0>=8388608:0)){if(!(b&2147483647)){return p(p(-1)/p(a*a))}if((b|0)<=-1){return p(p(a-a)/p(0))}b=(hNa(p(a*p(33554432))),dNa(2));g=-152;break b}if(b>>>0>2139095039){break a}g=-127;a=p(0);if((b|0)==1065353216){break a}}b=b+4913933|0;h=p((b>>>23|0)+g|0);a=p((eNa(2,(b&8388607)+1060439283|0),iNa())+p(-1));c=p(a*p(a*p(.5)));d=p(a/p(a+p(2)));e=p(d*d);f=p(e*e);i=a;a=(eNa(2,(hNa(p(a-c)),dNa(2))&-4096),iNa());c=p(p(p(i-a)-c)+p(d*p(c+p(p(e*p(p(f*p(.2849878668785095))+p(.6666666269302368)))+p(f*p(p(f*p(.24279078841209412))+p(.40000972151756287)))))));a=p(p(h*p(.3010292053222656))+p(p(a*p(.434326171875))+p(p(c*p(.434326171875))+p(p(h*p(7.903415166765626e-7))+p(p(c+a)*p(-3168997136526741e-20))))))}return a}function zD(a,b){var c=0,d=0,e=0;a:{if(j[b|0]){break a}b=Wu(57968);if(j[b|0]?b:0){break a}b=Wu(o(a,12)+57984|0);if(j[b|0]?b:0){break a}b=Wu(58056);if(j[b|0]?b:0){break a}b=58061}b:{while(1){e=j[b+c|0];if(!(!e|(e|0)==47)){e=15;c=c+1|0;if((c|0)!=15){continue}break b}break}e=c}d=58061;c:{d:{c=j[b|0];e:{f:{if(!(j[b+e|0]|(c|0)==46)){d=b;if((c|0)!=67){break f}}if(!j[d+1|0]){break e}}if(!Ih(d,58061)){break e}if(Ih(d,58069)){break d}}if(!a){c=57892;if(j[d+1|0]==46){break c}}return 0}c=i[115399];if(c){while(1){if(!Ih(d,c+8|0)){break c}c=i[c+24>>2];if(c){continue}break}}c=i[115399];if(c){while(1){if(!Ih(d,c+8|0)){return c}c=i[c+24>>2];if(c){continue}break}}c=Zc(28);g:{if(!c){c=0;break g}b=i[14474];i[c>>2]=i[14473];i[c+4>>2]=b;b=c+8|0;Tb(b,d,e);g[b+e|0]=0;i[c+24>>2]=i[115399];i[115399]=c}c=a|c?c:57892}return c}function Fpa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=p(0),g=0,k=0,l=p(0),n=0,o=0;e=Xa-16|0;Xa=e;i[e+12>>2]=c>>>3;i[e+8>>2]=i[a>>2];k=i[rb(e+12|0,e+8|0)>>2];l=m[d>>2];b=jb(b);if(k){a=i[a+20>>2];c=k;while(1){d=j[b|0]|j[b+1|0]<<8|(j[b+2|0]<<16|j[b+3|0]<<24);m[e+12>>2]=l*(eNa(2,d<<24|d<<8&16711680|(d>>>8&65280|d>>>24)),iNa());Id(e+12|0,p(-1));f=p(m[e+12>>2]*p(32768));m[e+12>>2]=f;d=a;f=Qd(f);a:{if(p(q(f))<p(2147483648)){g=~~f;break a}g=-2147483648}n=d,o=Bc(g),h[n>>1]=o;d=j[b+4|0]|j[b+5|0]<<8|(j[b+6|0]<<16|j[b+7|0]<<24);m[e+12>>2]=l*(eNa(2,d<<24|d<<8&16711680|(d>>>8&65280|d>>>24)),iNa());Id(e+12|0,p(-1));f=p(m[e+12>>2]*p(32768));m[e+12>>2]=f;d=a;f=Qd(f);b:{if(p(q(f))<p(2147483648)){g=~~f;break b}g=-2147483648}n=d,o=Bc(g),h[n+2>>1]=o;a=a+4|0;b=b+8|0;c=c+ -1|0;if(c){continue}break}}Xa=e+16|0;return k<<3}function kla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=Xa-16|0;Xa=d;kd(b,4);h[b+30>>1]=j[a+12|0]<<2;Ag(b+30|0,256);c=j[a+15|0];h[b+34>>1]=32;h[b+28>>1]=c;g[b+37|0]=j[a+13|0];g[b+36|0]=j[a+16|0];i[b>>2]=j[a|0]|j[a+1|0]<<8|(j[a+2|0]<<16|j[a+3|0]<<24);c=a+4|0;e=j[c|0]|j[c+1|0]<<8|(j[c+2|0]<<16|j[c+3|0]<<24);i[b+4>>2]=e;c=a+8|0;i[b+8>>2]=e+(j[c|0]|j[c+1|0]<<8|(j[c+2|0]<<16|j[c+3|0]<<24));a=a+14|0;if(j[a|0]&16){i[b>>2]=i[b>>2]>>>1;i[b+4>>2]=i[b+4>>2]>>>1;i[b+8>>2]=i[b+8>>2]>>>1}if(j[a|0]&32){i[b>>2]=i[b>>2]>>>1;i[b+4>>2]=i[b+4>>2]>>>1;i[b+8>>2]=i[b+8>>2]>>>1}a:{if(!(j[a|0]&3)|l[b+8>>2]<=l[b+4>>2]){break a}h[b+34>>1]=k[b+34>>1]|2;if(!(j[a|0]&2)){break a}h[b+34>>1]=k[b+34>>1]|4}a=Bb(d,31664);i[114610]=0;C(370,b+43|0,a|0)|0;b=i[114610];i[114610]=0;if((b|0)!=1){eb(a);Xa=d+16|0;return}b=B()|0;A()|0;eb(a);E(b|0);x()}function twa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,i=0,l=0,m=0;e=Xa-48|0;Xa=e;h[a>>1]=0;h[a+2>>1]=0;h[a+4>>1]=0;$m(b,e+44|0);a:{if(!FM(e+44|0)){break a}d=j[e+46|0];i=j[e+47|0];f=j[e+45|0];g[a+4|0]=1;l=f>>>3&3;c=(l|0)!=3;m=f>>>1&3;f=m^3;i=i>>>0<192;h[a+2>>1]=k[(o(c,6)+18408|0)+(f<<1)>>1]<<i;f=o(o(j[f+(o(c,3)+18185|0)|0],k[((o(c,90)+18192|0)+o(f,30)|0)+(d>>>3&30)>>1]),1e3);d=d>>>1|0;d=o(((f>>>0)/k[(o(l,6)+18384|0)+(d&6)>>1]|0)+(d&1)|0,(m|0)==3?4:1);h[a>>1]=d;c=j[i+((c<<1)+18420|0)|0];if(c+8>>>0>(d&65535)>>>0){break a}swa(b,e,c+4|0);b=2;if(c>>>0>2){while(1){if(j[b+e|0]){break a}b=b+1|0;if((c|0)!=(b|0)){continue}break}}b=a;c=c+e|0;d=1;b:{if((j[c|0]|j[c+1|0]<<8|(j[c+2|0]<<16|j[c+3|0]<<24))==1868983881){break b}d=(j[c|0]|j[c+1|0]<<8|(j[c+2|0]<<16|j[c+3|0]<<24))==1735289176}g[b+5|0]=d}Xa=e+48|0;return a|0}function faa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;e=Xa-48|0;Xa=e;h=co(a,c);j=kG(a+4|0);k=jG(a+24|0);l=iG(a+32|0);m=Xv(a+36|0);i[a+56>>2]=3;n=Mg(a+68|0);i[114610]=0;D(2165,a|0,d|0);c=i[114610];i[114610]=0;a:{b:{c:{d:{if((c|0)!=1){c=i[b>>2];f=i[b+4>>2];g=i[b+12>>2];b=i[b+8>>2];i[e+8>>2]=b;i[e+12>>2]=g;i[114610]=0;i[e+24>>2]=b;i[e+28>>2]=g;i[e+16>>2]=c;i[e+20>>2]=f;i[e>>2]=c;i[e+4>>2]=f;D(2166,e+32|0,e|0);b=i[114610];i[114610]=0;if((b|0)==1){break d}i[114610]=0;G(2167,a|0,e+32|0,d|0);b=i[114610];i[114610]=0;if((b|0)==1){break c}hb(e+32|0);i[114610]=0;L(2168,a|0);b=i[114610];i[114610]=0;if((b|0)==1){break b}Xa=e+48|0;return a|0}a=B()|0;A()|0;break a}a=B()|0;A()|0;break a}a=B()|0;A()|0;hb(e+32|0);break a}a=B()|0;A()|0}Sc(n);We(m);$e(l);ih(k);Ec(j);Ec(h);E(a|0);x()}function rpa(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;e=Xa-32|0;Xa=e;Eoa(a+8|0);i[a+32>>2]=0;i[a+36>>2]=0;c=a+4|0;i[i[c>>2]>>2]=0;i[i[c>>2]+40>>2]=i[i[a>>2]+480196>>2];i[i[c>>2]+44>>2]=i[i[a>>2]+480204>>2];i[i[c>>2]+68>>2]=i[i[a>>2]+480200>>2];f=k[i[a>>2]+480188>>1];b=e;i[b+24>>2]=0;i[b+28>>2]=0;i[b+16>>2]=0;i[b+20>>2]=0;i[b+8>>2]=0;i[b+12>>2]=0;b=b+8|0;i[b>>2]=0;i[b+4>>2]=0;g[b+21|0]=255;g[b+13|0]=0;g[b+14|0]=0;g[b+15|0]=0;g[b+16|0]=0;g[b+17|0]=0;g[b+18|0]=0;g[b+19|0]=0;g[b+20|0]=0;i[b+8>>2]=0;i[b+12>>2]=0;fpa(a+20|0,f,b);if(k[i[a>>2]+480188>>1]){while(1){b=o(d,896);Pm((b+i[c>>2]|0)+608|0,i[a>>2],d&65535);g[(b+i[c>>2]|0)+1445|0]=0;g[(b+i[c>>2]|0)+1444|0]=0;g[(b+i[c>>2]|0)+1429|0]=0;g[(b+i[c>>2]|0)+1432|0]=0;g[(b+i[c>>2]|0)+1427|0]=0;d=d+1|0;if(d>>>0<k[i[a>>2]+480188>>1]){continue}break}}Xa=e+32|0}function pr(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=Xa-176|0;Xa=d;e=Kg(d+40|0);f=i[i[e>>2]+ -12>>2];i[114610]=0;g=R(122)|0;h=i[114610];i[114610]=0;a:{b:{c:{d:{e:{if((h|0)==1){break e}i[114610]=0;G(123,d+32|0,f+(d+40|0)|0,g|0);f=i[114610];i[114610]=0;if((f|0)==1){break e}ub(d+32|0);i[114610]=0;D(142,e|0,c|0);f=i[114610];i[114610]=0;if((f|0)==1){break e}i[114610]=0;D(133,e|0,b|0);b=i[114610];i[114610]=0;if((b|0)==1){break e}i[114610]=0;D(125,d|0,e|0);b=i[114610];i[114610]=0;if((b|0)==1){break e}i[114610]=0;G(140,d+16|0,d|0,c|0);b=i[114610];i[114610]=0;if((b|0)==1){break d}i[114610]=0;G(141,a|0,d+16|0,c|0);a=i[114610];i[114610]=0;if((a|0)==1){break c}eb(d+16|0);eb(d);Fd(e);Xa=d+176|0;return}c=B()|0;A()|0;break a}c=B()|0;A()|0;break b}c=B()|0;A()|0;eb(d+16|0)}eb(d)}Fd(e);E(c|0);x()}function eea(){var a=0,b=0,c=0,d=0,e=0;a=Xa-48|0;Xa=a;c=Ab(a+32|0);i[114610]=0;L(1994,a+16|0);b=i[114610];i[114610]=0;a:{b:{c:{d:{e:{f:{if((b|0)!=1){d=a,e=Jb(a+16|0),i[d+8>>2]=e;d=a,e=Kb(a+16|0),i[d>>2]=e;if(!pb(a+8|0,a)){break e}break f}b=H(0)|0;A()|0;break c}while(1){b=i[a+8>>2];i[114610]=0;C(1251,c|0,b|0)|0;b=i[114610];i[114610]=0;if((b|0)==1){break d}_m(a+8|0);d=a,e=Kb(a+16|0),i[d>>2]=e;if(!pb(a+8|0,a)){break e}i[114610]=0;C(1995,c|0,34153)|0;b=i[114610];i[114610]=0;if((b|0)!=1){continue}break}break d}b=Ed(xb(c));Sc(a+16|0);eb(c);break b}b=H(0)|0;A()|0;Sc(a+16|0)}eb(c);M(b|0)|0;b=0;i[114610]=0;J(1989,34155,0,0,0);c=i[114610];i[114610]=0;if((c|0)==1){break a}O()}Xa=a+48|0;return b|0}a=B()|0;A()|0;i[114610]=0;K(20);c=i[114610];i[114610]=0;if((c|0)!=1){E(a|0);x()}a=H(0)|0;A()|0;gb(a);x()}function Q4(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=Xa-32|0;Xa=d;gNa(+a);g=dNa(1)|0;e=dNa(0)|0;gNa(+b);f=dNa(1)|0;h=dNa(0)|0;i=g&2147483647;c=i;f=f&2147483647;j=(c|0)==(f|0)&e>>>0<h>>>0|c>>>0<f>>>0;g=j?e:h;c=j?c:f;j=c;eNa(0,g|0);eNa(1,c|0);a=+fNa();c=c>>>20|0;a:{if((c|0)==2047){break a}l=e;e=(f|0)==(i|0)&e>>>0>h>>>0|i>>>0>f>>>0;h=e?l:h;i=e?i:f;e=i;eNa(0,h|0);eNa(1,e|0);b=+fNa();b:{if(!(g|j)){break b}g=e>>>20|0;if((g|0)==2047){break b}if((g-c|0)>=65){a=b+a;break a}c:{if(g>>>0>=1534){a=a*1.90109156629516e-211;b=b*1.90109156629516e-211;k=5.260135901548374e+210;break c}k=1;if(c>>>0>572){break c}a=a*5.260135901548374e+210;b=b*5.260135901548374e+210;k=1.90109156629516e-211}IE(d+24|0,d+16|0,b);IE(d+8|0,d,a);a=k*w(n[d>>3]+n[d+16>>3]+n[d+8>>3]+n[d+24>>3]);break a}a=b}Xa=d+32|0;return a}function kH(a){var b=0,c=p(0),d=0,e=0,f=p(0);b=Xa-16|0;Xa=b;d=we(i[a+16>>2]);e=a,f=Wd(p(10),p(p(p(m[a+4208>>2]*p(120))+p(-60))*p(.05000000074505806))),m[e+4232>>2]=f;c=p(p(d>>>0)*p(.0010000000474974513));e=a,f=Wd(p(10),p(p(-1)/p(p(p(m[a+4212>>2]*p(499.989990234375))+p(.009999999776482582))*c))),m[e+4236>>2]=f;e=a,f=Wd(p(10),p(p(-1)/p(p(p(m[a+4216>>2]*p(2950))+p(50))*c))),m[e+4240>>2]=f;i[b+12>>2]=1325400064;e=b,f=p(p(U4(p(Wd(p(10),p(p(p(m[a+4220>>2]*p(60))+p(-60))*p(.05000000074505806)))*p(2147483648)))*p(96817624))+p(67108864)),m[e+8>>2]=f;e=a,f=p(m[Sk(b+12|0,b+8|0)>>2]*p(4.656612873077393e-10)),m[e+4244>>2]=f;m[a+4248>>2]=p(p(-1)/p(p(m[a+4224>>2]*p(99))+p(1)))+p(1);d=a;c=p(p(p(m[a+4228>>2]*p(4))*c)+p(2));a:{if(p(q(c))<p(2147483648)){a=~~c;break a}a=-2147483648}i[d+4252>>2]=a;Xa=b+16|0}function zY(a,b){var c=0;while(1){if(i[a>>2]==1){continue}break}a:{b:{if(!i[a>>2]){c:{gf(a,1);i[114610]=0;c=i[114610];i[114610]=0;d:{if((c|0)==1){break d}i[114610]=0;L(2567,b|0);b=i[114610];i[114610]=0;if((b|0)==1){break d}i[114610]=0;b=i[114610];i[114610]=0;if((b|0)==1){break d}i[a>>2]=-1;i[114610]=0;b=i[114610];i[114610]=0;if((b|0)==1){break d}i[114610]=0;b=i[114610];i[114610]=0;if((b|0)!=1){break c}}b=H(0)|0;A()|0;M(b|0)|0;i[114610]=0;b=i[114610];i[114610]=0;e:{if((b|0)==1){break e}gf(a,0);i[114610]=0;a=i[114610];i[114610]=0;if((a|0)==1){break e}i[114610]=0;a=i[114610];i[114610]=0;if((a|0)==1){break e}i[114610]=0;K(81);a=i[114610];i[114610]=0;if((a|0)!=1){break a}}a=B()|0;A()|0;i[114610]=0;K(20);b=i[114610];i[114610]=0;if((b|0)==1){break b}E(a|0);x()}}return}a=H(0)|0;A()|0;gb(a)}x()}function DEa(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var h=0;h=Xa-16|0;Xa=h;g[h+14|0]=d;g[h+15|0]=c;g[h+13|0]=e;g[h+12|0]=f;if((d+ -1&255)>>>0<=5){g[h+14|0]=d+15}HP(h+15|0,h+13|0);HP(h+14|0,h+12|0);a:{if(j[h+15|0]==10){g[h+13|0]=j[h+13|0]&15?-1:j[h+12|0];if(j[h+14|0]!=10){break a}g[h+14|0]=0;break a}if(j[h+14|0]!=10){break a}g[h+12|0]=j[h+12|0]&15?-1:0}if(b){g[a+2|0]=1;g[a+4|0]=b+2>>>2}Dw(h+15|0,h+13|0,h+14|0,h+12|0);c=j[h+15|0];b:{if(!c){break b}d=j[h+14|0];if(!d){g[h+14|0]=c;g[h+12|0]=j[h+13|0];g[h+15|0]=0;break b}if(!((c|0)==20|(c|0)!=(d|0))){g[h+15|0]=0;break b}if(!b){Cw(h+8|0,h+15|0,h+13|0,h+14|0,h+12|0);g[a+2|0]=j[h+15|0];g[a+4|0]=j[h+13|0];break b}if(tm(c)>>>0<=tm(j[h+14|0])>>>0){break b}Sg(h+15|0,h+14|0);Sg(h+13|0,h+12|0)}g[a+3|0]=j[h+14|0];g[a+5|0]=j[h+12|0];Xa=h+16|0}function daa(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0;f=Xa-32|0;Xa=f;d=co(a,d);h=kG(a+4|0);j=jG(a+24|0);k=iG(a+32|0);l=Xv(a+36|0);i[a+56>>2]=3;m=Mg(a+68|0);i[114610]=0;D(2165,a|0,e|0);g=i[114610];i[114610]=0;a:{b:{c:{d:{if((g|0)!=1){i[114610]=0;b=F(2172,b|0)|0;g=i[114610];i[114610]=0;if((g|0)==1){break d}i[114610]=0;G(2173,f+8|0,b|0,c|0);b=i[114610];i[114610]=0;if((b|0)==1){break d}i[114610]=0;D(2174,f+16|0,f+8|0);b=i[114610];i[114610]=0;if((b|0)==1){break d}i[114610]=0;G(2167,a|0,f+16|0,e|0);b=i[114610];i[114610]=0;if((b|0)==1){break c}hb(f+16|0);i[114610]=0;L(2168,a|0);b=i[114610];i[114610]=0;if((b|0)!=1){break a}}a=B()|0;A()|0;break b}a=B()|0;A()|0;break b}a=B()|0;A()|0;hb(f+16|0)}Sc(m);We(l);$e(k);ih(j);Ec(h);Ec(d);E(a|0);x()}Xa=f+32|0;return a|0}function c5(a,b,c,d,e){var f=p(0),g=p(0),h=0,i=p(0),j=p(0),k=p(0),l=0;if((0-(a<<4)|0)<=-1){b=(c<<2)+b|0;c=b-(a<<6)|0;k=m[(e>>3<<2)+d>>2];while(1){a=b+ -32|0;f=m[a>>2];i=m[b>>2];m[b>>2]=f+i;d=b+ -4|0;g=m[d>>2];e=d;d=b+ -36|0;j=m[d>>2];m[e>>2]=j+g;m[a>>2]=i-f;m[d>>2]=g-j;d=b+ -8|0;g=m[d>>2];e=d;d=b+ -40|0;i=m[d>>2];m[e>>2]=i+g;e=b+ -12|0;f=m[e>>2];h=e;e=b+ -44|0;j=m[e>>2];m[h>>2]=j+f;f=p(f-j);g=p(g-i);m[d>>2]=p(f+g)*k;m[e>>2]=p(f-g)*k;d=b+ -20|0;g=m[d>>2];e=b+ -52|0;f=m[e>>2];h=b+ -16|0;i=m[h>>2];l=h;h=b+ -48|0;j=m[h>>2];m[l>>2]=i+j;m[d>>2]=f+g;m[h>>2]=g-f;m[e>>2]=j-i;d=b+ -60|0;g=m[d>>2];e=b+ -28|0;f=m[e>>2];h=b+ -24|0;i=m[h>>2];l=h;h=b+ -56|0;j=m[h>>2];m[l>>2]=i+j;m[e>>2]=g+f;g=p(f-g);f=p(j-i);m[h>>2]=p(g+f)*k;m[d>>2]=p(f-g)*k;PE(b);PE(a);b=b+ -64|0;if(b>>>0>c>>>0){continue}break}}}function oo(a){var b=0,c=0,d=0,e=0,f=0,g=0;c=Xa-16|0;Xa=c;a:{b:{switch(i[a+480224>>2]+ -1|0){default:b=i[a+24620>>2];d=b>>31;i[c+8>>2]=1;i[c>>2]=i[a+1074420>>2]<<1;d=XMa(b,d,5e4,0);e=_a;b=i[Jc(c+8|0,c)>>2];b=gc(YMa(d,e,b,b>>31),_a);i[a+1074404>>2]=b;break a;case 1:b=i[a+24620>>2];i[c+8>>2]=1;i[c+12>>2]=0;f=c,g=XMa(i[a+1074420>>2],0,XMa(i[a+1074408>>2],0,i[a+1074416>>2],0),_a),i[f>>2]=g;i[c+4>>2]=_a;d=XMa(b,0,6e5,0);e=_a;b=dna(c+8|0,c);b=_Ma(d,e,i[b>>2],i[b+4>>2]);i[a+1074404>>2]=b;break a;case 0:break b}}b=i[a+24620>>2];d=b>>31;i[c+8>>2]=1;i[c>>2]=i[a+1074420>>2];d=XMa(b,d,1e4,0);e=_a;b=i[Jc(c+8|0,c)>>2];b=gc(YMa(d,e,b,b>>31),_a);i[a+1074404>>2]=b}d=a+1074404|0;a=i[a+480244>>2];b=XMa(a,a>>31,b,b>>31)+32768|0;a=_a;a=gc(YMa(b,b>>>0<32768?a+1|0:a,65536,0),_a);i[d>>2]=a?a:1;Xa=c+16|0}function mK(a,b,c){var d=0,e=0,f=0,g=0,h=0,k=0;e=Xa-16|0;Xa=e;a:{if(!i[b+700>>2]){break a}f=i[a+480180>>2]==64?o(c,-20):c;b:{if(!(!(j[a+480208|0]&16)|i[a+480180>>2]==4)){g=i[b+700>>2];c=f>>31;i[e+12>>2]=(c+f^c)>>>2;kc(e+12|0,255);d=i[e+12>>2];c:{if(!d){break c}h=b;c=i[b+700>>2];k=c;c=c>>31;d:{if((f|0)<=-1){d=kx(a,d);break d}d=jx(a,d)}d=XMa(k,c,d,d>>31)+32768|0;c=_a;c=gc(YMa(d,d>>>0<32768?c+1|0:c,65536,0),_a);i[h+700>>2]=c;if((c|0)!=(g|0)){break c}kb(e,a+1074308|0,7);d=ib(e);c=i[b+700>>2];if((d|0)==(f>>>31|0)){if((c|0)>=2147483647){break c}i[b+700>>2]=i[b+700>>2]+1;break c}if((c|0)<2){break c}i[b+700>>2]=c+ -1}c=i[b+700>>2];break b}c=f+i[b+700>>2]|0;i[b+700>>2]=c}if((c|0)>0){break a}i[b+700>>2]=1;if(i[a+480180>>2]!=2){break a}i[b+696>>2]=0;i[b+88>>2]=i[b+88>>2]|2101248}Xa=e+16|0}function jf(a){var b=0,c=0;b=i[a+4>>2];c=i[i[b>>2]+ -12>>2];i[114610]=0;b=i[(b+c|0)+24>>2];c=i[114610];i[114610]=0;a:{if((c|0)==1){break a}b:{if(!b){break b}b=i[a+4>>2];c=i[i[b>>2]+ -12>>2];i[114610]=0;b=hf(b+c|0);c=i[114610];i[114610]=0;if((c|0)==1){break a}if(!b){break b}b=i[a+4>>2];if(!(i[(i[i[b>>2]+ -12>>2]+b|0)+4>>2]&8192)){break b}if(jv()){break b}b=i[a+4>>2];c=i[i[b>>2]+ -12>>2];i[114610]=0;b=i[(b+c|0)+24>>2];c=i[114610];i[114610]=0;c:{if((c|0)==1){break c}i[114610]=0;b=F(2315,b|0)|0;c=i[114610];i[114610]=0;if((c|0)==1){break c}if((b|0)!=-1){break b}a=i[a+4>>2];b=i[i[a>>2]+ -12>>2];i[114610]=0;D(18,a+b|0,1);a=i[114610];i[114610]=0;if((a|0)!=1){break b}}a=H(0)|0;A()|0;M(a|0)|0;i[114610]=0;K(20);a=i[114610];i[114610]=0;if((a|0)==1){break a}}return}a=H(0)|0;A()|0;gb(a);x()}function HBa(a,b,c){var d=0,e=0,f=0,l=0,m=0,n=0;f=Xa-16|0;Xa=f;kd(b,1);d=a+22|0;d=j[d|0]|j[d+1|0]<<8;i[b>>2]=(d<<24|d<<8&16711680)>>>15;g[b+37|0]=j[a+24|0]<<4;g[f+15|0]=j[a+25|0];g[f+14|0]=64;m=b,n=j[Xb(f+15|0,f+14|0)|0]<<2,h[m+30>>1]=n;d=a+26|0;d=j[d|0]|j[d+1|0]<<8;l=(d<<24|d<<8&16711680)>>>16|0;d=l<<1;a=a+28|0;a=j[a|0]|j[a+1|0]<<8;a=(a<<24|a<<8&16711680)>>>16|0;e=a<<1;a:{if(a>>>0<=1){a=i[b>>2];break a}a=i[b>>2];d=d+e>>>0<=a>>>0?d:e+l>>>0>a>>>0?d:l}b:{c:{switch(a|0){case 2:i[b>>2]=0;break b;case 0:break b;default:break c}}i[b+4>>2]=d;e=d+e|0;i[b+8>>2]=e;if(d>>>0>=a>>>0){d=a+ -1|0;i[b+4>>2]=d}if(!(e-d>>>0>3?!(e>>>0<4|e>>>0<d>>>0):0)){i[b+4>>2]=0;i[b+8>>2]=0;e=0;d=0}if(!(a>>>0<=e>>>0|e>>>0>8|(!c|d))){i[b+8>>2]=0;break b}if(e>>>0<=d>>>0){break b}h[b+34>>1]=k[b+34>>1]|2}Xa=f+16|0}function bH(a){var b=p(0),c=0,d=p(0),e=p(0),f=p(0),h=0,j=0,k=0,l=p(0);c=Xa-16|0;Xa=c;j=a,k=_h(p(m[a+4256>>2]*p(3))),i[j+4264>>2]=k;j=a,l=p(we(i[a+16>>2])>>>((i[a+4264>>2]>>>1^-1)&1)>>>0),m[j+4268>>2]=l;m[a+4272>>2]=p(m[a+4244>>2]*p(100))*p(.0061803399585187435);j=c,l=Wd(p(10),p(p(aH(a)+p(p(m[a+4228>>2]*p(11e3))+p(-1e4)))*p(.0005000000237487257))),m[j+12>>2]=l;i[c+8>>2]=1065353216;j=a,l=p(m[Sk(c+12|0,c+8|0)>>2]*p(.7609999775886536)),m[j+4280>>2]=l;h=a;b=Wd(p(10),p(p(p(m[a+4212>>2]*p(1e4))+p(-1e4))*p(.0010000000474974513)));if(b!=p(1)){d=Yn(p(p($G(a)*p(6.2831854820251465))/m[a+4268>>2]));e=p(b+b);f=p(b*b);b=p(b*p(8));b=Fm(p(p(p(p(d*e)+p(-2))+p(w(p(p(p(f*p(-4))+b)+p(p(p(p(f*p(4))*d)-b)*d)))))/p(e+p(-2))),p(0),p(1))}else{b=p(0)}m[h+4276>>2]=b;Tea(a);Sea(a);g[a+5046|0]=0;Xa=c+16|0}function Uva(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,p=0;e=Xa-32|0;Xa=e;k=i[a+40>>2];l=i[a+36>>2];n=i[a+16>>2];b=i[a+4>>2];g=b;f=i[a>>2];i[e+24>>2]=f;i[e+28>>2]=b;b=i[a+12>>2];i[e+16>>2]=i[a+8>>2];i[e+20>>2]=b;a:{if(!d){j=k>>12;b=l>>12;break a}while(1){p=f>>>18|0;g=((((g&2147483647)<<1|f>>>31)&2147483646)<<1)+n|0;j=0;b=1;while(1){m=j<<1;f=h[m+g>>1];i[(e+8|0)+(j<<2)>>2]=f+((o(h[(m|4)+g>>1]-f|0,p)|0)/16384|0);f=b;b=0;j=1;if(f){continue}break}f=i[a+32>>2];l=i[a+28>>2]+l|0;b=l>>12;i[c>>2]=i[c>>2]+o(b,i[e+8>>2]);k=f+k|0;j=k>>12;i[c+4>>2]=i[c+4>>2]+o(j,i[e+12>>2]);zb(e+24|0,e+16|0);d=d+ -1|0;if(d){c=c+8|0;f=i[e+24>>2];g=i[e+28>>2];continue}break}f=i[e+24>>2];g=i[e+28>>2]}i[a+40>>2]=k;i[a+20>>2]=b;i[a+36>>2]=l;i[a+24>>2]=j;i[a>>2]=f;i[a+4>>2]=g;Xa=e+32|0}function ega(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=Xa-176|0;Xa=d;e=Kg(d+40|0);f=i[i[e>>2]+ -12>>2];i[114610]=0;g=R(122)|0;h=i[114610];i[114610]=0;a:{b:{c:{d:{e:{if((h|0)==1){break e}i[114610]=0;G(123,d+32|0,f+(d+40|0)|0,g|0);f=i[114610];i[114610]=0;if((f|0)==1){break e}ub(d+32|0);i[114610]=0;D(148,e|0,c|0);f=i[114610];i[114610]=0;if((f|0)==1){break e}i[114610]=0;D(132,e|0,b|0);b=i[114610];i[114610]=0;if((b|0)==1){break e}i[114610]=0;D(125,d|0,e|0);b=i[114610];i[114610]=0;if((b|0)==1){break e}i[114610]=0;G(140,d+16|0,d|0,c|0);b=i[114610];i[114610]=0;if((b|0)==1){break d}i[114610]=0;G(141,a|0,d+16|0,c|0);a=i[114610];i[114610]=0;if((a|0)==1){break c}eb(d+16|0);eb(d);Fd(e);Xa=d+176|0;return}c=B()|0;A()|0;break a}c=B()|0;A()|0;break b}c=B()|0;A()|0;eb(d+16|0)}eb(d)}Fd(e);E(c|0);x()}function T4(a){var b=0,c=p(0),d=p(0),e=0,f=0,g=p(0),h=p(0);e=(hNa(a),dNa(2));f=e>>>31|0;a:{b:{c:{d:{d=a;e:{f:{b=e&2147483647;g:{if(b>>>0>=1118743632){if(b>>>0>2139095040){return a}if(!((e|0)<0|b>>>0<1118925336)){return p(a*p(1.7014118346046923e+38))}if(b>>>0<=1120924084|(e|0)>-1){break g}break b}if(b>>>0<1051816473){break d}if(b>>>0<1065686419){break f}}a=p(p(a*p(1.4426950216293335))+m[(f<<2)+52224>>2]);if(p(q(a))<p(2147483648)){b=~~a;break e}b=-2147483648;break e}b=(f^1)-f|0}c=p(b|0);a=p(d+p(c*p(-.693145751953125)));g=p(c*p(1428606765330187e-21));d=p(a-g);break c}if(b>>>0<=956301312){break a}b=0;d=a}c=d;h=a;c=p(c*c);a=p(d-p(c*p(p(c*p(-.0027667332906275988))+p(.16666625440120697))));c=p(p(h+p(p(p(d*a)/p(p(2)-a))-g))+p(1));if(!b){break b}c=ME(c,b)}return c}return p(a+p(1))}function rH(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=Xa-176|0;Xa=d;e=Kg(d+40|0);f=i[i[e>>2]+ -12>>2];i[114610]=0;g=R(122)|0;h=i[114610];i[114610]=0;a:{b:{c:{d:{e:{if((h|0)==1){break e}i[114610]=0;G(123,d+32|0,f+(d+40|0)|0,g|0);f=i[114610];i[114610]=0;if((f|0)==1){break e}ub(d+32|0);i[114610]=0;D(147,e|0,c|0);f=i[114610];i[114610]=0;if((f|0)==1){break e}i[114610]=0;D(130,e|0,b|0);b=i[114610];i[114610]=0;if((b|0)==1){break e}i[114610]=0;D(125,d|0,e|0);b=i[114610];i[114610]=0;if((b|0)==1){break e}i[114610]=0;G(140,d+16|0,d|0,c|0);b=i[114610];i[114610]=0;if((b|0)==1){break d}i[114610]=0;G(141,a|0,d+16|0,c|0);a=i[114610];i[114610]=0;if((a|0)==1){break c}eb(d+16|0);eb(d);Fd(e);Xa=d+176|0;return}c=B()|0;A()|0;break a}c=B()|0;A()|0;break b}c=B()|0;A()|0;eb(d+16|0)}eb(d)}Fd(e);E(c|0);x()}function Yn(a){var b=p(0),c=0,d=0,e=0,f=0;c=Xa-16|0;Xa=c;e=(hNa(a),dNa(2));d=e&2147483647;a:{if(d>>>0<=1061752794){b=p(1);if(d>>>0<964689920){break a}b=eh(+a);break a}if(d>>>0<=1081824209){f=+a;if(d>>>0>=1075235812){b=p(-eh(((e|0)>-1?-3.141592653589793:3.141592653589793)+f));break a}if((e|0)<=-1){b=fh(f+1.5707963267948966);break a}b=fh(1.5707963267948966-f);break a}if(d>>>0<=1088565717){if(d>>>0>=1085271520){b=eh(((e|0)>-1?-6.283185307179586:6.283185307179586)+ +a);break a}if((e|0)<=-1){b=fh(-4.71238898038469- +a);break a}b=fh(+a+ -4.71238898038469);break a}b=p(a-a);if(d>>>0>=2139095040){break a}b:{switch(sv(a,c+8|0)&3){case 0:b=eh(n[c+8>>3]);break a;case 1:b=fh(-n[c+8>>3]);break a;case 2:b=p(-eh(n[c+8>>3]));break a;default:break b}}b=fh(n[c+8>>3])}a=b;Xa=c+16|0;return a}function vj(a,b,c,d,e,f,h,k,l,m){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;h=h|0;k=k|0;l=l|0;m=m|0;var n=0,o=0,p=0;n=Xa-16|0;Xa=n;g[n+15|0]=a;a:{b:{c:{if(i[d>>2]!=(c|0)){break c}o=43;p=a&255;if((p|0)!=j[m+24|0]){o=45;if(j[m+25|0]!=(p|0)){break c}}i[d>>2]=c+1;g[c|0]=o;break b}if(!(!lb(h)|(a|0)!=(f|0))){a=0;b=i[l>>2];if((b-k|0)>159){break a}a=i[e>>2];i[l>>2]=b+4;i[b>>2]=a;break b}a=-1;f=um(m,m+26|0,n+15|0)-m|0;if((f|0)>23){break a}d:{e:{switch(b+ -8|0){case 0:case 2:if((f|0)<(b|0)){break d}break a;case 1:break d;default:break e}}if((b|0)!=16|(f|0)<22){break d}b=i[d>>2];if((b|0)==(c|0)|(b-c|0)>2|j[b+ -1|0]!=48){break a}a=0;i[e>>2]=0;i[d>>2]=b+1;g[b|0]=j[f+62112|0];break a}a=i[d>>2];i[d>>2]=a+1;g[a|0]=j[f+62112|0];i[e>>2]=i[e>>2]+1;a=0;break a}a=0;i[e>>2]=0}Xa=n+16|0;return a|0}function uj(a,b,c,d,e,f,h,k,l,m){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;h=h|0;k=k|0;l=l|0;m=m|0;var n=0,o=0;n=Xa-16|0;Xa=n;i[n+12>>2]=a;a:{b:{c:{if(i[d>>2]!=(c|0)){break c}o=43;if(i[m+96>>2]!=(a|0)){o=45;if(i[m+100>>2]!=(a|0)){break c}}i[d>>2]=c+1;g[c|0]=o;break b}if(!(!lb(h)|(a|0)!=(f|0))){a=0;b=i[l>>2];if((b-k|0)>159){break a}a=i[e>>2];i[l>>2]=b+4;i[b>>2]=a;break b}a=-1;h=Ju(m,m+104|0,n+12|0)-m|0;if((h|0)>92){break a}f=h>>2;d:{e:{switch(b+ -8|0){case 0:case 2:if((f|0)<(b|0)){break d}break a;case 1:break d;default:break e}}if((b|0)!=16|(h|0)<88){break d}b=i[d>>2];if((b|0)==(c|0)|(b-c|0)>2|j[b+ -1|0]!=48){break a}a=0;i[e>>2]=0;i[d>>2]=b+1;g[b|0]=j[f+62112|0];break a}a=i[d>>2];i[d>>2]=a+1;g[a|0]=j[f+62112|0];i[e>>2]=i[e>>2]+1;a=0;break a}a=0;i[e>>2]=0}Xa=n+16|0;return a|0}function aya(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,l=0;e=Xa-16|0;Xa=e;c=j[a|0]|j[a+1|0]<<8|(j[a+2|0]<<16|j[a+3|0]<<24);i[b>>2]=c<<24|c<<8&16711680|(c>>>8&65280|c>>>24);g[e+15|0]=j[a+4|0];g[e+14|0]=64;f=b,l=j[Xb(e+15|0,e+14|0)|0]<<2,h[f+30>>1]=l;c=a+6|0;d=j[c|0]|j[c+1|0]<<8|(j[c+2|0]<<16|j[c+3|0]<<24);i[b+4>>2]=d<<24|d<<8&16711680|(d>>>8&65280|d>>>24);a=a+10|0;a=j[a|0]|j[a+1|0]<<8|(j[a+2|0]<<16|j[a+3|0]<<24);d=a<<24|a<<8&16711680|(a>>>8&65280|a>>>24);a=j[c|0]|j[c+1|0]<<8|(j[c+2|0]<<16|j[c+3|0]<<24);a=d+(a<<8&16711680|a<<24|(a>>>8&65280|a>>>24))|0;i[b+8>>2]=a;d=i[b+4>>2];c=i[b>>2];if(d>>>0>=c>>>0){d=c+ -1|0;i[b+4>>2]=d}if(a>>>0>c>>>0){i[b+8>>2]=c;a=c}a:{if(d>>>0>a>>>0){i[b+4>>2]=0;i[b+8>>2]=0;break a}if(a>>>0<=d>>>0){break a}i[b+68>>2]=d;h[b+34>>1]=k[b+34>>1]|2}Xa=e+16|0}function Qpa(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,k=0,l=0,m=0,n=0,p=0,q=0,r=0;l=Xa-16|0;Xa=l;q=l,r=o(i[a>>2],$d(a)),i[q+12>>2]=r;kc(l+12|0,c);c=jb(b);k=i[e+4>>2];f=i[l+12>>2];a:{if(!f){g=k;break a}while(1){e=jb(j[c|0])|jb(j[c+1|0])<<8|jb(j[c+2|0])<<16|jb(j[c+3|0])<<24;b:{if((e|0)<=-1){g=-2147483648;if((e|0)==-2147483648){break b}e=0-e|0}g=e>>>0>k>>>0?e:k}c=c+4|0;k=g;f=f+ -1|0;if(f){continue}break}}c:{if(!g){break c}e=i[l+12>>2];if(!e){break c}m=g+ -1|0;n=g>>>1|0;p=g;c=i[a+20>>2];while(1){a=jb(j[b|0])|jb(j[b+1|0])<<8|jb(j[b+2|0])<<16|jb(j[b+3|0])<<24;k=a>>31;f=a;a=k;k=a<<31|f>>>1;f=n|f<<31;a=m&a>>31;q=c,r=gc(YMa(f-a|0,k-(f>>>0<a>>>0)|0,p,0),_a)>>>16|0,h[q>>1]=r;b=b+4|0;c=c+2|0;e=e+ -1|0;if(e){continue}break}}if(d){i[d>>2]=g}Xa=l+16|0;return i[l+12>>2]}function Ppa(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,k=0,l=0,m=0,n=0,p=0,q=0,r=0;l=Xa-16|0;Xa=l;q=l,r=o(i[a>>2],$d(a)),i[q+12>>2]=r;kc(l+12|0,c);c=jb(b);k=i[e+4>>2];f=i[l+12>>2];a:{if(!f){g=k;break a}while(1){e=jb(j[c+3|0])|jb(j[c+2|0])<<8|jb(j[c+1|0])<<16|jb(j[c|0])<<24;b:{if((e|0)<=-1){g=-2147483648;if((e|0)==-2147483648){break b}e=0-e|0}g=e>>>0>k>>>0?e:k}c=c+4|0;k=g;f=f+ -1|0;if(f){continue}break}}c:{if(!g){break c}e=i[l+12>>2];if(!e){break c}m=g+ -1|0;n=g>>>1|0;p=g;c=i[a+20>>2];while(1){a=jb(j[b+3|0])|jb(j[b+2|0])<<8|jb(j[b+1|0])<<16|jb(j[b|0])<<24;k=a>>31;f=a;a=k;k=a<<31|f>>>1;f=n|f<<31;a=m&a>>31;q=c,r=gc(YMa(f-a|0,k-(f>>>0<a>>>0)|0,p,0),_a)>>>16|0,h[q>>1]=r;b=b+4|0;c=c+2|0;e=e+ -1|0;if(e){continue}break}}if(d){i[d>>2]=g}Xa=l+16|0;return i[l+12>>2]}function Ue(a,b){var c=0,d=0,e=0;d=Xa-32|0;Xa=d;a=og(a,-1,-1);a:{b:{if(j[Gi(d+24|0,b,1)|0]){c=i[i[b>>2]+ -12>>2];i[114610]=0;c=i[(b+c|0)+24>>2];e=i[114610];i[114610]=0;c:{d:{if((e|0)==1){break d}i[114610]=0;Aa(2325,d+8|0,c|0,0,0,1,8);c=i[114610];i[114610]=0;if((c|0)==1){break d}c=i[d+12>>2];i[a>>2]=i[d+8>>2];i[a+4>>2]=c;c=i[d+20>>2];i[a+8>>2]=i[d+16>>2];i[a+12>>2]=c;a=0;break c}a=H(0)|0;A()|0;M(a|0)|0;Ei(i[i[b>>2]+ -12>>2]+b|0,1);a=i[i[b>>2]+ -12>>2];i[114610]=0;a=i[(a+b|0)+20>>2];c=i[114610];i[114610]=0;e:{if((c|0)!=1){if(!(a&1)){break e}i[114610]=0;K(81);a=i[114610];i[114610]=0;if((a|0)!=1){break a}}a=B()|0;A()|0;i[114610]=0;K(20);b=i[114610];i[114610]=0;if((b|0)==1){break b}E(a|0);x()}O();a=1}ag(i[i[b>>2]+ -12>>2]+b|0,a)}Xa=d+32|0;return}a=H(0)|0;A()|0;gb(a)}x()}function _p(a,b){a=a|0;b=b|0;var c=0,d=0;d=Xa-16|0;Xa=d;a=Oc(a);a:{b:{c:{switch(b|0){case 0:i[114610]=0;b=C(2,d|0,7167)|0;c=i[114610];i[114610]=0;if((c|0)==1){break a}mb(a,b);eb(b);break b;case 1:i[114610]=0;b=C(2,d|0,7192)|0;c=i[114610];i[114610]=0;if((c|0)!=1){mb(a,b);eb(b);break b}break a;case 2:i[114610]=0;b=C(2,d|0,7237)|0;c=i[114610];i[114610]=0;if((c|0)!=1){mb(a,b);eb(b);break b}break a;case 3:i[114610]=0;b=C(2,d|0,7264)|0;c=i[114610];i[114610]=0;if((c|0)!=1){mb(a,b);eb(b);break b}break a;case 4:i[114610]=0;b=C(2,d|0,7290)|0;c=i[114610];i[114610]=0;if((c|0)!=1){mb(a,b);eb(b);break b}break a;case 5:break c;default:break b}}i[114610]=0;b=C(2,d|0,7319)|0;c=i[114610];i[114610]=0;if((c|0)==1){break a}mb(a,b);eb(b)}Xa=d+16|0;return}b=B()|0;A()|0;eb(a);E(b|0);x()}function KZ(a,b,c,d,e,f){var h=0;i[c>>2]=a;i[f>>2]=d;d=i[c>>2];a:{while(1){if(d>>>0>=b>>>0){h=0;break a}h=2;a=i[d>>2];if(a>>>0>1114111|(a&-2048)==55296){break a}b:{c:{if(a>>>0<=127){h=1;d=i[f>>2];if((e-d|0)<1){break a}i[f>>2]=d+1;g[d|0]=a;break c}if(a>>>0<=2047){d=i[f>>2];if((e-d|0)<2){break b}i[f>>2]=d+1;g[d|0]=a>>>6|192;d=i[f>>2];i[f>>2]=d+1;g[d|0]=a&63|128;break c}d=i[f>>2];h=e-d|0;if(a>>>0<=65535){if((h|0)<3){break b}i[f>>2]=d+1;g[d|0]=a>>>12|224;d=i[f>>2];i[f>>2]=d+1;g[d|0]=a>>>6&63|128;d=i[f>>2];i[f>>2]=d+1;g[d|0]=a&63|128;break c}if((h|0)<4){break b}i[f>>2]=d+1;g[d|0]=a>>>18|240;d=i[f>>2];i[f>>2]=d+1;g[d|0]=a>>>12&63|128;d=i[f>>2];i[f>>2]=d+1;g[d|0]=a>>>6&63|128;d=i[f>>2];i[f>>2]=d+1;g[d|0]=a&63|128}d=i[c>>2]+4|0;i[c>>2]=d;continue}break}return 1}return h}function Gfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,k=p(0),l=0,n=0,o=0,q=0,r=p(0),s=p(0),t=0,u=0,v=0,w=0;g=Xa-16|0;Xa=g;l=a+44|0;if(Wg(l)){v=g,w=ud(l,0),i[v+8>>2]=w;v=g,w=ud(l,1),i[v+12>>2]=w;v=g,w=Pc(l,0),i[v>>2]=w;v=g,w=Pc(l,1),i[v+4>>2]=w;if(d){t=j[a+4273|0];u=j[a+4272|0];n=d;while(1){e=0;o=1;while(1){h=e<<2;f=h+(g+8|0)|0;e=i[f>>2];i[f>>2]=e+4;f=a+h|0;q=f+4228|0;k=p(p(m[a+4236>>2]*m[q>>2])+p(m[a+4240>>2]*m[e>>2]));m[q>>2]=k;k=p(m[a+4260>>2]*iH(p(k*p(1073741824)),u,t));e=f+4244|0;r=m[a+4264>>2];f=f+4252|0;s=m[f>>2];k=p(k-p(p(m[a+4268>>2]*m[e>>2])+p(r*s)));m[f>>2]=k;m[e>>2]=s+p(k*r);e=g+h|0;h=i[e>>2];i[e>>2]=h+4;m[h>>2]=k*p(9.313225746154785e-10);h=o;o=0;e=1;if(h){continue}break}n=n+ -1|0;if(n){continue}break}}Oh(a,b,c,Pc(l,0),Pc(l,1),d)}Xa=g+16|0}function Vva(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,h=0,j=0,k=0,l=0,m=0,n=0;e=Xa-32|0;Xa=e;k=i[a+40>>2];l=i[a+36>>2];m=i[a+16>>2];b=i[a+4>>2];j=b;f=i[a>>2];i[e+24>>2]=f;i[e+28>>2]=b;b=i[a+12>>2];i[e+16>>2]=i[a+8>>2];i[e+20>>2]=b;a:{if(!d){h=k>>12;b=l>>12;break a}while(1){n=f>>>10&4194048;j=(((j&2147483647)<<1|f>>>31)&-2)+m|0;h=0;b=1;while(1){f=g[j+h|0];i[(e+8|0)+(h<<2)>>2]=((o(g[(h|2)+j|0]-f|0,n)|0)/16384|0)+(f<<8);f=b;b=0;h=1;if(f){continue}break}f=i[a+32>>2];l=i[a+28>>2]+l|0;b=l>>12;i[c>>2]=i[c>>2]+o(b,i[e+8>>2]);k=f+k|0;h=k>>12;i[c+4>>2]=i[c+4>>2]+o(h,i[e+12>>2]);zb(e+24|0,e+16|0);d=d+ -1|0;if(d){c=c+8|0;f=i[e+24>>2];j=i[e+28>>2];continue}break}f=i[e+24>>2];j=i[e+28>>2]}i[a+40>>2]=k;i[a+20>>2]=b;i[a+36>>2]=l;i[a+24>>2]=h;i[a>>2]=f;i[a+4>>2]=j;Xa=e+32|0}function LE(a){var b=0,c=0,d=0,e=0;b=Xa-16|0;Xa=b;e=(hNa(a),dNa(2));c=e&2147483647;a:{if(c>>>0<=1061752794){if(c>>>0<964689920){break a}a=fh(+a);break a}if(c>>>0<=1081824209){d=+a;if(c>>>0<=1075235811){if((e|0)<=-1){a=p(-eh(d+1.5707963267948966));break a}a=eh(d+ -1.5707963267948966);break a}a=fh(-(((e|0)>-1?-3.141592653589793:3.141592653589793)+d));break a}if(c>>>0<=1088565717){d=+a;if(c>>>0<=1085271519){if((e|0)<=-1){a=eh(d+4.71238898038469);break a}a=p(-eh(d+ -4.71238898038469));break a}a=fh(((e|0)>-1?-6.283185307179586:6.283185307179586)+d);break a}if(c>>>0>=2139095040){a=p(a-a);break a}b:{switch(sv(a,b+8|0)&3){case 0:a=fh(n[b+8>>3]);break a;case 1:a=eh(n[b+8>>3]);break a;case 2:a=fh(-n[b+8>>3]);break a;default:break b}}a=p(-eh(n[b+8>>3]))}Xa=b+16|0;return a}function C$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;b=Xa-32|0;Xa=b;d=Ab(b+16|0);i[114610]=0;c=OC(b+8|0);e=i[114610];i[114610]=0;a:{b:{c:{if((e|0)!=1){i[114610]=0;e=Pe(d);g=i[114610];i[114610]=0;if((g|0)==1){break c}g=xb(f);h=xb(f);f=lb(f);i[114610]=0;N(2510,c|0,e|0,g|0,(f<<2)+h|0)|0;c=i[114610];i[114610]=0;if((c|0)==1){break c}c=xb(d);i[114610]=0;e=i[114610];i[114610]=0;if((e|0)!=1){break b}a=B()|0;A()|0;break a}a=B()|0;A()|0;break a}a=B()|0;A()|0;break a}e=Ke(a);i[114610]=0;a=NC(b+8|0);f=i[114610];i[114610]=0;if((f|0)!=1){d:{i[114610]=0;f=Pe(e);g=i[114610];i[114610]=0;if((g|0)==1){break d}g=le(c);i[114610]=0;N(2513,a|0,f|0,c|0,c+g|0)|0;a=i[114610];i[114610]=0;if((a|0)==1){break d}eb(d);Xa=b+32|0;return}}a=B()|0;A()|0;nc(e)}eb(d);E(a|0);x()}function zda(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,m=0,n=0,o=0;if(l[b+44>>2]<l[b+24>>2]){i[b+44>>2]=i[b+24>>2]}m=-1;n=-1;h=f&24;a:{if(!h|((h|0)==24?(e|0)==1:0)){break a}h=i[b+44>>2];if(h){g=h-xb(b+32|0)|0;o=g;g=g>>31}b:{c:{switch(e|0){case 1:if(f&8){e=i[b+12>>2]-i[b+8>>2]|0;j=e;k=e>>31;break b}e=i[b+24>>2]-i[b+20>>2]|0;j=e;k=e>>31;break b;case 0:break b;case 2:break c;default:break a}}j=o;k=g}d=d+k|0;c=c+j|0;if(c>>>0<j>>>0){d=d+1|0}e=c;c=d;if(((d|0)<0?1:(d|0)<=0?e>>>0<0:0)|((g|0)<(d|0)?1:(g|0)<=(d|0)?o>>>0<e>>>0:0)){break a}d=f&8;d:{if(!(c|e)){break d}if(i[b+12>>2]?0:d){break a}if(!(f&16)){break d}if(!i[b+24>>2]){break a}}if(d){pm(b,i[b+8>>2],e+i[b+8>>2]|0,i[b+44>>2])}if(f&16){aw(b,i[b+20>>2],i[b+28>>2]);fr(b,e)}m=e;n=c}og(a,m,n)}function MI(a,b,c,d,e,f,i){var l=0,m=0,n=0;l=Xa-16|0;Xa=l;g[l+15|0]=b;g[l+14|0]=10;Lf(i,j[Xb(l+15|0,l+14|0)|0]);g[i+15|0]=c;g[i+16|0]=c;g[i+14|0]=e;g[i+13|0]=d;if(qb(i)){c=0;while(1){b=o(c,3)+f|0;d=j[b|0]|j[b+1|0]<<8;m=vb(i,c),n=d>>>4|0,h[m>>1]=n;a:{b:{if(!c){e=0;d=0;break b}d=c+ -1|0;if(k[vb(i,c)>>1]>=k[vb(i,d)>>1]){break a}e=c;d=k[vb(i,d)>>1]+1|0}m=vb(i,e),n=d,h[m>>1]=n}b=hd(j[b+2|0],0,64);m=vb(i,c),n=b,g[m+2|0]=n;c=c+1|0;if(c>>>0<qb(i)>>>0){continue}break}}c=j[i+12|0]&-2|a&1;g[i+12|0]=c;b=i;c:{d:{if(!(a&2)){break d}d=j[i+15|0];e=qb(i);c=j[i+12|0];if(e>>>0<d>>>0){break d}c=c|4;break c}c=c&251}g[b+12|0]=c;b=i;e:{f:{if(!(a&4)){break f}a=j[i+13|0];if(a>>>0>j[i+14|0]){break f}d=qb(i);c=j[i+12|0];if(d>>>0<a>>>0){break f}a=c|2;break e}a=c&253}g[b+12|0]=a;Xa=l+16|0}function E9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,j=0;e=Xa-32|0;Xa=e;h=Ab(a);a=Ab(e+16|0);a:{b:{c:{d:{f=b+24|0;if(!k[i[f>>2]+480192>>1]){break d}b=1;while(1){c=i[f>>2];i[114610]=0;c=C(2183,c|0,b&65535)|0;d=i[114610];i[114610]=0;if((d|0)==1){break c}i[114610]=0;c=C(85,e|0,c|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break c}d=Cc(c);i[114610]=0;C(1251,a|0,c|0)|0;g=i[114610];i[114610]=0;if((g|0)==1){break b}i[114610]=0;C(1995,a|0,38797)|0;g=i[114610];i[114610]=0;if((g|0)==1){break b}j=d^1|j;eb(c);b=b+1|0;if((b&65535)>>>0<=k[i[f>>2]+480192>>1]){continue}break}if(!(j&1)){break d}i[114610]=0;C(448,h|0,a|0)|0;b=i[114610];i[114610]=0;if((b|0)!=1){break d}b=B()|0;A()|0;break a}eb(a);Xa=e+32|0;return}b=B()|0;A()|0;break a}b=B()|0;A()|0;eb(c)}eb(a);eb(h);E(b|0);x()}function D9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,j=0;e=Xa-32|0;Xa=e;h=Ab(a);a=Ab(e+16|0);a:{b:{c:{d:{f=b+24|0;if(!k[i[f>>2]+480190>>1]){break d}b=1;while(1){c=i[f>>2];i[114610]=0;c=C(2184,c|0,b&65535)|0;d=i[114610];i[114610]=0;if((d|0)==1){break c}i[114610]=0;c=C(85,e|0,c|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break c}d=Cc(c);i[114610]=0;C(1251,a|0,c|0)|0;g=i[114610];i[114610]=0;if((g|0)==1){break b}i[114610]=0;C(1995,a|0,38797)|0;g=i[114610];i[114610]=0;if((g|0)==1){break b}j=d^1|j;eb(c);b=b+1|0;if((b&65535)>>>0<=k[i[f>>2]+480190>>1]){continue}break}if(!(j&1)){break d}i[114610]=0;C(448,h|0,a|0)|0;b=i[114610];i[114610]=0;if((b|0)!=1){break d}b=B()|0;A()|0;break a}eb(a);Xa=e+32|0;return}b=B()|0;A()|0;break a}b=B()|0;A()|0;eb(c)}eb(a);eb(h);E(b|0);x()}function C5(a,b,c,d){var e=0,f=0,g=0,h=0,j=0,k=0,l=0,n=0,o=0;a:{h=i[a+992>>2];b:{if(!h){e=i[a+4>>2];j=0;break b}o=y5(a,h);if(!o){break a}e=i[a+4>>2];if((e|0)>=1){n=(h|0)<1;while(1){if(!n){g=(f<<2)+a|0;k=g;e=0;while(1){l=i[g+800>>2]+(c+e<<2)|0;j=e<<2;m[l>>2]=p(m[o+(h+(e^-1)<<2)>>2]*m[j+i[k+928>>2]>>2])+p(m[j+o>>2]*m[l>>2]);e=e+1|0;if((h|0)!=(e|0)){continue}break}e=i[a+4>>2]}f=f+1|0;if((f|0)<(e|0)){continue}break}}j=i[a+992>>2]}n=b-d|0;i[a+992>>2]=n;if((e|0)>=1){f=0;while(1){if((b|0)>(d|0)){g=(f<<2)+a|0;k=g;e=0;l=d;while(1){m[i[k+928>>2]+(e<<2)>>2]=m[i[g+800>>2]+(l<<2)>>2];e=e+1|0;l=e+d|0;if((e|0)!=(n|0)){continue}break}e=i[a+4>>2]}f=f+1|0;if((f|0)<(e|0)){continue}break}}if(!j){break a}g=a;k=i[a+1416>>2];a=((b|0)<(d|0)?b:d)-c|0;i[g+1416>>2]=k+a;return a}return 0}function Upa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,k=0,l=0,m=0;e=Xa-16|0;Xa=e;i[e+8>>2]=c>>>4;i[e+4>>2]=i[a>>2];d=i[rb(e+8|0,e+4|0)>>2];b=jb(b);if(d){a=i[a+20>>2];c=d;while(1){g=j[b+4|0]|j[b+5|0]<<8|(j[b+6|0]<<16|j[b+7|0]<<24);i[e+8>>2]=j[b|0]|j[b+1|0]<<8|(j[b+2|0]<<16|j[b+3|0]<<24);i[e+12>>2]=g;mf(e+8|0,-1,1);f=n[e+8>>3]*32768;n[e+8>>3]=f;g=a;f=xd(f);a:{if(q(f)<2147483648){k=~~f;break a}k=-2147483648}l=g,m=Bc(k),h[l>>1]=m;g=j[b+12|0]|j[b+13|0]<<8|(j[b+14|0]<<16|j[b+15|0]<<24);i[e+8>>2]=j[b+8|0]|j[b+9|0]<<8|(j[b+10|0]<<16|j[b+11|0]<<24);i[e+12>>2]=g;mf(e+8|0,-1,1);f=n[e+8>>3]*32768;n[e+8>>3]=f;g=a;f=xd(f);b:{if(q(f)<2147483648){k=~~f;break b}k=-2147483648}l=g,m=Bc(k),h[l+2>>1]=m;a=a+4|0;b=b+16|0;c=c+ -1|0;if(c){continue}break}}Xa=e+16|0;return d<<4}function Wea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;d=Ph(a,b,c,d);i[a+4260>>2]=0;i[a>>2]=81568;c=a+4960|0;e=a+4504|0;b=e;while(1){Gj(b);b=b+24|0;if((c|0)!=(b|0)){continue}break}g[a+5046|0]=1;h[a+5044>>1]=0;i[a+4208>>2]=1063675494;i[a+4212>>2]=1065185444;i[a+4256>>2]=1059760811;b=a+4248|0;i[b>>2]=1065353216;i[b+4>>2]=1048525618;b=a+4240|0;i[b>>2]=1038174126;i[b+4>>2]=1065353216;b=a+4232|0;i[b>>2]=1047457519;i[b+4>>2]=1062836634;b=a+4224|0;i[b>>2]=1053079357;i[b+4>>2]=1059859440;b=a+4216|0;i[b>>2]=0;i[b+4>>2]=1032805417;i[114610]=0;I(1639,a+44|0,2,2)|0;b=i[114610];i[114610]=0;a:{if((b|0)!=1){i[114610]=0;L(1640,d|0);b=i[114610];i[114610]=0;if((b|0)!=1){break a}}a=B()|0;A()|0;while(1){c=c+ -24|0;uf(c);if((c|0)!=(e|0)){continue}break}ve(d);E(a|0);x()}return a|0}function Gt(a,b,c,d){var e=0,f=0,i=0,l=0,m=0,n=0,p=0;f=Xa-16|0;Xa=f;g[f+15|0]=d;g[b+12|0]=j[a|0]&15|j[b+12|0]&240;i=a+1|0;Lf(b,j[Xb(i,f+15|0)|0]);d=j[Xb(a+2|0,f+15|0)|0];g[b+13|0]=d;n=b,p=hd(j[a+3|0],d,j[f+15|0]),g[n+14|0]=p;d=j[Xb(a+4|0,f+15|0)|0];g[b+15|0]=d;n=b,p=hd(j[a+5|0],d,j[f+15|0]),g[n+16|0]=p;g[f+14|0]=25;if(j[Xb(f+14|0,i)|0]){d=0;while(1){e=o(d,3)+a|0;l=Eb(j[e+6|0]+c<<24>>24,0,64);n=vb(b,d),p=l,g[n+2|0]=p;e=e+7|0;e=j[e|0]|j[e+1|0]<<8;n=vb(b,d),p=e,h[n>>1]=p;a:{if(!d){break a}e=d+ -1|0;if(k[vb(b,d)>>1]>=k[vb(b,e)>>1]){break a}if(k[vb(b,d)>>1]>255){break a}l=j[vb(b,e)+1|0];m=vb(b,d);h[m>>1]=k[m>>1]|l<<8;if(k[vb(b,d)>>1]>=k[vb(b,e)>>1]){break a}e=vb(b,d);h[e>>1]=k[e>>1]+256}g[f+14|0]=25;d=d+1|0;if(d>>>0<j[Xb(f+14|0,i)|0]){continue}break}}Xa=f+16|0}function qla(a,b,c,d){var e=0,f=0;e=1;b=+(a|0)-b;f=b+ -3.5;if(!(q(f)<1e-8)){a:{b:{switch(d|0){case 0:e=.5-ee(b*.8975979010256552)*.5;break a;case 1:e=ee(b*.8975979010256552)*-.46+.54;break a;case 2:b=b*.8975979010256552;e=ee(b+b);e=ee(b)*-.5+.42+e*.08;break a;case 3:b=b*.8975979010256552;e=ee(b+b);e=ee(b)*-.49364+.44959+e*.05677;break a;case 4:b=b*.8975979010256552;e=ee(b+b);e=ee(b)*-.49755+.42323+e*.07922;break a;case 5:b=b*.8975979010256552;e=ee(b+b);e=ee(b)*-.48829+.35875+e*.14128+ee(b*3)*-.01168;break a;case 6:b=b*.8975979010256552;e=ee(b+b);e=ee(b)*-.49703+.40217+e*.09392+ee(b*3)*-.00183;break a;case 7:break b;default:break a}}b=b*.8975979010256552;e=ee(b+b);e=ee(b)*-.49804+.40243+e*.09831+ee(b*3)*-.00122}b=f*3.141592653589793;c=Hh(b*c)/b}return c*e}function lK(a,b,c){var d=0,e=0,f=0;e=Xa-16|0;Xa=e;a:{if(i[a+480180>>2]==4){d=j[b+833|0];if(c){g[b+833|0]=d&240|c&15;break a}c=d&15;break a}if(i[a+480180>>2]!=1048576){break a}if(c){g[b+833|0]=c;break a}c=j[b+833|0]}b:{c:{if(!(g[b+872|0]&1)|!(c&255)){break c}d=i[b+700>>2];if(!d){break c}if(!(j[a+480208|0]&16)){break b}d=i[b+700>>2];if(i[a+480180>>2]==4){break b}c=jx(a,c&15);f=XMa(c,c>>31,d,d>>31)+32768|0;c=_a;c=gc(YMa(f,f>>>0<32768?c+1|0:c,65536,0),_a);i[b+700>>2]=c;if((c|0)!=(d|0)){break c}a=a+1074308|0;kb(e+8|0,a,7);if(!(ib(e+8|0)|i[b+700>>2]>=2147483647)){i[b+700>>2]=i[b+700>>2]+1;break c}kb(e+8|0,a,7);if(!ib(e+8|0)){break c}a=i[b+700>>2];if((a|0)<2){break c}i[b+700>>2]=a+ -1}Xa=e+16|0;return}a=((c&255)<<2)+d|0;i[b+700>>2]=(a|0)<65535?a:65535;Xa=e+16|0}function kAa(a,b){var c=0,d=0,e=0,f=0;d=Xa-16|0;Xa=d;kd(b,0);h[d+14>>1]=j[a+35|0]<<2;h[d+12>>1]=256;e=b,f=k[ef(d+14|0,d+12|0)>>1],h[e+30>>1]=f;c=a+22|0;a:{if((j[c|0]|j[c+1|0]<<8|(j[c+2|0]<<16|j[c+3|0]<<24))>>>0<3){break a}i[b>>2]=j[c|0]|j[c+1|0]<<8|(j[c+2|0]<<16|j[c+3|0]<<24);c=a+26|0;i[b+4>>2]=j[c|0]|j[c+1|0]<<8|(j[c+2|0]<<16|j[c+3|0]<<24);c=a+30|0;i[d+8>>2]=j[c|0]|j[c+1|0]<<8|(j[c+2|0]<<16|j[c+3|0]<<24);i[d+4>>2]=1;e=b,f=i[Jc(d+8|0,d+4|0)>>2]+ -1|0,i[e+8>>2]=f;kc(b+8|0,i[b>>2]);b:{if(i[b+4>>2]+4>>>0>=l[b+8>>2]){i[b+4>>2]=0;i[b+8>>2]=0;break b}h[b+34>>1]=k[b+34>>1]|2}c=a+34|0;g[b+37|0]=j[c|0];e=b,f=hs(0,g[c|0]<<4),i[e+24>>2]=f;if(!(g[a+36|0]&1)){break a}h[b+34>>1]=k[b+34>>1]|1;i[b>>2]=i[b>>2]>>>1;i[b+4>>2]=i[b+4>>2]>>>1;i[b+8>>2]=i[b+8>>2]>>>1}Xa=d+16|0}function Vn(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;a:{b:{c:{d:{gNa(+a);b=dNa(1)|0;d=dNa(0)|0;if((b|0)>0?1:(b|0)>=0?d>>>0>=0:0){f=b;if(b>>>0>1048575){break d}}if(!(b&2147483647|d)){return-1/(a*a)}if((b|0)>-1){break c}return(a-a)/0}if(f>>>0>2146435071){break a}b=1072693248;g=-1023;if((f|0)!=1072693248){b=f;break b}if(d){break b}return 0}gNa(+(a*0x40000000000000));b=dNa(1)|0;d=dNa(0)|0;g=-1077}b=b+614242|0;e=+((b>>>20|0)+g|0);eNa(0,d|0);eNa(1,(b&1048575)+1072079006|0);a=+fNa()+ -1;c=a/(a+2);h=e*.6931471803691238;i=a;j=e*1.9082149292705877e-10;k=c;e=a*(a*.5);c=c*c;a=c*c;a=h+(i+(j+k*(e+(a*(a*(a*.15313837699209373+.22222198432149784)+.3999999999940942)+c*(a*(a*(a*.14798198605116586+.1818357216161805)+.2857142874366239)+.6666666666666735)))-e))}return a}function mJ(a,b,c){var d=0,e=0,f=0,h=0,k=0,l=0,m=0;e=Xa-16|0;Xa=e;h=-1;a:{if(!Sw(a,b,2)){break a}k=i[b+656>>2];f=a+1074308|0;kb(e+8|0,f,31);b:{if(ib(e+8|0)){d=i[b+752>>2];if(d){break b}break a}d=i[b+752>>2]}kb(e+8|0,f,31);f=d-ib(e+8|0)|0;d=i[a+480180>>2];d=(d|0)==4096?64:(d|0)==16384?192:512;d=Po(k+88|0,f,d,i[a+480180>>2]==4096?255:64)-(d>>>1|0)|0;if(j[b+748|0]&16){h=Eo(a,b,!(i[b+88>>2]&32768),d);break a}if(Vi(b)){if((d|0)==i[b+768>>2]){break a}i[b+768>>2]=d;g[b+872|0]=j[b+872|0]|8;break a}b=wo(a);i[e+8>>2]=d;f=c;c:{if((d|0)<=-1){i[e+8>>2]=0-d;Xj(e+8|0,255);a=(i[e+8>>2]<<2)+(b?26320:25296)|0;break c}Xj(e+8|0,255);a=(i[e+8>>2]<<2)+(b?25296:26320)|0}a=i[a>>2];b=a;d=a>>31;a=i[c>>2];l=f,m=gc(YMa(XMa(b,d,a,a>>31),_a,65536,0),_a),i[l>>2]=m}Xa=e+16|0;return h}function bF(a){var b=p(0),c=p(0),d=p(0),e=p(0),f=p(0),g=p(0),h=p(0),i=p(0),j=p(0),k=p(0),l=p(0),n=p(0),o=p(0),q=p(0);b=m[a+32>>2];c=m[a+8>>2];e=m[a+16>>2];f=p(p(b-c)+e);i=m[a>>2];j=m[a+24>>2];k=p(i-j);m[a+16>>2]=f+k;d=m[a+4>>2];g=m[a+20>>2];h=m[a+28>>2];l=p(p(d-p(g+h))*p(.8660253882408142));k=p(k-p(f*p(.5)));m[a+4>>2]=l+k;n=p(p(g+d)*p(.9848077297210693));f=p(m[a+12>>2]*p(.8660253882408142));o=p(p(h+d)*p(-.6427876353263855));q=p(p(n-f)+o);d=p(i+p(j*p(.5)));i=p(p(b+c)*p(.7660444378852844));b=p(p(e-b)*p(.1736481785774231));j=p(p(d-i)+b);m[a+12>>2]=q+j;m[a+20>>2]=j-q;m[a+28>>2]=k-l;g=p(p(g-h)*p(.3420201539993286));h=p(g-p(f+n));c=p(p(e+c)*p(.9396926164627075));b=p(p(d+c)-b);m[a+32>>2]=h+b;e=p(p(g+f)+o);c=p(p(d-c)+i);m[a+24>>2]=e+c;m[a+8>>2]=c-e;m[a>>2]=b-h}function h9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=Xa-32|0;Xa=c;g=Mg(a);f=b+24|0;a=k[i[f>>2]+480192>>1];i[114610]=0;D(1532,g|0,a|0);a=i[114610];i[114610]=0;a:{if((a|0)!=1){b:{c:{d:{e:{if(k[i[f>>2]+480192>>1]){a=1;while(1){d=i[f>>2];i[114610]=0;d=C(2183,d|0,a&65535)|0;e=i[114610];i[114610]=0;if((e|0)==1){break e}i[114610]=0;d=C(85,c|0,d|0)|0;e=i[114610];i[114610]=0;if((e|0)==1){break e}i[114610]=0;G(2185,c+16|0,b|0,d|0);e=i[114610];i[114610]=0;if((e|0)==1){break d}i[114610]=0;D(1534,g|0,c+16|0);e=i[114610];i[114610]=0;if((e|0)==1){break c}eb(c+16|0);eb(d);a=a+1|0;if((a&65535)>>>0<=k[i[f>>2]+480192>>1]){continue}break}}Xa=c+32|0;return}a=B()|0;A()|0;break a}a=B()|0;A()|0;break b}a=B()|0;A()|0;eb(c+16|0)}eb(d);break a}a=B()|0;A()|0}Sc(g);E(a|0);x()}function f9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=Xa-32|0;Xa=c;g=Mg(a);f=b+24|0;a=k[i[f>>2]+480190>>1];i[114610]=0;D(1532,g|0,a|0);a=i[114610];i[114610]=0;a:{if((a|0)!=1){b:{c:{d:{e:{if(k[i[f>>2]+480190>>1]){a=1;while(1){d=i[f>>2];i[114610]=0;d=C(2184,d|0,a&65535)|0;e=i[114610];i[114610]=0;if((e|0)==1){break e}i[114610]=0;d=C(85,c|0,d|0)|0;e=i[114610];i[114610]=0;if((e|0)==1){break e}i[114610]=0;G(2185,c+16|0,b|0,d|0);e=i[114610];i[114610]=0;if((e|0)==1){break d}i[114610]=0;D(1534,g|0,c+16|0);e=i[114610];i[114610]=0;if((e|0)==1){break c}eb(c+16|0);eb(d);a=a+1|0;if((a&65535)>>>0<=k[i[f>>2]+480190>>1]){continue}break}}Xa=c+32|0;return}a=B()|0;A()|0;break a}a=B()|0;A()|0;break b}a=B()|0;A()|0;eb(c+16|0)}eb(d);break a}a=B()|0;A()|0}Sc(g);E(a|0);x()}function Xpa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=p(0),k=0,l=0,n=0;e=Xa-16|0;Xa=e;i[e+12>>2]=c>>>3;i[e+8>>2]=i[a>>2];d=i[rb(e+12|0,e+8|0)>>2];b=jb(b);if(d){a=i[a+20>>2];c=d;while(1){f=j[b|0]|j[b+1|0]<<8|(j[b+2|0]<<16|j[b+3|0]<<24);i[e+12>>2]=f<<24|f<<8&16711680|(f>>>8&65280|f>>>24);Id(e+12|0,p(-1));g=p(m[e+12>>2]*p(32768));m[e+12>>2]=g;f=a;g=Qd(g);a:{if(p(q(g))<p(2147483648)){k=~~g;break a}k=-2147483648}l=f,n=Bc(k),h[l>>1]=n;f=j[b+4|0]|j[b+5|0]<<8|(j[b+6|0]<<16|j[b+7|0]<<24);i[e+12>>2]=f<<24|f<<8&16711680|(f>>>8&65280|f>>>24);Id(e+12|0,p(-1));g=p(m[e+12>>2]*p(32768));m[e+12>>2]=g;f=a;g=Qd(g);b:{if(p(q(g))<p(2147483648)){k=~~g;break b}k=-2147483648}l=f,n=Bc(k),h[l+2>>1]=n;a=a+4|0;b=b+8|0;c=c+ -1|0;if(c){continue}break}}Xa=e+16|0;return d<<3}function Hva(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,p=0,q=0,r=0;e=Xa-32|0;Xa=e;k=i[a+24>>2];l=i[a+20>>2];m=i[a+16>>2];g=i[a+4>>2];b=g;f=i[a>>2];i[e+24>>2]=f;i[e+28>>2]=b;g=i[a+12>>2];i[e+16>>2]=i[a+8>>2];i[e+20>>2]=g;if(d){while(1){g=((((b&2147483647)<<1|f>>>31)&2147483646)<<1)+m|0;b=(f>>>21&2040)+27872|0;n=h[b+6>>1];p=h[b+4>>1];q=h[b+2>>1];r=h[b>>1];j=0;b=1;while(1){f=j<<1;i[(e+8|0)+(j<<2)>>2]=(((o(h[f+g>>1],q)+o(h[(f|-4)+g>>1],r)|0)+o(h[(f|4)+g>>1],p)|0)+o(h[(f|8)+g>>1],n)|0)/16384;f=b;b=0;j=1;if(f){continue}break}i[c>>2]=i[c>>2]+o(i[e+8>>2],l);i[c+4>>2]=i[c+4>>2]+o(i[e+12>>2],k);zb(e+24|0,e+16|0);d=d+ -1|0;if(d){c=c+8|0;f=i[e+24>>2];b=i[e+28>>2];continue}break}f=i[e+24>>2];b=i[e+28>>2]}i[a>>2]=f;i[a+4>>2]=b;Xa=e+32|0}function Spa(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,k=0,l=0,m=0,n=0,p=0,q=0,r=0;l=Xa-16|0;Xa=l;q=l,r=o(i[a>>2],$d(a)),i[q+12>>2]=r;kc(l+12|0,c);c=jb(b);k=i[e+4>>2];f=i[l+12>>2];a:{if(!f){g=k;break a}while(1){e=jb(j[c|0]);e=jb(j[c+1|0])<<16|e<<8|jb(j[c+2|0])<<24;b:{if((e|0)<=-1){g=-2147483648;if((e|0)==-2147483648){break b}e=0-e|0}g=e>>>0>k>>>0?e:k}c=c+3|0;k=g;f=f+ -1|0;if(f){continue}break}}c:{if(!g){break c}e=i[l+12>>2];if(!e){break c}m=g+ -1|0;n=g>>>1|0;p=g;c=i[a+20>>2];while(1){a=jb(j[b|0]);a=jb(j[b+1|0])<<16|a<<8|jb(j[b+2|0])<<24;k=a>>31;f=a;a=k;k=a<<31|f>>>1;f=n|f<<31;a=m&a>>31;q=c,r=gc(YMa(f-a|0,k-(f>>>0<a>>>0)|0,p,0),_a)>>>16|0,h[q>>1]=r;b=b+3|0;c=c+2|0;e=e+ -1|0;if(e){continue}break}}if(d){i[d>>2]=g}Xa=l+16|0;return i[l+12>>2]}function Rpa(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,k=0,l=0,m=0,n=0,p=0,q=0,r=0;l=Xa-16|0;Xa=l;q=l,r=o(i[a>>2],$d(a)),i[q+12>>2]=r;kc(l+12|0,c);c=jb(b);k=i[e+4>>2];f=i[l+12>>2];a:{if(!f){g=k;break a}while(1){e=jb(j[c+2|0]);e=jb(j[c+1|0])<<16|e<<8|jb(j[c|0])<<24;b:{if((e|0)<=-1){g=-2147483648;if((e|0)==-2147483648){break b}e=0-e|0}g=e>>>0>k>>>0?e:k}c=c+3|0;k=g;f=f+ -1|0;if(f){continue}break}}c:{if(!g){break c}e=i[l+12>>2];if(!e){break c}m=g+ -1|0;n=g>>>1|0;p=g;c=i[a+20>>2];while(1){a=jb(j[b+2|0]);a=jb(j[b+1|0])<<16|a<<8|jb(j[b|0])<<24;k=a>>31;f=a;a=k;k=a<<31|f>>>1;f=n|f<<31;a=m&a>>31;q=c,r=gc(YMa(f-a|0,k-(f>>>0<a>>>0)|0,p,0),_a)>>>16|0,h[q>>1]=r;b=b+3|0;c=c+2|0;e=e+ -1|0;if(e){continue}break}}if(d){i[d>>2]=g}Xa=l+16|0;return i[l+12>>2]}function G$(a,b,c,d,e,f,h,j,k,l){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0;m=Xa-16|0;Xa=m;a:{if(a){a=TC(c);b:{if(b){oj(m,a);b=i[m>>2];g[d|0]=b;g[d+1|0]=b>>>8;g[d+2|0]=b>>>16;g[d+3|0]=b>>>24;nj(m,a);break b}mq(m,a);b=i[m>>2];g[d|0]=b;g[d+1|0]=b>>>8;g[d+2|0]=b>>>16;g[d+3|0]=b>>>24;Eg(m,a)}Ah(k,m);nc(m);n=e,o=Eh(a),i[n>>2]=o;n=f,o=Dh(a),i[n>>2]=o;Pf(m,a);mb(h,m);eb(m);Fg(m,a);Ah(j,m);nc(m);a=mj(a);break a}a=SC(c);c:{if(b){oj(m,a);b=i[m>>2];g[d|0]=b;g[d+1|0]=b>>>8;g[d+2|0]=b>>>16;g[d+3|0]=b>>>24;nj(m,a);break c}mq(m,a);b=i[m>>2];g[d|0]=b;g[d+1|0]=b>>>8;g[d+2|0]=b>>>16;g[d+3|0]=b>>>24;Eg(m,a)}Ah(k,m);nc(m);n=e,o=Eh(a),i[n>>2]=o;n=f,o=Dh(a),i[n>>2]=o;Pf(m,a);mb(h,m);eb(m);Fg(m,a);Ah(j,m);nc(m);a=mj(a)}i[l>>2]=a;Xa=m+16|0}function $la(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;e=Xa-48|0;Xa=e;c=78880;g=_la(e+32|0);a=Oc(a);while(1){if(i[c>>2]==(b|0)){f=i[c+4>>2];i[114610]=0;f=C(2,e+16|0,f|0)|0;d=i[114610];i[114610]=0;a:{b:{c:{d:{e:{f:{if((d|0)!=1){i[114610]=0;G(1520,e|0,g|0,f|0);d=i[114610];i[114610]=0;if((d|0)==1){break d}if(!j[e+4|0]){break a}if(!Cc(a)){i[114610]=0;d=C(2,e|0,20800)|0;h=i[114610];i[114610]=0;if((h|0)==1){break f}i[114610]=0;C(192,a|0,d|0)|0;h=i[114610];i[114610]=0;if((h|0)==1){break e}eb(d)}i[114610]=0;C(192,a|0,f|0)|0;d=i[114610];i[114610]=0;if((d|0)!=1){break a}c=B()|0;A()|0;break c}c=B()|0;A()|0;break b}c=B()|0;A()|0;break c}c=B()|0;A()|0;eb(d);break c}c=B()|0;A()|0}eb(f)}eb(a);bJ(g);E(c|0);x()}eb(f)}c=c+12|0;if((c|0)!=78928){continue}break}bJ(g);Xa=e+48|0}function $ia(a,b,c){var d=0,e=0,f=p(0),g=0,j=0,l=0;a:{if(c){g=i[a+36>>2];if(g){break a}}return Uk(a,b+c<<16>>16)}d=g+1|0;b:{if((c|0)>=0){e=c;c=(c|0)/(d|0)|0;e=e-o(d,c)|0;break b}e=g-((c^-1)%(d|0)|0)|0;c=((c+1|0)/(d|0)|0)+ -1|0}l=h[a+28>>1];j=a+4|0;qb(j);f=p(1);c=b+c<<16>>16;c:{if((l|0)>(c|0)){break c}if((k[a+28>>1]+qb(j)<<16)+ -65536>>16<(c|0)){break c}if(!e){return m[vb(j,c-h[a+28>>1]|0)>>2]}b=k[a>>1];d:{if((b|0)==3){b=a+16|0;if(qb(b)){f=m[vb(b,e+ -1|0)>>2];break d}b=k[a>>1]}e:{if((b&65535)!=1){break e}b=a+16|0;if(!qb(b)){break e}d=k[a+30>>1];if((c|0)>=0){d=(c|0)%(d|0)|0}else{d=d+((c^-1)%(d|0)^-1)|0}f=m[vb(b,(o(d<<16>>16,g)+e|0)+ -1|0)>>2];break d}f=Wd(p(Uk(a,(c<<16)+65536>>16)/Uk(a,c)),p(p(e|0)/p(d|0)))}f=p(m[vb(j,c-h[a+28>>1]|0)>>2]*f)}return f}function Bm(a,b){var c=0,d=0,e=0,f=0,h=0,l=0,m=0;c=i[b+88>>2];d=c|2048;i[b+88>>2]=d;e=i[b+656>>2];if(!(!e|g[b+724|0]&1)){d=c|6144;i[b+88>>2]=d}a:{if(!i[b+76>>2]){break a}b:{if(!(d&8)|c&2048){break b}c=i[b+104>>2];if(!c){break b}f=k[c+34>>1];if(f&2){i[b+88>>2]=(f&4?d|4:d&-135)|2;d=i[c>>2];i[b+76>>2]=d;f=i[c+4>>2];i[b+80>>2]=f;c=i[c+8>>2];i[b+84>>2]=c;if(d>>>0>c>>>0){i[b+76>>2]=c;d=c}h=d;d=i[b+4>>2];if(h>>>0>=d>>>0){break b}i[b>>2]=0;i[b+4>>2]=f+((d-f>>>0)%(c-f>>>0)|0);break b}i[b+88>>2]=d&-135;i[b+76>>2]=i[c>>2]}if(!e){break a}if(!(!i[e>>2]|(i[a+480180>>2]&1064964?0:!(j[e+60|0]&2)))){i[b+88>>2]=i[b+88>>2]|4096}if(j[e+65|0]==255|i[b+732>>2]!=-1){break a}a=e+48|0;l=b,m=Po(a,i[b+728>>2],256,64),i[l+732>>2]=m;l=b,m=k[vb(a,j[e+65|0])>>1],i[l+728>>2]=m}}function _ka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;kd(c,0);h[c+28>>1]=j[a+36|0]<<2;d=j[a+37|0];h[c+32>>1]=64;h[c+30>>1]=d<<2;d=a+40|0;i[c>>2]=j[d|0]|j[d+1|0]<<8|(j[d+2|0]<<16|j[d+3|0]<<24);d=a+44|0;i[c+4>>2]=j[d|0]|j[d+1|0]<<8|(j[d+2|0]<<16|j[d+3|0]<<24);d=a+48|0;i[c+8>>2]=j[d|0]|j[d+1|0]<<8|(j[d+2|0]<<16|j[d+3|0]<<24);d=a+52|0;i[c+24>>2]=j[d|0]|j[d+1|0]<<8|(j[d+2|0]<<16|j[d+3|0]<<24);d=b+151|0;if(5>j[d|0]){g[c+38|0]=j[j[d|0]+31834|0]}g[c+39|0]=j[b+152|0];d=b+156|0;g[c+41|0]=(j[d|0]|j[d+1|0]<<8)>>>4;b=b+154|0;b=(j[b|0]|j[b+1|0]<<8)>>>2|0;g[c+40|0]=b;if(j[c+41|0]|b&255){g[c+39|0]=j[c+39|0]^-1}a=a+38|0;if(j[a|0]&4){h[c+34>>1]=k[c+34>>1]|1}if(j[a|0]&8){h[c+34>>1]=k[c+34>>1]|2}if(j[a|0]&16){h[c+34>>1]=k[c+34>>1]|4}if(j[a|0]&32){h[c+34>>1]=k[c+34>>1]|32}}function XG(a){var b=0,c=0,d=0,e=0,f=0,g=p(0),h=0,j=0,k=0,n=0,o=0,q=0,r=p(0);c=we(i[a+16>>2]);g=p(p(m[a+4220>>2]*p(.9980000257492065))+p(.0010000000474974513));d=-9965.784284662086/+p(p(p(m[a+4216>>2]*p(2999.9990234375))+p(.0010000000474974513))*p(c>>>0));q=a,r=p(zg(d*+l[a+4288>>2])),m[q+4232>>2]=r;q=a+4236|0,r=p(zg(d*+l[a+4292>>2])),m[q>>2]=r;o=d*(1/+g+ -1);c=0;h=a+4272|0;j=a+4232|0;while(1){k=i[(c<<2)+h>>2];e=c<<1&-4;f=zg(o*+(k+i[(e+h|0)+16>>2]>>>0));b=zg(d*+(k>>>0));g=m[e+j>>2];e=(c<<3)+j|0;f=f*.5;m[e+12>>2]=b*(.5-f);m[e+8>>2]=b*(f+.5);b=b*+g;b=(((b+1)*b+1)*b+1)*b+1;n=b*b+n;c=c+1|0;if((c|0)!=4){continue}break}d=zg(+WG(m[a+4208>>2])*.16609640474436813);b=zg(+WG(m[a+4212>>2])*.33219280948873625);m[a+4228>>2]=d*4*w(b)/w(n);m[a+4224>>2]=d*w(1-b)}function K$(a,b,c,d,e,f,h,j,k,l){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0;m=Xa-16|0;Xa=m;a:{if(a){a=XC(c);b:{if(b){oj(m,a);b=i[m>>2];g[d|0]=b;g[d+1|0]=b>>>8;g[d+2|0]=b>>>16;g[d+3|0]=b>>>24;nj(m,a);break b}mq(m,a);b=i[m>>2];g[d|0]=b;g[d+1|0]=b>>>8;g[d+2|0]=b>>>16;g[d+3|0]=b>>>24;Eg(m,a)}mb(k,m);eb(m);n=e,o=Eh(a),g[n|0]=o;n=f,o=Dh(a),g[n|0]=o;Pf(m,a);mb(h,m);eb(m);Fg(m,a);mb(j,m);eb(m);a=mj(a);break a}a=WC(c);c:{if(b){oj(m,a);b=i[m>>2];g[d|0]=b;g[d+1|0]=b>>>8;g[d+2|0]=b>>>16;g[d+3|0]=b>>>24;nj(m,a);break c}mq(m,a);b=i[m>>2];g[d|0]=b;g[d+1|0]=b>>>8;g[d+2|0]=b>>>16;g[d+3|0]=b>>>24;Eg(m,a)}mb(k,m);eb(m);n=e,o=Eh(a),g[n|0]=o;n=f,o=Dh(a),g[n|0]=o;Pf(m,a);mb(h,m);eb(m);Fg(m,a);mb(j,m);eb(m);a=mj(a)}i[l>>2]=a;Xa=m+16|0}function c8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=Xa-80|0;Xa=d;a=i[a+4>>2];_t(d+16|0,b);i[114610]=0;b=C(2,d|0,38582)|0;e=i[114610];i[114610]=0;a:{b:{c:{d:{e:{f:{g:{h:{if((e|0)!=1){i[114610]=0;G(3,d+32|0,d+16|0,b|0);e=i[114610];i[114610]=0;if((e|0)==1){break h}i[114610]=0;G(723,d+48|0,d+32|0,c|0);c=i[114610];i[114610]=0;if((c|0)==1){break g}i[114610]=0;G(9,d- -64|0,0,d+48|0);c=i[114610];i[114610]=0;if((c|0)==1){break f}c=i[i[a>>2]+8>>2];i[114610]=0;D(c|0,a|0,d- -64|0);a=i[114610];i[114610]=0;if((a|0)==1){break e}eb(d- -64|0);eb(d+48|0);eb(d+32|0);eb(b);eb(d+16|0);Xa=d+80|0;return}a=B()|0;A()|0;break a}a=B()|0;A()|0;break b}a=B()|0;A()|0;break c}a=B()|0;A()|0;break d}a=B()|0;A()|0;eb(d- -64|0)}eb(d+48|0)}eb(d+32|0)}eb(b)}eb(d+16|0);E(a|0);x()}function Uv(a,b,c,d,e,f){var h=0,j=0,k=p(0),l=0;h=Xa-96|0;Xa=h;j=a+24|0;no(i[j>>2]);g[i[j>>2]+1304512|0]=i[a+52>>2]!=0;i[h+92>>2]=f;i[h+88>>2]=e;i[h+84>>2]=d;i[h+80>>2]=c;c=oG(h+32|0,h+80|0,pG(h+80|0),b);d=i[a+32>>2];k=m[a+48>>2];e=i[c+12>>2];i[h+8>>2]=i[c+8>>2];i[h+12>>2]=e;e=i[c+4>>2];i[h>>2]=i[c>>2];i[h+4>>2]=e;d=Caa(h+48|0,h,d,k);e=0;a:{while(1){if(b){c=i[j>>2];i[h+24>>2]=b;i[h+28>>2]=0;i[114610]=0;i[h+16>>2]=134217727;i[h+20>>2]=0;f=C(2153,h+24|0,h+16|0)|0;l=i[114610];i[114610]=0;if((l|0)==1){break a}f=i[f>>2];i[114610]=0;c=I(2154,c|0,f|0,d|0)|0;f=i[114610];i[114610]=0;if((f|0)==1){break a}e=c+e|0;b=b-c|0;if(c){continue}}break}if(!(i[a+52>>2]!=1|e)){a=i[j>>2];i[a+480208>>2]=i[a+480208>>2]&-513}Xa=h+96|0;return e}a=B()|0;A()|0;E(a|0);x()}function Tv(a,b,c,d,e,f){var h=0,j=0,k=p(0),l=0;h=Xa-96|0;Xa=h;j=a+24|0;no(i[j>>2]);g[i[j>>2]+1304512|0]=i[a+52>>2]!=0;i[h+92>>2]=f;i[h+88>>2]=e;i[h+84>>2]=d;i[h+80>>2]=c;c=oG(h+32|0,h+80|0,pG(h+80|0),b);d=i[a+32>>2];k=m[a+48>>2];e=i[c+12>>2];i[h+8>>2]=i[c+8>>2];i[h+12>>2]=e;e=i[c+4>>2];i[h>>2]=i[c>>2];i[h+4>>2]=e;d=zaa(h+48|0,h,d,k);e=0;a:{while(1){if(b){c=i[j>>2];i[h+24>>2]=b;i[h+28>>2]=0;i[114610]=0;i[h+16>>2]=134217727;i[h+20>>2]=0;f=C(2153,h+24|0,h+16|0)|0;l=i[114610];i[114610]=0;if((l|0)==1){break a}f=i[f>>2];i[114610]=0;c=I(2154,c|0,f|0,d|0)|0;f=i[114610];i[114610]=0;if((f|0)==1){break a}e=c+e|0;b=b-c|0;if(c){continue}}break}if(!(i[a+52>>2]!=1|e)){a=i[j>>2];i[a+480208>>2]=i[a+480208>>2]&-513}Xa=h+96|0;return e}a=B()|0;A()|0;E(a|0);x()}function Fx(a,b,c){var d=0,e=0,f=0,h=0,k=0;a:{h=xsa(a,b);if((h|0)==255){break a}b=0;if(Si(a)){break a}e=ji(a+314|0,h);d=j[c+8|0]|j[c+9|0]<<8|(j[c+10|0]<<16|j[c+11|0]<<24);g[e+8|0]=d;g[e+9|0]=d>>>8;g[e+10|0]=d>>>16;g[e+11|0]=d>>>24;d=j[c+4|0]|j[c+5|0]<<8|(j[c+6|0]<<16|j[c+7|0]<<24);f=j[c|0]|j[c+1|0]<<8|(j[c+2|0]<<16|j[c+3|0]<<24);g[e|0]=f;g[e+1|0]=f>>>8;g[e+2|0]=f>>>16;g[e+3|0]=f>>>24;g[e+4|0]=d;g[e+5|0]=d>>>8;g[e+6|0]=d>>>16;g[e+7|0]=d>>>24;f=GL(h);k=f+3|0;d=1;while(1){e=d;d=d?f:k;Ng(i[a>>2],(d|32)&65535,j[Nb(c,b)|0]);Ng(i[a>>2],(d|64)&65535,j[Nb(c,b|2)|0]);Ng(i[a>>2],(d|96)&65535,j[Nb(c,b|4)|0]);Ng(i[a>>2],(d|128)&65535,j[Nb(c,b|6)|0]);Ng(i[a>>2],(d|224)&65535,j[Nb(c,b|8)|0]);d=0;b=1;if(e){continue}break}Ng(i[a>>2],bs(h)|192,j[Nb(c,10)|0])}}function Nla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,j=0;c=Xa-80|0;Xa=c;h=wL(a,1<<b+ -1);i[a+12>>2]=b;a:{b=1<<b;f=b>>>2|0;if(f){j=1/+(b>>>0);b=f;e=1;while(1){i[114610]=0;n[c+40>>3]=+(b>>>0)*-6.283185307179586*j;G(1529,c+48|0,30848,c+40|0);d=i[114610];i[114610]=0;if((d|0)==1){break a}i[114610]=0;D(1220,c- -64|0,c+48|0);d=i[114610];i[114610]=0;if((d|0)==1){break a}d=_b(h,e);g=i[c+76>>2];i[d+8>>2]=i[c+72>>2];i[d+12>>2]=g;g=i[c+68>>2];i[d>>2]=i[c+64>>2];i[d+4>>2]=g;e=e<<1;b=b>>>1|0;if(b){continue}break}}b=cl(c+24|0,1,0);i[114610]=0;e=i[b+12>>2];i[c+16>>2]=i[b+8>>2];i[c+20>>2]=e;e=i[b+4>>2];i[c+8>>2]=i[b>>2];i[c+12>>2]=e;J(1530,a|0,0,f|0,c+8|0);b=i[114610];i[114610]=0;if((b|0)==1){break a}Xa=c+80|0;return a|0}a=B()|0;A()|0;Go(h);E(a|0);x()}function Fw(a){a=a|0;var b=0;a:{b:{c:{if(j[a+3|0]!=19){break c}g[a+3|0]=20;d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{b=j[a+5|0];switch(b>>>4|0){case 6:break j;case 5:break k;case 4:break l;case 3:break m;case 2:break n;case 1:break o;case 0:break b;case 13:break d;case 12:break e;case 11:break f;case 10:break g;case 9:break h;case 7:break i;default:break c}}g[a+3|0]=2;break a}g[a+3|0]=3;break a}g[a+5|0]=b&15|16;return}g[a+5|0]=b&3|48;return}g[a+5|0]=b&15|32;return}g[a+5|0]=b&15|176;return}g[a+5|0]=b&3|64;return}g[a+3|0]=15;g[a+5|0]=b&15;return}if(b&15){g[a+3|0]=11;g[a+5|0]=b<<4|15;return}break b}if(b&15){g[a+3|0]=11;break a}break b}if((b|0)!=192){break c}g[a|0]=254;break b}if((b|0)!=208){break c}g[a+3|0]=0}return}g[a+3|0]=0;return}g[a+5|0]=b|240}function exa(a,b){var c=0,d=0,e=0;d=Xa-16|0;Xa=d;if(!(j[b+5|0]|j[b+3|0]!=4)){Ld(d+8|0,a,k[a+14>>1]);Od(d+8|0,0);g[b+3|0]=0}c=j[b+2|0];a:{if((c|0)!=11){break a}c=11;if(j[b+4|0]){break a}Ld(d+8|0,a,k[a+14>>1]);c=0;Od(d+8|0,0);g[b+2|0]=0}b:{c:{d:{if(!j[b|0]){Ld(d+8|0,a,k[a+14>>1]);if(ib(d+8|0)){break d}c=j[b+2|0]}e=j[b+3|0];Ld(d+8|0,a,k[a+14>>1]);Od(d+8|0,(e|0)==4|(c|0)==11);c=j[b+3|0];break c}c=j[b+3|0];e=j[b+2|0];if(!(c|(e|0)==11)){g[b+5|0]=0;g[b+3|0]=4;break b}if(e|(c|0)==4){break c}g[b+4|0]=0;g[b+2|0]=11}e:{if(!(!j[a+16|0]|c)){g[b+5|0]=125;g[b+3|0]=17;break e}f:{switch(c+ -16|0){case 0:break f;case 1:break e;default:break b}}if(j[b+5|0]){break b}g[b+5|0]=6;g[a+16|0]=1;break b}g[a+16|0]=0}h[a+14>>1]=(k[a+14>>1]+1>>>0)%k[a+12>>1];Xa=d+16|0}function lHa(a,b){var c=0,d=0;d=Xa-32|0;Xa=d;kd(b,0);oi(d,1,a);oc(d+16|0,d);i[114610]=0;C(370,b+43|0,d+16|0)|0;c=i[114610];i[114610]=0;if((c|0)!=1){eb(d+16|0);c=a+16|0;i[b>>2]=j[c|0]|j[c+1|0]<<8|(j[c+2|0]<<16|j[c+3|0]<<24);c=a+20|0;i[b+4>>2]=j[c|0]|j[c+1|0]<<8|(j[c+2|0]<<16|j[c+3|0]<<24);c=a+24|0;i[b+8>>2]=j[c|0]|j[c+1|0]<<8|(j[c+2|0]<<16|j[c+3|0]<<24);c=a+28|0;i[b+24>>2]=j[c|0]|j[c+1|0]<<8|(j[c+2|0]<<16|j[c+3|0]<<24);h[b+30>>1]=j[a+32|0]<<2;h[b+28>>1]=j[a+33|0];a=a+48|0;if(g[a|0]&1){h[b+34>>1]=k[b+34>>1]|2}if(j[a|0]&2){h[b+34>>1]=k[b+34>>1]|4}if(j[a|0]&4){h[b+34>>1]=k[b+34>>1]|1;i[b>>2]=i[b>>2]>>>1;i[b+4>>2]=i[b+4>>2]>>>1;i[b+8>>2]=i[b+8>>2]>>>1}if(j[a|0]&8){h[b+34>>1]=k[b+34>>1]|32}Xa=d+32|0;return}a=B()|0;A()|0;eb(d+16|0);E(a|0);x()}function Nya(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,h=0;c=Xa-16|0;Xa=c;f=Ab(a+4|0);d=Hya(a+16|0);g[a+20|0]=0;h=Aya(a+24|0);i[114610]=0;L(80,c+8|0);b=i[114610];i[114610]=0;a:{b:{c:{if((b|0)!=1){Xx(d,sd(c+8|0));$e(c+8|0);g[a+20|0]=0;b=0;break c}b=oa(71348,71324)|0;e=A()|0;if((e|0)==(U(71348)|0)){M(b|0)|0;i[114610]=0;K(81);a=i[114610];i[114610]=0;if((a|0)==1){b=B()|0;A()|0;i[114610]=0;K(20);a=i[114610];i[114610]=0;if((a|0)!=1){break b}a=H(0)|0;A()|0;gb(a)}x()}if((U(71324)|0)!=(e|0)){break b}M(b|0)|0;g[a+20|0]=0;i[114610]=0;K(20);b=i[114610];i[114610]=0;if((b|0)==1){b=B()|0;A()|0;break b}b=j[a+20|0]}if(b&255){break a}i[114610]=0;L(82,a|0);b=i[114610];i[114610]=0;if((b|0)!=1){break a}b=B()|0;A()|0}$e(h);$e(d);eb(f);E(b|0);x()}Xa=c+16|0;return a|0}function hza(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=Xa-32|0;Xa=d;kd(b,0);oi(d,1,a);oc(d+16|0,d);i[114610]=0;C(370,b+43|0,d+16|0)|0;c=i[114610];i[114610]=0;if((c|0)!=1){eb(d+16|0);c=a+48|0;i[b>>2]=j[c|0]|j[c+1|0]<<8|(j[c+2|0]<<16|j[c+3|0]<<24);c=a+52|0;i[b+4>>2]=j[c|0]|j[c+1|0]<<8|(j[c+2|0]<<16|j[c+3|0]<<24);c=a+56|0;i[b+8>>2]=j[c|0]|j[c+1|0]<<8|(j[c+2|0]<<16|j[c+3|0]<<24);c=a+62|0;i[b+24>>2]=j[c|0]|j[c+1|0]<<8;gs(b,+((j[a+60|0]^8)+ -120|0)*.005208333333333333);g[d+16|0]=j[a+61|0];g[d|0]=64;e=b,f=j[Xb(d+16|0,d)|0]<<2,h[e+30>>1]=f;h[b+34>>1]=0;a=a+47|0;if(j[a|0]&4){h[b+34>>1]=k[b+34>>1]|1;i[b>>2]=i[b>>2]>>>1}if(j[a|0]&32){h[b+34>>1]=k[b+34>>1]|4}if(g[a|0]<=-1){h[b+34>>1]=k[b+34>>1]|2}Xa=d+32|0;return}a=B()|0;A()|0;eb(d+16|0);E(a|0);x()}function vD(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0;g=Xa-272|0;Xa=g;h=i[b>>2];i[g+12>>2]=h;j=a?a:g+16|0;e=0;a:{b:{c:{d=a?d:256;if(!d|!h){break c}f=d>>>0>c>>>0;if(!(d>>>0<=c>>>0|c>>>0>32)){break b}while(1){f=f?c:d;c=c-f|0;f=C2(j,g+12|0,f);if((f|0)==-1){d=0;h=i[g+12>>2];e=-1;break c}h=(g+16|0)==(j|0);j=h?j:f+j|0;e=e+f|0;d=d-(h?0:f)|0;h=i[g+12>>2];if(!d|!h){break c}f=c>>>0<d>>>0;if(c>>>0>32|c>>>0>=d>>>0){continue}break}break b}if(!h){break a}}if(!d|!c){break a}f=e;while(1){d:{k=Aj(j,i[h>>2],0);e:{if(k+1>>>0<=1){e=-1;if(k){break a}i[g+12>>2]=0;break e}h=i[g+12>>2]+4|0;i[g+12>>2]=h;f=f+k|0;d=d-k|0;if(d){break d}}e=f;break a}j=j+k|0;e=f;c=c+ -1|0;if(c){continue}break}}if(a){i[b>>2]=i[g+12>>2]}Xa=g+272|0;return e|0}function nca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=Xa-32|0;Xa=d;i[114610]=0;L(2015,a|0);e=i[114610];i[114610]=0;a:{b:{c:{if((e|0)==1){break c}i[114610]=0;L(2041,b|0);e=i[114610];i[114610]=0;if((e|0)==1){break c}i[114610]=0;L(2041,c|0);f=i[114610];i[114610]=0;e=1;if((f|0)==1){break c}f=i[a+24>>2];b=Zb(d+24|0,b);c=Zb(d+16|0,c);i[114610]=0;g=i[b+4>>2];i[d+8>>2]=i[b>>2];i[d+12>>2]=g;b=i[c+4>>2];i[d>>2]=i[c>>2];i[d+4>>2]=b;J(2085,f|0,d+8|0,d|0,1);b=i[114610];i[114610]=0;if((b|0)!=1){break b}}b=H(0)|0;A()|0;M(b|0)|0;i[114610]=0;J(1989,37153,a|0,0,0);a=i[114610];i[114610]=0;if((a|0)==1){break a}O();e=0}Xa=d+32|0;return e|0}a=B()|0;A()|0;i[114610]=0;K(20);b=i[114610];i[114610]=0;if((b|0)!=1){E(a|0);x()}a=H(0)|0;A()|0;gb(a);x()}function dJ(a,b){var c=p(0),d=p(0),e=p(0);a:{b:{c:{switch(b|0){case 0:ko(a,p(1));jo(a,p(3.725290298461914e-9));io(a,p(268435456));ho(a,0);break b;case 1:ko(a,p(32));jo(a,p(4.656612873077393e-10));io(a,p(2147483648));ho(a,0);break b;case 2:ko(a,p(2));jo(a,p(7.450580596923828e-9));io(a,p(134217728));ho(a,1);break b;default:ko(a,p(1));jo(a,p(7.450580596923828e-9));io(a,p(134217728));ho(a,1);Pw(a,0);Xk(a,1);Ow(a,1);d=p(256);c=p(128);e=p(128);b=0;break a;case 4:case 5:break c}}ko(a,p(.75));jo(a,p(7.450580596923828e-9));io(a,p(134217728));ho(a,1);Pw(a,0);b=(b|0)==4;Xk(a,b?2:3);Ow(a,1);d=p(256);c=b?p(256):p(192);e=c;b=1;break a}Pw(a,1);Xk(a,0);Ow(a,0);d=p(128);e=p(100);c=p(256);b=4}m[a+16>>2]=c;m[a+20>>2]=e;m[a+24>>2]=d;i[a+28>>2]=b}function tP(a){var b=0,c=0;b=Xa-48|0;Xa=b;c=j[a+8|0]|j[a+9|0]<<8|(j[a+10|0]<<16|j[a+11|0]<<24);i[b+8>>2]=(c<<24|c<<8&16711680|(c>>>8&65280|c>>>24))+788;i[b+12>>2]=0;c=j[a+16|0]|j[a+17|0]<<8|(j[a+18|0]<<16|j[a+19|0]<<24);i[b+16>>2]=c<<24|c<<8&16711680|(c>>>8&65280|c>>>24);i[b+20>>2]=0;c=j[a+24|0]|j[a+25|0]<<8|(j[a+26|0]<<16|j[a+27|0]<<24);i[b+24>>2]=c<<24|c<<8&16711680|(c>>>8&65280|c>>>24);i[b+28>>2]=0;a=j[a+32|0]|j[a+33|0]<<8|(j[a+34|0]<<16|j[a+35|0]<<24);i[b+44>>2]=4;i[b+40>>2]=b+8;c=i[b+44>>2];i[b>>2]=i[b+40>>2];i[b+4>>2]=c;i[b+32>>2]=(a<<8&16711680|a<<24|(a>>>8&65280|a>>>24))+80;i[b+36>>2]=0;a=fDa(i[b>>2],i[b>>2]+(i[b+4>>2]<<3)|0);c=i[a>>2];Xa=b+48|0;a=i[a+4>>2]+ -1|0;b=c+ -52|0;if(b>>>0<4294967244){a=a+1|0}_a=a;return b}function Iva(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,j=0,k=0,l=0,m=0,n=0,p=0,q=0,r=0,s=0;e=Xa-32|0;Xa=e;l=i[a+24>>2];m=i[a+20>>2];n=i[a+16>>2];b=i[a+4>>2];f=i[a>>2];i[e+24>>2]=f;i[e+28>>2]=b;j=i[a+12>>2];i[e+16>>2]=i[a+8>>2];i[e+20>>2]=j;if(d){while(1){k=(((b&2147483647)<<1|f>>>31)&-2)+n|0;b=(f>>>21&2040)+27872|0;p=h[b+6>>1];q=h[b+4>>1];r=h[b+2>>1];s=h[b>>1];j=0;b=1;while(1){i[(e+8|0)+(j<<2)>>2]=(((o(g[j+k|0],r)+o(g[(j|-2)+k|0],s)|0)+o(g[(j|2)+k|0],q)|0)+o(g[(j|4)+k|0],p)<<8)/16384;f=b;b=0;j=1;if(f){continue}break}i[c>>2]=i[c>>2]+o(i[e+8>>2],m);i[c+4>>2]=i[c+4>>2]+o(i[e+12>>2],l);zb(e+24|0,e+16|0);d=d+ -1|0;if(d){c=c+8|0;f=i[e+24>>2];b=i[e+28>>2];continue}break}f=i[e+24>>2];b=i[e+28>>2]}i[a>>2]=f;i[a+4>>2]=b;Xa=e+32|0}function IW(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=Xa-96|0;Xa=g;ai(g+48|0,g+40|0,c);i[114610]=0;G(224,g+60|0,g+32|0,d|0);d=i[114610];i[114610]=0;c=1;a:{b:{c:{d:{e:{if((d|0)!=1){i[114610]=0;G(224,g+72|0,g+24|0,e|0);c=i[114610];i[114610]=0;if((c|0)==1){break e}i[114610]=0;G(224,g+84|0,g+16|0,f|0);c=i[114610];i[114610]=0;if((c|0)==1){break d}i[114610]=0;D(225,g+8|0,g+48|0);c=i[114610];i[114610]=0;if((c|0)==1){break b}i[114610]=0;G(72,a|0,b|0,g+8|0);a=i[114610];i[114610]=0;if((a|0)==1){break b}AB(g+48|0);Xa=g+96|0;return}a=B()|0;A()|0;break c}a=B()|0;c=2;A()|0;break c}a=B()|0;A()|0;c=3}c=(g+48|0)+o(c,12)|0;while(1){c=eb(c+ -12|0);if((c|0)!=(g+48|0)){continue}break}break a}a=B()|0;A()|0;AB(g+48|0)}E(a|0);x()}function YJa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;f=Ab(a);g=lb(b);i[114610]=0;D(524,f|0,g|0);a=i[114610];i[114610]=0;if((a|0)!=1){a:{if(g){while(1){a=d+1|0;e=j[Sb(b,d)|0];b:{c:{if((a|0)==(g|0)|(e|0)!=37){break c}e=j[Sb(b,a)|0];d=e+ -49|0;if((d&255)>>>0<=8){if(d>>>0>=BJa(c)>>>0){d=a;break b}i[114610]=0;d=C(525,c|0,d|0)|0;e=i[114610];i[114610]=0;if((e|0)!=1){i[114610]=0;C(526,f|0,d|0)|0;e=i[114610];i[114610]=0;d=a;if((e|0)!=1){break b}}break a}if((e|0)==37){d=a;e=37;break c}i[114610]=0;I(527,f|0,1,37)|0;h=i[114610];i[114610]=0;d=a;if((h|0)==1){break a}}i[114610]=0;I(527,f|0,1,e<<24>>24)|0;a=i[114610];i[114610]=0;if((a|0)==1){break a}}d=d+1|0;if((g|0)!=(d|0)){continue}break}}return}}a=B()|0;A()|0;eb(f);E(a|0);x()}function F4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0;d=Xa-32|0;Xa=d;e=i[a+28>>2];i[d+16>>2]=e;f=i[a+20>>2];i[d+28>>2]=c;i[d+24>>2]=b;b=f-e|0;i[d+20>>2]=b;e=b+c|0;k=2;b=d+16|0;a:{b:{c:{if(!Jq(ia(i[a+60>>2],d+16|0,2,d+12|0)|0)){while(1){f=i[d+12>>2];if((f|0)==(e|0)){break c}if((f|0)<=-1){break b}g=i[b+4>>2];h=f>>>0>g>>>0;j=(h<<3)+b|0;g=f-(h?g:0)|0;i[j>>2]=g+i[j>>2];j=(h?12:4)+b|0;i[j>>2]=i[j>>2]-g;e=e-f|0;b=h?b+8|0:b;k=k-h|0;if(!Jq(ia(i[a+60>>2],b|0,k|0,d+12|0)|0)){continue}break}}i[d+12>>2]=-1;if((e|0)!=-1){break b}}b=i[a+44>>2];i[a+28>>2]=b;i[a+20>>2]=b;i[a+16>>2]=b+i[a+48>>2];a=c;break a}i[a+28>>2]=0;i[a+16>>2]=0;i[a+20>>2]=0;i[a>>2]=i[a>>2]|32;a=0;if((k|0)==2){break a}a=c-i[b+4>>2]|0}Xa=d+32|0;return a|0}function yi(a,b,c){var d=0;a:{if((a|0)==(b|0)){break a}if((b-a|0)-c>>>0<=0-(c<<1)>>>0){Tb(a,b,c);return}d=(a^b)&3;b:{c:{if(a>>>0<b>>>0){if(d){break b}if(!(a&3)){break c}while(1){if(!c){break a}g[a|0]=j[b|0];b=b+1|0;c=c+ -1|0;a=a+1|0;if(a&3){continue}break}break c}d:{if(d){break d}if(a+c&3){while(1){if(!c){break a}c=c+ -1|0;d=c+a|0;g[d|0]=j[b+c|0];if(d&3){continue}break}}if(c>>>0<=3){break d}while(1){c=c+ -4|0;i[c+a>>2]=i[b+c>>2];if(c>>>0>3){continue}break}}if(!c){break a}while(1){c=c+ -1|0;g[c+a|0]=j[b+c|0];if(c){continue}break}break a}if(c>>>0<=3){break b}while(1){i[a>>2]=i[b>>2];b=b+4|0;a=a+4|0;c=c+ -4|0;if(c>>>0>3){continue}break}}if(!c){break a}while(1){g[a|0]=j[b|0];a=a+1|0;b=b+1|0;c=c+ -1|0;if(c){continue}break}}}function lua(a){var b=0,c=0,d=0,e=0,f=0,h=0;d=Xa-16|0;Xa=d;yc(d+8|0,a);a:{b:{c:{f=a+16|0;d:{if($c(f)){while(1){e:{e=i[f>>2];i[114610]=0;e=F(98,e|0)|0;h=i[114610];i[114610]=0;if((h|0)==1){break e}c=c|e;b=b+32|0;if(b>>>0<32){continue}break d}break}b=H(71324)|0;if((A()|0)!=(U(71324)|0)){break a}M(b|0)|0;g[a+20|0]=0;i[114610]=0;L(82,a|0);b=i[114610];i[114610]=0;if((b|0)==1){break c}i[114610]=0;K(20);b=i[114610];i[114610]=0;if((b|0)!=1){break d}b=B()|0;A()|0;break a}g[a+20|0]=0}if(!j[a+20|0]){a=i[a+24>>2];i[114610]=0;a=F(99,a|0)|0;b=i[114610];i[114610]=0;if((b|0)==1){break b}c=a^c}Xa=d+16|0;return c}b=B()|0;A()|0;i[114610]=0;K(20);a=i[114610];i[114610]=0;if((a|0)!=1){break a}a=H(0)|0;A()|0;gb(a);x()}b=B()|0;A()|0}E(b|0);x()}function Opa(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=p(0),k=p(0),l=0,n=p(0),r=0,s=0;f=Xa-16|0;Xa=f;r=f,s=o(i[a>>2],$d(a)),i[r+8>>2]=s;kc(f+8|0,c);c=jb(b);g=m[e+4>>2];e=i[f+8>>2];if(e){while(1){g=p(t(p(q((eNa(2,j[c|0]|j[c+1|0]<<8|(j[c+2|0]<<16|j[c+3|0]<<24)),iNa()))),g));c=c+4|0;e=e+ -1|0;if(e){continue}break}}c=g==p(0);a:{if(c){break a}e=i[f+8>>2];if(!e){break a}n=c?p(1):p(p(1)/g);c=i[a+20>>2];while(1){m[f+12>>2]=n*(eNa(2,j[b|0]|j[b+1|0]<<8|(j[b+2|0]<<16|j[b+3|0]<<24)),iNa());Id(f+12|0,p(-1));k=p(m[f+12>>2]*p(32768));m[f+12>>2]=k;a=c;k=Qd(k);b:{if(p(q(k))<p(2147483648)){l=~~k;break b}l=-2147483648}r=a,s=Bc(l),h[r>>1]=s;b=b+4|0;c=c+2|0;e=e+ -1|0;if(e){continue}break}}if(d){m[d>>2]=g}Xa=f+16|0;return i[f+8>>2]}function fGa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,j=0;d=Xa-32|0;Xa=d;i[d+28>>2]=0;di(a,d+28|0);a:{b:{e=i[d+28>>2];c:{if(e>>>0>500){break c}d:{e:{f:{if(e){while(1){e=Ab(d+16|0);i[114610]=0;h[d+14>>1]=0;f=I(724,a|0,e|0,255)|0;g=i[114610];i[114610]=0;if((g|0)==1){break b}if(!f){break d}i[114610]=0;C(715,a|0,d+14|0)|0;f=i[114610];i[114610]=0;if((f|0)==1){break b}i[114610]=0;G(13,d|0,c|0,e|0);f=i[114610];i[114610]=0;if((f|0)==1){break f}i[114610]=0;f=C(725,b|0,d+14|0)|0;g=i[114610];i[114610]=0;if((g|0)==1){break e}mb(f,d);eb(d);eb(e);j=j+1|0;if(j>>>0<l[d+28>>2]){continue}break}}hf(i[i[a>>2]+ -12>>2]+a|0);break c}a=B()|0;A()|0;break a}a=B()|0;A()|0;eb(d);break a}eb(e)}Xa=d+32|0;return}a=B()|0;A()|0}eb(e);E(a|0);x()}function eGa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,j=0;d=Xa-32|0;Xa=d;h[d+30>>1]=0;af(a,d+30|0);a:{b:{e=k[d+30>>1];c:{if(e>>>0>500){break c}d:{e:{f:{if(e){while(1){e=Ab(d+16|0);i[114610]=0;h[d+14>>1]=0;f=I(726,a|0,e|0,255)|0;g=i[114610];i[114610]=0;if((g|0)==1){break b}if(!f){break d}i[114610]=0;C(715,a|0,d+14|0)|0;f=i[114610];i[114610]=0;if((f|0)==1){break b}i[114610]=0;G(13,d|0,c|0,e|0);f=i[114610];i[114610]=0;if((f|0)==1){break f}i[114610]=0;f=C(725,b|0,d+14|0)|0;g=i[114610];i[114610]=0;if((g|0)==1){break e}mb(f,d);eb(d);eb(e);j=j+1|0;if(j>>>0<k[d+30>>1]){continue}break}}hf(i[i[a>>2]+ -12>>2]+a|0);break c}a=B()|0;A()|0;break a}a=B()|0;A()|0;eb(d);break a}eb(e)}Xa=d+32|0;return}a=B()|0;A()|0}eb(e);E(a|0);x()}function SQ(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,h=0,j=0,k=0,l=0,m=0,n=0;e=Xa-32|0;Xa=e;i[e+24>>2]=b;m=e,n=ld(a),i[m+8>>2]=n;h=En(e+24|0,e+8|0);b=pi(c,d);a:{b:{if(!b){break b}if(iz(c,xb(a),xb(a)+lb(a)|0)){b=Uh(e+8|0,c,d);c=i[e+24>>2];d=xb(b);h=xb(b);j=lb(b);i[114610]=0;c=N(613,a|0,c|0,d|0,h+j|0)|0;a=i[114610];i[114610]=0;if((a|0)!=1){eb(b);break a}a=B()|0;A()|0;eb(b);E(a|0);x()}j=lb(a);f=qc(a);c:{if(f-j>>>0>=b>>>0){f=xb(a);k=j-h|0;if(!k){break c}l=h+f|0;Cl(b+l|0,l,k);break c}rl(a,f,(b+j|0)-f|0,j,h,0,b);f=i[a>>2]}b=b+j|0;yg(a,b);g[e+8|0]=0;Rd(b+f|0,e+8|0);if((c|0)==(d|0)){break b}b=h+f|0;while(1){Rd(b,c);b=b+1|0;c=c+1|0;if((d|0)!=(c|0)){continue}break}}m=e,n=ld(a),i[m+8>>2]=n;c=Ze(e+8|0,h)}Xa=e+32|0;return c|0}function QAa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;f=Oc(a);g=lb(b);i[114610]=0;D(73,f|0,g|0);a=i[114610];i[114610]=0;if((a|0)!=1){a:{if(g){while(1){a=d+1|0;e=j[Sb(b,d)|0];b:{c:{if((a|0)==(g|0)|(e|0)!=37){break c}e=j[Sb(b,a)|0];d=e+ -49|0;if((d&255)>>>0<=8){if(d>>>0>=yza(c)>>>0){d=a;break b}i[114610]=0;d=C(74,c|0,d|0)|0;e=i[114610];i[114610]=0;if((e|0)!=1){i[114610]=0;C(75,f|0,d|0)|0;e=i[114610];i[114610]=0;d=a;if((e|0)!=1){break b}}break a}if((e|0)==37){d=a;e=37;break c}i[114610]=0;I(76,f|0,1,37)|0;h=i[114610];i[114610]=0;d=a;if((h|0)==1){break a}}i[114610]=0;I(76,f|0,1,e<<24>>24)|0;a=i[114610];i[114610]=0;if((a|0)==1){break a}}d=d+1|0;if((g|0)!=(d|0)){continue}break}}return}}a=B()|0;A()|0;eb(f);E(a|0);x()}function pF(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;f=Xa-16|0;Xa=f;a:{b:{c:{d:{if((b|0)>=0){if((Rk(a+8|0)|0)>(b|0)){break d}}b=P(8)|0;i[114610]=0;c=C(85,f|0,40609)|0;a=i[114610];i[114610]=0;if((a|0)==1){break c}Ub(b,c);i[114610]=0;G(2009,b|0,83568,2017);a=i[114610];i[114610]=0;if((a|0)!=1){break a}a=B()|0;A()|0;eb(c);break b}d=a+32|0;a=(i[d>>2]+(b<<5)|0)+480280|0;c=c?134218752:0;i[a>>2]=c|i[a>>2]&-134218753;a=(i[d>>2]+o(b,896)|0)+1075072|0;i[a>>2]=c|i[a>>2]&-134218753;a=k[i[d>>2]+480188>>1];if(a>>>0<=255){b=b+1|0;while(1){e=o(a,896);if((b|0)==k[(e+i[d>>2]|0)+1075792>>1]){e=(e+i[d>>2]|0)+1075072|0;i[e>>2]=c|i[e>>2]&-134218753}a=a+1|0;if((a&65535)!=256){continue}break}}Xa=f+16|0;return}a=B()|0;A()|0;Q(b|0)}E(a|0)}x()}function Gpa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=p(0),g=0,k=0,l=p(0),n=0,o=0;e=Xa-16|0;Xa=e;i[e+12>>2]=c>>>3;i[e+8>>2]=i[a>>2];c=i[rb(e+12|0,e+8|0)>>2];l=m[d>>2];b=jb(b);if(c){a=i[a+20>>2];d=c;while(1){m[e+12>>2]=l*(eNa(2,j[b|0]|j[b+1|0]<<8|(j[b+2|0]<<16|j[b+3|0]<<24)),iNa());Id(e+12|0,p(-1));f=p(m[e+12>>2]*p(32768));m[e+12>>2]=f;k=a;f=Qd(f);a:{if(p(q(f))<p(2147483648)){g=~~f;break a}g=-2147483648}n=k,o=Bc(g),h[n>>1]=o;m[e+12>>2]=l*(eNa(2,j[b+4|0]|j[b+5|0]<<8|(j[b+6|0]<<16|j[b+7|0]<<24)),iNa());Id(e+12|0,p(-1));f=p(m[e+12>>2]*p(32768));m[e+12>>2]=f;k=a;f=Qd(f);b:{if(p(q(f))<p(2147483648)){g=~~f;break b}g=-2147483648}n=k,o=Bc(g),h[n+2>>1]=o;a=a+4|0;b=b+8|0;d=d+ -1|0;if(d){continue}break}}Xa=e+16|0;return c<<3}function ona(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=Xa-32|0;Xa=d;a:{b:{c:{d:{e:{if(Oi(b)){break e}h[d+8>>1]=k[a+480190>>1];h[d+24>>1]=i[b+4>>2]+ -1;c=k[ef(d+8|0,d+24|0)>>1];if(!c){break e}while(1){Ld(d+8|0,b,c);if(!ib(d+8|0)){i[114610]=0;e=C(1425,a|0,c&65535)|0;f=i[114610];i[114610]=0;if((f|0)==1){break b}if(e){i[114610]=0;e=C(85,d+8|0,20509)|0;f=i[114610];i[114610]=0;if((f|0)==1){break d}i[114610]=0;C(369,((c<<5)+a|0)+946300|0,e|0)|0;f=i[114610];i[114610]=0;if((f|0)==1){break c}eb(e);g=g+1|0}if(!(k[a+480190>>1]!=(c|0)|c>>>0<2)){h[a+480190>>1]=k[a+480190>>1]+ -1}}e=c&65535;c=c+ -1|0;if((e|0)!=1){continue}break}}Xa=d+32|0;return g&65535}c=B()|0;A()|0;break a}c=B()|0;A()|0;eb(e);break a}c=B()|0;A()|0}E(c|0);x()}function yj(a,b,c){var d=0,e=0,f=0;e=Xa-16|0;Xa=e;i[a+4>>2]=0;a:{b:{d=4;c:{if(!j[Gi(e+8|0,a,1)|0]){break c}d=i[i[a>>2]+ -12>>2];i[114610]=0;d=i[(a+d|0)+24>>2];f=i[114610];i[114610]=0;d:{if((f|0)==1){break d}i[114610]=0;b=I(2324,d|0,b|0,c|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break d}i[a+4>>2]=b;d=(b|0)==(c|0)?0:6;break c}b=H(0)|0;A()|0;M(b|0)|0;Ei(i[i[a>>2]+ -12>>2]+a|0,1);b=i[i[a>>2]+ -12>>2];i[114610]=0;b=i[(a+b|0)+20>>2];c=i[114610];i[114610]=0;e:{if((c|0)!=1){if(!(b&1)){break e}i[114610]=0;K(81);a=i[114610];i[114610]=0;if((a|0)!=1){break a}}a=B()|0;A()|0;i[114610]=0;K(20);b=i[114610];i[114610]=0;if((b|0)==1){break b}E(a|0);x()}O();d=1}ag(i[i[a>>2]+ -12>>2]+a|0,d);Xa=e+16|0;return}a=H(0)|0;A()|0;gb(a)}x()}function yb(a,b,c){var d=0,e=0,f=0,h=0;a:{if(!c){break a}d=a+c|0;g[d+ -1|0]=b;g[a|0]=b;if(c>>>0<3){break a}g[d+ -2|0]=b;g[a+1|0]=b;g[d+ -3|0]=b;g[a+2|0]=b;if(c>>>0<7){break a}g[d+ -4|0]=b;g[a+3|0]=b;if(c>>>0<9){break a}d=0-a&3;e=d+a|0;b=o(b&255,16843009);i[e>>2]=b;c=c-d&-4;d=c+e|0;i[d+ -4>>2]=b;if(c>>>0<9){break a}i[e+8>>2]=b;i[e+4>>2]=b;i[d+ -8>>2]=b;i[d+ -12>>2]=b;if(c>>>0<25){break a}i[e+24>>2]=b;i[e+20>>2]=b;i[e+16>>2]=b;i[e+12>>2]=b;i[d+ -16>>2]=b;i[d+ -20>>2]=b;i[d+ -24>>2]=b;i[d+ -28>>2]=b;h=e&4|24;c=c-h|0;if(c>>>0<32){break a}d=b;f=b;b=e+h|0;while(1){i[b+24>>2]=f;i[b+28>>2]=d;i[b+16>>2]=f;i[b+20>>2]=d;i[b+8>>2]=f;i[b+12>>2]=d;i[b>>2]=f;i[b+4>>2]=d;b=b+32|0;c=c+ -32|0;if(c>>>0>31){continue}break}}return a}function xca(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=Xa-32|0;Xa=d;i[114610]=0;L(2015,a|0);c=i[114610];i[114610]=0;a:{b:{c:{d:{e:{f:{if((c|0)==1){break f}i[114610]=0;L(2041,b|0);c=i[114610];i[114610]=0;if((c|0)==1){break f}e=i[a+24>>2];i[114610]=0;c=C(85,d|0,b|0)|0;b=i[114610];i[114610]=0;if((b|0)==1){break e}i[114610]=0;J(2076,d+16|0,e|0,c|0,1);b=i[114610];i[114610]=0;if((b|0)==1){break d}b=Ed(xb(d+16|0));eb(d+16|0);eb(c);break b}b=H(0)|0;A()|0;break c}b=H(0)|0;A()|0;break c}b=H(0)|0;A()|0;eb(c)}M(b|0)|0;b=0;i[114610]=0;J(1989,36881,a|0,0,0);a=i[114610];i[114610]=0;if((a|0)==1){break a}O()}Xa=d+32|0;return b|0}a=B()|0;A()|0;i[114610]=0;K(20);b=i[114610];i[114610]=0;if((b|0)!=1){E(a|0);x()}a=H(0)|0;A()|0;gb(a);x()}function sMa(a,b){var c=0,d=0,e=0,f=0,l=0,m=0;e=Xa-16|0;Xa=e;kd(b,0);g[b+37|0]=j[a+22|0]<<4;g[e+15|0]=j[a+23|0];g[e+14|0]=64;l=b,m=j[Xb(e+15|0,e+14|0)|0]<<2,h[l+30>>1]=m;g[b+36|0]=j[a+24|0];f=a+25|0;d=f;i[b>>2]=j[d|0]|j[d+1|0]<<8|(j[d+2|0]<<16|j[d+3|0]<<24);d=a+33|0;c=d;a:{if((j[c|0]|j[c+1|0]<<8|(j[c+2|0]<<16|j[c+3|0]<<24))>>>0<3){break a}c=a+29|0;if((j[c|0]|j[c+1|0]<<8|(j[c+2|0]<<16|j[c+3|0]<<24))+(j[d|0]|j[d+1|0]<<8|(j[d+2|0]<<16|j[d+3|0]<<24))>>>0>(j[f|0]|j[f+1|0]<<8|(j[f+2|0]<<16|j[f+3|0]<<24))>>>0){break a}h[b+34>>1]=k[b+34>>1]|2;i[b+4>>2]=j[c|0]|j[c+1|0]<<8|(j[c+2|0]<<16|j[c+3|0]<<24);i[b+8>>2]=(j[c|0]|j[c+1|0]<<8|(j[c+2|0]<<16|j[c+3|0]<<24))+(j[d|0]|j[d+1|0]<<8|(j[d+2|0]<<16|j[d+3|0]<<24))}Xa=e+16|0}function eda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=Xa-32|0;Xa=d;i[114610]=0;L(2015,a|0);c=i[114610];i[114610]=0;a:{b:{c:{d:{e:{f:{if((c|0)==1){break f}i[114610]=0;L(2041,b|0);c=i[114610];i[114610]=0;if((c|0)==1){break f}e=i[a+24>>2];i[114610]=0;c=C(85,d|0,b|0)|0;b=i[114610];i[114610]=0;if((b|0)==1){break e}i[114610]=0;G(2042,d+16|0,e|0,c|0);b=i[114610];i[114610]=0;if((b|0)==1){break d}b=Ed(xb(d+16|0));eb(d+16|0);eb(c);break b}b=H(0)|0;A()|0;break c}b=H(0)|0;A()|0;break c}b=H(0)|0;A()|0;eb(c)}M(b|0)|0;b=0;i[114610]=0;J(1989,35647,a|0,0,0);a=i[114610];i[114610]=0;if((a|0)==1){break a}O()}Xa=d+32|0;return b|0}a=B()|0;A()|0;i[114610]=0;K(20);b=i[114610];i[114610]=0;if((b|0)!=1){E(a|0);x()}a=H(0)|0;A()|0;gb(a);x()}function ava(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,j=0,k=0,l=0,m=0;g=Xa-16|0;Xa=g;k=i[a+24>>2];l=i[a+20>>2];m=i[a+16>>2];j=i[a+4>>2];e=j;f=i[a>>2];i[g+8>>2]=f;i[g+12>>2]=e;j=i[a+12>>2];i[g>>2]=i[a+8>>2];i[g+4>>2]=j;if(d){while(1){e=(e<<1)+m|0;f=(((f>>>16|0)+4&131064)<<1)+b|0;e=(((((o(h[e+4>>1],h[f+34>>1])+o(h[e+2>>1],h[f+32>>1])|0)+o(h[e+6>>1],h[f+36>>1])|0)+o(h[e+8>>1],h[f+38>>1])|0)/2|0)+((((o(h[e+ -4>>1],h[f+26>>1])+o(h[e+ -6>>1],h[f+24>>1])|0)+o(h[e+ -2>>1],h[f+28>>1])|0)+o(h[e>>1],h[f+30>>1])|0)/2|0)|0)/16384|0;i[c>>2]=i[c>>2]+o(e,l);i[c+4>>2]=i[c+4>>2]+o(e,k);zb(g+8|0,g);d=d+ -1|0;if(d){c=c+8|0;f=i[g+8>>2];e=i[g+12>>2];continue}break}f=i[g+8>>2];e=i[g+12>>2]}i[a>>2]=f;i[a+4>>2]=e;Xa=g+16|0}function ID(a,b,c,d,e,f){var g=0;g=Xa-80|0;Xa=g;a:{if((f|0)>=16384){_c(g+32|0,b,c,d,e,0,0,0,2147352576);d=i[g+40>>2];e=i[g+44>>2];b=i[g+32>>2];c=i[g+36>>2];if((f|0)<32767){f=f+ -16383|0;break a}_c(g+16|0,b,c,d,e,0,0,0,2147352576);f=((f|0)<49149?f:49149)+ -32766|0;d=i[g+24>>2];e=i[g+28>>2];b=i[g+16>>2];c=i[g+20>>2];break a}if((f|0)>-16383){break a}_c(g- -64|0,b,c,d,e,0,0,0,65536);d=i[g+72>>2];e=i[g+76>>2];b=i[g+64>>2];c=i[g+68>>2];if((f|0)>-32765){f=f+16382|0;break a}_c(g+48|0,b,c,d,e,0,0,0,65536);f=((f|0)>-49146?f:-49146)+32764|0;d=i[g+56>>2];e=i[g+60>>2];b=i[g+48>>2];c=i[g+52>>2]}_c(g,b,c,d,e,0,0,0,f+16383<<16);b=i[g+12>>2];i[a+8>>2]=i[g+8>>2];i[a+12>>2]=b;b=i[g+4>>2];i[a>>2]=i[g>>2];i[a+4>>2]=b;Xa=g+80|0}function aea(a){a=a|0;var b=0;b=34232;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{if((a|0)<=276){if(!a){break n}if((a|0)==257){break m}if((a|0)!=267){break a}b=34269;break a}switch(a+ -277|0){case 1:case 2:case 3:case 4:case 5:case 6:case 7:case 8:case 13:case 14:case 15:case 16:case 17:case 18:break a;case 10:break j;case 9:break k;case 0:break l;case 23:break c;case 22:break d;case 21:break e;case 20:break f;case 19:break g;case 12:break h;case 11:break i;default:break b}}b=34133;break a}b=34246;break a}b=34288;break a}b=34302;break a}b=34316;break a}b=34328;break a}b=34348;break a}b=34369;break a}b=34381;break a}b=34400;break a}b=34432;break a}b=34454;break a}if((a|0)!=357){break a}b=34471}return Ed(b)|0}function hE(a){a=a|0;var b=0,c=0,d=0,e=0;d=Xa-16|0;Xa=d;a:{b:{if(!i[(i[i[a>>2]+ -12>>2]+a|0)+24>>2]){break b}i[114610]=0;c=C(2328,d+8|0,a|0)|0;b=i[114610];i[114610]=0;c:{if((b|0)!=1){d:{if(!j[c|0]){break d}b=i[(i[i[a>>2]+ -12>>2]+a|0)+24>>2];i[114610]=0;b=F(2329,b|0)|0;e=i[114610];i[114610]=0;if((e|0)!=1){if((b|0)!=-1){break d}b=i[i[a>>2]+ -12>>2];i[114610]=0;D(2330,a+b|0,1);b=i[114610];i[114610]=0;if((b|0)!=1){break d}}b=H(0)|0;A()|0;gE(c);break c}gE(c);break b}b=H(0)|0;A()|0}M(b|0)|0;c=i[i[a>>2]+ -12>>2];i[114610]=0;L(19,a+c|0);c=i[114610];i[114610]=0;if((c|0)==1){break a}O()}Xa=d+16|0;return a|0}a=B()|0;A()|0;i[114610]=0;K(20);c=i[114610];i[114610]=0;if((c|0)!=1){E(a|0);x()}a=H(0)|0;A()|0;gb(a);x()}function Cm(a,b,c){var d=0,e=0,f=0,h=0,k=0;a:{if(c){g[b+829|0]=c;break a}c=j[b+829|0]}d=i[a+480180>>2]&202376205?c&240?c&-16:c&15:c;c=i[b+688>>2];b:{if(i[a+480180>>2]&69206029){break b}e=d&240;f=d&15;if((f|0)==15){if(e){Ao(a,b,(d&240)>>>4|0,0);return}if(!(g[b+872|0]&1)){break b}c=j[a+480208|0]&2?c:c+ -60|0;break b}if((e|0)!=240){break b}if(f){zo(a,b,f,0);return}if(!(g[b+872|0]&1)){break b}c=j[a+480208|0]&2?c:c+60|0}c:{if(i[a+1074416>>2]!=1|i[a+480180>>2]!=524288?!(!(g[b+872|0]&1)|j[a+480208|0]&2):0){break c}e=d&255;d=d&15;d:{if(d){if(i[a+480180>>2]&16777248?e&240:0){break d}c=c-(d<<2)|0;break d}c=(e>>>2&60)+c|0}if(i[a+480180>>2]!=1){break c}i[b+88>>2]=i[b+88>>2]|2097152}h=b,k=Eb(c,0,256),i[h+688>>2]=k}function Vpa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,k=0,l=0,m=0,o=0,p=0,r=0,s=0;g=Xa-16|0;Xa=g;i[g+8>>2]=c>>>3;i[g+4>>2]=i[a>>2];d=i[rb(g+8|0,g+4|0)>>2];b=jb(b);if(d){a=i[a+20>>2];c=d;while(1){o=0;e=b;k=j[e+4|0]|j[e+5|0]<<8|(j[e+6|0]<<16|j[e+7|0]<<24);l=j[e|0]|j[e+1|0]<<8|(j[e+2|0]<<16|j[e+3|0]<<24);f=k<<24|l>>>8;e=0;p=f&65280;f=e;e=k<<8|l>>>24;f=f|o;o=e&255|p|(l<<24|l<<8&16711680);e=g;i[e+8>>2]=((k&255)<<24|l>>>8)&-16777216|((k&16777215)<<8|l>>>24)&16711680|(k>>>8&65280|k>>>24)|f;i[e+12>>2]=o;mf(e+8|0,-1,1);m=n[e+8>>3]*32768;n[e+8>>3]=m;e=a;m=xd(m);a:{if(q(m)<2147483648){f=~~m;break a}f=-2147483648}r=e,s=Bc(f),h[r>>1]=s;a=a+2|0;b=b+8|0;c=c+ -1|0;if(c){continue}break}}Xa=g+16|0;return d<<3}function mea(a,b,c){var d=0,e=0,f=0,g=0,j=0,l=0,m=0,n=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;e=k[a+22>>1];f=k[a+20>>1];g=i[a+4>>2];if(c){n=h[a+26>>1];t=h[a+18>>1];p=h[a+24>>1];u=h[a+16>>1];m=i[a>>2]+ -1|0;q=a+32928|0;while(1){j=zc(i[b>>2]);d=zc(i[b+4>>2]);f=zc((f<<16>>16)-j|0);e=zc((e<<16>>16)-d|0);f=Bc(zc((o(f,u)|0)/65536<<1)+j|0);e=Bc(zc((o(e,t)|0)/65536<<1)+d|0);d=(g<<2)+q|0;j=h[d+2>>1];r=h[d>>1];d=Bc(((o(r,p)|0)/-65536|0)+f|0);g=g+1&127;l=(g<<2)+q|0;s=Bc(((o(j,n)|0)/-65536|0)+e|0);h[l+2>>1]=s;h[l>>1]=d;m=m+1&8191;l=(m<<2)+a|0;v=l,w=Bc(((o(d,p)|0)/65536|0)+r|0),h[v+160>>1]=w;v=l,w=Bc(j+((o(n,s)|0)/65536|0)|0),h[v+162>>1]=w;b=b+8|0;c=c+ -1|0;if(c){continue}break}}h[a+22>>1]=e;h[a+20>>1]=f;i[a+4>>2]=g}function Fva(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,j=0,k=0,l=0,m=0;e=Xa-16|0;Xa=e;j=i[a+40>>2];k=i[a+36>>2];m=i[a+16>>2];g=i[a+4>>2];b=g;f=i[a>>2];i[e+8>>2]=f;i[e+12>>2]=b;g=i[a+12>>2];i[e>>2]=i[a+8>>2];i[e+4>>2]=g;a:{if(!d){g=j>>12;l=k>>12;break a}while(1){g=i[a+32>>2];k=i[a+28>>2]+k|0;l=k>>12;b=(b<<1)+m|0;f=(f>>>21&2040)+27872|0;b=(((o(h[b>>1],h[f+2>>1])+o(h[b+ -2>>1],h[f>>1])|0)+o(h[b+2>>1],h[f+4>>1])|0)+o(h[b+4>>1],h[f+6>>1])|0)/16384|0;i[c>>2]=i[c>>2]+o(l,b);j=g+j|0;g=j>>12;i[c+4>>2]=i[c+4>>2]+o(b,g);zb(e+8|0,e);d=d+ -1|0;if(d){c=c+8|0;f=i[e+8>>2];b=i[e+12>>2];continue}break}f=i[e+8>>2];b=i[e+12>>2]}i[a+40>>2]=j;i[a+20>>2]=l;i[a+36>>2]=k;i[a+24>>2]=g;i[a>>2]=f;i[a+4>>2]=b;Xa=e+16|0}function nx(a,b,c,d){var e=0,f=0;e=Xa-16|0;Xa=e;a:{if(!d){break a}if(c){g[b+835|0]=c;break a}c=j[b+835|0]}c=i[a+480180>>2]&1048580?c&240?c&-16:c&15:c;b:{c:{d:{e:{if(!(i[a+480180>>2]&1048580)){d=c&240;c=c&15;if((c|0)==15){if(!d){d=0;break e}if(!(j[a+480209|0]&16)){break b}c=0-(d>>>2|0)|0;break d}f=!c;if(!c|(d|0)!=240){break e}if(!(j[a+480209|0]&16)){break b}c=c<<2;break c}if(j[a+480209|0]&16){break b}kb(e+8|0,a+1074308|0,56);a=c&240;a=a?a>>>2|0:0-(c<<2&60)|0;c=a;if(!ib(e+8|0)){break d}c=(a|0)/4<<24>>24;break d}if(j[a+480209|0]&16){break b}if(!f){c=c<<2;if(!d|!(i[a+480180>>2]&16777248)){break c}break b}c=0-(d>>>2|0)|0}if(!c){break b}}a=Eb(i[b+692>>2]+c|0,0,256);h[b+796>>1]=0;i[b+692>>2]=a}Xa=e+16|0}function CE(a,b,c,d){a:{if(b>>>0>20){break a}b:{switch(b+ -9|0){case 0:b=i[c>>2];i[c>>2]=b+4;i[a>>2]=i[b>>2];return;case 1:b=i[c>>2];i[c>>2]=b+4;b=i[b>>2];i[a>>2]=b;i[a+4>>2]=b>>31;return;case 2:b=i[c>>2];i[c>>2]=b+4;i[a>>2]=i[b>>2];i[a+4>>2]=0;return;case 3:b=i[c>>2]+7&-8;i[c>>2]=b+8;c=i[b+4>>2];i[a>>2]=i[b>>2];i[a+4>>2]=c;return;case 4:b=i[c>>2];i[c>>2]=b+4;b=h[b>>1];i[a>>2]=b;i[a+4>>2]=b>>31;return;case 5:b=i[c>>2];i[c>>2]=b+4;i[a>>2]=k[b>>1];i[a+4>>2]=0;return;case 6:b=i[c>>2];i[c>>2]=b+4;b=g[b|0];i[a>>2]=b;i[a+4>>2]=b>>31;return;case 7:b=i[c>>2];i[c>>2]=b+4;i[a>>2]=j[b|0];i[a+4>>2]=0;return;case 8:b=i[c>>2]+7&-8;i[c>>2]=b+8;n[a>>3]=n[b>>3];return;case 9:break b;default:break a}}$a[d|0](a,c)}}function yy(a,b,c){var d=0,e=0,f=0,i=0,l=0,m=0;i=Xa-16|0;Xa=i;if(g[a|0]&1){g[b+12|0]=j[b+12|0]|1}if(j[a|0]&2){g[b+12|0]=j[b+12|0]|4}if(j[a|0]&4){g[b+12|0]=j[b+12|0]|2}if(j[a|0]&16){g[b+12|0]=j[b+12|0]|16}if(j[a|0]&32){g[b+12|0]=j[b+12|0]|8}g[i+15|0]=j[a+1|0];g[i+14|0]=25;Lf(b,j[Xb(i+15|0,i+14|0)|0]);g[b+15|0]=j[a+2|0];g[b+16|0]=j[a+3|0];g[b+13|0]=j[a+4|0];g[b+14|0]=j[a+5|0];if(qb(b)){while(1){f=(d<<2)+a|0;e=f+6|0;e=j[e|0]|j[e+1|0]<<8;l=vb(b,d),m=e,h[l>>1]=m;a:{if(!d){break a}e=d+ -1|0;if(k[vb(b,d)>>1]>=k[vb(b,e)>>1]){break a}e=k[vb(b,e)>>1];l=vb(b,d),m=e+1|0,h[l>>1]=m}f=f+8|0;f=Eb((j[f|0]|j[f+1|0]<<8)<<16>>16>>c,0,64);l=vb(b,d),m=f,g[l+2|0]=m;d=d+1|0;if(d>>>0<qb(b)>>>0){continue}break}}Xa=i+16|0}function uP(a){var b=0,c=0;a:{if(Xc(a,15078,3)){break a}b=a+3|0;if(j[b|0]<48|j[b|0]>51){break a}b=a+8|0;c=j[b|0]|j[b+1|0]<<8|(j[b+2|0]<<16|j[b+3|0]<<24);if((c<<24|c<<8&16711680|(c>>>8&65280|c>>>24))>>>0<52){break a}b=j[b|0]|j[b+1|0]<<8|(j[b+2|0]<<16|j[b+3|0]<<24);if((b<<24|b<<8&16711680|(b>>>8&65280|b>>>24))>>>0>4294966507){break a}b=a+16|0;b=j[b|0]|j[b+1|0]<<8|(j[b+2|0]<<16|j[b+3|0]<<24);if((b<<24|b<<8&16711680|(b>>>8&65280|b>>>24))>>>0<52){break a}b=a+24|0;b=j[b|0]|j[b+1|0]<<8|(j[b+2|0]<<16|j[b+3|0]<<24);if((b<<24|b<<8&16711680|(b>>>8&65280|b>>>24))>>>0<52){break a}a=a+32|0;a=j[a|0]|j[a+1|0]<<8|(j[a+2|0]<<16|j[a+3|0]<<24);return(a<<24|a<<8&16711680|(a>>>8&65280|a>>>24))>>>0<4294967216}return 0}function e6(a,b,c,d){var e=0,f=0,g=0,h=0,l=0,m=0;if((d|0)>=1){f=b+7548|0;l=a+6152|0;while(1){g=o(e,28)+c|0;m=k[g+4>>1];h=i[b+4>>2];_5(l,(o(e,39)+b|0)+16156|0,b,g,f,e);Z5((o(e,2304)+b|0)+2940|0,b,g,f,m+h|0);e=e+1|0;if((e|0)!=(d|0)){continue}break}}e=j[a+6155|0];a:{if(e&16){Y5(b+2940|0,b+16195|0,c,a+6152|0);break a}if((e&224)!=96){break a}eF(b+2940|0,576)}if((d|0)>=1){m=b+7708|0;e=0;while(1){f=j[a+6153|0];f=(j[c+12|0]!=0)<<1<<((o((f>>>3&1)+(f>>>4&1)|0,3)+(j[a+6154|0]>>>2&3)|0)==2);g=(o(e,2304)+b|0)+2940|0;l=g;if(j[c+14|0]){X5(((o(e,2304)+b|0)+o(f,72)|0)+2940|0,m,i[c>>2]+j[c+13|0]|0);h=f+ -1|0}else{h=31}W5(l,h);V5(g,o(e,1152)+a|0,j[c+11|0],f);U5(g);c=c+28|0;e=e+1|0;if((e|0)!=(d|0)){continue}break}}}function bva(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,j=0,k=0,l=0,m=0,n=0;j=Xa-16|0;Xa=j;l=i[a+24>>2];m=i[a+20>>2];n=i[a+16>>2];k=i[a+4>>2];e=k;f=i[a>>2];i[j+8>>2]=f;i[j+12>>2]=e;k=i[a+12>>2];i[j>>2]=i[a+8>>2];i[j+4>>2]=k;if(d){while(1){e=e+n|0;f=(((f>>>16|0)+4&131064)<<1)+b|0;e=(((((o(g[e+2|0],h[f+34>>1])+o(g[e+1|0],h[f+32>>1])|0)+o(g[e+3|0],h[f+36>>1])|0)+o(g[e+4|0],h[f+38>>1])<<8)/2|0)+((((o(g[e+ -2|0],h[f+26>>1])+o(g[e+ -3|0],h[f+24>>1])|0)+o(g[e+ -1|0],h[f+28>>1])|0)+o(g[e|0],h[f+30>>1])<<8)/2|0)|0)/16384|0;i[c>>2]=i[c>>2]+o(e,m);i[c+4>>2]=i[c+4>>2]+o(e,l);zb(j+8|0,j);d=d+ -1|0;if(d){c=c+8|0;f=i[j+8>>2];e=i[j+12>>2];continue}break}f=i[j+8>>2];e=i[j+12>>2]}i[a>>2]=f;i[a+4>>2]=e;Xa=j+16|0}function Dla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=Xa-16|0;Xa=e;d=Ab(e);a:{b:{if(c>>>0>=64){i[114610]=0;c=F(339,b|0)|0;f=i[114610];i[114610]=0;if((f|0)==1){break a}if((c|0)<=0){i[114610]=0;C(85,a|0,30864)|0;a=i[114610];i[114610]=0;if((a|0)!=1){break b}break a}i[114610]=0;D(111,d|0,c|0);c=i[114610];i[114610]=0;if((c|0)==1){break a}}c:{while(1){d:{i[114610]=0;c=F(387,b|0)|0;f=i[114610];i[114610]=0;if((f|0)==1){break d}if(!c){break c}i[114610]=0;I(1531,d|0,1,((c+ -65&255)>>>0<26?c+32|0:c)<<24>>24)|0;c=i[114610];i[114610]=0;if((c|0)!=1){continue}}break}break a}i[114610]=0;C(338,b|0,4)|0;b=i[114610];i[114610]=0;if((b|0)==1){break a}Lc(a,d)}eb(d);Xa=e+16|0;return}a=B()|0;A()|0;eb(d);E(a|0);x()}function qX(a,b){var c=0,d=0,e=0,f=0,g=0;c=16;d=a>>>0>16?a:16;a:{if(!(d+ -1&d)){a=d;break a}while(1){a=c;c=a<<1;if(a>>>0<d>>>0){continue}break}}if(-64-a>>>0<=b>>>0){i[114584]=48;return 0}d=b>>>0<11?16:b+11&-8;c=Zc((d+a|0)+12|0);if(!c){return 0}b=c+ -8|0;b:{if(!(c&a+ -1)){a=b;break b}f=c+ -4|0;g=i[f>>2];c=((a+c|0)+ -1&0-a)+ -8|0;a=c-b>>>0>15?c:a+c|0;c=a-b|0;e=(g&-8)-c|0;if(!(g&3)){b=i[b>>2];i[a+4>>2]=e;i[a>>2]=b+c;break b}i[a+4>>2]=e|i[a+4>>2]&1|2;e=a+e|0;i[e+4>>2]=i[e+4>>2]|1;i[f>>2]=c|i[f>>2]&1|2;i[a+4>>2]=i[a+4>>2]|1;cq(b,c)}b=i[a+4>>2];c:{if(!(b&3)){break c}c=b&-8;if(c>>>0<=d+16>>>0){break c}i[a+4>>2]=d|b&1|2;b=a+d|0;d=c-d|0;i[b+4>>2]=d|3;c=a+c|0;i[c+4>>2]=i[c+4>>2]|1;cq(b,d)}return a+8|0}function c6(a,b,c){var d=0,e=0,f=0,h=0,i=0,k=0,l=0,m=0;e=R5(a,c);a:{if(!j[c+768|0]){e=0;break a}h=50048;while(1){if((d|0)==(k|0)){h=j[e|0]+50048|0;k=j[e+2|0]+k|0;l=j[e+1|0];e=e+3|0}m=d<<1;f=j[zd(b,l)+h|0];g[(m+c|0)+770|0]=f;i=j[c+769|0];if(d>>>0<i>>>0){f=j[zd(b,l)+h|0];i=j[c+769|0]}g[((m|1)+c|0)+770|0]=i?f:0;d=d+1|0;f=j[c+768|0];if(d>>>0<f>>>0){continue}break}if(!f){e=f<<1;break a}d=0;while(1){h=c+d|0;b:{if(!j[h+770|0]){e=6;break b}e=2;if((j[a+1|0]&6)==6){break b}e=zd(b,2);f=j[c+768|0]}g[h+834|0]=e;d=d+1|0;e=f<<1&510;if(d>>>0<e>>>0){continue}break}}Q5(b,c+770|0,c+834|0,e,c);d=j[c+769|0];a=j[c+768|0];if(d>>>0<a>>>0){while(1){g[((d<<1|1)+c|0)+770|0]=0;d=d+1|0;if(d>>>0<a>>>0){continue}break}}}function Gva(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,j=0,k=0,l=0,m=0,n=0;e=Xa-16|0;Xa=e;k=i[a+40>>2];l=i[a+36>>2];n=i[a+16>>2];j=i[a+4>>2];b=j;f=i[a>>2];i[e+8>>2]=f;i[e+12>>2]=b;j=i[a+12>>2];i[e>>2]=i[a+8>>2];i[e+4>>2]=j;a:{if(!d){j=k>>12;m=l>>12;break a}while(1){j=i[a+32>>2];l=i[a+28>>2]+l|0;m=l>>12;b=b+n|0;f=(f>>>21&2040)+27872|0;b=(((o(g[b|0],h[f+2>>1])+o(g[b+ -1|0],h[f>>1])|0)+o(g[b+1|0],h[f+4>>1])|0)+o(g[b+2|0],h[f+6>>1])<<8)/16384|0;i[c>>2]=i[c>>2]+o(m,b);k=j+k|0;j=k>>12;i[c+4>>2]=i[c+4>>2]+o(b,j);zb(e+8|0,e);d=d+ -1|0;if(d){c=c+8|0;f=i[e+8>>2];b=i[e+12>>2];continue}break}f=i[e+8>>2];b=i[e+12>>2]}i[a+40>>2]=k;i[a+20>>2]=m;i[a+36>>2]=l;i[a+24>>2]=j;i[a>>2]=f;i[a+4>>2]=b;Xa=e+16|0}function Ooa(a,b,c){var d=0,e=0,f=0,g=0;a:{d=i[a+480208>>2];if(!(d&4096)){break a}b:{switch(c&15){case 0:i[b+88>>2]=i[b+88>>2]&-257;return;case 1:i[b+692>>2]=128;i[b+88>>2]=i[b+88>>2]|256;return;case 8:i[b+88>>2]=i[b+88>>2]&-25165825|16777216;return;case 9:i[b+88>>2]=i[b+88>>2]&-25165825|8388608;return;case 10:i[a+480208>>2]=d&-16385;return;case 11:i[a+480208>>2]=d|16384;return;case 12:i[a+480208>>2]=d&-8193;return;case 13:i[a+480208>>2]=d|8192;return;case 14:i[b+88>>2]=i[b+88>>2]&-129;return;case 15:break b;default:break a}}c:{if(!i[b+76>>2]|(i[b>>2]|i[b+4>>2])){break c}if(e=!Jf(b+810|0),f=0,g=j[b+88|0]&2,g?e:f){break c}c=i[b+76>>2]+ -1|0;i[b>>2]=-1;i[b+4>>2]=c}i[b+88>>2]=i[b+88>>2]|128}}function sLa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,m=0;d=Xa-16|0;Xa=d;kd(b,0);i[b>>2]=j[a|0]|j[a+1|0]<<8|(j[a+2|0]<<16|j[a+3|0]<<24);c=ot(a+4|0,a);i[b+4>>2]=j[c|0]|j[c+1|0]<<8|(j[c+2|0]<<16|j[c+3|0]<<24);c=ot(a+8|0,a);i[b+8>>2]=j[c|0]|j[c+1|0]<<8|(j[c+2|0]<<16|j[c+3|0]<<24);g[d+15|0]=127;g[d+14|0]=j[a+15|0];f=b,m=(((j[Xb(d+15|0,d+14|0)|0]<<8|64)&65344)>>>0)/127|0,h[f+30>>1]=m;e=a+12|0;if(j[e|0]>=16){c=j[e|0];h[b+34>>1]=32;h[b+28>>1]=c&240}c=a+13|0;i[b+24>>2]=(j[c|0]|j[c+1|0]<<8)<<1;if(!(j[c|0]|j[c+1|0]<<8)){i[b+24>>2]=16726}f=b,m=(o(hs(0,j[e|0]<<28>>24),i[b+24>>2])>>>0)/8363|0,i[f+24>>2]=m;if(l[b+4>>2]<l[b+8>>2]){h[b+34>>1]=k[b+34>>1]|2}if(j[a+16|0]&132){h[b+34>>1]=k[b+34>>1]|1}Xa=d+16|0}function Fba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,k=0,l=0,m=0,n=0,o=0;e=Xa-16|0;Xa=e;a:{b:{if(!ae(b,-1)){f=i[a+12>>2];g=i[a+8>>2];if(i[a+24>>2]==i[a+28>>2]){c=-1;if(!(j[a+48|0]&16)){break a}h=i[a+24>>2];k=i[a+20>>2];l=i[a+44>>2];m=i[a+20>>2];i[114610]=0;c=a+32|0;D(110,c|0,0);d=i[114610];i[114610]=0;if((d|0)==1){break b}d=qc(c);i[114610]=0;D(149,c|0,d|0);d=i[114610];i[114610]=0;if((d|0)==1){break b}d=xb(c);aw(a,d,lb(c)+d|0);fr(a,h-k|0);i[a+44>>2]=i[a+20>>2]+(l-m|0)}i[e+12>>2]=i[a+24>>2]+1;n=a,o=i[Jc(e+12|0,a+44|0)>>2],i[n+44>>2]=o;if(j[a+48|0]&8){c=xb(a+32|0);pm(a,c,c+(f-g|0)|0,i[a+44>>2])}c=EG(a,om(b));break a}c=er(b);break a}a=H(0)|0;A()|0;M(a|0)|0;O();c=-1}Xa=e+16|0;return c|0}function dI(a,b,c){var d=0,e=0,f=0,g=0,h=0;e=Xa-48|0;Xa=e;f=Ab(e+32|0);i[114610]=0;C(1619,a|0,e+24|0)|0;d=i[114610];i[114610]=0;a:{b:{if((d|0)!=1){d=i[e+28>>2];g=i[e+24>>2];Ce(f);i[114610]=0;g=!d&g>>>0<255|d>>>0<0?g:255;D(149,f|0,g|0);d=i[114610];i[114610]=0;if((d|0)==1){break a}if(g){d=0;while(1){h=Sb(f,d);i[114610]=0;C(1620,a|0,h|0)|0;h=i[114610];i[114610]=0;if((h|0)==1){break a}d=d+1|0;if((g|0)!=(d|0)){continue}break}}if(($B(f)|0)!=-1){a=$B(f);i[114610]=0;D(149,f|0,a|0);a=i[114610];i[114610]=0;if((a|0)==1){break a}}i[114610]=0;G(13,e+8|0,c|0,f|0);a=i[114610];i[114610]=0;if((a|0)!=1){break b}break a}break a}mb(b,e+8|0);eb(e+8|0);eb(f);Xa=e+48|0;return}a=B()|0;A()|0;eb(f);E(a|0);x()}function X8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;b=Xa-32|0;Xa=b;e=Mg(a);jd(b+24|0);i[114610]=0;a=C(2200,i[b+24>>2],i[b+28>>2])|0;c=i[114610];i[114610]=0;a:{b:{if((c|0)==1){break b}i[114610]=0;D(1532,e|0,a|0);a=i[114610];i[114610]=0;if((a|0)==1){break b}a=0;c:{while(1){i[114610]=0;c=C(2200,i[b+24>>2],i[b+28>>2])|0;d=i[114610];i[114610]=0;d:{if((d|0)!=1){if((a|0)<(c|0)){break d}Xa=b+32|0;return}a=B()|0;A()|0;break a}c=i[i[b+24>>2]+(a<<3)>>2];i[114610]=0;c=C(85,b+8|0,c|0)|0;d=i[114610];i[114610]=0;if((d|0)!=1){i[114610]=0;D(1534,e|0,c|0);d=i[114610];i[114610]=0;if((d|0)==1){break c}eb(c);a=a+1|0;continue}break}a=B()|0;A()|0;break a}a=B()|0;A()|0;eb(c);break a}a=B()|0;A()|0}Sc(e);E(a|0);x()}function EH(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;c=Xa-48|0;Xa=c;i[c+8>>2]=542066252;d=c+8|4;g[d|0]=0;g[d+1|0]=0;g[d+2|0]=0;g[d+3|0]=0;d=i[b+4220>>2];g[c+16|0]=d;g[c+17|0]=d>>>8;g[c+18|0]=d>>>16;g[c+19|0]=d>>>24;d=i[b+4224>>2];g[c+20|0]=d;g[c+21|0]=d>>>8;g[c+22|0]=d>>>16;g[c+23|0]=d>>>24;d=i[b+4228>>2];g[c+24|0]=d;g[c+25|0]=d>>>8;g[c+26|0]=d>>>16;g[c+27|0]=d>>>24;d=i[b+4232>>2];g[c+28|0]=d;g[c+29|0]=d>>>8;g[c+30|0]=d>>>16;g[c+31|0]=d>>>24;d=i[b+4236>>2];g[c+32|0]=d;g[c+33|0]=d>>>8;g[c+34|0]=d>>>16;g[c+35|0]=d>>>24;g[c+36|0]=j[b+4240|0];g[c+37|0]=j[b+4241|0];g[c+38|0]=j[b+4242|0];g[c+39|0]=j[b+4243|0];g[c+40|0]=j[b+4244|0];b=b+4208|0;ck(b,33);Tb(i[b>>2],c+8|0,33);ui(c,b);td(a,c);Xa=c+48|0}function Qn(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,h=0,k=0,l=0,m=0;k=Xa-16|0;Xa=k;f=d?d:461580;d=i[f>>2];a:{b:{c:{if(!b){if(d){break c}break a}e=-2;if(!c){break a}l=a?a:k+12|0;d:{if(d){a=c;break d}a=j[b|0];d=a<<24>>24;if((d|0)>=0){i[l>>2]=a;e=(d|0)!=0;break a}a=g[b|0];if(!i[i[21199]>>2]){i[l>>2]=a&57343;e=1;break a}a=(a&255)+ -194|0;if(a>>>0>50){break c}d=i[(a<<2)+57664>>2];a=c+ -1|0;if(!a){break b}b=b+1|0}h=j[b|0];m=h>>>3|0;if((m+ -16|(d>>26)+m)>>>0>7){break c}while(1){a=a+ -1|0;d=h+ -128|d<<6;if((d|0)>=0){i[f>>2]=0;i[l>>2]=d;e=c-a|0;break a}if(!a){break b}b=b+1|0;h=j[b|0];if((h&192)==128){continue}break}}i[f>>2]=0;i[114584]=25;e=-1;break a}i[f>>2]=d}Xa=k+16|0;return e|0}function Una(a){var b=0,c=0,d=0;i[114610]=0;F(1402,a|0)|0;b=i[114610];i[114610]=0;if((b|0)!=1){b=i[a+4>>2];if(b){Sna(b);Cb(b)}i[a+4>>2]=0;fx(a+1304500|0);Ir(a+1304436|0);eb(a+1304424|0);eb(a+1304412|0);eb(a+1304400|0);Hr(a+1304396|0);Gr(a+1304392|0);yo(a+1304360|0);b=a+946300|0;c=a+906300|0;while(1){b=wm(b+ -160|0);if((c|0)!=(b|0)){continue}break}es(a+484360|0);ex(a+484344|0);Sd(a+480248|0);return a}c=H(0)|0;A()|0;fx(a+1304500|0);Ir(a+1304436|0);eb(a+1304424|0);eb(a+1304412|0);eb(a+1304400|0);Hr(a+1304396|0);Gr(a+1304392|0);yo(a+1304360|0);b=a+946300|0;d=a+906300|0;while(1){b=wm(b+ -160|0);if((d|0)!=(b|0)){continue}break}es(a+484360|0);ex(a+484344|0);Sd(a+480248|0);gb(c);x()}function N9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,l=0,m=0;d=Xa+ -64|0;Xa=d;a:{b:{if((b|0)>=0){e=a+24|0;if((Ti(Db(i[e>>2]+484360|0))|0)>(b|0)){break b}}a=a+16|0;break a}g=k[$b(Db(i[e>>2]+484360|0),b)>>1];c:{if(!sp(i[e>>2]+484344|0,g)){break c}if((c|0)>=0){f=c;if(i[Fb(i[e>>2]+484344|0,g)+12>>2]>(f|0)){break c}}a=a+16|0;break a}h[i[e>>2]+1074438>>1]=b;b=b&65535;FJ(i[e>>2],b);i[i[e>>2]+1074428>>2]=f;c=i[e>>2];e=j[a+64|0];b=ena(d+24|0,b,f);f=i[b+20>>2];i[d+16>>2]=i[b+16>>2];i[d+20>>2]=f;f=i[b+12>>2];i[d+8>>2]=i[b+8>>2];i[d+12>>2]=f;f=i[b+4>>2];i[d>>2]=i[b>>2];i[d+4>>2]=f;Tr(d+48|0,c,e?7:1,d);l=a,m=n[wg(d+48|0)>>3],n[l+16>>3]=m;hl(d+48|0);a=a+16|0}Xa=d- -64|0;return+n[a>>3]}function _4(a,b,c,d){var e=0,f=0,g=0,h=p(0),i=p(0),j=0,k=0,l=0,n=0,o=0,q=p(0);a:{if((a|0)<4){break a}e=a>>2;n=(e|0)>1?e:1;i=p(a|0);h=p(p(1)/i);e=0;while(1){j=e<<2;f=+p(p(p(g<<2)*p(3.1415927410125732))*h);o=j+b|0,q=p(ee(f)),m[o>>2]=q;k=e|1;l=k<<2;o=l+b|0,q=p(-p(Hh(f))),m[o>>2]=q;f=+p(p(p(k|0)*p(1.5707963705062866))*h);o=c+j|0,q=p(p(ee(f))*p(.5)),m[o>>2]=q;o=c+l|0,q=p(p(Hh(f))*p(.5)),m[o>>2]=q;e=e+2|0;g=g+1|0;if((n|0)!=(g|0)){continue}break}if((a|0)<8){break a}a=a>>3;a=(a|0)>1?a:1;h=p(p(1)/i);e=0;g=0;while(1){b=e|1;f=+p(p(p(b<<1)*p(3.1415927410125732))*h);o=(e<<2)+d|0,q=p(ee(f)),m[o>>2]=q;o=(b<<2)+d|0,q=p(-p(Hh(f))),m[o>>2]=q;e=e+2|0;g=g+1|0;if((a|0)!=(g|0)){continue}break}}}function to(a,b,c){var d=0,e=0,f=0;d=Ab(a);a=lb(b);i[114610]=0;D(111,d|0,a|0);a=i[114610];i[114610]=0;if((a|0)!=1){a:{if(lb(b)){while(1){f=i[Ki(b,e)>>2];a=32;b:{c:{while(1){if(i[(a<<2)+c>>2]!=(f|0)){a=a+1|0;if(a>>>0<256){continue}break c}break}i[114610]=0;D(110,d|0,a<<24>>24);a=i[114610];i[114610]=0;if((a|0)!=1){break b}break a}a=0;while(1){d:{if(i[(a<<2)+c>>2]==(f|0)){i[114610]=0;D(110,d|0,a<<24>>24);a=i[114610];i[114610]=0;if((a|0)!=1){break b}break a}if(a>>>0>30){break d}a=a+1|0;if(a>>>0<256){continue}}break}i[114610]=0;D(110,d|0,63);a=i[114610];i[114610]=0;if((a|0)!=1){break b}break a}e=e+1|0;if(e>>>0<lb(b)>>>0){continue}break}}return}}a=B()|0;A()|0;eb(d);E(a|0);x()}function tka(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,m=0;f=Xa-32|0;Xa=f;i[f+24>>2]=b;b=i[a>>2];k=f,m=Jb(a),i[k>>2]=m;b=b+o(yr(f+24|0,f),6)|0;a:{b:{if(!c){break b}g=i[fb(a)>>2];h=i[a+4>>2];if((g-h|0)/6>>>0>=c>>>0){e=c;j=h-b|0;g=(j|0)/6|0;if(g>>>0<c>>>0){Yy(a,c-g|0,d);e=g;if(!j){break b}}qka(a,b,h,o(c,6)+b|0);g=b;if(b>>>0<=d>>>0){d=d>>>0<l[a+4>>2]?o(c,6)+d|0:d}_ja(g,e,d);break b}e=fb(a);e=SP(f,Ny(a,If(a)+c|0),(b-i[a>>2]|0)/6|0,e);i[114610]=0;G(710,e|0,c|0,d|0);c=i[114610];i[114610]=0;if((c|0)==1){break a}i[114610]=0;b=I(1565,a|0,e|0,b|0)|0;a=i[114610];i[114610]=0;if((a|0)==1){break a}Ls(e)}a=Pe(b);Xa=f+32|0;return a|0}a=B()|0;A()|0;Ls(e);E(a|0);x()}function cra(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0;e=Xa-32|0;Xa=e;i[e+24>>2]=b;b=i[a>>2];k=e,l=Jb(a),i[k>>2]=l;b=b+(qp(e+24|0,e)<<1)|0;a:{f=xx(c,d);b:{if((f|0)<1){break b}g=i[fb(a)>>2];h=i[a+4>>2];if((f|0)<=g-h>>1){i[e>>2]=d;j=h-b|0;g=j>>1;if((f|0)>(g|0)){i[e>>2]=c;i[e>>2]=i[e>>2]+(g<<1);WL(a,i[e>>2],d,f-g|0);if((j|0)<1){break b}}ara(a,b,h,(f<<1)+b|0);Oe(c,i[e>>2],b);break b}h=fb(a);f=UT(e,qi(a,Wb(a)+f|0),b-i[a>>2]>>1,h);i[114610]=0;G(1247,f|0,c|0,d|0);c=i[114610];i[114610]=0;if((c|0)==1){break a}i[114610]=0;b=I(1248,a|0,f|0,b|0)|0;a=i[114610];i[114610]=0;if((a|0)==1){break a}tA(f)}a=Pe(b);Xa=e+32|0;return a|0}a=B()|0;A()|0;tA(f);E(a|0);x()}function Ypa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=p(0),g=0,k=0,l=0,n=0;e=Xa-16|0;Xa=e;i[e+12>>2]=c>>>3;i[e+8>>2]=i[a>>2];d=i[rb(e+12|0,e+8|0)>>2];b=jb(b);if(d){a=i[a+20>>2];c=d;while(1){i[e+12>>2]=j[b|0]|j[b+1|0]<<8|(j[b+2|0]<<16|j[b+3|0]<<24);Id(e+12|0,p(-1));f=p(m[e+12>>2]*p(32768));m[e+12>>2]=f;k=a;f=Qd(f);a:{if(p(q(f))<p(2147483648)){g=~~f;break a}g=-2147483648}l=k,n=Bc(g),h[l>>1]=n;i[e+12>>2]=j[b+4|0]|j[b+5|0]<<8|(j[b+6|0]<<16|j[b+7|0]<<24);Id(e+12|0,p(-1));f=p(m[e+12>>2]*p(32768));m[e+12>>2]=f;k=a;f=Qd(f);b:{if(p(q(f))<p(2147483648)){g=~~f;break b}g=-2147483648}l=k,n=Bc(g),h[l+2>>1]=n;a=a+4|0;b=b+8|0;c=c+ -1|0;if(c){continue}break}}Xa=e+16|0;return d<<3}function gua(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0;d=Xa-48|0;Xa=d;a:{b:{if(i[a+8>>2]!=i[Mb(a)>>2]){break b}g=a+8|0;h=a+4|0;c=i[a+4>>2];e=i[a>>2];if(c>>>0>e>>>0){f=c;c=((c-e>>2)+1|0)/-2<<2;j=g,k=Oe(f,i[g>>2],f+c|0),i[j>>2]=k;i[h>>2]=c+i[h>>2];break b}j=d,k=i[Mb(a)>>2]-i[a>>2]>>1,i[j+24>>2]=k;i[d+44>>2]=1;c=i[Jc(d+24|0,d+44|0)>>2];c=sn(d+24|0,c,c>>>2|0,i[a+16>>2]);e=yc(d+16|0,i[a+4>>2]);f=i[yc(d+8|0,i[a+8>>2])>>2];e=i[e>>2];i[114610]=0;G(1162,c|0,e|0,f|0);e=i[114610];i[114610]=0;if((e|0)==1){break a}Gb(a,c);Gb(h,c+4|0);Gb(g,c+8|0);Gb(Mb(a),Mb(c));uh(c)}yP(i[a+16>>2],i[a+8>>2],b);i[a+8>>2]=i[a+8>>2]+4;Xa=d+48|0;return}a=B()|0;A()|0;uh(c);E(a|0);x()}function _Ja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0;d=Xa-48|0;Xa=d;a:{b:{if(i[a+8>>2]!=i[Mb(a)>>2]){break b}g=a+8|0;h=a+4|0;c=i[a+4>>2];e=i[a>>2];if(c>>>0>e>>>0){f=c;c=((c-e>>1)+1|0)/-2<<1;j=g,k=GJa(f,i[g>>2],f+c|0),i[j>>2]=k;i[h>>2]=c+i[h>>2];break b}j=d,k=i[Mb(a)>>2]-i[a>>2]|0,i[j+24>>2]=k;i[d+44>>2]=1;c=i[Jc(d+24|0,d+44|0)>>2];c=IR(d+24|0,c,c>>>2|0,i[a+16>>2]);e=yc(d+16|0,i[a+4>>2]);f=i[yc(d+8|0,i[a+8>>2])>>2];e=i[e>>2];i[114610]=0;G(523,c|0,e|0,f|0);e=i[114610];i[114610]=0;if((e|0)==1){break a}Gb(a,c);Gb(h,c+4|0);Gb(g,c+8|0);Gb(Mb(a),Mb(c));jt(c)}Az(i[a+16>>2],i[a+8>>2],b);i[a+8>>2]=i[a+8>>2]+2;Xa=d+48|0;return}a=B()|0;A()|0;jt(c);E(a|0);x()}function U4(a){var b=0,c=p(0),d=p(0),e=p(0),f=0,g=p(0),h=p(0);b=(hNa(a),dNa(2));a:{b:{if(!((b|0)>-1?b>>>0>=8388608:0)){if(!(b&2147483647)){return p(p(-1)/p(a*a))}if((b|0)<=-1){return p(p(a-a)/p(0))}b=(hNa(p(a*p(33554432))),dNa(2));f=-152;break b}if(b>>>0>2139095039){break a}f=-127;a=p(0);if((b|0)==1065353216){break a}}b=b+4913933|0;g=p((b>>>23|0)+f|0);a=p((eNa(2,(b&8388607)+1060439283|0),iNa())+p(-1));c=p(a/p(a+p(2)));d=p(c*c);e=p(d*d);h=a;a=p(a*p(a*p(.5)));a=p(p(g*p(.6931381225585938))+p(h+p(p(p(g*p(905800061445916e-20))+p(c*p(a+p(p(d*p(p(e*p(.2849878668785095))+p(.6666666269302368)))+p(e*p(p(e*p(.24279078841209412))+p(.40000972151756287)))))))-a)))}return a}function rF(a,b,c){a=a|0;b=b|0;c=+c;var d=0,e=0;d=Xa-16|0;Xa=d;a:{b:{c:{d:{if((b|0)>=0){if((Rk(a+8|0)|0)>(b|0)){break d}}a=P(8)|0;i[114610]=0;d=C(85,d|0,40609)|0;b=i[114610];i[114610]=0;if((b|0)==1){break c}Ub(a,d);i[114610]=0;G(2009,a|0,83568,2017);a=i[114610];i[114610]=0;if((a|0)!=1){break a}b=B()|0;A()|0;eb(d);break b}if(!(c<=1?!(c<0):0)){a=P(8)|0;i[114610]=0;d=C(85,d|0,40587)|0;b=i[114610];i[114610]=0;if((b|0)!=1){Ub(a,d);i[114610]=0;G(2009,a|0,83568,2017);a=i[114610];i[114610]=0;if((a|0)!=1){break a}b=B()|0;A()|0;eb(d);break b}b=B()|0;A()|0;Q(a|0);break b}e=Mm(c*64);i[(i[a+32>>2]+o(b,896)|0)+1075744>>2]=e;Xa=d+16|0;return}b=B()|0;A()|0;Q(a|0)}E(b|0)}x()}function jha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;b=Ph(a,b,c,d);i[a>>2]=79620;c=ni(a+4208|0);d=a+4288|0;i[d>>2]=0;i[d+4>>2]=0;i[a+4280>>2]=0;i[a+4284>>2]=0;i[114610]=0;d=R(1393)|0;e=i[114610];i[114610]=0;a:{if((e|0)==1){break a}i[114610]=0;d=F(1394,d|0)|0;e=i[114610];i[114610]=0;if((e|0)==1){break a}i[a+4228>>2]=1049926264;i[a+4232>>2]=0;i[a+4220>>2]=1056964608;i[a+4224>>2]=1056964608;i[a+4296>>2]=d;g[a+4244|0]=0;i[a+4236>>2]=2147483647;i[a+4240>>2]=0;nw(a);sr(a);i[114610]=0;I(1639,a+44|0,2,2)|0;d=i[114610];i[114610]=0;if((d|0)==1){break a}i[114610]=0;L(1640,b|0);d=i[114610];i[114610]=0;if((d|0)==1){break a}return a|0}a=B()|0;A()|0;ug(c);ve(b);E(a|0);x()}function b6(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,k=0,l=0,n=0,q=0,r=0,s=p(0);g=j[c+768|0];e=576;while(1){a:{if(!(g&255)){g=0;break a}h=(o(d,k)<<2)+a|0;i=0;while(1){n=e;f=j[(c+i|0)+770|0];b:{if(!f){break b}if(f>>>0<=16){if((d|0)<1){break b}l=(-1<<f+ -1)+1|0;e=0;while(1){r=(e<<2)+h|0,s=p(zd(b,f)+l|0),m[r>>2]=s;e=e+1|0;if((e|0)!=(d|0)){continue}break}break b}e=2<<f+ -17;f=e|1;e=zd(b,(e-(f>>>3|0)|0)+3|0);if((d|0)<1){break b}l=f>>>1|0;g=0;while(1){q=e;e=(e>>>0)/(f>>>0)|0;m[(g<<2)+h>>2]=(q-o(f,e)|0)-l|0;g=g+1|0;if((g|0)!=(d|0)){continue}break}}e=18-n|0;h=(n<<2)+h|0;i=i+1|0;g=j[c+768|0];if(i>>>0<g<<1>>>0){continue}break}}k=k+1|0;if((k|0)!=4){continue}break}return d<<2}function Zw(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;c=Xa-16|0;Xa=c;if(!Uc(a)){m=c,n=Jb(a),i[m+8>>2]=n;m=c,n=Kb(a),i[m>>2]=n;if(pb(c+8|0,c)){while(1){f=i[c+8>>2];wn(f,4194304,67108864);b=d;d=i[f>>2];g=d+g|0;if(g>>>0<d>>>0){b=b+1|0}d=b;Gd(c+8|0);if(pb(c+8|0,c)){continue}break}}b=qb(a);h=qb(a);m=c,n=Jb(a),i[m+8>>2]=n;m=c,n=Kb(a),i[m>>2]=n;b=_Ma(g,d,b,0);f=_a;g=h<<24;d=0;if(pb(c+8|0,c)){h=b;f=((f&1)<<31|b>>>1)&2147483647;while(1){b=i[c+8>>2];j=b;e=i[b>>2];b=e>>>8|0;e=f+(e<<24)|0;b=b+k|0;b=Vc(_Ma(e,e>>>0<f>>>0?b+1|0:b,h,l),_a);i[j>>2]=b;e=g;g=e-b|0;d=d-(e>>>0<b>>>0)|0;Gd(c+8|0);if(pb(c+8|0,c)){continue}break}}a=hc(a,0);i[a>>2]=g+i[a>>2]}Xa=c+16|0}function Hc(a){var b=0,c=0,d=0,e=0,f=0,h=0,k=0,m=0,n=0;a:{c=i[a+112>>2];d=i[a+116>>2];b:{if(c|d){b=l[a+120>>2]>=c>>>0;c=i[a+124>>2];if((c|0)>(d|0)?1:(c|0)>=(d|0)?b:0){break b}}k=av(a);if((k|0)>-1){break a}}i[a+104>>2]=0;return-1}m=a;e=i[a+116>>2];b=e;d=i[a+8>>2];c=d;f=i[a+112>>2];c:{if(!(b|f)){break c}c=d;e=(i[a+124>>2]^-1)+b|0;b=i[a+120>>2]^-1;f=b+f|0;if(f>>>0<b>>>0){e=e+1|0}b=f;f=i[a+4>>2];h=d-f|0;n=b>>>0>=h>>>0;h=h>>31;if((e|0)>(h|0)?1:(e|0)>=(h|0)?n:0){break c}c=b+f|0}i[m+104>>2]=c;m=i[a+4>>2];if(d){c=a;e=(d-m|0)+1|0;b=e;d=b+i[a+120>>2]|0;a=i[a+124>>2]+(b>>31)|0;i[c+120>>2]=d;i[c+124>>2]=d>>>0<b>>>0?a+1|0:a}a=m+ -1|0;if(j[a|0]!=(k|0)){g[a|0]=k}return k}function rEa(a,b,c){var d=0,e=0,f=0;d=Xa+ -64|0;Xa=d;De(d+40|0,a,c);a=i[d+40>>2];i[114610]=0;e=F(412,d+40|0)|0;f=i[114610];i[114610]=0;a:{b:{c:{if((f|0)==1){break c}i[114610]=0;e=F(413,e|0)|0;f=i[114610];i[114610]=0;if((f|0)==1){break c}i[114610]=0;J(414,d+8|0,3,e|0,a|0);e=i[114610];i[114610]=0;if((e|0)==1){break c}i[114610]=0;D(415,d+24|0,d+8|0);e=i[114610];i[114610]=0;if((e|0)==1){break c}i[114610]=0;D(765,d|0,b|0);b=i[114610];i[114610]=0;if((b|0)==1){break b}i[114610]=0;C(470,d|0,d+24|0)|0;b=i[114610];i[114610]=0;if((b|0)==1){break b}eb(d+24|0);jc(d+40|0);Xa=d- -64|0;return!c|(a|0)!=0}a=B()|0;A()|0;break a}a=B()|0;A()|0;eb(d+24|0)}jc(d+40|0);E(a|0);x()}function nG(a,b,c,d){var e=0,f=0,h=0,j=0,k=p(0),l=0;e=Xa-80|0;Xa=e;h=a+24|0;no(i[h>>2]);g[i[h>>2]+1304512|0]=i[a+52>>2]!=0;c=Vd(e+32|0,d,c,b);d=i[a+32>>2];k=m[a+48>>2];i[e+8>>2]=i[c+8>>2];j=i[c+4>>2];i[e>>2]=i[c>>2];i[e+4>>2]=j;j=waa(e+48|0,e,d,k);c=0;a:{while(1){if(b){d=i[h>>2];i[e+24>>2]=b;i[e+28>>2]=0;i[114610]=0;i[e+16>>2]=134217727;i[e+20>>2]=0;f=C(2153,e+24|0,e+16|0)|0;l=i[114610];i[114610]=0;if((l|0)==1){break a}f=i[f>>2];i[114610]=0;d=I(2154,d|0,f|0,j|0)|0;f=i[114610];i[114610]=0;if((f|0)==1){break a}c=c+d|0;b=b-d|0;if(d){continue}}break}if(!(i[a+52>>2]!=1|c)){a=i[h>>2];i[a+480208>>2]=i[a+480208>>2]&-513}Xa=e+80|0;return c}a=B()|0;A()|0;E(a|0);x()}function mG(a,b,c,d){var e=0,f=0,h=0,j=0,k=p(0),l=0;e=Xa-80|0;Xa=e;h=a+24|0;no(i[h>>2]);g[i[h>>2]+1304512|0]=i[a+52>>2]!=0;c=Vd(e+32|0,d,c,b);d=i[a+32>>2];k=m[a+48>>2];i[e+8>>2]=i[c+8>>2];j=i[c+4>>2];i[e>>2]=i[c>>2];i[e+4>>2]=j;j=uaa(e+48|0,e,d,k);c=0;a:{while(1){if(b){d=i[h>>2];i[e+24>>2]=b;i[e+28>>2]=0;i[114610]=0;i[e+16>>2]=134217727;i[e+20>>2]=0;f=C(2153,e+24|0,e+16|0)|0;l=i[114610];i[114610]=0;if((l|0)==1){break a}f=i[f>>2];i[114610]=0;d=I(2154,d|0,f|0,j|0)|0;f=i[114610];i[114610]=0;if((f|0)==1){break a}c=c+d|0;b=b-d|0;if(d){continue}}break}if(!(i[a+52>>2]!=1|c)){a=i[h>>2];i[a+480208>>2]=i[a+480208>>2]&-513}Xa=e+80|0;return c}a=B()|0;A()|0;E(a|0);x()}function dKa(a,b,c){var d=0,e=0,f=0;d=Xa+ -64|0;Xa=d;De(d+40|0,a,c);a=i[d+40>>2];i[114610]=0;e=F(412,d+40|0)|0;f=i[114610];i[114610]=0;a:{b:{c:{if((f|0)==1){break c}i[114610]=0;e=F(413,e|0)|0;f=i[114610];i[114610]=0;if((f|0)==1){break c}i[114610]=0;J(414,d+8|0,2,e|0,a|0);e=i[114610];i[114610]=0;if((e|0)==1){break c}i[114610]=0;D(415,d+24|0,d+8|0);e=i[114610];i[114610]=0;if((e|0)==1){break c}i[114610]=0;D(519,d|0,b|0);b=i[114610];i[114610]=0;if((b|0)==1){break b}i[114610]=0;C(470,d|0,d+24|0)|0;b=i[114610];i[114610]=0;if((b|0)==1){break b}eb(d+24|0);jc(d+40|0);Xa=d- -64|0;return!c|(a|0)!=0}a=B()|0;A()|0;break a}a=B()|0;A()|0;eb(d+24|0)}jc(d+40|0);E(a|0);x()}function WFa(a,b,c){var d=0,e=0,f=0;d=Xa+ -64|0;Xa=d;De(d+40|0,a,c);a=i[d+40>>2];i[114610]=0;e=F(412,d+40|0)|0;f=i[114610];i[114610]=0;a:{b:{c:{if((f|0)==1){break c}i[114610]=0;e=F(413,e|0)|0;f=i[114610];i[114610]=0;if((f|0)==1){break c}i[114610]=0;J(414,d+8|0,2,e|0,a|0);e=i[114610];i[114610]=0;if((e|0)==1){break c}i[114610]=0;D(415,d+24|0,d+8|0);e=i[114610];i[114610]=0;if((e|0)==1){break c}i[114610]=0;D(512,d|0,b|0);b=i[114610];i[114610]=0;if((b|0)==1){break b}i[114610]=0;C(470,d|0,d+24|0)|0;b=i[114610];i[114610]=0;if((b|0)==1){break b}eb(d+24|0);jc(d+40|0);Xa=d- -64|0;return!c|(a|0)!=0}a=B()|0;A()|0;break a}a=B()|0;A()|0;eb(d+24|0)}jc(d+40|0);E(a|0);x()}function LKa(a,b,c){var d=0,e=0,f=0;d=Xa+ -64|0;Xa=d;De(d+40|0,a,c);a=i[d+40>>2];i[114610]=0;e=F(412,d+40|0)|0;f=i[114610];i[114610]=0;a:{b:{c:{if((f|0)==1){break c}i[114610]=0;e=F(413,e|0)|0;f=i[114610];i[114610]=0;if((f|0)==1){break c}i[114610]=0;J(414,d+8|0,3,e|0,a|0);e=i[114610];i[114610]=0;if((e|0)==1){break c}i[114610]=0;D(415,d+24|0,d+8|0);e=i[114610];i[114610]=0;if((e|0)==1){break c}i[114610]=0;D(469,d|0,b|0);b=i[114610];i[114610]=0;if((b|0)==1){break b}i[114610]=0;C(470,d|0,d+24|0)|0;b=i[114610];i[114610]=0;if((b|0)==1){break b}eb(d+24|0);jc(d+40|0);Xa=d- -64|0;return!c|(a|0)!=0}a=B()|0;A()|0;break a}a=B()|0;A()|0;eb(d+24|0)}jc(d+40|0);E(a|0);x()}function Lk(a,b,c,d,e,f,g,h){var i=0,j=0,k=0,l=0,m=0,n=0;j=1;i=d&2147483647;m=i;k=c;a:{if(!c&(i|0)==2147418112?a|b:(i|0)==2147418112&c>>>0>0|i>>>0>2147418112){break a}l=h&2147483647;n=l;i=g;if(!g&(l|0)==2147418112?e|f:(l|0)==2147418112&g>>>0>0|l>>>0>2147418112){break a}if(!(a|e|(i|k)|(b|f|(m|n)))){return 0}k=d&h;if((k|0)>0?1:(k|0)>=0?(c&g)>>>0>=0:0){j=-1;if((c|0)==(g|0)&(d|0)==(h|0)?(b|0)==(f|0)&a>>>0<e>>>0|b>>>0<f>>>0:(d|0)<(h|0)?1:(d|0)<=(h|0)?c>>>0<g>>>0:0){break a}return(a^e|c^g)!=0|(b^f|d^h)!=0}j=-1;if((c|0)==(g|0)&(d|0)==(h|0)?(b|0)==(f|0)&a>>>0>e>>>0|b>>>0>f>>>0:(d|0)>(h|0)?1:(d|0)>=(h|0)?c>>>0>g>>>0:0){break a}j=(a^e|c^g)!=0|(b^f|d^h)!=0}return j}function mia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,j=0;e=Xa+ -64|0;Xa=e;i[e+56>>2]=d;d=i[a+28>>2];jn(i[i[d>>2]+ -12>>2]+d|0,0);if(i[i[b>>2]+4>>2]){h=i[a+28>>2];j=e+40|0;f=i[a+12>>2];d=i[i[b>>2]+4>>2];g=d+i[a+8>>2]|0;if(g>>>0<d>>>0){f=f+1|0}f=og(j,g,f);d=i[f+12>>2];i[e+8>>2]=i[f+8>>2];i[e+12>>2]=d;d=i[f+4>>2];i[e>>2]=i[f>>2];i[e+4>>2]=d;Di(h,e)}Ue(e+16|0,i[a+28>>2]);d=i[e+28>>2];i[e+32>>2]=i[e+24>>2];i[e+36>>2]=d;dI(i[a+28>>2],c,i[e+56>>2]);c=i[b>>2];b=Ol(e+16|0,dc(a+32|0,i[i[b>>2]>>2]),k[i[b>>2]+12>>1]);i[114610]=0;N(1630,a|0,c|0,b|0,e+32|0)|0;a=i[114610];i[114610]=0;if((a|0)!=1){ob(b);Xa=e- -64|0;return}a=B()|0;A()|0;ob(b);E(a|0);x()}function kia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,j=0;e=Xa+ -64|0;Xa=e;i[e+56>>2]=d;d=i[a+28>>2];jn(i[i[d>>2]+ -12>>2]+d|0,0);if(i[i[b>>2]+4>>2]){h=i[a+28>>2];j=e+40|0;f=i[a+12>>2];d=i[i[b>>2]+4>>2];g=d+i[a+8>>2]|0;if(g>>>0<d>>>0){f=f+1|0}f=og(j,g,f);d=i[f+12>>2];i[e+8>>2]=i[f+8>>2];i[e+12>>2]=d;d=i[f+4>>2];i[e>>2]=i[f>>2];i[e+4>>2]=d;Di(h,e)}Ue(e+16|0,i[a+28>>2]);d=i[e+28>>2];i[e+32>>2]=i[e+24>>2];i[e+36>>2]=d;ZH(c,i[a+28>>2],i[e+56>>2]);c=i[b>>2];b=Ol(e+16|0,dc(a+32|0,i[i[b>>2]>>2]),k[i[b>>2]+12>>1]);i[114610]=0;N(1630,a|0,c|0,b|0,e+32|0)|0;a=i[114610];i[114610]=0;if((a|0)!=1){ob(b);Xa=e- -64|0;return}a=B()|0;A()|0;ob(b);E(a|0);x()}function Yva(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,p=0;e=Xa-32|0;Xa=e;l=i[a+24>>2];m=i[a+20>>2];n=i[a+16>>2];g=i[a+4>>2];f=g;b=i[a>>2];i[e+24>>2]=b;i[e+28>>2]=f;g=i[a+12>>2];i[e+16>>2]=i[a+8>>2];i[e+20>>2]=g;if(d){while(1){p=b>>>18|0;j=((((f&2147483647)<<1|b>>>31)&2147483646)<<1)+n|0;g=0;b=1;while(1){k=g<<1;f=h[k+j>>1];i[(e+8|0)+(g<<2)>>2]=f+((o(h[(k|4)+j>>1]-f|0,p)|0)/16384|0);f=b;b=0;g=1;if(f){continue}break}i[c>>2]=i[c>>2]+o(i[e+8>>2],m);i[c+4>>2]=i[c+4>>2]+o(i[e+12>>2],l);zb(e+24|0,e+16|0);d=d+ -1|0;if(d){c=c+8|0;b=i[e+24>>2];f=i[e+28>>2];continue}break}b=i[e+24>>2];f=i[e+28>>2]}i[a>>2]=b;i[a+4>>2]=f;Xa=e+32|0}function rza(a,b){a=a|0;b=b|0;var c=0,d=0;d=Xa-32|0;Xa=d;kd(b,0);EN(d,a+1|0);oc(d+16|0,d);i[114610]=0;C(370,b+43|0,d+16|0)|0;c=i[114610];i[114610]=0;if((c|0)!=1){eb(d+16|0);c=a+73|0;i[b+24>>2]=j[c|0]|j[c+1|0]<<8|(j[c+2|0]<<16|j[c+3|0]<<24);c=a+54|0;i[b>>2]=j[c|0]|j[c+1|0]<<8|(j[c+2|0]<<16|j[c+3|0]<<24);c=a+58|0;i[b+4>>2]=j[c|0]|j[c+1|0]<<8|(j[c+2|0]<<16|j[c+3|0]<<24);c=a+62|0;if(j[c|0]|j[c+1|0]<<8|(j[c+2|0]<<16|j[c+3|0]<<24)){i[b+8>>2]=(j[c|0]|j[c+1|0]<<8|(j[c+2|0]<<16|j[c+3|0]<<24))+1}h[b+30>>1]=(j[a+68|0]<<1)+2;h[b+34>>1]=k[b+34>>1]&65533|j[a|0]>>>6&2;kc(b+8|0,i[b>>2]);kc(b+4|0,i[b+8>>2]);Xa=d+32|0;return}a=B()|0;A()|0;eb(d+16|0);E(a|0);x()}function mg(a,b){var c=p(0),d=p(0),e=p(0),f=p(0),g=p(0);d=m[a+4268>>2];f=$G(a);c=p(p(m[a+4224>>2]*p(1.899999976158142))+p(.10000000149011612));e=Wd(p(10),p(p(p(i[((b<<2)+a|0)+4292>>2])*p(-3))/p(m[a+4268>>2]*p(p(m[a+4220>>2]*p(19.899999618530273))+p(.10000000149011612)))));c=p(p(Wd(e,p(p(2)-p(p(2)/c)))+p(-1))/p(p(1)-Yn(c>p(1)?p(3.1415927410125732):p(p(f*p(6.2831854820251465))/d))));a:{if(c==p(0)){break a}f=p(c+c);d=p(p(-2)-f);c=p(w(p(p(d*d)+p(p(c*c)*p(-4)))));g=p(p(c-d)/f);if(p(q(g))<=p(1)){break a}g=p(p(-p(c+d))/f)}b=(b<<3)+a|0;m[b+4404>>2]=g;m[b+4400>>2]=e;c=m[a+4272>>2];c=p(c*c);d=p(p(1)-c);e=p(e*e);return p(p(p(p(d*d)*e)/p(p(1)-p(c*e)))+c)}function aza(a,b){var c=0,d=0,e=0;c=Xa+ -64|0;Xa=c;De(c+40|0,a,4);a=i[c+40>>2];i[114610]=0;d=F(412,c+40|0)|0;e=i[114610];i[114610]=0;a:{b:{c:{if((e|0)==1){break c}i[114610]=0;d=F(413,d|0)|0;e=i[114610];i[114610]=0;if((e|0)==1){break c}i[114610]=0;J(414,c+8|0,3,d|0,a|0);a=i[114610];i[114610]=0;if((a|0)==1){break c}i[114610]=0;D(415,c+24|0,c+8|0);a=i[114610];i[114610]=0;if((a|0)==1){break c}i[114610]=0;D(987,c|0,b|0);a=i[114610];i[114610]=0;if((a|0)==1){break b}i[114610]=0;C(470,c|0,c+24|0)|0;a=i[114610];i[114610]=0;if((a|0)==1){break b}eb(c+24|0);jc(c+40|0);Xa=c- -64|0;return}a=B()|0;A()|0;break a}a=B()|0;A()|0;eb(c+24|0)}jc(c+40|0);E(a|0);x()}function Kia(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=Xa-48|0;Xa=d;jj(a,d+40|0);e=i[d+44>>2];if(!e&l[d+40>>2]>256|e>>>0>0){i[d+40>>2]=256;i[d+44>>2]=0}a:{b:{c:{d:{if(i[d+40>>2]|i[d+44>>2]){while(1){af(a,d+38|0);e=Ab(d+24|0);i[114610]=0;I(726,a|0,e|0,255)|0;f=i[114610];i[114610]=0;if((f|0)==1){break d}i[114610]=0;G(13,d+8|0,c|0,e|0);f=i[114610];i[114610]=0;if((f|0)==1){break c}i[114610]=0;f=C(1617,b|0,d+38|0)|0;h=i[114610];i[114610]=0;if((h|0)==1){break b}mb(f,d+8|0);eb(d+8|0);eb(e);e=i[d+44>>2];g=g+1|0;if(!e&l[d+40>>2]>g>>>0|e>>>0>0){continue}break}}Xa=d+48|0;return}a=B()|0;A()|0;break a}a=B()|0;A()|0;break a}a=B()|0;A()|0;eb(d+8|0)}eb(e);E(a|0);x()}function Fla(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,k=0,l=0,m=0,n=0,o=0;e=le(11555);if(e){n=i[a+12>>2];c=b+16|0;if(Vj(a,j[c|0]|j[c+1|0]<<8|(j[c+2|0]<<16|j[c+3|0]<<24))){g=b+12|0;c=g;a:{if(!(j[c|0]|j[c+1|0]<<8|(j[c+2|0]<<16|j[c+3|0]<<24))){break a}h=b+4|0;while(1){if(!ff(a,4)){break a}b:{if((j[h|0]|j[h+1|0]<<8)>>>0>=64){if((Ela(a)|0)<1){break b}}d=0;b=1;while(1){c=nt(a);if(c){o=mo(c<<24>>24);k=d>>>0>=e>>>0;l=k&b;c=l;c:{if(k){break c}c=l;if(!(b&1)){break c}c=j[d+11555|0]==(o&255)}b=c;d=d+1|0;continue}break}Dc(a,4);f=b?(d|0)==(e|0)?1:f:f}m=m+1|0;b=g;if(m>>>0<(j[b|0]|j[b+1|0]<<8|(j[b+2|0]<<16|j[b+3|0]<<24))>>>0){continue}break}}d=f&1}Vj(a,n)}return d}function Bwa(a){var b=0,c=0,d=0;b=Xa+ -64|0;Xa=b;a:{b:{c:{d:{e:{while(1){i[b+60>>2]=c;i[b+60>>2]=c<<3;Dz(b+32|0,c>>>0<16?18110:18045);i[114610]=0;D(510,b+16|0,b+60|0);d=i[114610];i[114610]=0;if((d|0)==1){break e}i[114610]=0;G(511,b+48|0,b+32|0,b+16|0);d=i[114610];i[114610]=0;if((d|0)==1){break d}i[114610]=0;D(512,b+8|0,(c<<5)+a|0);d=i[114610];i[114610]=0;if((d|0)==1){break c}i[114610]=0;C(470,b+8|0,b+48|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break c}eb(b+48|0);eb(b+16|0);ob(b+32|0);c=c+1|0;if((c|0)!=128){continue}break}Xa=b- -64|0;return}c=B()|0;A()|0;break a}c=B()|0;A()|0;break b}c=B()|0;A()|0;eb(b+48|0)}eb(b+16|0)}ob(b+32|0);E(c|0);x()}function Gla(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,k=0,l=0,m=0,n=0,o=0;e=le(11555);if(e){n=i[a+8>>2];c=b+16|0;if(vc(a,j[c|0]|j[c+1|0]<<8|(j[c+2|0]<<16|j[c+3|0]<<24))){g=b+12|0;c=g;a:{if(!(j[c|0]|j[c+1|0]<<8|(j[c+2|0]<<16|j[c+3|0]<<24))){break a}h=b+4|0;while(1){if(!wb(a,4)){break a}b:{if((j[h|0]|j[h+1|0]<<8)>>>0>=64){if((kh(a)|0)<1){break b}}d=0;b=1;while(1){c=id(a);if(c){o=mo(c<<24>>24);k=d>>>0>=e>>>0;l=k&b;c=l;c:{if(k){break c}c=l;if(!(b&1)){break c}c=j[d+11555|0]==(o&255)}b=c;d=d+1|0;continue}break}Ib(a,4);f=b?(d|0)==(e|0)?1:f:f}m=m+1|0;b=g;if(m>>>0<(j[b|0]|j[b+1|0]<<8|(j[b+2|0]<<16|j[b+3|0]<<24))>>>0){continue}break}}d=f&1}vc(a,n)}return d}function wsa(a,b,c,d,e){var f=0,l=0,m=0,n=0,o=0,p=0;l=Xa-16|0;Xa=l;m=Sj(a,b);a:{if((m|0)==255){break a}if(Si(a)){break a}b:{if(c>>>0>6208431){n=7;c=1023;break b}f=7;c:{if(c>>>0>3104215){break c}f=6;if(c>>>0>1552107){break c}f=5;if(c>>>0>776053){break c}f=4;if(c>>>0>388026){break c}f=3;if(c>>>0>194013){break c}f=2;if(c>>>0>97006){break c}f=c>>>0>48503}n=f;c=XMa(1<<20-f,0,c,0)+24858e3|0;f=_a;c=Vc(_Ma(c,c>>>0<24858e3?f+1|0:f,49716e3,0),_a)}if(e){h[l+14>>1]=(b&3)+c;h[l+12>>1]=1023;c=k[ef(l+14|0,l+12|0)>>1]}e=bs(m);b=a+4|0;o=Nb(b,m),p=(n<<10|c)>>>8|(d?0:32),g[o|0]=p;Ng(i[a>>2],e|160,c&255);Ng(i[a>>2],e|176,j[Nb(b,m)|0]);g[a+530|0]=1}Xa=l+16|0}function jia(a,b,c){var d=0,e=0,f=0,g=0,h=0,j=0;d=Xa+ -64|0;Xa=d;e=i[a+28>>2];jn(i[i[e>>2]+ -12>>2]+e|0,0);if(i[i[b>>2]+4>>2]){j=i[a+28>>2];e=d+48|0;h=i[a+12>>2];f=i[i[b>>2]+4>>2];g=f+i[a+8>>2]|0;if(g>>>0<f>>>0){h=h+1|0}f=og(e,g,h);g=i[f+12>>2];i[d+16>>2]=i[f+8>>2];i[d+20>>2]=g;e=i[f+4>>2];i[d+8>>2]=i[f>>2];i[d+12>>2]=e;Di(j,d+8|0)}Ue(d+24|0,i[a+28>>2]);e=i[d+36>>2];i[d+40>>2]=i[d+32>>2];i[d+44>>2]=e;$a[1187](i[a+28>>2],c,i[i[b>>2]+8>>2]);c=i[b>>2];e=Ol(d+24|0,dc(a+32|0,i[i[b>>2]>>2]),k[i[b>>2]+12>>1]);i[114610]=0;b=N(1630,a|0,c|0,e|0,d+40|0)|0;a=i[114610];i[114610]=0;if((a|0)!=1){ob(e);Xa=d- -64|0;return b}a=B()|0;A()|0;ob(e);E(a|0);x()}function Oma(a){var b=0,c=0,d=0;d=Xa-32|0;Xa=d;rM(d);b=i[d+28>>2];c=i[d+24>>2];g[a+24|0]=c;g[a+25|0]=c>>>8;g[a+26|0]=c>>>16;g[a+27|0]=c>>>24;g[a+28|0]=b;g[a+29|0]=b>>>8;g[a+30|0]=b>>>16;g[a+31|0]=b>>>24;b=i[d+20>>2];c=i[d+16>>2];g[a+16|0]=c;g[a+17|0]=c>>>8;g[a+18|0]=c>>>16;g[a+19|0]=c>>>24;g[a+20|0]=b;g[a+21|0]=b>>>8;g[a+22|0]=b>>>16;g[a+23|0]=b>>>24;b=i[d+12>>2];c=i[d+8>>2];g[a+8|0]=c;g[a+9|0]=c>>>8;g[a+10|0]=c>>>16;g[a+11|0]=c>>>24;g[a+12|0]=b;g[a+13|0]=b>>>8;g[a+14|0]=b>>>16;g[a+15|0]=b>>>24;b=i[d+4>>2];c=i[d>>2];g[a|0]=c;g[a+1|0]=c>>>8;g[a+2|0]=c>>>16;g[a+3|0]=c>>>24;g[a+4|0]=b;g[a+5|0]=b>>>8;g[a+6|0]=b>>>16;g[a+7|0]=b>>>24;Xa=d+32|0}function uE(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,j=0;f=Xa-16|0;Xa=f;c=1;a:{b:{switch(b-a>>2){case 2:b=b+ -4|0;if(!pd(b,a)){break a}Gb(a,b);break a;case 3:bm(a,a+4|0,b+ -4|0);break a;case 4:lv(a,a+4|0,a+8|0,b+ -4|0);break a;case 5:kv(a,a+4|0,a+8|0,a+12|0,b+ -4|0);break a;case 0:case 1:break a;default:break b}}e=a+8|0;bm(a,a+4|0,e);d=a+12|0;c:{while(1){g=(b|0)==(d|0);if(g){break c}d:{if(pd(d,e)){i[f+12>>2]=i[d>>2];h=d;while(1){e:{c=e;i[h>>2]=i[c>>2];if((a|0)==(c|0)){c=a;break e}h=c;e=c+ -4|0;if(pd(f+12|0,e)){continue}}break}i[c>>2]=i[f+12>>2];j=j+1|0;if((j|0)==8){break d}}e=d;d=d+4|0;continue}break}c=(d+4|0)==(b|0)}c=c|g}Xa=f+16|0;return c&1}function HO(a,b,c,d,e,f){var g=0,j=0,l=0,m=0,n=0,p=0,q=0;while(1){n=k[$b(b,g)>>1];p=n+1|0;q=n>>>0>127|(j&65535)>>>0>n>>>0;l=q?l:g>>>0<c>>>0?p:l;m=n>>>0<(m&65535)>>>0?m:p;j=q?j:p;g=g+1|0;if((g|0)!=128){continue}break}Zf(b,c);c=i[a+8>>2];a:{b:{if(!f){break b}g=j&65535;if((c+((g<<11)+f|0)|0)!=(hj(a)&-2)){break b}vc(a,c+(g<<10)|0);if(uy(a,16,1)){h[e>>1]=8}vc(a,c);break a}g=l&65535;if((g|0)==(j&65535)){j=l;break a}if(k[e>>1]!=4|f){break a}vc(a,c+(g<<10)|0);f=uy(a,64,1);vc(a,c);j=f?j:l}f=m&65535;c:{if(f>>>0>(j&65535)>>>0){if(((c+d|0)+(o(f,k[e>>1])<<8)|0)==(hj(a)|0)){break c}}if(f>>>0>=255){ty(b,254,65534);ty(b,255,65535)}m=j}return m&65535}function xsa(a,b){var c=0,d=0,e=0,f=0,i=0,l=0,m=0,n=0;i=255;a:{b:{e=a+58|0;c=j[Nb(e,b)|0];if((c|0)==255){break b}if(g[Nb(e,b)|0]>-1){break a}d=a+22|0;c=c&127;if(k[Mc(d,c)>>1]!=65535){if(k[Mc(d,c)>>1]!=(b|0)){break b}}m=Mc(d,c),n=b,h[m>>1]=n;m=Nb(e,b),n=c,g[m|0]=n;break a}l=a+4|0;f=a+22|0;c=0;d=255;while(1){if(k[Mc(f,c)>>1]==65535){m=Mc(f,c),n=b,h[m>>1]=n;m=Nb(e,b),n=c,g[m|0]=n;break a}if(!(j[Nb(l,c)|0]&32)){i=g[Nb(e,k[Mc(f,c)>>1])|0]>-1?i:c;d=c}c=c+1|0;if((c|0)!=18){continue}break}if((d&255)!=255){c=(i&255)==255?d:i;d=c&255;m=Nb(e,k[Mc(f,d)>>1]),n=255,g[m|0]=n;m=Mc(f,d),n=b,h[m>>1]=n;m=Nb(e,b),n=c,g[m|0]=n}c=Sj(a,b)}return c&255}function oR(a,b,c,d,e){var f=0,h=0,i=0,k=0,l=0,m=0;a:{if(!d){break a}k=j[e|0];if(!k|!b){break a}h=d+ -6|0;l=35>>>h&(h&255)>>>0<6;i=o(0-c|0,6);m=(d+ -2&255)>>>0>2;while(1){h=a+i|0;f=j[h+3|0];b:{if(!((f+ -2&255)>>>0>2|m)){c=1;if(j[(a+i|0)+5|0]<224){break b}break a}c=(d|0)==(f|0);if(!(1<<f&2240)|(!l|f>>>0>11)){break b}c=1}c:{if(m){break c}f=a+i|0;if((j[f+2|0]+ -11&255)>>>0>2){break c}if(j[f+4|0]){break a}}d:{if(!l){break d}f=a+i|0;if((j[f+2|0]+ -3&255)>>>0>3){break d}if(j[f+4|0]){break a}}e:{if(!c){break e}c=k;a=j[(a+i|0)+5|0];if(a?(c|0)!=(a|0):0){break a}if((a|0)!=(c|0)){break e}g[e|0]=0;return}a=h;b=b+ -1|0;if(b){continue}break}}}function Gi(a,b,c){var d=0,e=0,f=0,h=0,j=0;d=Xa-32|0;Xa=d;g[a|0]=0;f=hf(i[i[b>>2]+ -12>>2]+b|0);e=i[i[b>>2]+ -12>>2]+b|0;a:{b:{if(f){if(i[e+72>>2]){Eq(i[(i[i[b>>2]+ -12>>2]+b|0)+72>>2])}c:{if(!(i[(i[i[b>>2]+ -12>>2]+b|0)+4>>2]&4096)|c){break c}fc(d+24|0,i[i[b>>2]+ -12>>2]+b|0);i[114610]=0;f=F(21,d+24|0)|0;c=i[114610];i[114610]=0;if((c|0)==1){break a}ub(d+24|0);c=am(d+16|0,b);e=ak(d+8|0);while(1){d:{if(!Tn(c,e)){break d}if(!jg(f,8192,zj(c))){break d}Jk(c);continue}break}if(!Fi(c,e)){break c}ag(i[i[b>>2]+ -12>>2]+b|0,6)}h=a,j=hf(i[i[b>>2]+ -12>>2]+b|0),g[h|0]=j;break b}ag(e,4)}Xa=d+32|0;return a}a=B()|0;A()|0;ub(d+24|0);E(a|0);x()}function Laa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=Xa-32|0;Xa=c;AG(c+24|0);yG(a+24|0,sd(c+24|0));ih(c+24|0);h[a+28>>1]=0;Jaa(c+24|0,kM());ks(a+32|0,c+24|0);$e(c+24|0);zG(c+24|0,i[a>>2]);JG(a+4|0,sd(c+24|0));Ec(c+24|0);km(i[a+24>>2],i[a+4>>2]);i[a+60>>2]=0;i[a+48>>2]=1065353216;i[a+52>>2]=0;i[a+16>>2]=0;i[a+20>>2]=0;i[a+8>>2]=0;g[a- -64|0]=0;e=c,f=Wm(b),i[e+24>>2]=f;e=c,f=fi(b),i[e+16>>2]=f;a:{if(ei(c+24|0,c+16|0)){while(1){d=Qg(c+24|0);b=Kf(c,d);i[114610]=0;J(2081,a|0,b|0,d+12|0,0);d=i[114610];i[114610]=0;if((d|0)==1){break a}eb(b);$o(c+24|0);if(ei(c+24|0,c+16|0)){continue}break}}Xa=c+32|0;return}a=B()|0;A()|0;eb(b);E(a|0);x()}function Do(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,h=0,k=0,l=0,m=0,n=0,p=0,q=0;f=Xa-16|0;Xa=f;if(e){g[e|0]=0}i[f+12>>2]=4;m=a+484344|0;d=Qe(Fb(m,b),c,d);h=j[d+5|0];a:{b:{c:{d:{k=j[d+3|0];switch(k+ -10|0){case 2:case 4:case 7:break c;case 0:break d;default:break a}}i[f+12>>2]=2;l=0;break b}i[f+12>>2]=1;l=0;if((k|0)!=17){break b}l=i[a+480180>>2]==4}p=f,q=i[Fb(m,b)+12>>2]+(c^-1)|0,i[p+8>>2]=q;c=i[rb(f+8|0,f+12|0)>>2];if(!c){break a}while(1){n=o(Hj(Fb(m,b)),6);a=n+d|0;if(j[a+3|0]!=34){break a}k=h<<8;h=l?h>>>0<256?k+ -8192|0:k:k;d=j[(d+n|0)+5|0];c=c+ -1|0;if(e){g[e|0]=1}h=d|h;d=a;if(c){continue}break}}Xa=f+16|0;return h|0}function tD(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=Xa-16|0;Xa=d;Xa=d+16|0;e=0;a:{if(!b){break a}b:{if(!c){break b}a=a?a:d+12|0;d=j[b|0];e=d<<24>>24;if((e|0)>=0){i[a>>2]=d;e=(e|0)!=0;break a}d=g[b|0];if(!i[i[21199]>>2]){i[a>>2]=d&57343;e=1;break a}d=(d&255)+ -194|0;if(d>>>0>50){break b}d=i[(d<<2)+57664>>2];if(d<<o(c,6)+ -6<0?c>>>0<=3:0){break b}c=j[b+1|0];e=c>>>3|0;if((e+ -16|e+(d>>26))>>>0>7){break b}c=c+ -128|d<<6;if((c|0)>=0){i[a>>2]=c;e=2;break a}d=j[b+2|0]+ -128|0;if(d>>>0>63){break b}c=d|c<<6;if((c|0)>=0){i[a>>2]=c;e=3;break a}b=j[b+3|0]+ -128|0;if(b>>>0>63){break b}i[a>>2]=b|c<<6;e=4;break a}i[114584]=25;e=-1}return e|0}function Zva(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,h=0,j=0,k=0,l=0,m=0,n=0;e=Xa-32|0;Xa=e;k=i[a+24>>2];l=i[a+20>>2];m=i[a+16>>2];b=i[a+4>>2];f=i[a>>2];i[e+24>>2]=f;i[e+28>>2]=b;h=i[a+12>>2];i[e+16>>2]=i[a+8>>2];i[e+20>>2]=h;if(d){while(1){n=f>>>10&4194048;j=(((b&2147483647)<<1|f>>>31)&-2)+m|0;h=0;b=1;while(1){f=g[h+j|0];i[(e+8|0)+(h<<2)>>2]=((o(g[(h|2)+j|0]-f|0,n)|0)/16384|0)+(f<<8);f=b;b=0;h=1;if(f){continue}break}i[c>>2]=i[c>>2]+o(i[e+8>>2],l);i[c+4>>2]=i[c+4>>2]+o(i[e+12>>2],k);zb(e+24|0,e+16|0);d=d+ -1|0;if(d){c=c+8|0;f=i[e+24>>2];b=i[e+28>>2];continue}break}f=i[e+24>>2];b=i[e+28>>2]}i[a>>2]=f;i[a+4>>2]=b;Xa=e+32|0}function B5(a,b,c,d,e,f){var g=0,h=0,k=0,l=0;i[a+1504>>2]=0;i[a+1508>>2]=0;a:{if(i[a+96>>2]){break a}if(!m5(a)){break a}if(Rb(a,1)){Lb(a,35);return 0}h=c;b:{c:{if(!(i[a+84>>2]!=i[a+92>>2]?i[a+80>>2]:0)){c=Rb(a,Pk(i[a+408>>2]+ -1|0));if((c|0)==-1|(c|0)>=i[a+408>>2]){break a}i[f>>2]=c;c=o(c,6)+a|0;if(!j[c+412|0]){g=i[a+112>>2];f=g>>1;break c}g=i[a+116>>2];f=g>>1;k=Rb(a,1);l=Rb(a,1);if(!j[c+412|0]|k){break c}i[b>>2]=g-i[a+112>>2]>>2;b=i[a+112>>2]+g>>2;break b}V(50392,50448,3137,50480);x()}i[b>>2]=0;b=f}i[h>>2]=b;d:{if(!(!j[c+412|0]|l)){b=o(g,3);i[d>>2]=b-i[a+112>>2]>>2;g=b+i[a+112>>2]>>2;break d}i[d>>2]=f}i[e>>2]=g;g=1}return g}function Wva(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0;b=Xa-16|0;Xa=b;g=i[a+40>>2];j=i[a+36>>2];n=i[a+16>>2];f=i[a+4>>2];e=f;k=i[a>>2];i[b+8>>2]=k;i[b+12>>2]=e;f=i[a+12>>2];i[b>>2]=i[a+8>>2];i[b+4>>2]=f;a:{if(!d){f=g>>12;l=j>>12;break a}while(1){f=i[a+32>>2];m=(e<<1)+n|0;e=h[m>>1];j=i[a+28>>2]+j|0;l=j>>12;e=e+((o(h[m+2>>1]-e|0,k>>>18|0)|0)/16384|0)|0;i[c>>2]=i[c>>2]+o(l,e);g=f+g|0;f=g>>12;i[c+4>>2]=i[c+4>>2]+o(e,f);zb(b+8|0,b);d=d+ -1|0;if(d){c=c+8|0;k=i[b+8>>2];e=i[b+12>>2];continue}break}k=i[b+8>>2];e=i[b+12>>2]}i[a+40>>2]=g;i[a+20>>2]=l;i[a+36>>2]=j;i[a+24>>2]=f;i[a>>2]=k;i[a+4>>2]=e;Xa=b+16|0}function tca(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=Xa-32|0;Xa=c;i[114610]=0;L(2015,a|0);d=i[114610];i[114610]=0;a:{b:{c:{if((d|0)==1){break c}i[114610]=0;L(2041,b|0);d=i[114610];i[114610]=0;if((d|0)==1){break c}d=i[a+24>>2];b=Zb(c+8|0,b);i[114610]=0;e=i[b+4>>2];i[c>>2]=i[b>>2];i[c+4>>2]=e;J(2080,c+16|0,d|0,c|0,1);b=i[114610];i[114610]=0;if((b|0)==1){break c}b=Ed(xb(c+16|0));eb(c+16|0);break b}b=H(0)|0;A()|0;M(b|0)|0;b=0;i[114610]=0;J(1989,37003,a|0,0,0);a=i[114610];i[114610]=0;if((a|0)==1){break a}O()}Xa=c+32|0;return b|0}a=B()|0;A()|0;i[114610]=0;K(20);b=i[114610];i[114610]=0;if((b|0)!=1){E(a|0);x()}a=H(0)|0;A()|0;gb(a);x()}function Xva(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,h=0,j=0,k=0,l=0,m=0,n=0;b=Xa-16|0;Xa=b;h=i[a+40>>2];j=i[a+36>>2];n=i[a+16>>2];f=i[a+4>>2];e=f;k=i[a>>2];i[b+8>>2]=k;i[b+12>>2]=e;f=i[a+12>>2];i[b>>2]=i[a+8>>2];i[b+4>>2]=f;a:{if(!d){f=h>>12;l=j>>12;break a}while(1){f=i[a+32>>2];m=e+n|0;e=g[m|0];j=i[a+28>>2]+j|0;l=j>>12;e=((o(g[m+1|0]-e|0,k>>>18|0)<<8)/16384|0)+(e<<8)|0;i[c>>2]=i[c>>2]+o(l,e);h=f+h|0;f=h>>12;i[c+4>>2]=i[c+4>>2]+o(e,f);zb(b+8|0,b);d=d+ -1|0;if(d){c=c+8|0;k=i[b+8>>2];e=i[b+12>>2];continue}break}k=i[b+8>>2];e=i[b+12>>2]}i[a+40>>2]=h;i[a+20>>2]=l;i[a+36>>2]=j;i[a+24>>2]=f;i[a>>2]=k;i[a+4>>2]=e;Xa=b+16|0}function Tna(a){a=a|0;var b=0,c=0,d=0;c=a+1304360|0;b=a+1074984|0;while(1){i[b+104>>2]=0;i[b+656>>2]=0;i[b+76>>2]=0;i[b+16>>2]=0;b=b+896|0;if((c|0)!=(b|0)){continue}break}xI(a+484344|0);Ce(a+1304400|0);Ce(a+1304412|0);Ce(a+1304424|0);wz(a+1304500|0);c=a+900380|0;b=a+484380|0;while(1){Om(b);b=b+104|0;if((c|0)!=(b|0)){continue}break}c=a+901404|0;b=a+900380|0;while(1){d=i[b>>2];if(d){Cb(Is(d))}i[b>>2]=0;b=b+4|0;if((c|0)!=(b|0)){continue}break}c=a+946300|0;b=a+906300|0;while(1){uH(b);b=b+160|0;if((c|0)!=(b|0)){continue}break}i[a+480180>>2]=0;i[a+480184>>2]=0;a=a+480186|0;h[a>>1]=0;h[a+2>>1]=0;h[a+4>>1]=0;h[a+6>>1]=0;return 1}function EE(a,b,c,d,e){var f=0,h=0,j=0;f=Xa-208|0;Xa=f;i[f+204>>2]=c;c=0;yb(f+160|0,0,40);i[f+200>>2]=i[f+204>>2];a:{if((qv(0,b,f+200|0,f+80|0,f+160|0,d,e)|0)<0){b=-1;break a}c=i[a+76>>2]>=0?1:c;h=i[a>>2];if(g[a+74|0]<=0){i[a>>2]=h&-33}j=h&32;b:{if(i[a+48>>2]){b=qv(a,b,f+200|0,f+80|0,f+160|0,d,e);break b}i[a+48>>2]=80;i[a+16>>2]=f+80;i[a+28>>2]=f;i[a+20>>2]=f;h=i[a+44>>2];i[a+44>>2]=f;d=qv(a,b,f+200|0,f+80|0,f+160|0,d,e);b=d;if(!h){break b}$a[i[a+36>>2]](a,0,0)|0;i[a+48>>2]=0;i[a+44>>2]=h;i[a+28>>2]=0;i[a+16>>2]=0;b=i[a+20>>2];i[a+20>>2]=0;b=b?d:-1}d=a;a=i[a>>2];i[d>>2]=a|j;b=a&32?-1:b;if(!c){break a}}Xa=f+208|0;return b}function uIa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=Xa-32|0;Xa=d;kd(b,0);oi(d,1,a);oc(d+16|0,d);i[114610]=0;C(370,b+43|0,d+16|0)|0;c=i[114610];i[114610]=0;if((c|0)!=1){eb(d+16|0);c=a+32|0;i[b+24>>2]=j[c|0]|j[c+1|0]<<8|(j[c+2|0]<<16|j[c+3|0]<<24);c=a+13|0;h[b+34>>1]=k[b+34>>1]&65533|(j[c|0]|j[c+1|0]<<8)<<1&2;c=a+16|0;i[b>>2]=j[c|0]|j[c+1|0]<<8|(j[c+2|0]<<16|j[c+3|0]<<24);c=a+20|0;i[b+4>>2]=j[c|0]|j[c+1|0]<<8|(j[c+2|0]<<16|j[c+3|0]<<24);c=a+24|0;i[b+8>>2]=j[c|0]|j[c+1|0]<<8|(j[c+2|0]<<16|j[c+3|0]<<24);g[d+16|0]=j[a+15|0];g[d|0]=64;e=b,f=j[Xb(d+16|0,d)|0]<<2,h[e+30>>1]=f;Xa=d+32|0;return}a=B()|0;A()|0;eb(d+16|0);E(a|0);x()}function nF(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;e=Xa-16|0;Xa=e;a:{b:{c:{d=a+8|0;d:{if(!Qk(d)){if((b|0)<0|(ar(d)|0)<=(b|0)){break d}a=Uo(i[a+32>>2],b+1&65535);h[a+34>>1]=k[a+34>>1]&64511|(c?1024:0);break b}d=Qk(d);if((b|0)<0){break d}if((d|0)>(b|0)){break c}}a=P(8)|0;i[114610]=0;c=C(85,e|0,40625)|0;b=i[114610];i[114610]=0;e:{if((b|0)!=1){Ub(a,c);i[114610]=0;G(2009,a|0,83568,2017);a=i[114610];i[114610]=0;if((a|0)!=1){break a}b=B()|0;A()|0;eb(c);break e}b=B()|0;A()|0;Q(a|0)}E(b|0);x()}b=b+1<<2;a=a+32|0;if(!i[(b+i[a>>2]|0)+900380>>2]){break b}a=i[(b+i[a>>2]|0)+900380>>2];g[a+15|0]=j[a+15|0]&253|(c?2:0)}Xa=e+16|0;return}x()}function f1(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=Xa-48|0;Xa=f;i[f+40>>2]=b;a:{if(!(i[c+4>>2]&1)){c=$a[i[i[a>>2]+24>>2]](a,b,c,d,e)|0;break a}fc(f+24|0,c);i[114610]=0;a=F(2450,f+24|0)|0;b=i[114610];i[114610]=0;b:{if((b|0)!=1){ub(f+24|0);c:{if(e){Fg(f+24|0,a);break c}Eg(f+24|0,a)}g=f,h=ld(f+24|0),i[g+16>>2]=h;while(1){g=f,h=rj(f+24|0),i[g+8>>2]=h;if(!pb(f+16|0,f+8|0)){c=i[f+40>>2];nc(f+24|0);break a}a=i[i[f+16>>2]>>2];i[114610]=0;C(2473,f+40|0,a|0)|0;a=i[114610];i[114610]=0;if((a|0)!=1){Gd(f+16|0);continue}break}c=B()|0;A()|0;nc(f+24|0);break b}c=B()|0;A()|0;ub(f+24|0)}E(c|0);x()}Xa=f+48|0;return c|0}function iwa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,j=0,k=0,l=0,m=0;b=Xa-16|0;Xa=b;j=i[a+40>>2];k=i[a+36>>2];m=i[a+16>>2];e=i[a+4>>2];f=e;g=i[a>>2];i[b+8>>2]=g;i[b+12>>2]=e;e=i[a+12>>2];i[b>>2]=i[a+8>>2];i[b+4>>2]=e;a:{if(!d){e=j>>12;l=k>>12;break a}while(1){f=((((f&2147483647)<<1|g>>>31)&2147483646)<<1)+m|0;g=h[f+2>>1];e=i[a+32>>2];k=i[a+28>>2]+k|0;l=k>>12;i[c>>2]=i[c>>2]+o(l,h[f>>1]);j=e+j|0;e=j>>12;i[c+4>>2]=i[c+4>>2]+o(g,e);zb(b+8|0,b);d=d+ -1|0;if(d){c=c+8|0;g=i[b+8>>2];f=i[b+12>>2];continue}break}g=i[b+8>>2];f=i[b+12>>2]}i[a+40>>2]=j;i[a+20>>2]=l;i[a+36>>2]=k;i[a+24>>2]=e;i[a>>2]=g;i[a+4>>2]=f;Xa=b+16|0}function Fh(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0;f=Xa-16|0;Xa=f;gNa(+b);h=dNa(1)|0;g=dNa(0)|0;e=h&2147483647;c=e;e=c+ -1048576|0;d=g;if(d>>>0<0){e=e+1|0}a:{if((e|0)==2145386495|e>>>0<2145386495){j=d<<28;e=(c&15)<<28|d>>>4;c=(c>>>4|0)+1006632960|0;d=e;c=d>>>0<0?c+1|0:c;break a}if((c|0)==2146435072&d>>>0>=0|c>>>0>2146435072){j=g<<28;e=g;c=h;g=c>>>4|0;d=(c&15)<<28|e>>>4;c=g|2147418112;break a}if(!(c|d)){d=0;c=0;break a}e=c;c=(c|0)==1&d>>>0<0|c>>>0<1?r(g)+32|0:r(c);kf(f,d,e,0,0,c+49|0);k=i[f>>2];j=i[f+4>>2];d=i[f+8>>2];c=i[f+12>>2]^65536|15372-c<<16}i[a>>2]=k;i[a+4>>2]=j;i[a+8>>2]=d;i[a+12>>2]=h&-2147483648|c;Xa=f+16|0}function bma(a){var b=0,c=0,d=0,e=0,f=0;b=Xa+ -64|0;Xa=b;a:{e=i[a+4>>2];if(!e){break a}d=78352;while(1){c=i[a+4>>2];i[b+56>>2]=i[a>>2];i[b+60>>2]=c;c=Zb(b+48|0,i[d+8>>2]);f=i[b+60>>2];i[b+24>>2]=i[b+56>>2];i[b+28>>2]=f;f=i[c+4>>2];i[b+16>>2]=i[c>>2];i[b+20>>2]=f;if(cJ(b+24|0,b+16|0)){break a}d=d+12|0;if((d|0)!=78868){continue}break}d=78880;while(1){b:{c=i[a+4>>2];i[b+40>>2]=i[a>>2];i[b+44>>2]=c;c=Zb(b+32|0,i[d+8>>2]);e=i[b+44>>2];i[b+8>>2]=i[b+40>>2];i[b+12>>2]=e;e=i[c+4>>2];i[b>>2]=i[c>>2];i[b+4>>2]=e;c=cJ(b+8|0,b);if(c){break b}d=d+12|0;if((d|0)!=78928){continue}}break}Xa=b- -64|0;return c}Xa=b- -64|0;return(e|0)!=0}function r1(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,h=0,j=0;f=Xa-48|0;Xa=f;i[f+40>>2]=b;a:{if(!(i[c+4>>2]&1)){c=$a[i[i[a>>2]+24>>2]](a,b,c,d,e)|0;break a}fc(f+24|0,c);i[114610]=0;a=F(2416,f+24|0)|0;b=i[114610];i[114610]=0;b:{if((b|0)!=1){ub(f+24|0);c:{if(e){Fg(f+24|0,a);break c}Eg(f+24|0,a)}h=f,j=ld(f+24|0),i[h+16>>2]=j;while(1){h=f,j=Ye(f+24|0),i[h+8>>2]=j;if(!pb(f+16|0,f+8|0)){c=i[f+40>>2];eb(f+24|0);break a}a=g[i[f+16>>2]];i[114610]=0;C(2336,f+40|0,a|0)|0;a=i[114610];i[114610]=0;if((a|0)!=1){Tf(f+16|0);continue}break}c=B()|0;A()|0;eb(f+24|0);break b}c=B()|0;A()|0;ub(f+24|0)}E(c|0);x()}Xa=f+48|0;return c|0}function rBa(a,b,c,d){var e=0,f=0,g=0;e=Xa-80|0;Xa=e;Ce(b);De(e+56|0,a,d);a=i[e+56>>2];i[114610]=0;f=F(412,e+56|0)|0;g=i[114610];i[114610]=0;a:{b:{c:{if((g|0)==1){break c}i[114610]=0;f=F(413,f|0)|0;g=i[114610];i[114610]=0;if((g|0)==1){break c}i[114610]=0;J(414,e+8|0,2,f|0,a|0);f=i[114610];i[114610]=0;if((f|0)==1){break c}i[114610]=0;D(415,e+24|0,e+8|0);f=i[114610];i[114610]=0;if((f|0)==1){break c}i[114610]=0;G(13,e+40|0,c|0,e+24|0);c=i[114610];i[114610]=0;if((c|0)==1){break b}mb(b,e+40|0);eb(e+40|0);eb(e+24|0);jc(e+56|0);Xa=e+80|0;return!d|(a|0)!=0}a=B()|0;A()|0;break a}a=B()|0;A()|0;eb(e+24|0)}jc(e+56|0);E(a|0);x()}function ZBa(a,b,c,d){var e=0,f=0,g=0;e=Xa-80|0;Xa=e;Ce(b);De(e+56|0,a,d);a=i[e+56>>2];i[114610]=0;f=F(412,e+56|0)|0;g=i[114610];i[114610]=0;a:{b:{c:{if((g|0)==1){break c}i[114610]=0;f=F(413,f|0)|0;g=i[114610];i[114610]=0;if((g|0)==1){break c}i[114610]=0;J(414,e+8|0,3,f|0,a|0);f=i[114610];i[114610]=0;if((f|0)==1){break c}i[114610]=0;D(415,e+24|0,e+8|0);f=i[114610];i[114610]=0;if((f|0)==1){break c}i[114610]=0;G(13,e+40|0,c|0,e+24|0);c=i[114610];i[114610]=0;if((c|0)==1){break b}mb(b,e+40|0);eb(e+40|0);eb(e+24|0);jc(e+56|0);Xa=e+80|0;return!d|(a|0)!=0}a=B()|0;A()|0;break a}a=B()|0;A()|0;eb(e+24|0)}jc(e+56|0);E(a|0);x()}function tK(a,b,c){var d=0,e=0;a:{if(i[a+480180>>2]==4){d=j[b+834|0];if(c){g[b+834|0]=d&15|c<<4;break a}c=(d&240)>>>4|0;break a}if(i[a+480180>>2]!=1048576){break a}if(c){g[b+833|0]=c;break a}c=j[b+833|0]}b:{if(!(g[b+872|0]&1)|!(c&255)){break b}d=i[b+700>>2];if(!d){break b}c:{if(!(j[a+480208|0]&16)){break c}d=i[b+700>>2];if(i[a+480180>>2]==4){break c}e=b;a=kK(a,c&15);b=XMa(a,a>>31,d,d>>31)+32768|0;a=_a;a=gc(YMa(b,b>>>0<32768?a+1|0:a,65536,0),_a);i[e+700>>2]=((a|0)==(d|0))+a;return}c=d-(c&255)|0;i[b+700>>2]=c;if((c|0)>0){break b}i[b+700>>2]=1;if(i[a+480180>>2]!=2){break b}i[b+696>>2]=0;i[b+88>>2]=i[b+88>>2]|2101248}}function jwa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,h=0,j=0,k=0,l=0,m=0;b=Xa-16|0;Xa=b;j=i[a+40>>2];k=i[a+36>>2];m=i[a+16>>2];e=i[a+4>>2];f=e;h=i[a>>2];i[b+8>>2]=h;i[b+12>>2]=e;e=i[a+12>>2];i[b>>2]=i[a+8>>2];i[b+4>>2]=e;a:{if(!d){e=j>>12;l=k>>12;break a}while(1){f=(((f&2147483647)<<1|h>>>31)&-2)+m|0;h=g[f+1|0];e=i[a+32>>2];k=i[a+28>>2]+k|0;l=k>>12;i[c>>2]=i[c>>2]+(o(l,g[f|0])<<8);j=e+j|0;e=j>>12;i[c+4>>2]=i[c+4>>2]+(o(h,e)<<8);zb(b+8|0,b);d=d+ -1|0;if(d){c=c+8|0;h=i[b+8>>2];f=i[b+12>>2];continue}break}h=i[b+8>>2];f=i[b+12>>2]}i[a+40>>2]=j;i[a+20>>2]=l;i[a+36>>2]=k;i[a+24>>2]=e;i[a>>2]=h;i[a+4>>2]=f;Xa=b+16|0}function C3(a,b){var c=0,d=0,e=0;c=Xa-16|0;Xa=c;i[114610]=0;e=C(15,c+8|0,a|0)|0;d=i[114610];i[114610]=0;a:{b:{c:{if((d|0)!=1){d:{if(!j[e|0]){break d}d=sk(c,a);i[114610]=0;C(2336,d|0,b|0)|0;b=i[114610];i[114610]=0;if((b|0)!=1){if(!rk(d)){break d}b=i[i[a>>2]+ -12>>2];i[114610]=0;D(18,a+b|0,1);b=i[114610];i[114610]=0;if((b|0)!=1){break d}}b=H(0)|0;A()|0;jf(e);break c}jf(e);break b}b=H(0)|0;A()|0}M(b|0)|0;b=i[i[a>>2]+ -12>>2];i[114610]=0;L(19,a+b|0);a=i[114610];i[114610]=0;if((a|0)==1){break a}O()}Xa=c+16|0;return}a=B()|0;A()|0;i[114610]=0;K(20);b=i[114610];i[114610]=0;if((b|0)!=1){E(a|0);x()}a=H(0)|0;A()|0;gb(a);x()}function $ma(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var h=0,j=0,l=0,m=0;h=Xa-32|0;Xa=h;a:{if(k[a+480192>>1]<b>>>0){break a}b=i[((b<<2)+a|0)+900380>>2];if(!b){break a}qM(h+16|0,b);l=h,m=iP(h+16|0),i[l+8>>2]=m;l=h,m=Zi(h+16|0),i[l>>2]=m;while(1){b:{i[114610]=0;b=C(789,h+8|0,h|0)|0;j=i[114610];i[114610]=0;if((j|0)==1){break b}if(!b){_o(h+16|0);break a}i[114610]=0;b=F(790,h+8|0)|0;j=i[114610];i[114610]=0;if((j|0)==1){break b}b=k[b>>1];if(b>>>0<=k[a+480190>>1]){b=o(b,104)+a|0;g[b+484421|0]=f;g[b+484418|0]=c;g[b+484420|0]=e;g[b+484419|0]=d}Js(h+8|0);continue}break}a=B()|0;A()|0;_o(h+16|0);E(a|0);x()}Xa=h+32|0}function caa(a,b){a=a|0;b=b|0;var c=0,d=p(0);c=Xa-16|0;Xa=c;a:{b:{c:{d:{switch(b+ -1|0){case 0:d=p(oX(m[a+48>>2])*p(2e3));if(!(p(q(d))<p(2147483648))){break c}a=~~d;break b;case 1:a=(o(i[i[a+24>>2]+24604>>2],100)|0)/128|0;break b;case 2:a=baa(j[i[a+24>>2]+24648|0]);break b;case 3:i[c>>2]=0;aaa(c,i[a+24>>2]+24604|0);a=i[c>>2];break b;default:break d}}a=P(8)|0;i[114610]=0;c=C(85,c|0,38621)|0;b=i[114610];i[114610]=0;e:{if((b|0)!=1){Ub(a,c);i[114610]=0;G(2009,a|0,83568,2017);a=i[114610];i[114610]=0;if((a|0)!=1){break a}b=B()|0;A()|0;eb(c);break e}b=B()|0;A()|0;Q(a|0)}E(b|0);x()}a=-2147483648}Xa=c+16|0;return a|0}x()}function Jta(a,b){var c=0,d=0,e=0,f=0,g=0,j=0,l=0,m=0,n=0;f=Xa+ -64|0;Xa=f;d=$d(a);m=d<<6;j=i[a+20>>2];g=j+(o(i[a>>2],d)<<1)|0;while(1){if(d){l=o(d,e);n=o(e^-1,d);c=0;while(1){h[g+(c+l<<1)>>1]=k[g+(c-d<<1)>>1];h[(c+n<<1)+j>>1]=k[(c<<1)+j>>1];c=c+1|0;if((c|0)!=(d|0)){continue}break}}e=e+1|0;if((e|0)!=16){continue}break}g=g+(d<<5)|0;c=k[a+34>>1];if(c&2){l=i[a+8>>2];e=i[a+4>>2];kb(f+32|0,b+1074308|0,33);mM(f+40|0,g,(o(d,e)<<1)+j|0,l-e|0,d,(c&4)>>>2|0,ib(f+32|0));c=k[a+34>>1]}if(c&8){e=i[a+16>>2];a=i[a+12>>2];kb(f+32|0,b+1074308|0,33);mM(f+8|0,g+(m<<1)|0,(o(a,d)<<1)+j|0,e-a|0,d,(c&16)>>>4|0,ib(f+32|0))}Xa=f- -64|0}function vya(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=Xa-80|0;Xa=f;ai(f+40|0,f+32|0,c);i[114610]=0;G(240,f+52|0,f+24|0,d|0);d=i[114610];i[114610]=0;c=1;a:{b:{c:{d:{if((d|0)!=1){i[114610]=0;G(224,f- -64|0,f+16|0,e|0);c=i[114610];i[114610]=0;if((c|0)==1){break d}i[114610]=0;D(241,f+8|0,f+40|0);c=i[114610];i[114610]=0;if((c|0)==1){break b}i[114610]=0;G(72,a|0,b|0,f+8|0);a=i[114610];i[114610]=0;if((a|0)==1){break b}Hl(f+40|0);Xa=f+80|0;return}a=B()|0;A()|0;break c}a=B()|0;A()|0;c=2}c=(f+40|0)+o(c,12)|0;while(1){c=eb(c+ -12|0);if((c|0)!=(f+40|0)){continue}break}break a}a=B()|0;A()|0;Hl(f+40|0)}E(a|0);x()}function bHa(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=Xa-80|0;Xa=f;ai(f+40|0,f+32|0,c);i[114610]=0;G(224,f+52|0,f+24|0,d|0);d=i[114610];i[114610]=0;c=1;a:{b:{c:{d:{if((d|0)!=1){i[114610]=0;G(224,f- -64|0,f+16|0,e|0);c=i[114610];i[114610]=0;if((c|0)==1){break d}i[114610]=0;D(241,f+8|0,f+40|0);c=i[114610];i[114610]=0;if((c|0)==1){break b}i[114610]=0;G(72,a|0,b|0,f+8|0);a=i[114610];i[114610]=0;if((a|0)==1){break b}Hl(f+40|0);Xa=f+80|0;return}a=B()|0;A()|0;break c}a=B()|0;A()|0;c=2}c=(f+40|0)+o(c,12)|0;while(1){c=eb(c+ -12|0);if((c|0)!=(f+40|0)){continue}break}break a}a=B()|0;A()|0;Hl(f+40|0)}E(a|0);x()}function uW(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=Xa-80|0;Xa=f;Il(f+40|0,f+32|0,c);i[114610]=0;G(240,f+52|0,f+24|0,d|0);d=i[114610];i[114610]=0;c=1;a:{b:{c:{d:{if((d|0)!=1){i[114610]=0;G(240,f- -64|0,f+16|0,e|0);c=i[114610];i[114610]=0;if((c|0)==1){break d}i[114610]=0;D(241,f+8|0,f+40|0);c=i[114610];i[114610]=0;if((c|0)==1){break b}i[114610]=0;G(72,a|0,b|0,f+8|0);a=i[114610];i[114610]=0;if((a|0)==1){break b}Hl(f+40|0);Xa=f+80|0;return}a=B()|0;A()|0;break c}a=B()|0;A()|0;c=2}c=(f+40|0)+o(c,12)|0;while(1){c=eb(c+ -12|0);if((c|0)!=(f+40|0)){continue}break}break a}a=B()|0;A()|0;Hl(f+40|0)}E(a|0);x()}function jI(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=p(0),j=0,l=p(0),n=0,o=0,r=p(0);e=Xa-16|0;Xa=e;if(!(!k[b>>1]|h[d>>1]>h[d+2>>1]|(!(m[c>>2]>p(0))|(h[d+2>>1]-h[d>>1]|0)>32766))){h[a>>1]=3;f=a+4|0;Sh(f);h[a+28>>1]=65472;i[e+12>>2]=1065353216;mI(f,128,e+12|0);i[a+32>>2]=0;h[a+30>>1]=0;Sh(a+16|0);h[a+28>>1]=k[d>>1];n=a,o=ija(k[b>>1]),h[n+30>>1]=o;g=p(q(m[c>>2]));m[a+32>>2]=g;g=Wd(g,p(p(1)/p(h[a+30>>1])));j=1;Tk(f,(h[d+2>>1]-h[d>>1]|0)+1|0);b=h[d>>1];if((b|0)<=h[d+2>>1]){while(1){l=Wd(g,p(b|0));n=vb(f,b-h[a+28>>1]|0),r=l,m[n>>2]=r;c=(b|0)<h[d+2>>1];b=b+1|0;if(c){continue}break}}go(a)}Xa=e+16|0;return j|0}function aAa(a,b,c,d){var e=0,f=0,g=0,h=0;f=Xa-16|0;Xa=f;c=$h(c,b);i[f+12>>2]=c;a:{if((c|0)<1){break a}e=i[b+4>>2];b:{if(!e){e=i[d>>2];break b}g=32-e|0;i[f+8>>2]=g;c=i[Nd(f+8|0,f+12|0)>>2];i[f+12>>2]=i[f+12>>2]-c;e=i[d>>2];g=-1<<i[b+4>>2]&-1>>>g-c;h=i[b>>2];i[e>>2]=i[e>>2]&(g^-1)|g&i[h>>2];c=c+i[d+4>>2]|0;i[d+4>>2]=c&31;e=e+(c>>>3&536870908)|0;i[d>>2]=e;i[b>>2]=h+4;c=i[f+12>>2]}h=e;e=(c|0)/32|0;c=e<<2;yi(h,i[b>>2],c);e=i[f+12>>2]-(e<<5)|0;i[f+12>>2]=e;g=c+i[d>>2]|0;i[d>>2]=g;if((e|0)<1){break a}h=b;b=c+i[b>>2]|0;i[h>>2]=b;c=-1>>>32-e|0;i[g>>2]=i[g>>2]&(c^-1)|c&i[b>>2];i[d+4>>2]=i[f+12>>2]}td(a,d);Xa=f+16|0}function Sf(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=Xa+ -64|0;Xa=e;a:{b:{if(c+ -1>>>0>1023){break b}if(pg(a,b)){break b}c:{d:{if(bf(a)>>>0<=b>>>0){d=yw(e+8|0,a);i[114610]=0;G(1582,a|0,b+1|0,d|0);f=i[114610];i[114610]=0;if((f|0)==1){break d}Yk(d)}d=se(a,b);i[114610]=0;C(1583,d|0,c|0)|0;c=i[114610];i[114610]=0;e:{if((c|0)!=1){c=se(a,b);i[c+16>>2]=0;i[c+20>>2]=0;c=se(a,b);i[114610]=0;C(1584,c|0,32308)|0;c=i[114610];i[114610]=0;if((c|0)!=1){break e}}a=H(71348)|0;b=A()|0;break c}g=rh(se(a,b));break b}a=H(71348)|0;b=A()|0;Yk(d)}if((U(71348)|0)!=(b|0)){break a}M(a|0)|0;O()}Xa=e- -64|0;return g|0}E(a|0);x()}function M2(a,b,c){var d=0,e=0,f=0,g=0,h=0,k=0,l=0,m=0,n=0,o=0,p=0;f=i[a>>2]+1794895138|0;e=Fk(i[a+8>>2],f);g=Fk(i[a+12>>2],f);d=Fk(i[a+16>>2],f);a:{if(e>>>0>=b>>>2>>>0){break a}h=b-(e<<2)|0;if((d|g)&3|(g>>>0>=h>>>0|d>>>0>=h>>>0)){break a}n=d>>>2|0;o=g>>>2|0;g=0;while(1){h=e>>>1|0;k=h+g|0;l=k<<1;d=(l+o<<2)+a|0;m=Fk(i[d>>2],f);d=Fk(i[d+4>>2],f);if(b>>>0<=d>>>0|m>>>0>=b-d>>>0|j[(d+m|0)+a|0]){break a}d=Ih(c,a+d|0);if(!d){c=(n+l<<2)+a|0;e=Fk(i[c>>2],f);c=Fk(i[c+4>>2],f);if(b>>>0<=c>>>0|e>>>0>=b-c>>>0){break a}p=j[(c+e|0)+a|0]?0:a+c|0;break a}if((e|0)==1){break a}d=(d|0)<0;e=d?h:e-h|0;g=d?g:k;continue}}return p}function Isa(a,b){var c=0,d=0,e=0;i[a+3832>>2]=0;i[a+3836>>2]=0;c=a+3837|0;g[c|0]=0;g[c+1|0]=0;g[c+2|0]=0;g[c+3|0]=0;g[c+4|0]=0;g[c+5|0]=0;g[c+6|0]=0;g[c+7|0]=0;while(1){gf((o(e,84)+a|0)+808|0,a);e=e+1|0;if((e|0)!=36){continue}break}while(1){i[(o(d,44)+a|0)+32>>2]=a;d=d+1|0;if((d|0)!=18){continue}break}d=0;while(1){c=i[(d<<2)+19792>>2];e=(o(d,44)+a|0)+16|0;a:{if(!(!(1<<d&3591)|d>>>0>11)){c=o(c,84)+a|0;RL(e,c+808|0,c+1060|0,c+1312|0,c+1564|0);break a}c=o(c,84)+a|0;RL(e,c+808|0,c+1060|0,0,0)}d=d+1|0;if((d|0)!=18){continue}break}d=0;while(1){Lm((o(d,84)+a|0)+808|0);d=d+1|0;if((d|0)!=36){continue}break}QL(a,b)}function zg(a){var b=0,c=0,d=0,e=0,f=0;a:{gNa(+a);b=dNa(1)|0;f=dNa(0)|0;c=b;b=b&2147483647;b:{if(b>>>0>=1083174912){if(!(b>>>0<1083179008|((c|0)<0?1:(c|0)<=0?f>>>0<0:0))){return a*8.98846567431158e+307}if(b>>>0>=2146435072){return-1/a}if(a<=-1075^1){break a}d=0;if((c|0)<-1?1:(c|0)<=-1){break b}break a}if(b>>>0>1016070143){break a}d=a+1}return d}e=a+26388279066624;gNa(+e);dNa(1)|0;c=(dNa(0)|0)+128|0;b=c<<4&4080;d=n[b+72272>>3];a=a-(e+ -26388279066624)-n[(b|8)+72272>>3];return yh(d+d*a*(a*(a*(a*(a*.0013333559164630223+.009618129842126066)+.0555041086648214)+.2402265069591)+.6931471805599453),(c&-256)/256|0)}function qca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=Xa-16|0;Xa=d;i[114610]=0;L(2015,a|0);e=i[114610];i[114610]=0;a:{b:{c:{if((e|0)==1){break c}i[114610]=0;L(2041,b|0);e=i[114610];i[114610]=0;if((e|0)==1){break c}e=i[a+24>>2];b=Zb(d+8|0,b);i[114610]=0;f=i[b+4>>2];i[d>>2]=i[b>>2];i[d+4>>2]=f;J(2082,e|0,d|0,(c|0)!=0|0,1);c=i[114610];i[114610]=0;b=1;if((c|0)!=1){break b}}b=H(0)|0;A()|0;M(b|0)|0;i[114610]=0;J(1989,37054,a|0,0,0);a=i[114610];i[114610]=0;if((a|0)==1){break a}O();b=0}Xa=d+16|0;return b|0}a=B()|0;A()|0;i[114610]=0;K(20);b=i[114610];i[114610]=0;if((b|0)!=1){E(a|0);x()}a=H(0)|0;A()|0;gb(a);x()}function ina(a,b,c){var d=0,e=0,f=0;d=Xa-32|0;Xa=d;a:{if(CJ(b)){i[d+16>>2]=i[5140];c=i[5137];i[d>>2]=i[5136];i[d+4>>2]=c;c=i[5139];i[d+8>>2]=i[5138];i[d+12>>2]=c;Bb(a,((b<<2)+d|0)+ -1004|0);break a}if(Jd(b)){f=Oc(d);i[114610]=0;e=b+ -1|0;b=(e<<16>>16)/12|0;c=C(1433,f|0,(e-o(b,12)<<16>>16<<2)+c|0)|0;e=i[114610];i[114610]=0;b:{if((e|0)==1){break b}i[114610]=0;b=I(1434,c|0,1,(b<<16)+3145728>>16)|0;c=i[114610];i[114610]=0;if((c|0)==1){break b}i[114610]=0;C(4,a|0,b|0)|0;a=i[114610];i[114610]=0;if((a|0)==1){break b}eb(f);break a}a=B()|0;A()|0;eb(f);E(a|0);x()}if(!b){Bb(a,20564);break a}Bb(a,20568)}Xa=d+32|0}function O4(a){var b=0,c=0,d=0,e=0;e=Xa-16|0;Xa=e;c=(hNa(a),dNa(2));b=c&2147483647;a:{if(b>>>0<=1061752794){if(b>>>0<964689920){break a}a=em(+a,0);break a}if(b>>>0<=1081824209){d=+a;if(b>>>0<=1075235811){a=em(((c|0)>-1?-1.5707963267948966:1.5707963267948966)+d,1);break a}a=em(((c|0)>-1?-3.141592653589793:3.141592653589793)+d,0);break a}if(b>>>0<=1088565717){d=+a;if(b>>>0<=1085271519){a=em(((c|0)>-1?-4.71238898038469:4.71238898038469)+d,1);break a}a=em(((c|0)>-1?-6.283185307179586:6.283185307179586)+d,0);break a}if(b>>>0>=2139095040){a=p(a-a);break a}b=sv(a,e+8|0);a=em(n[e+8>>3],b&1)}Xa=e+16|0;return a}function Lm(a){var b=0,c=0,d=0;b=(k[a+24>>1]<<2)+(k[i[a+4>>2]+28>>1]>>>(!j[a+77|0]<<1)|0)|0;i[a+40>>2]=((b&3)<<4)+18704;c=b>>>2|0;b=b>>>0<48;d=b?12-c|0:0;h[a+32>>1]=d;h[a+36>>1]=b?1:1<<c+ -12;h[a+34>>1]=-1<<d^-1;if(k[a+24>>1]==15){h[a+36>>1]=4095}b=(k[a+26>>1]<<2)+(k[i[a+4>>2]+28>>1]>>>(!j[a+77|0]<<1)|0)|0;i[a+52>>2]=((b&3)<<4)+18704;c=b>>>2|0;b=b>>>0<48;d=b?12-c|0:0;h[a+44>>1]=d;h[a+48>>1]=b?1:1<<c+ -12;h[a+46>>1]=-1<<d^-1;b=(k[a+30>>1]<<2)+(k[i[a+4>>2]+28>>1]>>>(!j[a+77|0]<<1)|0)|0;i[a+64>>2]=((b&3)<<4)+18704;c=b>>>2|0;b=b>>>0<48;d=b?12-c|0:0;h[a+56>>1]=d;h[a+60>>1]=b?1:1<<c+ -12;h[a+58>>1]=-1<<d^-1}function D$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;b=Xa-32|0;Xa=b;d=Ab(b+16|0);i[114610]=0;c=Pe(d);e=i[114610];i[114610]=0;a:{b:{if((e|0)==1){break b}e=xb(f);g=xb(f);f=lb(f);i[114610]=0;N(2506,b+8|0,c|0,e|0,f+g|0)|0;c=i[114610];i[114610]=0;if((c|0)==1){break b}c=xb(d);i[114610]=0;e=i[114610];i[114610]=0;c:{if((e|0)!=1){e=Ab(a);i[114610]=0;a=Pe(e);f=i[114610];i[114610]=0;if((f|0)==1){break c}f=le(c);i[114610]=0;N(2508,b|0,a|0,c|0,c+f|0)|0;a=i[114610];i[114610]=0;if((a|0)==1){break c}eb(d);Xa=b+32|0;return}a=B()|0;A()|0;break a}a=B()|0;A()|0;eb(e);break a}a=B()|0;A()|0}eb(d);E(a|0);x()}function gya(a,b){var c=0,d=0,e=0,f=0,k=0;d=Xa-32|0;Xa=d;kd(b,0);bk(d,2,a);oc(d+16|0,d);i[114610]=0;C(370,b+43|0,d+16|0)|0;c=i[114610];i[114610]=0;a:{b:{if((c|0)!=1){eb(d+16|0);c=a+24|0;i[b+24>>2]=j[c|0]|j[c+1|0]<<8;g[d+16|0]=j[a+22|0];g[d|0]=64;f=b,k=j[Xb(d+16|0,d)|0]<<2,h[f+30>>1]=k;c=a+16|0;i[b>>2]=j[c|0]|j[c+1|0]<<8;c=a+18|0;i[b+4>>2]=j[c|0]|j[c+1|0]<<8;a=a+20|0;a=j[a|0]|j[a+1|0]<<8;i[b+8>>2]=a;c=i[b>>2];if(c>>>0>1){break b}i[b>>2]=0;break a}a=B()|0;A()|0;eb(d+16|0);E(a|0);x()}e=i[b+4>>2];if((a|0)==65535|e>>>0>=c>>>0|e>>>0>=a>>>0){break a}h[b+34>>1]=2;f=b,k=i[rb(b+8|0,b)>>2],i[f+8>>2]=k}Xa=d+32|0}function GH(a,b,c){a=a|0;b=b|0;c=p(c);var d=0;d=Xa-16|0;Xa=d;m[d+12>>2]=c;ow(a);Id(d+12|0,p(0));a:{b:{switch(b|0){case 0:m[a+4220>>2]=m[d+12>>2];break a;case 1:m[a+4224>>2]=m[d+12>>2];break a;case 2:m[a+4228>>2]=m[d+12>>2];nw(a);break a;case 3:g[a+4240|0]=m[d+12>>2]>=p(.5);nw(a);break a;case 4:b=a;a=oh(p(m[d+12>>2]*p(32)));i[b+4232>>2]=(a|0)<5?a:5;Xa=d+16|0;return;case 5:g[a+4241|0]=m[d+12>>2]>=p(.5);break a;case 6:g[a+4242|0]=m[d+12>>2]>=p(.5);break a;case 7:g[a+4244|0]=m[d+12>>2]>=p(.5);break a;case 8:break b;default:break a}}b=a;c=m[d+12>>2];if(c==p(0)){mw(a);c=m[d+12>>2]}n[b+4256>>3]=c}Xa=d+16|0}function MU(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=Xa-48|0;Xa=d;pc(b);Yp(a);a:{if(!Se(b,d+40|0)){break a}if(!OA(d+40|0)){break a}if(!c){f=1;break a}if(!wb(b,4)){break a}ju(a);iu(d+24|0);hu(wg(a)+28|0,d+24|0);Xp(d+24|0);c=i[wg(a)+28>>2];e=hj(b);if(e&1){break a}g=e+ -4|0;vc(b,g);e=id(b);e=id(b)<<8|e<<16|id(b);if(!e){break a}i[114610]=0;D(331,c|0,e|0);h=i[114610];i[114610]=0;f=1;if((h|0)==1){a=H(71348)|0;if((A()|0)==(U(71348)|0)){M(a|0)|0;O();f=0;break a}E(a|0);x()}vc(b,4);KU(NA(b),g,jb(i[c>>2]),e);ui(d+8|0,c);eu(d+16|0,d+8|0);b=Dn(d+24|0,d+16|0);Cd(wg(a)+12|0,b);hb(b)}Xa=d+48|0;return f|0}function Lq(a,b,c,d,e,f){var g=0,h=0,j=0,k=0;g=Xa-240|0;Xa=g;h=i[c>>2];i[g+232>>2]=h;c=i[c+4>>2];i[g>>2]=a;i[g+236>>2]=c;j=1;a:{b:{c:{d:{if(c?0:(h|0)==1){break d}h=a-i[(d<<2)+f>>2]|0;if(($a[b|0](h,a)|0)<1){break d}k=!e;while(1){e:{c=h;if(!(!k|(d|0)<2)){e=i[((d<<2)+f|0)+ -8>>2];h=a+ -4|0;if(($a[b|0](h,c)|0)>-1){break e}if(($a[b|0](h-e|0,c)|0)>-1){break e}}i[(j<<2)+g>>2]=c;a=zE(g+232|0);Mq(g+232|0,a);j=j+1|0;d=a+d|0;if(i[g+236>>2]?0:i[g+232>>2]==1){break b}e=0;k=1;a=c;h=c-i[(d<<2)+f>>2]|0;if(($a[b|0](h,i[g>>2])|0)>0){continue}break c}break}c=a;break b}c=a}if(e){break a}}yE(g,j);pv(c,b,d,f)}Xa=g+240|0}function T$(a,b,c,d,e,f,h,j,k,l){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0;m=Xa-16|0;Xa=m;a:{if(a){a=TC(b);oj(m,a);b=i[m>>2];g[c|0]=b;g[c+1|0]=b>>>8;g[c+2|0]=b>>>16;g[c+3|0]=b>>>24;nj(m,a);Ah(k,m);nc(m);Eg(m,a);Ah(j,m);nc(m);n=d,o=Eh(a),i[n>>2]=o;n=e,o=Dh(a),i[n>>2]=o;Pf(m,a);mb(f,m);eb(m);Fg(m,a);Ah(h,m);nc(m);a=mj(a);break a}a=SC(b);oj(m,a);b=i[m>>2];g[c|0]=b;g[c+1|0]=b>>>8;g[c+2|0]=b>>>16;g[c+3|0]=b>>>24;nj(m,a);Ah(k,m);nc(m);Eg(m,a);Ah(j,m);nc(m);n=d,o=Eh(a),i[n>>2]=o;n=e,o=Dh(a),i[n>>2]=o;Pf(m,a);mb(f,m);eb(m);Fg(m,a);Ah(h,m);nc(m);a=mj(a)}i[l>>2]=a;Xa=m+16|0}function vW(a){var b=0,c=0,d=0;b=Xa+ -64|0;Xa=b;d=Oc(a);i[114610]=0;c=C(2,b+16|0,7127)|0;a=i[114610];i[114610]=0;a:{b:{c:{d:{e:{f:{if((a|0)!=1){i[114610]=0;D(219,b+32|0,c|0);a=i[114610];i[114610]=0;if((a|0)==1){break f}i[114610]=0;i[b+12>>2]=12;i[b+8>>2]=0;i[b+4>>2]=0;T(239,b+48|0,b+32|0,b+12|0,b+8|0,b+4|0);a=i[114610];i[114610]=0;if((a|0)==1){break e}i[114610]=0;C(192,d|0,b+48|0)|0;a=i[114610];i[114610]=0;if((a|0)==1){break d}eb(b+48|0);ob(b+32|0);eb(c);Xa=b- -64|0;return}a=B()|0;A()|0;break a}a=B()|0;A()|0;break b}a=B()|0;A()|0;break c}a=B()|0;A()|0;eb(b+48|0)}ob(b+32|0)}eb(c)}eb(d);E(a|0);x()}function oca(a,b,c){a=a|0;b=b|0;c=+c;var d=0,e=0,f=0;e=Xa-16|0;Xa=e;i[114610]=0;L(2015,a|0);d=i[114610];i[114610]=0;a:{b:{c:{if((d|0)==1){break c}i[114610]=0;L(2041,b|0);d=i[114610];i[114610]=0;if((d|0)==1){break c}d=i[a+24>>2];b=Zb(e+8|0,b);i[114610]=0;f=i[b+4>>2];i[e>>2]=i[b>>2];i[e+4>>2]=f;Sa(2084,d|0,e|0,+c,1);d=i[114610];i[114610]=0;b=1;if((d|0)!=1){break b}}b=H(0)|0;A()|0;M(b|0)|0;i[114610]=0;J(1989,37116,a|0,0,0);a=i[114610];i[114610]=0;if((a|0)==1){break a}O();b=0}Xa=e+16|0;return b|0}a=B()|0;A()|0;i[114610]=0;K(20);b=i[114610];i[114610]=0;if((b|0)!=1){E(a|0);x()}a=H(0)|0;A()|0;gb(a);x()}function fHa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=Xa-704|0;Xa=e;a:{b:{if(d>>>0<=511){d=0;if(!eHa(b,e+24|0)){break b}QT(e+24|0,c);d=554;break b}f=i[b+8>>2];dHa(b,e+24|0);d=KT(e+24|0,c,i[a+480180>>2]);vc(b,f+d|0);if(!sh(b,13380)){break b}ad(e+8|0,b,Cf(b));i[114610]=0;b=F(255,e+8|0)|0;a=i[114610];i[114610]=0;if((a|0)==1){break a}i[114610]=0;a=C(621,e+8|0,13385)|0;f=i[114610];i[114610]=0;if((f|0)==1){break a}if(a){i[114610]=0;a=F(387,e+8|0)|0;f=i[114610];i[114610]=0;if((f|0)==1){break a}g[c+34|0]=a>>>0>250?0:a}d=(b+d|0)+8|0;hb(e+8|0)}Xa=e+704|0;return d|0}a=B()|0;A()|0;hb(e+8|0);E(a|0);x()}function Lga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,j=p(0);c=Xa-4112|0;Xa=c;f=$a[i[i[a>>2]+112>>2]](a)|0;if(!f){$a[i[i[a>>2]+116>>2]](a)}i[c+12>>2]=0;Kga(a+44|0);if(b){g=c+2064|0;while(1){i[c+8>>2]=b;kc(c+8|0,512);Ro(c+16|0);$a[i[i[a>>2]+60>>2]](a,c+16|0,g,i[c+8>>2]);d=0;e=0;if(i[c+8>>2]){while(1){d=(c+16|0)+(e<<2)|0;m[c+4>>2]=q(m[d>>2]);h=c,j=m[jw(c+12|0,c+4|0)>>2],m[h+12>>2]=j;m[c+4>>2]=q(m[d+2048>>2]);h=c,j=m[jw(c+12|0,c+4|0)>>2],m[h+12>>2]=j;e=e+1|0;d=i[c+8>>2];if(e>>>0<d>>>0){continue}break}}b=b-d|0;if(b){continue}break}}if(!f){$a[i[i[a>>2]+120>>2]](a)}Xa=c+4112|0;return p(m[c+12>>2])}function Ku(a,b,c,d,e){var f=0,g=0;f=Xa-16|0;Xa=f;fc(f+8|0,b);i[114610]=0;b=F(2449,f+8|0)|0;g=i[114610];i[114610]=0;a:{if((g|0)==1){break a}i[114610]=0;N(2463,b|0,62112,62144,c|0)|0;b=i[114610];i[114610]=0;if((b|0)==1){break a}i[114610]=0;b=F(2450,f+8|0)|0;c=i[114610];i[114610]=0;if((c|0)==1){break a}i[114610]=0;c=F(2464,b|0)|0;g=i[114610];i[114610]=0;if((g|0)==1){break a}i[d>>2]=c;i[114610]=0;c=F(2460,b|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break a}i[e>>2]=c;i[114610]=0;D(2461,a|0,b|0);a=i[114610];i[114610]=0;if((a|0)==1){break a}ub(f+8|0);Xa=f+16|0;return}a=B()|0;A()|0;ub(f+8|0);E(a|0);x()}function ez(a,b,c){var d=0,e=0,f=0,l=0,m=0,n=0;e=Xa-16|0;Xa=e;d=(c<<3)+a|0;f=j[d+356|0];g[b+12|0]=j[b+12|0]&248|f&1|f<<1&4|f>>>1&2;Lf(b,hd(j[d+352|0],2,16));g[b+13|0]=j[d+354|0];g[b+14|0]=j[d+355|0];d=j[d+353|0];g[b+15|0]=d;g[b+16|0]=d;d=0;h[e+14>>1]=0;if(qb(b)){f=((c|0)!=0)<<1;a=(c<<6)+a|0;while(1){c=a+(d<<2)|0;l=c+160|0;h[e+12>>1]=j[l|0]|j[l+1|0]<<8;l=k[ri(e+14|0,e+12|0)>>1];h[e+14>>1]=l;m=vb(b,d),n=l,h[m>>1]=n;h[e+14>>1]=k[e+14>>1]+1;c=c+162|0;i[e+8>>2]=(j[c|0]|j[c+1|0]<<8)>>>f;i[e+4>>2]=64;c=i[Nd(e+8|0,e+4|0)>>2];m=vb(b,d),n=c,g[m+2|0]=n;d=d+1|0;if(d>>>0<qb(b)>>>0){continue}break}}Xa=e+16|0}function Yza(a,b,c,d){var e=0,f=0,g=0,h=0;f=Xa-16|0;Xa=f;c=$h(c,b);i[f+12>>2]=c;a:{if((c|0)<1){break a}e=i[b+4>>2];if(e){g=32-e|0;i[f+8>>2]=g;c=i[Nd(f+8|0,f+12|0)>>2];i[f+12>>2]=i[f+12>>2]-c;e=i[d>>2];g=-1<<i[b+4>>2]&-1>>>g-c;i[e>>2]=i[e>>2]&(g^-1)|g&i[i[b>>2]>>2];c=c+i[d+4>>2]|0;i[d+4>>2]=c&31;i[d>>2]=e+(c>>>3&536870908);i[b>>2]=i[b>>2]+4;c=i[f+12>>2]}e=(c|0)/32|0;c=e<<2;yi(i[d>>2],i[b>>2],c);e=i[f+12>>2]-(e<<5)|0;i[f+12>>2]=e;i[d>>2]=c+i[d>>2];if((e|0)<1){break a}g=b;b=c+i[b>>2]|0;i[g>>2]=b;c=i[d>>2];g=c;h=i[c>>2];c=-1>>>32-e|0;i[g>>2]=h&(c^-1)|c&i[b>>2];i[d+4>>2]=i[f+12>>2]}td(a,d);Xa=f+16|0}function b0(a,b,c,d,e,f,h,j,k,l){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0;m=Xa-16|0;Xa=m;a:{if(a){a=XC(b);oj(m,a);b=i[m>>2];g[c|0]=b;g[c+1|0]=b>>>8;g[c+2|0]=b>>>16;g[c+3|0]=b>>>24;nj(m,a);mb(k,m);eb(m);Eg(m,a);mb(j,m);eb(m);n=d,o=Eh(a),g[n|0]=o;n=e,o=Dh(a),g[n|0]=o;Pf(m,a);mb(f,m);eb(m);Fg(m,a);mb(h,m);eb(m);a=mj(a);break a}a=WC(b);oj(m,a);b=i[m>>2];g[c|0]=b;g[c+1|0]=b>>>8;g[c+2|0]=b>>>16;g[c+3|0]=b>>>24;nj(m,a);mb(k,m);eb(m);Eg(m,a);mb(j,m);eb(m);n=d,o=Eh(a),g[n|0]=o;n=e,o=Dh(a),g[n|0]=o;Pf(m,a);mb(f,m);eb(m);Fg(m,a);mb(h,m);eb(m);a=mj(a)}i[l>>2]=a;Xa=m+16|0}function Tq(a,b,c){var d=0,e=0;d=a,e=Lh(p(p(p(p(p(p(p(p(p(m[c+3328>>2]+m[c+256>>2])*p(213))+p(p(m[c+3584>>2]-m[c>>2])*p(29)))+p(p(m[c+3072>>2]-m[c+512>>2])*p(459)))+p(p(m[c+2816>>2]+m[c+768>>2])*p(2037)))+p(p(m[c+2560>>2]-m[c+1024>>2])*p(5153)))+p(p(m[c+2304>>2]+m[c+1280>>2])*p(6574)))+p(p(m[c+2048>>2]-m[c+1536>>2])*p(37489)))+p(m[c+1792>>2]*p(75038)))),h[d>>1]=e;d=(b<<5)+a|0,e=Lh(p(p(p(p(p(p(p(p(m[c+3080>>2]*p(1567))+p(m[c+3592>>2]*p(104)))+p(m[c+2568>>2]*p(9727)))+p(m[c+2056>>2]*p(64019)))+p(m[c+1544>>2]*p(-9975)))+p(m[c+1032>>2]*p(-45)))+p(m[c+520>>2]*p(146)))+p(m[c+8>>2]*p(-5)))),h[d>>1]=e}function TE(a){var b=0,c=0,d=0,e=0,f=0,h=0;if(fe(a)){Lb(a,31);return 0}f=a,h=fe(a),g[f+1375|0]=h;d=Kh(a);b=Kh(a);Kh(a);f=a,h=Kh(a),i[f+1112>>2]=h;Kh(a);c=fe(a);i[a+1116>>2]=c;if(!zv(a,a+1120|0,c)){Lb(a,10);return 0}i[a+1404>>2]=-2;a:{if((b&d)==-1){break a}b=i[a+1116>>2];while(1){if((b|0)<1){break a}b=b+ -1|0;if(j[(b+a|0)+1120|0]==255){continue}break}i[a+1408>>2]=d;i[a+1404>>2]=b}if(j[a+1377|0]){e=i[a+1116>>2];b=27;b:{if((e|0)<1){break b}c=0;b=0;while(1){c=j[(a+b|0)+1120|0]+c|0;b=b+1|0;if((e|0)!=(b|0)){continue}break}b=c+27|0}i[a- -64>>2]=d;i[a+60>>2]=i[a+56>>2]+(b+e|0)}i[a+1380>>2]=0;return 1}function Mu(a,b,c,d,e){var f=0,h=0;f=Xa-16|0;Xa=f;fc(f+8|0,b);i[114610]=0;b=F(21,f+8|0)|0;h=i[114610];i[114610]=0;a:{if((h|0)==1){break a}i[114610]=0;N(2440,b|0,62112,62144,c|0)|0;b=i[114610];i[114610]=0;if((b|0)==1){break a}i[114610]=0;b=F(2416,f+8|0)|0;c=i[114610];i[114610]=0;if((c|0)==1){break a}i[114610]=0;c=F(2441,b|0)|0;h=i[114610];i[114610]=0;if((h|0)==1){break a}g[d|0]=c;i[114610]=0;c=F(2431,b|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break a}g[e|0]=c;i[114610]=0;D(2432,a|0,b|0);a=i[114610];i[114610]=0;if((a|0)==1){break a}ub(f+8|0);Xa=f+16|0;return}a=B()|0;A()|0;ub(f+8|0);E(a|0);x()}function wK(a,b,c){var d=0,e=0,f=0,h=0;d=Xa-16|0;Xa=d;i[d+12>>2]=0;a:{if(b){g[c|0]=b;break a}b=j[c|0]}b=i[a+480180>>2]&1048580?b&240?b&-16:b&15:b;c=b&240;e=b&255;h=d;b=b&15;b:{c:{d:{if(!(!c|(b|0)!=15)){if(!(j[a+480209|0]&16)){break b}b=e>>>3&30;break d}f=i[a+480208>>2]&4096;if(!(!b|(c|0)!=240)){if(!f){break b}b=0-(b<<1)|0;i[d+12>>2]=b;break c}if(f){break b}if(c){if(i[a+480180>>2]&59314208?b:0){break b}b=e>>>3&30;break d}b=0-(b<<1)|0}i[h+12>>2]=b;if(!b){break b}}if(!(i[a+480180>>2]&59314208)){b=b<<1;i[d+12>>2]=b}a=a+1074444|0;i[d+12>>2]=i[a>>2]+b;Kd(d+12|0,0,256);i[a>>2]=i[d+12>>2]}Xa=d+16|0}function Kt(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,j=0;c=Xa-16|0;Xa=c;i[c+12>>2]=b;a:{b:{c:{if(4294967279>=b>>>0){f=qc(a);h=c,j=lb(a),i[h+8>>2]=j;b=i[Jc(c+12|0,c+8|0)>>2];i[c+12>>2]=b;d=Dk(b);i[c+12>>2]=d;if((d|0)==(f|0)){break a}if((d|0)==10){g=1;b=a;e=i[a>>2];break b}b=i[c+12>>2]+1|0;if(d>>>0>f>>>0){b=Ii(b);break c}i[114610]=0;b=C(30,a|0,b|0)|0;e=i[114610];i[114610]=0;if((e|0)!=1){break c}a=H(0)|0;A()|0;M(a|0)|0;O();break a}gg();x()}g=oe(a);e=xb(a)}jh(b,e,lb(a)+1|0);if(g){Uf(a,e,f+1|0)}d:{if((d|0)!=10){fg(a,i[c+12>>2]+1|0);ce(a,i[c+8>>2]);gf(a,b);break d}Te(a,i[c+8>>2])}}Xa=c+16|0}function uca(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=Xa-16|0;Xa=c;i[114610]=0;L(2015,a|0);d=i[114610];i[114610]=0;a:{b:{c:{if((d|0)==1){break c}i[114610]=0;L(2041,b|0);d=i[114610];i[114610]=0;if((d|0)==1){break c}d=i[a+24>>2];b=Zb(c+8|0,b);i[114610]=0;f=i[b+4>>2];i[c>>2]=i[b>>2];i[c+4>>2]=f;e=+aa(2079,d|0,c|0,1);b=i[114610];i[114610]=0;if((b|0)!=1){break b}}b=H(0)|0;A()|0;M(b|0)|0;i[114610]=0;J(1989,36966,a|0,0,0);a=i[114610];i[114610]=0;if((a|0)==1){break a}O();e=0}Xa=c+16|0;return+e}a=B()|0;A()|0;i[114610]=0;K(20);b=i[114610];i[114610]=0;if((b|0)!=1){E(a|0);x()}a=H(0)|0;A()|0;gb(a);x()}function fY(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,j=0;c=Xa-16|0;Xa=c;i[c+12>>2]=b;a:{b:{c:{if(1073741807>=b>>>0){f=iq(a);h=c,j=lb(a),i[h+8>>2]=j;b=i[Jc(c+12|0,c+8|0)>>2];i[c+12>>2]=b;d=Nl(b);i[c+12>>2]=d;if((d|0)==(f|0)){break a}g=1;if((d|0)==1){b=a;e=i[a>>2];break b}b=i[c+12>>2]+1|0;if(d>>>0>f>>>0){b=Ak(b);break c}i[114610]=0;b=C(2840,a|0,b|0)|0;e=i[114610];i[114610]=0;if((e|0)!=1){break c}a=H(0)|0;A()|0;M(a|0)|0;O();break a}gg();x()}g=oe(a);e=xb(a)}Gh(b,e,lb(a)+1|0);if(g){Ln(e,f+1|0)}d:{if((d|0)!=1){fg(a,i[c+12>>2]+1|0);ce(a,i[c+8>>2]);gf(a,b);break d}Te(a,i[c+8>>2])}}Xa=c+16|0}function mF(a,b){a=a|0;b=b|0;var c=0,d=0;d=Xa-16|0;Xa=d;a:{b:{c:{c=a+8|0;d:{if(!Qk(c)){if((b|0)<0|(ar(c)|0)<=(b|0)){break d}c=(j[Uo(i[a+32>>2],b+1&65535)+35|0]&4)>>>2|0;break b}c=Qk(c);if((b|0)<0){break d}if((c|0)>(b|0)){break c}}a=P(8)|0;i[114610]=0;c=C(85,d|0,40625)|0;b=i[114610];i[114610]=0;e:{if((b|0)!=1){Ub(a,c);i[114610]=0;G(2009,a|0,83568,2017);a=i[114610];i[114610]=0;if((a|0)!=1){break a}b=B()|0;A()|0;eb(c);break e}b=B()|0;A()|0;Q(a|0)}E(b|0);x()}b=b+1<<2;a=a+32|0;c=1;if(!i[(b+i[a>>2]|0)+900380>>2]){break b}c=(j[i[(b+i[a>>2]|0)+900380>>2]+15|0]&2)>>>1|0}Xa=d+16|0;return c|0}x()}function EM(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;f=Xa-16|0;Xa=f;i[f+8>>2]=e;i[f+12>>2]=d;a:{if(!d){break a}Ce(a);Kt(a,c);if(!c){break a}e=0;while(1){l=c-h|0;i[f+4>>2]=l;j=i[rb(f+12|0,f+4|0)>>2];Gn(a,jb(b)+h|0,j);qs(a,1,13);k=e+j|0;if(e>>>0<k>>>0){while(1){b:{c:{d:{m=g[Ll(a,e)|0];switch(m+ -10|0){case 1:case 2:break b;case 0:case 3:break c;default:break d}}if(m){break b}}n=Ll(a,e),o=32,g[n|0]=o}e=e+1|0;if((k|0)!=(e|0)){continue}break}}i[f+4>>2]=l-j;e=k+1|0;h=i[rb(f+8|0,f+4|0)>>2]+(j+h|0)|0;if(h>>>0<c>>>0){continue}break}}Xa=f+16|0;return(d|0)!=0|0}function yGa(a,b,c){var d=0,e=0,f=0;d=Xa+ -64|0;Xa=d;De(d+40|0,a,c);a=i[d+40>>2];i[114610]=0;e=F(412,d+40|0)|0;f=i[114610];i[114610]=0;a:{b:{c:{if((f|0)==1){break c}i[114610]=0;e=F(413,e|0)|0;f=i[114610];i[114610]=0;if((f|0)==1){break c}i[114610]=0;J(414,d+8|0,2,e|0,a|0);e=i[114610];i[114610]=0;if((e|0)==1){break c}i[114610]=0;D(415,d+24|0,d+8|0);e=i[114610];i[114610]=0;if((e|0)==1){break c}i[114610]=0;C(378,b|0,d+24|0)|0;b=i[114610];i[114610]=0;if((b|0)==1){break b}eb(d+24|0);jc(d+40|0);Xa=d- -64|0;return!c|(a|0)!=0}a=B()|0;A()|0;break a}a=B()|0;A()|0;eb(d+24|0)}jc(d+40|0);E(a|0);x()}function wca(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=Xa-16|0;Xa=d;i[114610]=0;L(2015,a|0);c=i[114610];i[114610]=0;a:{b:{c:{if((c|0)==1){break c}i[114610]=0;L(2041,b|0);c=i[114610];i[114610]=0;if((c|0)==1){break c}c=i[a+24>>2];b=Zb(d+8|0,b);i[114610]=0;e=i[b+4>>2];i[d>>2]=i[b>>2];i[d+4>>2]=e;b=I(2077,c|0,d|0,1)|0;c=i[114610];i[114610]=0;if((c|0)!=1){break b}}b=H(0)|0;A()|0;M(b|0)|0;i[114610]=0;J(1989,36904,a|0,0,0);a=i[114610];i[114610]=0;if((a|0)==1){break a}O();b=0}Xa=d+16|0;return b|0}a=B()|0;A()|0;i[114610]=0;K(20);b=i[114610];i[114610]=0;if((b|0)!=1){E(a|0);x()}a=H(0)|0;A()|0;gb(a);x()}function bMa(a,b,c){var d=0,e=0,f=0;d=Xa+ -64|0;Xa=d;De(d+40|0,a,c);a=i[d+40>>2];i[114610]=0;e=F(412,d+40|0)|0;f=i[114610];i[114610]=0;a:{b:{c:{if((f|0)==1){break c}i[114610]=0;e=F(413,e|0)|0;f=i[114610];i[114610]=0;if((f|0)==1){break c}i[114610]=0;J(414,d+8|0,2,e|0,a|0);e=i[114610];i[114610]=0;if((e|0)==1){break c}i[114610]=0;D(415,d+24|0,d+8|0);e=i[114610];i[114610]=0;if((e|0)==1){break c}i[114610]=0;C(369,b|0,d+24|0)|0;b=i[114610];i[114610]=0;if((b|0)==1){break b}eb(d+24|0);jc(d+40|0);Xa=d- -64|0;return!c|(a|0)!=0}a=B()|0;A()|0;break a}a=B()|0;A()|0;eb(d+24|0)}jc(d+40|0);E(a|0);x()}function aMa(a,b,c){var d=0,e=0,f=0;d=Xa+ -64|0;Xa=d;De(d+40|0,a,c);a=i[d+40>>2];i[114610]=0;e=F(412,d+40|0)|0;f=i[114610];i[114610]=0;a:{b:{c:{if((f|0)==1){break c}i[114610]=0;e=F(413,e|0)|0;f=i[114610];i[114610]=0;if((f|0)==1){break c}i[114610]=0;J(414,d+8|0,1,e|0,a|0);e=i[114610];i[114610]=0;if((e|0)==1){break c}i[114610]=0;D(415,d+24|0,d+8|0);e=i[114610];i[114610]=0;if((e|0)==1){break c}i[114610]=0;C(370,b|0,d+24|0)|0;b=i[114610];i[114610]=0;if((b|0)==1){break b}eb(d+24|0);jc(d+40|0);Xa=d- -64|0;return!c|(a|0)!=0}a=B()|0;A()|0;break a}a=B()|0;A()|0;eb(d+24|0)}jc(d+40|0);E(a|0);x()}function ZIa(a,b,c){var d=0,e=0,f=0;d=Xa+ -64|0;Xa=d;De(d+40|0,a,c);a=i[d+40>>2];i[114610]=0;e=F(412,d+40|0)|0;f=i[114610];i[114610]=0;a:{b:{c:{if((f|0)==1){break c}i[114610]=0;e=F(413,e|0)|0;f=i[114610];i[114610]=0;if((f|0)==1){break c}i[114610]=0;J(414,d+8|0,3,e|0,a|0);e=i[114610];i[114610]=0;if((e|0)==1){break c}i[114610]=0;D(415,d+24|0,d+8|0);e=i[114610];i[114610]=0;if((e|0)==1){break c}i[114610]=0;C(370,b|0,d+24|0)|0;b=i[114610];i[114610]=0;if((b|0)==1){break b}eb(d+24|0);jc(d+40|0);Xa=d- -64|0;return!c|(a|0)!=0}a=B()|0;A()|0;break a}a=B()|0;A()|0;eb(d+24|0)}jc(d+40|0);E(a|0);x()}function Qxa(a,b,c){var d=0,e=0,f=0;d=Xa+ -64|0;Xa=d;De(d+40|0,a,c);a=i[d+40>>2];i[114610]=0;e=F(412,d+40|0)|0;f=i[114610];i[114610]=0;a:{b:{c:{if((f|0)==1){break c}i[114610]=0;e=F(413,e|0)|0;f=i[114610];i[114610]=0;if((f|0)==1){break c}i[114610]=0;J(414,d+8|0,2,e|0,a|0);e=i[114610];i[114610]=0;if((e|0)==1){break c}i[114610]=0;D(415,d+24|0,d+8|0);e=i[114610];i[114610]=0;if((e|0)==1){break c}i[114610]=0;C(370,b|0,d+24|0)|0;b=i[114610];i[114610]=0;if((b|0)==1){break b}eb(d+24|0);jc(d+40|0);Xa=d- -64|0;return!c|(a|0)!=0}a=B()|0;A()|0;break a}a=B()|0;A()|0;eb(d+24|0)}jc(d+40|0);E(a|0);x()}function pca(a,b,c,d){var e=0,f=0,g=0;e=Xa-16|0;Xa=e;i[114610]=0;L(2015,a|0);f=i[114610];i[114610]=0;a:{b:{c:{if((f|0)==1){break c}i[114610]=0;L(2041,b|0);f=i[114610];i[114610]=0;if((f|0)==1){break c}f=i[a+24>>2];b=Zb(e+8|0,b);i[114610]=0;g=i[b+4>>2];i[e>>2]=i[b>>2];i[e+4>>2]=g;sa(2083,f|0,e|0,c|0,d|0,1);c=i[114610];i[114610]=0;b=1;if((c|0)!=1){break b}}b=H(0)|0;A()|0;M(b|0)|0;i[114610]=0;J(1989,37085,a|0,0,0);a=i[114610];i[114610]=0;if((a|0)==1){break a}O();b=0}Xa=e+16|0;return b}a=B()|0;A()|0;i[114610]=0;K(20);b=i[114610];i[114610]=0;if((b|0)!=1){E(a|0);x()}a=H(0)|0;A()|0;gb(a);x()}function hJa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;kd(b,0);i[b>>2]=j[a|0]|j[a+1|0]<<8|(j[a+2|0]<<16|j[a+3|0]<<24);c=a+4|0;i[b+12>>2]=j[c|0]|j[c+1|0]<<8|(j[c+2|0]<<16|j[c+3|0]<<24);c=a+8|0;i[b+16>>2]=j[c|0]|j[c+1|0]<<8|(j[c+2|0]<<16|j[c+3|0]<<24);c=a+12|0;c=j[c|0]|j[c+1|0]<<8;h[b+32>>1]=64;i[b+24>>2]=c;e=b;c=a+14|0;d=256;a:{if(!j[c|0]){break a}d=j[c|0]+1|0}h[e+30>>1]=d;h[b+34>>1]=k[b+34>>1]&32767|!j[c|0]<<15;a=a+15|0;if(!(!(g[a|0]&1)|l[b+16>>2]<=l[b+12>>2])){h[b+34>>1]=k[b+34>>1]|8}if(j[a|0]&2){h[b+34>>1]=k[b+34>>1]|1;i[b>>2]=i[b>>2]>>>1;i[b+12>>2]=i[b+12>>2]>>>1;i[b+16>>2]=i[b+16>>2]>>>1}}function fS(a,b,c){var d=0,e=0,f=0;d=Xa+ -64|0;Xa=d;De(d+40|0,a,c);a=i[d+40>>2];i[114610]=0;e=F(412,d+40|0)|0;f=i[114610];i[114610]=0;a:{b:{c:{if((f|0)==1){break c}i[114610]=0;e=F(413,e|0)|0;f=i[114610];i[114610]=0;if((f|0)==1){break c}i[114610]=0;J(414,d+8|0,3,e|0,a|0);e=i[114610];i[114610]=0;if((e|0)==1){break c}i[114610]=0;D(415,d+24|0,d+8|0);e=i[114610];i[114610]=0;if((e|0)==1){break c}i[114610]=0;C(369,b|0,d+24|0)|0;b=i[114610];i[114610]=0;if((b|0)==1){break b}eb(d+24|0);jc(d+40|0);Xa=d- -64|0;return!c|(a|0)!=0}a=B()|0;A()|0;break a}a=B()|0;A()|0;eb(d+24|0)}jc(d+40|0);E(a|0);x()}function eS(a,b,c){var d=0,e=0,f=0;d=Xa+ -64|0;Xa=d;De(d+40|0,a,c);a=i[d+40>>2];i[114610]=0;e=F(412,d+40|0)|0;f=i[114610];i[114610]=0;a:{b:{c:{if((f|0)==1){break c}i[114610]=0;e=F(413,e|0)|0;f=i[114610];i[114610]=0;if((f|0)==1){break c}i[114610]=0;J(414,d+8|0,3,e|0,a|0);e=i[114610];i[114610]=0;if((e|0)==1){break c}i[114610]=0;D(415,d+24|0,d+8|0);e=i[114610];i[114610]=0;if((e|0)==1){break c}i[114610]=0;C(378,b|0,d+24|0)|0;b=i[114610];i[114610]=0;if((b|0)==1){break b}eb(d+24|0);jc(d+40|0);Xa=d- -64|0;return!c|(a|0)!=0}a=B()|0;A()|0;break a}a=B()|0;A()|0;eb(d+24|0)}jc(d+40|0);E(a|0);x()}function Ri(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,h=0,j=0,l=0,m=0;c=Xa-32|0;Xa=c;h=Fo(a);f=Ti(h);Cra(a,f);a:{if(!b){break a}d=a+12|0;$r(d);if(gd(d)>>>0>1023){break a}i[c+28>>2]=0;e=i[a+24>>2]+484344|0;l=c,m=Jb(e),i[l+24>>2]=m;l=c,m=Kb(e),i[l+16>>2]=m;if(pb(c+24|0,c+16|0)){while(1){i[c+12>>2]=i[i[c+24>>2]+12>>2];l=c,m=i[Jc(c+28|0,c+12|0)>>2],i[l+28>>2]=m;Bx(c+24|0);if(pb(c+24|0,c+16|0)){continue}break}e=i[c+28>>2]}else{e=0}oL(d,e)}if(f){d=0;while(1){e=Yc(a,d);j=Ax(a,k[$b(h,d)>>1]);b:{if(b){g[c+28|0]=0;nL(e,j,c+28|0);break b}ky(e,j,0)}d=d+1|0;if((f|0)!=(d|0)){continue}break}}Xa=c+32|0}function gE(a){var b=0,c=0;a:{b=i[a+4>>2];b:{if(!i[(i[i[b>>2]+ -12>>2]+b|0)+24>>2]){break b}b=i[a+4>>2];if(!hf(i[i[b>>2]+ -12>>2]+b|0)){break b}b=i[a+4>>2];if(!(i[(i[i[b>>2]+ -12>>2]+b|0)+4>>2]&8192)){break b}if(jv()){break b}b=i[a+4>>2];b=i[(i[i[b>>2]+ -12>>2]+b|0)+24>>2];i[114610]=0;b=F(2329,b|0)|0;c=i[114610];i[114610]=0;if((c|0)!=1){if((b|0)!=-1){break b}a=i[a+4>>2];b=i[i[a>>2]+ -12>>2];i[114610]=0;D(2330,a+b|0,1);a=i[114610];i[114610]=0;if((a|0)!=1){break b}}a=H(0)|0;A()|0;M(a|0)|0;i[114610]=0;K(20);a=i[114610];i[114610]=0;if((a|0)==1){break a}}return}a=H(0)|0;A()|0;gb(a);x()}function ana(a,b){var c=0,d=0;c=i[b+4>>2];i[a>>2]=i[b>>2];i[a+4>>2]=c;c=j[b+11|0]|j[b+12|0]<<8|(j[b+13|0]<<16|j[b+14|0]<<24);d=j[b+7|0]|j[b+8|0]<<8|(j[b+9|0]<<16|j[b+10|0]<<24);g[a+7|0]=d;g[a+8|0]=d>>>8;g[a+9|0]=d>>>16;g[a+10|0]=d>>>24;g[a+11|0]=c;g[a+12|0]=c>>>8;g[a+13|0]=c>>>16;g[a+14|0]=c>>>24;g[a+15|0]=j[b+15|0];c=i[b+44>>2];i[a+40>>2]=i[b+40>>2];i[a+44>>2]=c;c=i[b+36>>2];i[a+32>>2]=i[b+32>>2];i[a+36>>2]=c;c=i[b+28>>2];i[a+24>>2]=i[b+24>>2];i[a+28>>2]=c;c=i[b+20>>2];i[a+16>>2]=i[b+16>>2];i[a+20>>2]=c;_w(a+48|0,b+48|0);_w(a+68|0,b+68|0);_w(a+88|0,b+88|0);Tb(a+108|0,b+108|0,448)}function $k(a,b,c,d){var e=0,f=0;e=Xa-16|0;Xa=e;f=a+1074308|0;kb(e+8|0,f,84);a:{if(ib(e+8|0)){break a}b:{if(i[a+480208>>2]&16384){break b}if((d|0)!=8){kb(e+8|0,f,10);if(!ib(e+8|0)){break b}}i[b+88>>2]=i[b+88>>2]&-257}c:{d:{e:{switch(d+ -4|0){case 0:c=((c<<8|8)>>>0)/15|0;break d;case 2:c=(c>>>0<64?c:64)<<2;break d;default:break e}}if(!(i[a+480180>>2]&2107410)){break d}if(c>>>0<=128){c=c<<1;break d}if((c|0)!=164){break c}i[b+88>>2]=i[b+88>>2]|256;c=128}i[b+692>>2]=c}h[b+796>>1]=0;i[b+88>>2]=i[b+88>>2]|2097152;kb(e+8|0,f,10);if(!ib(e+8|0)){break a}g[b+851|0]=0;h[b+790>>1]=0}Xa=e+16|0}function Ita(a,b){var c=0,d=0,e=0,f=0,h=0,l=0,m=0,n=0,p=0;f=Xa+ -64|0;Xa=f;d=$d(a);n=d<<6;l=i[a+20>>2];h=l+o(i[a>>2],d)|0;while(1){if(d){m=o(d,e);p=o(e^-1,d);c=0;while(1){g[h+(c+m|0)|0]=j[h+(c-d|0)|0];g[(c+p|0)+l|0]=j[c+l|0];c=c+1|0;if((c|0)!=(d|0)){continue}break}}e=e+1|0;if((e|0)!=16){continue}break}h=h+(d<<4)|0;c=k[a+34>>1];if(c&2){m=i[a+8>>2];e=i[a+4>>2];kb(f+32|0,b+1074308|0,33);lM(f+40|0,h,o(d,e)+l|0,m-e|0,d,(c&4)>>>2|0,ib(f+32|0));c=k[a+34>>1]}if(c&8){e=i[a+16>>2];a=i[a+12>>2];kb(f+32|0,b+1074308|0,33);lM(f+8|0,h+n|0,o(a,d)+l|0,e-a|0,d,(c&16)>>>4|0,ib(f+32|0))}Xa=f- -64|0}function i6(a,b,c,d){var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;a:{if((b|0)>=5){l=b+ -4|0;while(1){if(fF(a)){g=Fv(a,i[c>>2]);h=g+_n(a)|0;j=0;b:{c:{if(g){break c}f=4;n=e+4|0;while(1){if(((f<<1)+e|0)>=(l|0)){break b}g=0;k=a+f|0;d:{if(!$n(a,k)){break d}j=f-_n(a)|0;m=_n(k)+j|0;if((m+(f+n|0)|0)>(b|0)){break d}if(!$n(a,k+m|0)){break d}i[c>>2]=j;g=j;h=f}j=!g;if(f>>>0>2302){break c}f=f+1|0;if(!g){continue}break}}if((e+h|0)>(b|0)|j){break b}if($5(a,b-e|0,g)){break a}}if(!((b|0)!=(h|0)|e)){e=0;h=b;break a}i[c>>2]=0}a=a+1|0;e=e+1|0;if((l|0)!=(e|0)){continue}break}}h=0;e=b}i[d>>2]=h;return e}function wX(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var k=0,l=0,m=0,n=0,o=0,p=0;if(Nf(a,i[b+8>>2],f)){ru(b,c,d,e);return}l=j[b+53|0];k=i[a+12>>2];g[b+53|0]=0;m=j[b+52|0];g[b+52|0]=0;n=a+16|0;pu(n,b,c,d,e,f);o=j[b+53|0];l=l|o;p=j[b+52|0];m=m|p;a:{if((k|0)<2){break a}n=n+(k<<3)|0;k=a+24|0;while(1){if(j[b+54|0]){break a}b:{if(p){if(i[b+24>>2]==1){break a}if(j[a+8|0]&2){break b}break a}if(!o){break b}if(!(g[a+8|0]&1)){break a}}h[b+52>>1]=0;pu(k,b,c,d,e,f);o=j[b+53|0];l=o|l;p=j[b+52|0];m=p|m;k=k+8|0;if(k>>>0<n>>>0){continue}break}}g[b+53|0]=(l&255)!=0;g[b+52|0]=(m&255)!=0}function p3(a){a=a|0;var b=0;b=i[14210];n3(b);m3();l3(b);k3();b=i[14211];TD(461348,b,461396);$u(460712,461348);SD(461404,b,461452);_u(460796,461404);b=i[13910];TD(461460,b,461508);$u(460880,461460);$u(461048,i[(i[i[115220]+ -12>>2]+460880|0)+24>>2]);SD(461516,b,461564);_u(460964,461516);_u(461132,i[(i[i[115241]+ -12>>2]+460964|0)+24>>2]);xq(i[i[115134]+ -12>>2]+460536|0,460712);xq(i[i[115156]+ -12>>2]+460624|0,460796);RD(i[i[115220]+ -12>>2]+460880|0);RD(i[i[115241]+ -12>>2]+460964|0);xq(i[i[115220]+ -12>>2]+460880|0,460712);xq(i[i[115241]+ -12>>2]+460964|0,460796);return a|0}function mKa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,h=0;e=Xa-32|0;Xa=e;i[e+24>>2]=b;b=i[a>>2];f=e,h=Jb(a),i[f>>2]=h;b=b+(qp(e+24|0,e)<<1)|0;a:{b:{if(l[a+4>>2]<l[fb(a)>>2]){d=i[a+4>>2];if((d|0)==(b|0)){aKa(a,c);break b}$Ja(a,b,d,b+2|0);c=b>>>0<=c>>>0?c>>>0<l[a+4>>2]?c+2|0:c:c;g[b|0]=j[c|0];g[b+1|0]=j[c+1|0];break b}d=fb(a);d=IR(e,qi(a,Wb(a)+1|0),b-i[a>>2]>>1,d);i[114610]=0;D(515,d|0,c|0);c=i[114610];i[114610]=0;if((c|0)==1){break a}i[114610]=0;b=I(516,a|0,d|0,b|0)|0;a=i[114610];i[114610]=0;if((a|0)==1){break a}jt(d)}a=Pe(b);Xa=e+32|0;return a|0}a=B()|0;A()|0;jt(d);E(a|0);x()}function vca(a,b){var c=0,d=0,e=0;d=Xa-16|0;Xa=d;i[114610]=0;L(2015,a|0);c=i[114610];i[114610]=0;a:{b:{c:{if((c|0)==1){break c}i[114610]=0;L(2041,b|0);c=i[114610];i[114610]=0;if((c|0)==1){break c}c=i[a+24>>2];b=Zb(d+8|0,b);i[114610]=0;e=i[b+4>>2];i[d>>2]=i[b>>2];i[d+4>>2]=e;b=JB(c,d,1);e=i[114610];i[114610]=0;c=_a;if((e|0)!=1){break b}}b=H(0)|0;A()|0;M(b|0)|0;i[114610]=0;J(1989,36935,a|0,0,0);a=i[114610];i[114610]=0;if((a|0)==1){break a}O();b=0;c=0}Xa=d+16|0;_a=c;return b}a=B()|0;A()|0;i[114610]=0;K(20);b=i[114610];i[114610]=0;if((b|0)!=1){E(a|0);x()}a=H(0)|0;A()|0;gb(a);x()}function e3(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,h=0;c=Xa-32|0;Xa=c;d=ae(b,-1);e=j[a+52|0];a:{if(d){d=b;if(e){break a}d=i[a+48>>2];f=a,h=ae(d,-1)^1,g[f+52|0]=h;break a}if(e){f=c,h=om(i[a+48>>2]),g[f+19|0]=h;b:{c:{switch(vq(i[a+36>>2],i[a+40>>2],c+19|0,c+20|0,c+12|0,c+24|0,c+32|0,c+20|0)+ -1|0){case 2:d=i[a+48>>2];i[c+20>>2]=c+25;g[c+24|0]=d;default:while(1){d=i[c+20>>2];e=1;if(d>>>0<=c+24>>>0){break b}d=d+ -1|0;i[c+20>>2]=d;if((zq(g[d|0],i[a+32>>2])|0)!=-1){continue}break}break;case 0:case 1:break c}}d=-1;e=0}if(!e){break a}}g[a+52|0]=1;i[a+48>>2]=b;d=b}Xa=c+32|0;return d|0}function t8(a){var b=0,c=0,d=0,e=0;c=Xa-160|0;Xa=c;a=jm(c+16|0,a,8);d=i[i[a>>2]+ -12>>2];i[114610]=0;b=R(122)|0;e=i[114610];i[114610]=0;a:{if((e|0)==1){break a}i[114610]=0;G(123,c+8|0,d+(c+16|0)|0,b|0);d=i[114610];i[114610]=0;if((d|0)==1){break a}ub(c+8|0);i[114610]=0;d=C(180,a|0,144)|0;b=i[114610];i[114610]=0;if((b|0)==1){break a}i[114610]=0;d=C(181,d|0,c+4|0)|0;b=i[114610];i[114610]=0;if((b|0)==1){break a}b=i[i[d>>2]+ -12>>2];i[114610]=0;d=F(174,b+d|0)|0;b=i[114610];i[114610]=0;if((b|0)==1){break a}b=i[c+4>>2];Ve(a);Xa=c+160|0;return d?0:b}c=B()|0;A()|0;Ve(a);E(c|0);x()}function Po(a,b,c,d){var e=0,f=0,g=0,h=0,l=0,m=0,n=0;f=Xa-16|0;Xa=f;g=qb(a)+ -1|0;a:{if((qb(a)|0)==1){break a}while(1){if(k[hc(a,e)>>1]>=(b|0)){g=e;break a}e=e+1|0;if(e>>>0<qb(a)+ -1>>>0){continue}break}}h=k[hc(a,g)>>1];i[f+12>>2]=0;b:{if((h|0)<=(b|0)){m=f,n=(j[hc(a,g)+2|0]<<16)/(d|0)|0,i[m+12>>2]=n;break b}e=0;if(g){e=g+ -1|0;l=(j[hc(a,e)+2|0]<<16)/(d|0)|0;i[f+12>>2]=l;e=k[hc(a,e)>>1]}if((e|0)>=(b|0)|e>>>0>=h>>>0){break b}m=f,n=((o(((j[hc(a,g)+2|0]<<16)/(d|0)|0)-l|0,b-e|0)|0)/(h-e|0)|0)+l|0,i[m+12>>2]=n}Kd(f+12|0,0,65536);Xa=f+16|0;return(o(i[f+12>>2],c)+32768|0)/65536|0}function JFa(a,b){var c=0,d=0;c=(a|0)==(b|0);g[b+12|0]=c;a:{if(c){break a}while(1){if(j[i[b+8>>2]+12|0]){break a}d=Pg(i[b+8>>2]);c=i[b+8>>2];b:{c:{if(d){c=i[i[c+8>>2]+4>>2];if(!(!c|j[c+12|0])){c=c+12|0;b=i[b+8>>2];g[b+12|0]=1;b=i[b+8>>2];break c}if(!Pg(b)){b=i[b+8>>2];cp(b)}a=i[b+8>>2];g[a+12|0]=1;a=i[a+8>>2];g[a+12|0]=0;bp(a);return}c=i[i[c+8>>2]>>2];if(!c|j[c+12|0]){break b}c=c+12|0;b=i[b+8>>2];g[b+12|0]=1;b=i[b+8>>2]}g[b+12|0]=(a|0)==(b|0);g[c|0]=1;if((a|0)!=(b|0)){continue}break a}break}if(Pg(b)){b=i[b+8>>2];bp(b)}a=i[b+8>>2];g[a+12|0]=1;a=i[a+8>>2];g[a+12|0]=0;cp(a)}}function FA(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,k=0;e=Xa-16|0;Xa=e;c=i[b+16>>2];i[a+4>>2]=0;i[a>>2]=c;d=b+80|0;g=a;c=i[b+84>>2];f=i[d>>2];a:{if(c>>>0<=15){break a}i[e+12>>2]=c+ -16;f=i[Jc(d,e+12|0)>>2]}i[g+8>>2]=f;b:{if(!(j[b+88|0]&2)|!j[b+816|0]){break b}c:{d:{e:{if(!((i[b+88>>2]&2050)==2?(j[i[b+104>>2]+34|0]&8)>>>3|0:0)){c=i[b+104>>2];break e}c=i[b+104>>2];if(i[b+80>>2]!=i[c+12>>2]){break e}d=i[b+84>>2];if((d|0)==i[c+16>>2]){break d}}b=i[b+84>>2];if((b|0)!=i[c+8>>2]){break b}b=(i[c>>2]-b|0)+48|0;break c}b=(i[c>>2]-d|0)+112|0}h=a,k=i[a>>2]+o(xn(c),b)|0,i[h+4>>2]=k}Xa=e+16|0}function cu(a,b,c,d){var e=0,f=0;e=Xa-32|0;Xa=e;i[e+28>>2]=d;a:{f=i[b>>2];b:{if(!($a[i[i[f>>2]+40>>2]](f,c,d)|0)){wh(a);break b}tk(e+8|0,b);i[114610]=0;b=F(271,b|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break a}d=i[i[b>>2]+24>>2];i[114610]=0;b=F(d|0,b|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break a}i[114610]=0;i[e+4>>2]=b-c;b=C(33,e+28|0,e+4|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break a}b=i[b>>2];i[114610]=0;J(272,e+16|0,e+8|0,c|0,b|0);b=i[114610];i[114610]=0;if((b|0)==1){break a}SA(a,e+16|0);hb(e+16|0);hb(e+8|0)}Xa=e+32|0;return}a=B()|0;A()|0;hb(e+8|0);E(a|0);x()}function xga(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;f=Xa-16|0;Xa=f;c=i[a+12>>2];d=c;e=i[a+8>>2];a:{if((c|0)<0?1:(c|0)<=0?e>>>0<0:0){break a}if(j=1,k=(m=e>>>0>nb(a)>>>0,n=0,o=(d|0)>=0,o?m:n),l=(d|0)>0,l?j:k){break a}d=nb(a);e=i[a+8>>2];g=0-((d>>>0<e>>>0)+i[a+12>>2]|0)|0;c=f;i[c+8>>2]=d-e;i[c+12>>2]=g;j=c,k=Vg(b),i[j>>2]=k;i[c+4>>2]=0;c=dz(c+8|0,c);c=BQ(i[c>>2],i[c+4>>2]);if((c|0)!=(Vg(b)|0)){break a}Oe(i[b>>2],i[b>>2]+c|0,jb(i[a>>2]+i[a+8>>2]|0));b=a;e=a;d=i[a+12>>2];a=c+i[a+8>>2]|0;if(a>>>0<c>>>0){d=d+1|0}i[e+8>>2]=a;i[b+12>>2]=d;h=1}Xa=f+16|0;return h}function Bv(a,b,c){var d=0,e=0,f=0,g=p(0),h=p(0),i=p(0),j=p(0),k=p(0),l=p(0),n=p(0),o=0;d=Xa-32|0;Xa=d;$E(p(-m[a>>2]),p(m[a+12>>2]+m[a+24>>2]),p(m[a+36>>2]+m[a+48>>2]),d+20|0);$E(m[a+60>>2],p(m[a+48>>2]-m[a+36>>2]),p(m[a+24>>2]-m[a+12>>2]),d+8|0);m[d+12>>2]=-m[d+12>>2];a=0;while(1){e=a<<2;f=e+c|0;h=m[f>>2];o=f;f=e+48960|0;g=m[f>>2];i=m[e+(d+20|0)>>2];j=m[e+(d+8|0)>>2];k=m[f+12>>2];m[o>>2]=p(g*i)-p(j*k);f=b+e|0;l=m[(0-a<<2)+48968>>2];e=5-a<<2;n=m[e+48960>>2];g=p(p(g*j)+p(k*i));m[f>>2]=p(h*l)-p(n*g);m[b+e>>2]=p(n*h)+p(g*l);a=a+1|0;if((a|0)!=3){continue}break}Xa=d+32|0}function rya(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=Xa-144|0;Xa=c;$x(a);a:{b:{if(!ff(a,64)){break b}c:{d:{e:{if(!Vj(a,60)){break e}if(!kN(a,17196)){break e}b=15;break d}$x(a);if(!ff(a,128)){break b}b=0;f=1;if(!Vj(a,124)){break d}d=31;if(kN(a,17201)){break c}}d=b;if(f){break a}}$x(a);b=0;while(1){if(nya(a)>>>0>131072){break a}b=b+1|0;if((b&65535)>>>0<d>>>0){continue}break}Dc(a,4);if(!ff(a,2)){break b}if(mya(a)>>>0<178){break a}e=-1;b=o(d,30);if(!ff(a,b)){break a}Dc(a,b);b=a;a=c+8|0;b=kya(b,a);if(!b){uO(a)}if(!b){break a}e=jN(c+8|0);break a}e=-1}Xa=c+144|0;return e|0}function l9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=Xa-32|0;Xa=c;f=Mg(a);a:{b:{c:{d:{e:{e=b+24|0;if(k[i[e>>2]+480188>>1]){a=0;while(1){d=i[e>>2];i[114610]=0;D(2192,c|0,(d+(a<<5)|0)+480289|0);d=i[114610];i[114610]=0;if((d|0)==1){break e}i[114610]=0;G(2185,c+16|0,b|0,c|0);d=i[114610];i[114610]=0;if((d|0)==1){break d}i[114610]=0;D(1534,f|0,c+16|0);d=i[114610];i[114610]=0;if((d|0)==1){break c}eb(c+16|0);eb(c);a=a+1|0;if(a>>>0<k[i[e>>2]+480188>>1]){continue}break}}Xa=c+32|0;return}a=B()|0;A()|0;break a}a=B()|0;A()|0;break b}a=B()|0;A()|0;eb(c+16|0)}eb(c)}Sc(f);E(a|0);x()}function Z2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,h=0,k=0,l=0;c=Xa-32|0;Xa=c;a:{b:{c:{if(ae(b,-1)){break c}k=c,l=om(b),g[k+23|0]=l;if(j[a+44|0]){if((xi(c+23|0,1,1,i[a+32>>2])|0)!=1){break b}break c}i[c+16>>2]=c+24;f=c+32|0;h=c+24|0;d=c+23|0;while(1){e=vq(i[a+36>>2],i[a+40>>2],d,h,c+12|0,c+24|0,f,c+16|0);if(i[c+12>>2]==(d|0)){break b}if((e|0)==3){if((xi(d,1,1,i[a+32>>2])|0)==1){break c}break b}if(e>>>0>1){break b}d=i[c+16>>2]-(c+24|0)|0;if((xi(c+24|0,1,d,i[a+32>>2])|0)!=(d|0)){break b}d=i[c+12>>2];if((e|0)==1){continue}break}}a=er(b);break a}a=-1}Xa=c+32|0;return a|0}function a3(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,h=0;c=Xa-32|0;Xa=c;d=ae(b,-1);e=j[a+52|0];a:{if(d){d=b;if(e){break a}d=i[a+48>>2];f=a,h=ae(d,-1)^1,g[f+52|0]=h;break a}if(e){i[c+16>>2]=i[a+48>>2];b:{c:{switch(vq(i[a+36>>2],i[a+40>>2],c+16|0,c+20|0,c+12|0,c+24|0,c+32|0,c+20|0)+ -1|0){case 2:d=i[a+48>>2];i[c+20>>2]=c+25;g[c+24|0]=d;default:while(1){d=i[c+20>>2];e=1;if(d>>>0<=c+24>>>0){break b}d=d+ -1|0;i[c+20>>2]=d;if((zq(g[d|0],i[a+32>>2])|0)!=-1){continue}break}break;case 0:case 1:break c}}d=-1;e=0}if(!e){break a}}g[a+52|0]=1;i[a+48>>2]=b;d=b}Xa=c+32|0;return d|0}function nJ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,h=0,k=0;c=Xa-16|0;Xa=c;a:{if(j[b+813|0]!=27){a=g[b+851|0];break a}e=a+1074308|0;kb(c+8|0,e,21);d=ib(c+8|0);f=a;a=j[b+841|0];a=Tw(f,j[b+848|0],d?a:a+16>>>2|0);kb(c+8|0,e,45);b:{if(!(!ib(c+8|0)|j[b+848|0]!=3)){f=b;d=j[b+841|0];c:{if(!(!d|d>>>0>=j[b+849|0])){a=j[b+852|0];d=d+1|0;break c}g[b+852|0]=a;g[b+841|0]=0;d=1}g[f+841|0]=d;a=a<<24>>24;break b}g[b+841|0]=j[b+841|0]+j[b+849|0]}kb(c+8|0,e,47);if(!ib(c+8|0)){break a}g[b+851|0]=a}if(a){h=b,k=Eb(i[b+684>>2]+((o(j[b+850|0],a)+2|0)/8|0)|0,0,256),i[h+684>>2]=k}Xa=c+16|0}function j5(a,b,c,d,e,f){var g=0,l=0,n=0,q=0,r=0,s=0,t=p(0);l=1;b=j[(j[(i[b+4>>2]+o(c,3)|0)+2|0]+b|0)+9|0];if(!k[((b<<1)+a|0)+132>>1]){Lb(a,21);return}n=d>>1;g=i[a+260>>2]+o(b,1596)|0;b=o(j[g+1588|0],h[f>>1]);a=0;q=i[g+1592>>2];if((q|0)>=2){r=g+1592|0;s=g+1588|0;while(1){d=j[(g+l|0)+838|0]<<1;c=h[d+f>>1];if((c|0)>=0){c=o(j[s|0],c&65535);d=k[(d+g|0)+338>>1];if((d|0)!=(a|0)){e5(e,a,b,d,c,n);q=i[r>>2];a=d}b=c}l=l+1|0;if((l|0)<(q|0)){continue}break}}if((a|0)<(n|0)){t=m[(b<<2)+50832>>2];while(1){b=(a<<2)+e|0;m[b>>2]=m[b>>2]*t;a=a+1|0;if((n|0)!=(a|0)){continue}break}}}function gj(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,k=0;a:{c=i[a+28>>2];if((c|0)>=(b|0)){e=i[a+24>>2];break a}k=a+32|0;f=i[a+20>>2];d=i[a+16>>2];g=c;while(1){b:{if(d>>>0>=f>>>0){f=Wp(a,k,1024);i[a+16>>2]=0;i[a+20>>2]=f;if(!f){break b}d=0;g=i[a+28>>2]}h=d+1|0;i[a+16>>2]=h;d=j[(a+d|0)+32|0];c=g+8|0;i[a+28>>2]=c;e=i[a+24>>2]|d<<g;i[a+24>>2]=e;d=h;g=c;if((c|0)<(b|0)){continue}break a}break}a=P(8)|0;i[114610]=0;F(264,a|0)|0;b=i[114610];i[114610]=0;if((b|0)==1){b=B()|0;A()|0;Q(a|0);E(b|0);x()}W(a|0,77024,265);x()}i[a+28>>2]=c-b;i[a+24>>2]=e>>>b;return(-1<<b^-1)&e}function Kva(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,j=0,k=0,l=0;b=Xa-16|0;Xa=b;j=i[a+24>>2];k=i[a+20>>2];l=i[a+16>>2];g=i[a+4>>2];e=g;f=i[a>>2];i[b+8>>2]=f;i[b+12>>2]=e;g=i[a+12>>2];i[b>>2]=i[a+8>>2];i[b+4>>2]=g;if(d){while(1){e=(e<<1)+l|0;f=(f>>>21&2040)+27872|0;e=(((o(h[e>>1],h[f+2>>1])+o(h[e+ -2>>1],h[f>>1])|0)+o(h[e+2>>1],h[f+4>>1])|0)+o(h[e+4>>1],h[f+6>>1])|0)/16384|0;i[c>>2]=i[c>>2]+o(e,k);i[c+4>>2]=i[c+4>>2]+o(e,j);zb(b+8|0,b);d=d+ -1|0;if(d){c=c+8|0;f=i[b+8>>2];e=i[b+12>>2];continue}break}f=i[b+8>>2];e=i[b+12>>2]}i[a>>2]=f;i[a+4>>2]=e;Xa=b+16|0}function EHa(a,b,c,d){var e=0,f=0,g=0,h=0,k=0,m=0,n=0,o=0;e=Xa-32|0;Xa=e;i[e+28>>2]=d;a:{b:{if(j[a+24|0]){if(!d){break a}k=a+40|0;break b}m=$a[i[i[a>>2]+44>>2]](a,b,c,d)|0;break a}while(1){f=PIa(a,c);g=c-i[ji(k,f)>>2]|0;i[e+8>>2]=4096-g;n=e,o=i[rb(e+8|0,e+28|0)>>2],i[n+24>>2]=o;d=e;if(l[ji(k,f)+4>>2]>g>>>0){h=i[ji(k,f)+4>>2]-g|0}else{h=0}i[d+20>>2]=h;d=i[rb(e+24|0,e+20|0)>>2];qz(e+8|0,a,f);h=i[e+8>>2];qz(e,a,f);Oe(g+h|0,d+(i[e>>2]+g|0)|0,b);f=i[e+28>>2]-d|0;i[e+28>>2]=f;m=d+m|0;if(l[e+24>>2]>d>>>0){break a}c=c+d|0;b=b+d|0;if(f){continue}break}}Xa=e+32|0;return m}function pza(a,b){a=a|0;b=b|0;var c=0,d=0;d=Xa-32|0;Xa=d;kd(b,0);EN(d,a+1|0);oc(d+16|0,d);i[114610]=0;C(370,b+43|0,d+16|0)|0;c=i[114610];i[114610]=0;if((c|0)!=1){eb(d+16|0);c=a+78|0;i[b+24>>2]=j[c|0]|j[c+1|0]<<8;c=a+58|0;i[b>>2]=j[c|0]|j[c+1|0]<<8|(j[c+2|0]<<16|j[c+3|0]<<24);c=a+62|0;i[b+4>>2]=j[c|0]|j[c+1|0]<<8|(j[c+2|0]<<16|j[c+3|0]<<24);c=a+66|0;i[b+8>>2]=j[c|0]|j[c+1|0]<<8|(j[c+2|0]<<16|j[c+3|0]<<24);h[b+30>>1]=(j[a+73|0]<<1)+2;h[b+34>>1]=k[b+34>>1]&65533|j[a|0]>>>6&2;kc(b+8|0,i[b>>2]);kc(b+4|0,i[b+8>>2]);Xa=d+32|0;return}a=B()|0;A()|0;eb(d+16|0);E(a|0);x()}function PIa(a,b){var c=0,d=0,e=0,f=0,h=0,k=0,l=0;d=Xa-16|0;Xa=d;f=a+40|0;c=a+232|0;h=b-(b&4095)|0;a:{while(1){b:{b=i[Ae(c,e)>>2];if(!j[ji(f,b)+8|0]){break b}if(i[ji(f,b)>>2]!=(h|0)){break b}k=d,l=i[Ae(c,e)>>2],i[k+8>>2]=l;a=e<<2;Zs(c,a+c|0,(a+c|0)+4|0);a=i[d+8>>2];k=Ae(c,0),l=a,i[k>>2]=l;break a}e=e+1|0;if((e|0)!=16){continue}break}k=d,l=i[Ae(c,15)>>2],i[k+8>>2]=l;Zs(c,c+60|0,c- -64|0);b=i[d+8>>2];k=Ae(c,0),l=b,i[k>>2]=l;b=i[Ae(c,0)>>2];c=ji(f,b);i[c>>2]=h;qz(d+8|0,a,b);k=c,l=$a[i[i[a>>2]+44>>2]](a,i[d+8>>2],h,4096)|0,i[k+4>>2]=l;g[c+8|0]=1}Xa=d+16|0;return b}function pya(a,b,c){var d=0,e=0,f=0,l=0,m=0;d=Xa-16|0;Xa=d;kd(b,1);i[b>>2]=c;g[b+37|0]=j[a+24|0]<<4;g[d+15|0]=j[a+25|0];g[d+14|0]=64;l=b,m=j[Xb(d+15|0,d+14|0)|0]<<2,h[l+30>>1]=m;c=a+26|0;c=j[c|0]|j[c+1|0]<<8;a=a+28|0;e=i[b>>2];a:{if(!e){break a}f=j[a|0]|j[a+1|0]<<8;a=(c<<8&16711680|c<<24)>>>16|0;i[b+4>>2]=a;c=((f<<8&16711680|f<<24)>>>15|0)+a|0;i[b+8>>2]=c;if(e>>>0<=a>>>0){a=e+ -1|0;i[b+4>>2]=a}if(c>>>0>e>>>0){i[b+8>>2]=e;c=e}if(!(c-a>>>0>3?!(c>>>0<a>>>0|c>>>0<4):0)){i[b+4>>2]=0;i[b+8>>2]=0;break a}if(c>>>0<=a>>>0){break a}h[b+34>>1]=k[b+34>>1]|2}Xa=d+16|0}



function Mwa(a,b,c){var d=0,e=0,f=0;e=Xa-16|0;Xa=e;i[e+12>>2]=c;d=i[b+4>>2];a:{if(d){i[e+8>>2]=32-d;c=i[rb(e+8|0,e+12|0)>>2];d=i[b>>2];f=-1<<i[b+4>>2]&-1>>>i[e+8>>2]-c&(i[d>>2]^-1);if(f){Ac(a,d,WMa(f));break a}f=i[e+12>>2];if((f|0)==(c|0)){Vx(a,b,c);break a}c=f-c|0;i[e+12>>2]=c;i[b>>2]=d+4}if(c>>>0>=32){d=i[b>>2];while(1){f=i[d>>2];if((f|0)!=-1){Ac(a,d,WMa(f^-1));break a}d=d+4|0;i[b>>2]=d;c=c+ -32|0;i[e+12>>2]=c;if(c>>>0>31){continue}break}}b:{if(!c){d=i[b>>2];break b}d=i[b>>2];b=(i[d>>2]^-1)&-1>>>32-c;if(!b){break b}Ac(a,d,WMa(b));break a}Ac(a,d,c)}Xa=e+16|0}function Gsa(a,b,c){var d=0,e=0,f=0,g=0;d=Xa-16|0;Xa=d;while(1){Fsa((o(e,44)+a|0)+16|0,d+14|0,d+12|0);f=h[d+12>>1]+f|0;g=h[d+14>>1]+g|0;e=e+1|0;if((e|0)!=18){continue}break}e=b;b=(g|0)<32767?g:32767;h[e>>1]=(b|0)>-32768?b:-32768;b=(f|0)<32767?f:32767;h[c>>1]=(b|0)>-32768?b:-32768;h[a+3832>>1]=k[a+3832>>1]+1;b=(k[a+3834>>1]+1>>>0)%13440|0;h[a+3834>>1]=b;b=((b>>>0<6720?b:13440-b|0)|0)/256|0;h[a+3836>>1]=b;if(!j[a+3843|0]){h[a+3836>>1]=(b&65532)>>>2}b=k[a+3838>>1]+1|0;h[a+3838>>1]=b;if((b&65535)>>>0>=1024){h[a+3838>>1]=0;h[a+3840>>1]=k[a+3840>>1]+1&7}Xa=d+16|0}function kwa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,j=0,k=0,l=0,m=0;b=Xa-16|0;Xa=b;g=i[a+40>>2];j=i[a+36>>2];m=i[a+16>>2];e=i[a+4>>2];f=e;k=i[a>>2];i[b+8>>2]=k;i[b+12>>2]=e;e=i[a+12>>2];i[b>>2]=i[a+8>>2];i[b+4>>2]=e;a:{if(!d){e=g>>12;l=j>>12;break a}while(1){e=i[a+32>>2];f=h[(f<<1)+m>>1];j=i[a+28>>2]+j|0;l=j>>12;i[c>>2]=i[c>>2]+o(f,l);g=e+g|0;e=g>>12;i[c+4>>2]=i[c+4>>2]+o(f,e);zb(b+8|0,b);d=d+ -1|0;if(d){c=c+8|0;f=i[b+12>>2];continue}break}k=i[b+8>>2];f=i[b+12>>2]}i[a+40>>2]=g;i[a+20>>2]=l;i[a+36>>2]=j;i[a+24>>2]=e;i[a>>2]=k;i[a+4>>2]=f;Xa=b+16|0}function ura(a,b,c){var d=0,e=0,f=0;e=Xa-16|0;Xa=e;i[e+12>>2]=c;d=i[b+4>>2];a:{if(d){i[e+8>>2]=32-d;c=i[rb(e+8|0,e+12|0)>>2];f=-1<<d&-1>>>i[e+8>>2]-c;d=i[b>>2];f=f&(i[d>>2]^-1);if(f){Ac(a,d,WMa(f));break a}f=i[e+12>>2];if((f|0)==(c|0)){dL(a,b,c);break a}c=f-c|0;i[e+12>>2]=c;i[b>>2]=d+4}if(c>>>0>=32){d=i[b>>2];while(1){f=i[d>>2];if((f|0)!=-1){Ac(a,d,WMa(f^-1));break a}d=d+4|0;i[b>>2]=d;c=c+ -32|0;i[e+12>>2]=c;if(c>>>0>31){continue}break}}b:{if(!c){d=i[b>>2];break b}d=i[b>>2];b=(i[d>>2]^-1)&-1>>>32-c;if(!b){break b}Ac(a,d,WMa(b));break a}Ac(a,d,c)}Xa=e+16|0}function Lva(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,j=0,k=0,l=0,m=0;b=Xa-16|0;Xa=b;k=i[a+24>>2];l=i[a+20>>2];m=i[a+16>>2];j=i[a+4>>2];e=j;f=i[a>>2];i[b+8>>2]=f;i[b+12>>2]=e;j=i[a+12>>2];i[b>>2]=i[a+8>>2];i[b+4>>2]=j;if(d){while(1){e=e+m|0;f=(f>>>21&2040)+27872|0;e=(((o(g[e|0],h[f+2>>1])+o(g[e+ -1|0],h[f>>1])|0)+o(g[e+1|0],h[f+4>>1])|0)+o(g[e+2|0],h[f+6>>1])<<8)/16384|0;i[c>>2]=i[c>>2]+o(e,l);i[c+4>>2]=i[c+4>>2]+o(e,k);zb(b+8|0,b);d=d+ -1|0;if(d){c=c+8|0;f=i[b+8>>2];e=i[b+12>>2];continue}break}f=i[b+8>>2];e=i[b+12>>2]}i[a>>2]=f;i[a+4>>2]=e;Xa=b+16|0}function lwa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,h=0,j=0,k=0,l=0,m=0;b=Xa-16|0;Xa=b;h=i[a+40>>2];j=i[a+36>>2];m=i[a+16>>2];e=i[a+4>>2];f=e;k=i[a>>2];i[b+8>>2]=k;i[b+12>>2]=e;e=i[a+12>>2];i[b>>2]=i[a+8>>2];i[b+4>>2]=e;a:{if(!d){e=h>>12;l=j>>12;break a}while(1){e=i[a+32>>2];f=g[f+m|0]<<8;j=i[a+28>>2]+j|0;l=j>>12;i[c>>2]=i[c>>2]+o(f,l);h=e+h|0;e=h>>12;i[c+4>>2]=i[c+4>>2]+o(f,e);zb(b+8|0,b);d=d+ -1|0;if(d){c=c+8|0;f=i[b+12>>2];continue}break}k=i[b+8>>2];f=i[b+12>>2]}i[a+40>>2]=h;i[a+20>>2]=l;i[a+36>>2]=j;i[a+24>>2]=e;i[a>>2]=k;i[a+4>>2]=f;Xa=b+16|0}function kna(a,b){var c=0,d=0,e=0,f=0;c=Xa-16|0;Xa=c;m[c+8>>2]=2;h[c+14>>1]=12;i[c+4>>2]=15;d=te(64);i[114610]=0;e=F(1427,d|0)|0;f=i[114610];i[114610]=0;a:{b:{if((f|0)!=1){d=ax(c,e);e=i[d>>2];i[114610]=0;D(1428,e|0,b|0);b=i[114610];i[114610]=0;if((b|0)==1){break b}b=i[d>>2];i[114610]=0;b=I(1429,b|0,c+14|0,c+8|0)|0;e=i[114610];i[114610]=0;if((e|0)==1){break b}c:{if(!b){$w(a);break c}b=i[d>>2];i[114610]=0;D(1430,b|0,c+4|0);b=i[114610];i[114610]=0;if((b|0)==1){break b}dp(a,d)}Hf(d);Xa=c+16|0;return}a=B()|0;A()|0;Cb(d);break a}a=B()|0;A()|0;Hf(d)}E(a|0);x()}function Rda(a,b,c,d,e,f,g,h,j,k){var l=0,m=0,n=0,o=0;m=Xa-32|0;Xa=m;o=i[c>>2];n=i[c+8>>2];l=m;c=i[c+4>>2];i[l+8>>2]=c;i[l+12>>2]=n;i[114610]=0;i[l+24>>2]=c;i[l+28>>2]=n;i[l+20>>2]=o;i[l+16>>2]=d;c=i[l+20>>2];i[l>>2]=i[l+16>>2];i[l+4>>2]=c;d=ua(2007,a|0,b|0,l|0)|0;a=i[114610];i[114610]=0;a:{if((a|0)==1){a=H(0)|0;A()|0;M(a|0)|0;i[114610]=0;X(2e3,34636,e|0,f|0,g|0,h|0,j|0,k|0);a=i[114610];i[114610]=0;if((a|0)==1){break a}O();d=-255}Xa=m+32|0;return d}b=B()|0;A()|0;i[114610]=0;K(20);a=i[114610];i[114610]=0;if((a|0)!=1){E(b|0);x()}a=H(0)|0;A()|0;gb(a);x()}function vma(a,b,c){var d=0,e=0,f=0,g=0,h=0,l=0,m=0,n=0;d=Xa-16|0;Xa=d;a:{if(!Sw(a,b,0)){break a}e=i[b+656>>2];h=a+1074308|0;kb(d+8|0,h,31);b:{if(ib(d+8|0)){a=i[b+728>>2];if(a){break b}break a}a=i[b+728>>2]}kb(d+8|0,h,31);f=e+48|0;l=a-ib(d+8|0)|0;a=Po(f,l,256,64);g=j[e+65|0];c:{if((g|0)==255){break c}b=i[b+732>>2];if((b|0)==-1){break c}g=j[vb(f,g)+2|0];f=k[vb(f,j[e+65|0])>>1];kb(d+8|0,h,94);e=g<<2;a=(f|0)==(l|0)?e:a;if(ib(d+8|0)){a=b+(a-e<<1)|0;break c}if(!g){a=0;break c}a=(o(a,b)|0)/(e|0)|0}m=c,n=(o(i[c>>2],Eb(a,0,512))|0)/256|0,i[m>>2]=n}Xa=d+16|0}function pZ(){var a=0;a:{if(g[462688]&1){break a}if(!cd(462688)){break a}a=462400;while(1){a=Ab(a)+12|0;if((a|0)!=462688){continue}break}bd(462688)}tc(462400,67548);tc(462412,67556);tc(462424,67565);tc(462436,67571);tc(462448,67577);tc(462460,67581);tc(462472,67586);tc(462484,67591);tc(462496,67598);tc(462508,67608);tc(462520,67616);tc(462532,67625);tc(462544,67634);tc(462556,67638);tc(462568,67642);tc(462580,67646);tc(462592,67577);tc(462604,67650);tc(462616,67654);tc(462628,67658);tc(462640,67662);tc(462652,67666);tc(462664,67670);tc(462676,67674)}function mZ(){var a=0;a:{if(g[462992]&1){break a}if(!cd(462992)){break a}a=462704;while(1){a=Ke(a)+12|0;if((a|0)!=462992){continue}break}bd(462992)}Gc(462704,67680);Gc(462716,67712);Gc(462728,67748);Gc(462740,67772);Gc(462752,67796);Gc(462764,67812);Gc(462776,67832);Gc(462788,67852);Gc(462800,67880);Gc(462812,67920);Gc(462824,67952);Gc(462836,67988);Gc(462848,68024);Gc(462860,68040);Gc(462872,68056);Gc(462884,68072);Gc(462896,67796);Gc(462908,68088);Gc(462920,68104);Gc(462932,68120);Gc(462944,68136);Gc(462956,68152);Gc(462968,68168);Gc(462980,68184)}function $1(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=Xa-16|0;Xa=e;a:{b:{c:{d:{if((a|0)!=(b|0)){e:{f:{f=j[a|0];if((f|0)!=45){break f}a=a+1|0;if((b|0)!=(a|0)){break f}break e}h=i[114584];i[114584]=0;a=Qu(a,e+12|0,d,Ud());d=_a;g=i[114584];g:{if(g){if(i[e+12>>2]!=(b|0)){break g}if((g|0)==68){break c}break d}i[114584]=h;if(i[e+12>>2]==(b|0)){break d}}}}i[c>>2]=4;a=0;b=0;break a}if((d|0)==-1&4294967295>=a>>>0|4294967295>d>>>0){break b}}i[c>>2]=4;a=-1;b=-1;break a}b=a;c=(f|0)==45;a=c?0-a|0:a;b=c?0-(d+(0<b>>>0)|0)|0:d}Xa=e+16|0;_a=b;return a|0}function Uxa(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;a:{b:{if(!ie(a)){break b}f=i[a>>2];if(f>>>0<=c>>>0|f-c>>>0<d>>>0){break b}Om(b);Yx(b,a);i[b+20>>2]=0;i[b>>2]=d;if(!Mo(b)){break b}if(i[a>>2]!=(d|0)){yb(b+68|0,0,36)}f=i[b+20>>2];i[114610]=0;f=F(466,f|0)|0;g=i[114610];i[114610]=0;if((g|0)==1){break a}a=i[a+20>>2];i[114610]=0;a=F(466,a|0)|0;g=i[114610];i[114610]=0;if((g|0)==1){break a}Tb(f,a+c|0,d);a=k[b+34>>1];if(e){i[b+8>>2]=d;i[b+4>>2]=0;h[b+34>>1]=a|2;return}i[b+4>>2]=0;i[b+8>>2]=0;h[b+34>>1]=a&65533}return}a=H(0)|0;A()|0;gb(a);x()}function wqa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,k=0,l=0,m=0;d=Xa-16|0;Xa=d;i[d+12>>2]=c;i[d+8>>2]=i[a>>2]<<1;e=i[rb(d+8|0,d+12|0)>>2];i[d+8>>2]=i[a>>2]<<1;i[d+4>>2]=i[d+12>>2]-e;g=i[rb(d+8|0,d+4|0)>>2]>>>1|0;c=jb(b);k=e>>>1|0;if(k){f=i[a+20>>2];e=k;while(1){l=f,m=(jb(j[c|0])|jb(j[c+1|0])<<8)^32768,h[l>>1]=m;f=f+4|0;c=c+2|0;e=e+ -1|0;if(e){continue}break}}b=jb(b);if(g){f=i[a+20>>2]+2|0;c=b+(i[a>>2]<<1)|0;e=g;while(1){l=f,m=(jb(j[c|0])|jb(j[c+1|0])<<8)^32768,h[l>>1]=m;f=f+4|0;c=c+2|0;e=e+ -1|0;if(e){continue}break}}Xa=d+16|0;return g+k<<1}function tqa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,k=0,l=0,m=0;d=Xa-16|0;Xa=d;i[d+12>>2]=c;i[d+8>>2]=i[a>>2]<<1;e=i[rb(d+8|0,d+12|0)>>2];i[d+8>>2]=i[a>>2]<<1;i[d+4>>2]=i[d+12>>2]-e;g=i[rb(d+8|0,d+4|0)>>2]>>>1|0;c=jb(b);k=e>>>1|0;if(k){f=i[a+20>>2];e=k;while(1){l=f,m=(jb(j[c+1|0])|jb(j[c|0])<<8)^32768,h[l>>1]=m;f=f+4|0;c=c+2|0;e=e+ -1|0;if(e){continue}break}}b=jb(b);if(g){f=i[a+20>>2]+2|0;c=b+(i[a>>2]<<1)|0;e=g;while(1){l=f,m=(jb(j[c+1|0])|jb(j[c|0])<<8)^32768,h[l>>1]=m;f=f+4|0;c=c+2|0;e=e+ -1|0;if(e){continue}break}}Xa=d+16|0;return g+k<<1}function W2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=Xa-32|0;Xa=c;a:{b:{c:{if(ae(b,-1)){break c}i[c+20>>2]=b;if(j[a+44|0]){if((xi(c+20|0,4,1,i[a+32>>2])|0)!=1){break b}break c}i[c+16>>2]=c+24;f=c+32|0;g=c+24|0;d=c+20|0;while(1){e=vq(i[a+36>>2],i[a+40>>2],d,g,c+12|0,c+24|0,f,c+16|0);if(i[c+12>>2]==(d|0)){break b}if((e|0)==3){if((xi(d,1,1,i[a+32>>2])|0)==1){break c}break b}if(e>>>0>1){break b}d=i[c+16>>2]-(c+24|0)|0;if((xi(c+24|0,1,d,i[a+32>>2])|0)!=(d|0)){break b}d=i[c+12>>2];if((e|0)==1){continue}break}}a=er(b);break a}a=-1}Xa=c+32|0;return a|0}function z4(){var a=0,b=0,c=0,d=0;a=Xa-48|0;Xa=a;i[114610]=0;b=C(2308,0,a+32|0)|0;c=i[114610];i[114610]=0;a:{b:{c:{if((c|0)==1){break c}if(b){i[114610]=0;a=i[114610];i[114610]=0;if((a|0)==1){break c}a=i[114584];i[114610]=0;D(2310,a|0,55644);a=i[114610];i[114610]=0;if((a|0)!=1){break b}break c}b=Iq(a+16|0,a+32|0);i[a+4>>2]=i[a+36>>2]/1e3;c=Iq(a+8|0,a+4|0);i[114610]=0;b=IB(2311,b,c);c=_a;d=i[114610];i[114610]=0;if((d|0)!=1){break a}}a=H(0)|0;A()|0;gb(a)}x()}i[a+24>>2]=b;i[a+28>>2]=c;b=Qj(a+40|0,a+24|0);c=i[b+4>>2];b=i[b>>2];Xa=a+48|0;_a=c;return b}function _N(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=Xa-80|0;Xa=e;a:{if(i[b+4>>2]==i[d+4>>2]){f=i[b+4>>2];i[e+72>>2]=i[b>>2];i[e+76>>2]=f;b=i[c+4>>2];i[e+64>>2]=i[c>>2];i[e+68>>2]=b;b=td(e+56|0,d);c=i[e+76>>2];i[e+8>>2]=i[e+72>>2];i[e+12>>2]=c;c=i[e+68>>2];i[e>>2]=i[e+64>>2];i[e+4>>2]=c;aAa(a,e+8|0,e,b);break a}f=i[b+4>>2];i[e+48>>2]=i[b>>2];i[e+52>>2]=f;b=i[c+4>>2];i[e+40>>2]=i[c>>2];i[e+44>>2]=b;b=td(e+32|0,d);c=i[e+52>>2];i[e+24>>2]=i[e+48>>2];i[e+28>>2]=c;c=i[e+44>>2];i[e+16>>2]=i[e+40>>2];i[e+20>>2]=c;$za(a,e+24|0,e+16|0,b)}Xa=e+80|0}function Nwa(a,b,c){var d=0,e=0,f=0;e=Xa-16|0;Xa=e;i[e+12>>2]=c;d=i[b+4>>2];a:{if(d){i[e+8>>2]=32-d;c=rb(e+8|0,e+12|0);d=i[b>>2];c=i[c>>2];f=i[d>>2]&(-1<<i[b+4>>2]&-1>>>i[e+8>>2]-c);if(f){Ac(a,d,WMa(f));break a}f=i[e+12>>2];if((f|0)==(c|0)){Vx(a,b,c);break a}c=f-c|0;i[e+12>>2]=c;i[b>>2]=d+4}if(c>>>0>=32){d=i[b>>2];while(1){f=i[d>>2];if(f){Ac(a,d,WMa(f));break a}d=d+4|0;i[b>>2]=d;c=c+ -32|0;i[e+12>>2]=c;if(c>>>0>31){continue}break}}b:{if(!c){d=i[b>>2];break b}d=i[b>>2];b=i[d>>2]&-1>>>32-c;if(!b){break b}Ac(a,d,WMa(b));break a}Ac(a,d,c)}Xa=e+16|0}function x2(a,b){var c=0,d=0,e=0,f=0;c=Xa-16|0;Xa=c;i[c+12>>2]=0;nD(a,c+12|0,1);d=i[c+12>>2];e=d>>>2&3;g[c+11|0]=e;if(e){g[c+4|0]=3;d=j[Xb(c+4|0,c+11|0)|0];g[c+4|0]=0;g[c|0]=0;g[c+10|0]=0;a:{if(!d){break a}bh(a,c+4|0);if((d|0)==1){break a}bh(a,c);if(d>>>0<3){break a}bh(a,c+10|0);f=j[c+10|0]<<24}d=j[c+12|0]|j[c+4|0]<<8|j[c|0]<<16|f;i[c+12>>2]=d}i[c+4>>2]=d>>>4;i[c>>2]=1e6;mm(b,i[rb(c+4|0,c)>>2]);if(lb(b)){d=0;while(1){yj(a,Sb(b,d),1);d=d+1|0;if(d>>>0<lb(b)>>>0){continue}break}}b=(i[c+12>>2]>>>4|0)-lb(b)|0;i[c+12>>2]=b;if(b){Hk(a,b,-1)}Xa=c+16|0}function Mya(a,b,c){var d=0,e=0,f=0,g=0,h=0,j=0;d=Xa-80|0;Xa=d;e=i[a+4>>2];f=i[b+4>>2];g=i[b>>2];i[d+72>>2]=g;i[d+76>>2]=f;h=i[c+4>>2];c=i[c>>2];i[d+64>>2]=c;i[d+68>>2]=h;i[d+24>>2]=g;i[d+28>>2]=f;i[d+16>>2]=c;i[d+20>>2]=h;b=uN(d+24|0,d+16|0)+i[a+4>>2]|0;i[a+4>>2]=b;if(!((b+ -1^e+ -1)>>>0<32?e:0)){j=i[a>>2];i[(b>>>0<33?j:j+(b+ -1>>>3&536870908)|0)>>2]=0}i[d+48>>2]=c;i[d+52>>2]=h;i[d+56>>2]=g;i[d+60>>2]=f;rn(d+40|0,a,e);a=i[d+60>>2];i[d+8>>2]=i[d+56>>2];i[d+12>>2]=a;a=i[d+52>>2];i[d>>2]=i[d+48>>2];i[d+4>>2]=a;_N(d+32|0,d+8|0,d,d+40|0);Xa=d+80|0}function vqa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,k=0,l=0,m=0;e=Xa-16|0;Xa=e;i[e+12>>2]=c;i[e+8>>2]=i[a>>2]<<1;f=i[rb(e+8|0,e+12|0)>>2];i[e+8>>2]=i[a>>2]<<1;i[e+4>>2]=i[e+12>>2]-f;k=i[rb(e+8|0,e+4|0)>>2]>>>1|0;c=jb(b);l=f>>>1|0;if(l){g=i[a+20>>2];f=l;m=d;while(1){m=(jb(j[c|0])|jb(j[c+1|0])<<8)+m|0;h[g>>1]=m;g=g+4|0;c=c+2|0;f=f+ -1|0;if(f){continue}break}}b=jb(b);if(k){g=i[a+20>>2]+2|0;c=b+(i[a>>2]<<1)|0;f=k;while(1){d=(jb(j[c|0])|jb(j[c+1|0])<<8)+d|0;h[g>>1]=d;g=g+4|0;c=c+2|0;f=f+ -1|0;if(f){continue}break}}Xa=e+16|0;return k+l<<1}function sqa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,k=0,l=0,m=0;e=Xa-16|0;Xa=e;i[e+12>>2]=c;i[e+8>>2]=i[a>>2]<<1;f=i[rb(e+8|0,e+12|0)>>2];i[e+8>>2]=i[a>>2]<<1;i[e+4>>2]=i[e+12>>2]-f;k=i[rb(e+8|0,e+4|0)>>2]>>>1|0;c=jb(b);l=f>>>1|0;if(l){g=i[a+20>>2];f=l;m=d;while(1){m=(jb(j[c+1|0])|jb(j[c|0])<<8)+m|0;h[g>>1]=m;g=g+4|0;c=c+2|0;f=f+ -1|0;if(f){continue}break}}b=jb(b);if(k){g=i[a+20>>2]+2|0;c=b+(i[a>>2]<<1)|0;f=k;while(1){d=(jb(j[c+1|0])|jb(j[c|0])<<8)+d|0;h[g>>1]=d;g=g+4|0;c=c+2|0;f=f+ -1|0;if(f){continue}break}}Xa=e+16|0;return k+l<<1}function j2(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=Xa-16|0;Xa=e;a:{b:{c:{if((a|0)!=(b|0)){g=i[114584];i[114584]=0;d=pD(a,e+12|0,d,Ud());a=_a;f=i[114584];d:{if(f){if(i[e+12>>2]!=(b|0)){break d}if((f|0)==68){break b}break c}i[114584]=g;if(i[e+12>>2]==(b|0)){break c}}}i[c>>2]=4;d=0;a=0;break a}if((a|0)<-2147483648?1:(a|0)<=-2147483648?d>>>0<0:0){break b}if(2147483647>(a|0)?1:2147483647>=(a|0)?4294967295>=d>>>0:0){break a}}i[c>>2]=4;if((a|0)>0?1:(a|0)>=0?d>>>0>=1:0){d=-1;a=2147483647;break a}d=0;a=-2147483648}Xa=e+16|0;_a=a;return d|0}function Voa(a,b,c){var d=0,e=0,f=0;e=Xa-16|0;Xa=e;a:{b:{if(c){d=j[b+861|0];c:{if(d){c=d+ -1|0;g[b+861|0]=c;if(c&255){break c}kb(e+8|0,a+1074308|0,16);if(!ib(e+8|0)){c=-1;if(i[a+480180>>2]!=2){break a}}i[b+804>>2]=i[a+1074424>>2]+1;break b}kb(e+8|0,a+1074308|0,17);if(!(ib(e+8|0)|i[a+480180>>2]&3|!k[a+480188>>1])){d=a+1074984|0;while(1){if(j[d+861|0]?(b|0)!=(d|0):0){break b}d=d+896|0;f=f+1|0;if((f&65535)>>>0<k[a+480188>>1]){continue}break}}g[b+861|0]=c}c=i[b+804>>2];i[a+1074432>>2]=c;break a}i[b+804>>2]=i[a+1074424>>2]}c=-1}Xa=e+16|0;return c}function CO(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0;c=EBa(a);a:{if(c>>>0>5){break a}while(1){b=o(d,30)+a|0;c=DBa(b+20|0)+c|0;if(c>>>0>48){break a}e=b+45|0;if(j[b+44|0]|j[e|0]>64){break a}b=b+42|0;f=j[b|0]|j[b+1|0]<<8;if((f<<24|f<<8&16711680)>>>16>>>0>32768){break a}b=j[b|0]|j[b+1|0]<<8;g=((b<<24|b<<8&16711680)>>>16|0)+g|0;h=j[e|0]|h;d=d+1|0;if((d|0)!=15){continue}break}if(!g|!(h&255)){break a}b=a+470|0;if(j[b|0]>128){break a}c=a+471|0;if(j[c|0]>220){break a}a=a+472|0;a=j[lBa(a,a+128|0)|0];if(a>>>0>63|(a|j[b|0]?0:!j[c|0])){break a}i=1}return i}function aU(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=Xa-16|0;Xa=d;i[d+12>>2]=i[i[a+1056>>2]>>2]-i[a+1060>>2];i[d+8>>2]=16384;e=i[rb(d+12|0,d+8|0)>>2];i[a+1068>>2]=e;c=17;i[d+4>>2]=17;a:{if(!e){break a}while(1){f=1<<c+ -1;e=gj(a,c);b:{c:{d:{if((c|0)<=6){if((e|0)!=(f|0)){break d}Hp(d+4|0,gj(a,4));break b}if((c|0)>16){break c}c=f+ -8|0;if((e|0)<(c|0)|(e|0)>(f+7|0)){break d}Hp(d+4|0,e-c|0);break b}AA(a,e,f,b);break b}c=e&(f^-1);if(e&f){i[d+4>>2]=c+1;break b}AA(a,c,0,b)}if(!i[a+1068>>2]){break a}c=i[d+4>>2];if((c|0)<18){continue}break}}Xa=d+16|0}function vra(a,b,c){var d=0,e=0,f=0;e=Xa-16|0;Xa=e;i[e+12>>2]=c;d=i[b+4>>2];a:{if(d){i[e+8>>2]=32-d;c=rb(e+8|0,e+12|0);f=i[b>>2];c=i[c>>2];d=i[f>>2]&(-1<<d&-1>>>i[e+8>>2]-c);if(d){Ac(a,f,WMa(d));break a}d=i[e+12>>2];if((d|0)==(c|0)){dL(a,b,c);break a}c=d-c|0;i[e+12>>2]=c;i[b>>2]=f+4}if(c>>>0>=32){d=i[b>>2];while(1){f=i[d>>2];if(f){Ac(a,d,WMa(f));break a}d=d+4|0;i[b>>2]=d;c=c+ -32|0;i[e+12>>2]=c;if(c>>>0>31){continue}break}}b:{if(!c){d=i[b>>2];break b}d=i[b>>2];b=i[d>>2]&-1>>>32-c;if(!b){break b}Ac(a,d,WMa(b));break a}Ac(a,d,c)}Xa=e+16|0}function $T(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=Xa-16|0;Xa=d;i[d+12>>2]=i[i[a+1056>>2]>>2]-i[a+1060>>2];i[d+8>>2]=32768;e=i[rb(d+12|0,d+8|0)>>2];i[a+1068>>2]=e;c=9;i[d+4>>2]=9;a:{if(!e){break a}while(1){f=1<<c+ -1;e=gj(a,c);b:{c:{d:{if((c|0)<=6){if((e|0)!=(f|0)){break d}Hp(d+4|0,gj(a,3));break b}if((c|0)>8){break c}c=f+ -4|0;if((e|0)<(c|0)|(e|0)>(f+3|0)){break d}Hp(d+4|0,e-c|0);break b}zA(a,e,f,b);break b}c=e&(f^-1);if(e&f){i[d+4>>2]=c+1;break b}zA(a,c,0,b)}if(!i[a+1068>>2]){break a}c=i[d+4>>2];if((c|0)<10){continue}break}}Xa=d+16|0}function dBa(a,b){var c=0,d=0,e=0,f=0;f=64;while(1){c=b;d=j[c+4|0]|j[c+5|0]<<8|(j[c+6|0]<<16|j[c+7|0]<<24);e=j[c|0]|j[c+1|0]<<8|(j[c+2|0]<<16|j[c+3|0]<<24);g[a|0]=e;g[a+1|0]=e>>>8;g[a+2|0]=e>>>16;g[a+3|0]=e>>>24;g[a+4|0]=d;g[a+5|0]=d>>>8;g[a+6|0]=d>>>16;g[a+7|0]=d>>>24;d=j[c+12|0]|j[c+13|0]<<8|(j[c+14|0]<<16|j[c+15|0]<<24);c=j[c+8|0]|j[c+9|0]<<8|(j[c+10|0]<<16|j[c+11|0]<<24);g[a+8|0]=c;g[a+9|0]=c>>>8;g[a+10|0]=c>>>16;g[a+11|0]=c>>>24;g[a+12|0]=d;g[a+13|0]=d>>>8;g[a+14|0]=d>>>16;g[a+15|0]=d>>>24;a=a+16|0;f=f+ -1|0;if(f){continue}break}}function NB(a,b){var c=0,d=0,e=0,f=0;c=Xa+ -64|0;Xa=c;d=i[a>>2];e=i[d+ -4>>2];f=i[d+ -8>>2];i[c+20>>2]=0;i[c+16>>2]=71880;i[c+12>>2]=a;i[c+8>>2]=b;d=0;yb(c+24|0,0,39);a=a+f|0;a:{if(Nf(e,b,0)){i[c+56>>2]=1;$a[i[i[e>>2]+20>>2]](e,c+8|0,a,a,1,0);d=i[c+32>>2]==1?a:0;break a}$a[i[i[e>>2]+24>>2]](e,c+8|0,a,1,0);b:{switch(i[c+44>>2]){case 0:d=i[c+48>>2]==1?i[c+36>>2]==1?i[c+40>>2]==1?i[c+28>>2]:0:0:0;break a;case 1:break b;default:break a}}if(i[c+32>>2]!=1){if(i[c+48>>2]|i[c+36>>2]!=1|i[c+40>>2]!=1){break a}}d=i[c+24>>2]}Xa=c- -64|0;return d}function Hpa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=p(0),g=0,k=0,l=p(0),n=0,o=0;e=Xa-16|0;Xa=e;i[e+8>>2]=c>>>2;i[e+4>>2]=i[a>>2];g=i[rb(e+8|0,e+4|0)>>2];l=m[d>>2];b=jb(b);if(g){d=i[a+20>>2];c=g;while(1){a=j[b|0]|j[b+1|0]<<8|(j[b+2|0]<<16|j[b+3|0]<<24);m[e+12>>2]=l*(eNa(2,a<<24|a<<8&16711680|(a>>>8&65280|a>>>24)),iNa());Id(e+12|0,p(-1));f=p(m[e+12>>2]*p(32768));m[e+12>>2]=f;a=d;f=Qd(f);a:{if(p(q(f))<p(2147483648)){k=~~f;break a}k=-2147483648}n=a,o=Bc(k),h[n>>1]=o;d=d+2|0;b=b+4|0;c=c+ -1|0;if(c){continue}break}}Xa=e+16|0;return g<<2}function xqa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,k=0,l=0,m=0;d=Xa-16|0;Xa=d;i[d+12>>2]=c;i[d+8>>2]=i[a>>2]<<1;e=i[rb(d+8|0,d+12|0)>>2];i[d+8>>2]=i[a>>2]<<1;i[d+4>>2]=i[d+12>>2]-e;g=i[rb(d+8|0,d+4|0)>>2]>>>1|0;c=jb(b);k=e>>>1|0;if(k){f=i[a+20>>2];e=k;while(1){l=f,m=jb(j[c|0])|jb(j[c+1|0])<<8,h[l>>1]=m;f=f+4|0;c=c+2|0;e=e+ -1|0;if(e){continue}break}}b=jb(b);if(g){f=i[a+20>>2]+2|0;c=b+(i[a>>2]<<1)|0;e=g;while(1){l=f,m=jb(j[c|0])|jb(j[c+1|0])<<8,h[l>>1]=m;f=f+4|0;c=c+2|0;e=e+ -1|0;if(e){continue}break}}Xa=d+16|0;return g+k<<1}function uqa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,k=0,l=0,m=0;d=Xa-16|0;Xa=d;i[d+12>>2]=c;i[d+8>>2]=i[a>>2]<<1;e=i[rb(d+8|0,d+12|0)>>2];i[d+8>>2]=i[a>>2]<<1;i[d+4>>2]=i[d+12>>2]-e;g=i[rb(d+8|0,d+4|0)>>2]>>>1|0;c=jb(b);k=e>>>1|0;if(k){f=i[a+20>>2];e=k;while(1){l=f,m=jb(j[c+1|0])|jb(j[c|0])<<8,h[l>>1]=m;f=f+4|0;c=c+2|0;e=e+ -1|0;if(e){continue}break}}b=jb(b);if(g){f=i[a+20>>2]+2|0;c=b+(i[a>>2]<<1)|0;e=g;while(1){l=f,m=jb(j[c+1|0])|jb(j[c|0])<<8,h[l>>1]=m;f=f+4|0;c=c+2|0;e=e+ -1|0;if(e){continue}break}}Xa=d+16|0;return g+k<<1}function fea(a){a=a|0;var b=0,c=0;b=Xa-32|0;Xa=b;a:{b:{if(!a){a=Ed(34133);break b}i[114610]=0;c=C(85,b|0,a|0)|0;a=i[114610];i[114610]=0;c:{d:{if((a|0)!=1){i[114610]=0;D(1993,b+16|0,c|0);a=i[114610];i[114610]=0;if((a|0)==1){break d}a=Ed(xb(b+16|0));eb(b+16|0);eb(c);break b}a=H(0)|0;A()|0;break c}a=H(0)|0;A()|0;eb(c)}M(a|0)|0;a=0;i[114610]=0;J(1989,34134,0,0,0);c=i[114610];i[114610]=0;if((c|0)==1){break a}O()}Xa=b+32|0;return a|0}a=B()|0;A()|0;i[114610]=0;K(20);b=i[114610];i[114610]=0;if((b|0)!=1){E(a|0);x()}a=H(0)|0;A()|0;gb(a);x()}function e1(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,k=0;a=Xa-32|0;Xa=a;h[a+28>>1]=j[62160]|j[62161]<<8;i[a+24>>2]=j[62156]|j[62157]<<8|(j[62158]<<16|j[62159]<<24);tj(a+24|1,62148,1,i[c+4>>2]);g=i[c+4>>2];f=a+ -16|0;Xa=f;k=Ud();i[a>>2]=e;e=g>>>9&1;g=Je(f,e+13|0,k,a+24|0,a)+f|0;k=Of(f,g,c);e=f-((e<<3)+107&112)|0;Xa=e;fc(a+8|0,c);i[114610]=0;X(2474,f|0,k|0,g|0,e|0,a+20|0,a+16|0,a+8|0);f=i[114610];i[114610]=0;if((f|0)!=1){ub(a+8|0);b=Tl(b,e,i[a+20>>2],i[a+16>>2],c,d);Xa=a+32|0;return b|0}b=B()|0;A()|0;ub(a+8|0);E(b|0);x()}function _Ka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,l=0;d=Xa-208|0;Xa=d;Oz(c,a);lS(c,d+16|0,o(j[a+4|0],3));a:{if(j[a+4|0]<2){break a}g[d+12|0]=64;Lf(b,j[Xb(a+4|0,d+12|0)|0]);g[b+13|0]=j[a+2|0];g[b+14|0]=j[a+3|0];a=j[a+1|0];g[b+15|0]=a;g[b+16|0]=a;if(!qb(b)){break a}a=0;while(1){if(a){c=k[vb(b,a+ -1|0)>>1];i[d+12>>2]=1;e=(d+16|0)+o(a,3)|0;i[d+8>>2]=(g[e+1|0]&1)<<8|j[e|0];e=k[wf(d+12|0,d+8|0)>>1];f=vb(b,a),l=c+e|0,h[f>>1]=l}c=j[((d+16|0)+o(a,3)|0)+2|0];f=vb(b,a),l=c,g[f+2|0]=l;a=a+1|0;if(a>>>0<qb(b)>>>0){continue}break}}Xa=d+208|0}function zca(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=Xa-16|0;Xa=g;i[114610]=0;L(2015,a|0);h=i[114610];i[114610]=0;a:{b:{if((h|0)!=1){c:{h=i[a+24>>2];i[114610]=0;X(2074,g|0,h|0,b|0,c|0,d|0,e|0,(f|0)!=0|0);b=i[114610];i[114610]=0;if((b|0)==1){break c}b=Ed(xb(g));eb(g);break b}}b=H(0)|0;A()|0;M(b|0)|0;b=0;i[114610]=0;J(1989,36812,a|0,0,0);a=i[114610];i[114610]=0;if((a|0)==1){break a}O()}Xa=g+16|0;return b|0}a=B()|0;A()|0;i[114610]=0;K(20);b=i[114610];i[114610]=0;if((b|0)!=1){E(a|0);x()}a=H(0)|0;A()|0;gb(a);x()}function zEa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,h=0,k=0;d=Xa-32|0;Xa=d;h=d+8|0;e=b;k=e;if(vP(e,d+24|0)){f=d+26|0;f=j[f|0]|j[f+1|0]<<8|(j[f+2|0]<<16|j[f+3|0]<<24)}ad(h,k,f);e=j[d+24|0]|j[d+25|0]<<8|(j[d+26|0]<<16|j[d+27|0]<<24);g[a|0]=e;g[a+1|0]=e>>>8;g[a+2|0]=e>>>16;g[a+3|0]=e>>>24;e=j[d+28|0]|j[d+29|0]<<8;g[a+4|0]=e;g[a+5|0]=e>>>8;zl(a+8|0,d+8|0);hb(d+8|0);a:{if(!c){break a}e=(f>>>0)%(c>>>0)|0;if(!e){break a}i[114610]=0;C(338,b|0,c-e|0)|0;b=i[114610];i[114610]=0;if((b|0)!=1){break a}b=B()|0;A()|0;re(a);E(b|0);x()}Xa=d+32|0}function fla(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=Xa-32|0;Xa=e;f=Iw(a);a:{b:{c:{d:{while(1){i[114610]=0;a=C(258,b|0,8)|0;g=i[114610];i[114610]=0;if((g|0)==1){break b}if(a){i[114610]=0;G(1554,e+8|0,b|0,c|0);a=i[114610];i[114610]=0;if((a|0)==1){break d}i[114610]=0;D(1555,f|0,e+8|0);a=i[114610];i[114610]=0;if((a|0)==1){break c}re(e+8|0);a=fy(f);if((j[a|0]|j[a+1|0]<<8|(j[a+2|0]<<16|j[a+3|0]<<24))!=(d|0)){continue}}break}Xa=e+32|0;return}a=B()|0;A()|0;break a}a=B()|0;A()|0;re(e+8|0);break a}a=B()|0;A()|0}Wk(f);E(a|0);x()}function Aca(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=Xa-16|0;Xa=g;i[114610]=0;L(2015,a|0);h=i[114610];i[114610]=0;a:{b:{if((h|0)!=1){c:{h=i[a+24>>2];i[114610]=0;X(2073,g|0,h|0,b|0,c|0,d|0,e|0,(f|0)!=0|0);b=i[114610];i[114610]=0;if((b|0)==1){break c}b=Ed(xb(g));eb(g);break b}}b=H(0)|0;A()|0;M(b|0)|0;b=0;i[114610]=0;J(1989,36770,a|0,0,0);a=i[114610];i[114610]=0;if((a|0)==1){break a}O()}Xa=g+16|0;return b|0}a=B()|0;A()|0;i[114610]=0;K(20);b=i[114610];i[114610]=0;if((b|0)!=1){E(a|0);x()}a=H(0)|0;A()|0;gb(a);x()}function vta(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,j=0,l=0,m=0,n=0;c=Xa-16|0;Xa=c;f=k[lk(a,b)>>1];a:{if(!Lo(a,b)){break a}d=i[a+24>>2]+484360|0;m=c,n=Jb(d),i[m+8>>2]=n;m=c,n=Kb(d),i[m>>2]=n;if(!pb(c+8|0,c)){break a}j=f&65535;while(1){b:{g=i[c+8>>2];l=ft(g);if(l){e=0;while(1){if(!(!((a|0)!=(g|0)|(b|0)!=(e|0))|k[$b(g,e)>>1]!=(j|0))){d=uI(i[a+24>>2]+484344|0,j,0);if((d|0)!=65535){break b}}e=e+1|0;if((l|0)!=(e|0)){continue}break}}Kx(c+8|0);if(pb(c+8|0,c)){continue}break a}break}m=lk(a,b),n=d,h[m>>1]=n;f=d}Xa=c+16|0;return f&65535}function Wka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,k=0,l=0,m=0;d=Xa-32|0;Xa=d;rg(d,2,a+6|0);oc(d+16|0,d);i[114610]=0;C(369,b+492|0,d+16|0)|0;e=i[114610];i[114610]=0;if((e|0)!=1){eb(d+16|0);f=b+236|0;g=c+1|0;c=0;e=0;while(1){k=j[(a+c|0)+38|0];l=Mc(f,c),m=g+k|0,h[l>>1]=m;e=e+1|0;c=e&255;if(128>c>>>0){continue}break}c=a+226|0;i[b>>2]=(j[c|0]|j[c+1|0]<<8)<<5;Hw(a+180|0,b+48|0,0);Hw(a+228|0,b+88|0,2);Hw(a+276|0,b+68|0,1);a=a+324|0;if(!(j[a|0]|j[a+1|0]<<8)){yb(b+236|0,0,256)}Xa=d+32|0;return}a=B()|0;A()|0;eb(d+16|0);E(a|0);x()}function Cza(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=Xa-32|0;Xa=e;f=hy(a);a:{b:{c:{d:{while(1){i[114610]=0;a=C(258,b|0,8)|0;g=i[114610];i[114610]=0;if((g|0)==1){break b}if(a){i[114610]=0;G(974,e+8|0,b|0,c|0);a=i[114610];i[114610]=0;if((a|0)==1){break d}i[114610]=0;D(975,f|0,e+8|0);a=i[114610];i[114610]=0;if((a|0)==1){break c}re(e+8|0);a=fy(f);if((j[a|0]|j[a+1|0]<<8|(j[a+2|0]<<16|j[a+3|0]<<24))!=(d|0)){continue}}break}Xa=e+32|0;return}a=B()|0;A()|0;break a}a=B()|0;A()|0;re(e+8|0);break a}a=B()|0;A()|0}gl(f);E(a|0);x()}function jj(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,h=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;e=Xa-16|0;Xa=e;i[b>>2]=0;i[b+4>>2]=0;g[e+15|0]=0;l=Bg(a,e+15|0);c=j[e+15|0];i[b>>2]=(c&252)>>>2;i[b+4>>2]=0;f=c&3;if(f){n=(f|0)==1?1:-1<<f^-1;while(1){g[e+15|0]=0;o=Bg(a,e+15|0);f=b;h=i[b>>2];p=i[b+4>>2];c=j[e+15|0];d=k;k=m+1|0;if(k>>>0<1){d=d+1|0}m=k;k=d;q=f;r=h;h=c;c=m;c=(c<<3)+ -2|0;d=c;c=c&31;if(32<=(d&63)>>>0){d=h<<c;c=0}else{d=(1<<c)-1&h>>>32-c;c=h<<c}i[q>>2]=r|c;i[f+4>>2]=d|p;l=l&o;if((m|0)!=(n|0)|k){continue}break}}Xa=e+16|0;return l|0}function w4(){var a=0,b=0,c=0,d=0;a=Xa-48|0;Xa=a;i[114610]=0;b=C(2308,1,a+32|0)|0;c=i[114610];i[114610]=0;a:{b:{c:{if((c|0)==1){break c}if(b){i[114610]=0;a=i[114610];i[114610]=0;if((a|0)==1){break c}a=i[114584];i[114610]=0;D(2310,a|0,55681);a=i[114610];i[114610]=0;if((a|0)!=1){break b}break c}b=Iq(a+16|0,a+32|0);c=Iq(a+8|0,a+32|4);i[114610]=0;b=IB(2312,b,c);c=_a;d=i[114610];i[114610]=0;if((d|0)!=1){break a}}a=H(0)|0;A()|0;gb(a)}x()}i[a+24>>2]=b;i[a+28>>2]=c;b=Qj(a+40|0,a+24|0);c=i[b+4>>2];b=i[b>>2];Xa=a+48|0;_a=c;return b}function hua(a,b,c){var d=0,e=0,f=0,m=0;e=Xa-32|0;Xa=e;i[e+24>>2]=b;b=i[a>>2];f=e,m=Jb(a),i[f>>2]=m;b=b+(Hs(e+24|0,e)<<2)|0;a:{b:{if(l[a+4>>2]<l[fb(a)>>2]){d=i[a+4>>2];if((d|0)!=(b|0)){break b}zP(a,c);break a}d=fb(a);d=sn(e,ge(a,qb(a)+1|0),b-i[a>>2]>>2,d);i[114610]=0;D(1160,d|0,c|0);c=i[114610];i[114610]=0;c:{if((c|0)==1){break c}i[114610]=0;b=I(1161,a|0,d|0,b|0)|0;a=i[114610];i[114610]=0;if((a|0)==1){break c}uh(d);break a}a=B()|0;A()|0;uh(d);E(a|0);x()}eua(a,b,d,b+4|0);h[b>>1]=k[c>>1];g[b+2|0]=j[c+2|0]}Pe(b);Xa=e+32|0}function Gma(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0;c=i[a+24620>>2];c=gc(YMa(XMa(c,c>>31,100,0),_a,1e3,0),_a);a:{if(!c){break a}e=c>>>0<1048576?c:1048576;i[a+1074380>>2]=e;b=k[a+480212>>1];if(!b){break a}h=b>>>0>1?b:1;f=a+1074376|0;b=0;while(1){a=o(k[((b<<1)+f|0)+90>>1],896)+f|0;d=a+1280|0;i[d>>2]=0;i[d+4>>2]=0;i[a+708>>2]=e;d=i[a+632>>2]<<12;i[a+648>>2]=d;g=i[a+628>>2]<<12;i[a+644>>2]=g;i[a+696>>2]=i[a+696>>2]|65536;i[a+636>>2]=(0-g|0)/(e|0);i[a+640>>2]=(0-d|0)/(e|0);b=b+1|0;if((h|0)!=(b|0)){continue}break}}return(c|0)!=0}function uK(a,b,c){var d=0,e=0;a:{if(i[a+480180>>2]==4){d=j[b+834|0];if(c){g[b+834|0]=d&240|c&15;break a}c=d&15;break a}if(i[a+480180>>2]!=1048576){break a}if(c){g[b+833|0]=c;break a}c=j[b+833|0]}b:{if(!(g[b+872|0]&1)|!(c&255)){break b}d=i[b+700>>2];if(!d){break b}c:{if(!(j[a+480208|0]&16)){break c}d=i[b+700>>2];if(i[a+480180>>2]==4){break c}e=b;a=jK(a,c&15);b=XMa(a,a>>31,d,d>>31)+32768|0;a=_a;a=gc(YMa(b,b>>>0<32768?a+1|0:a,65536,0),_a);i[e+700>>2]=a-((a|0)==(d|0));return}a=(c&255)+d|0;i[b+700>>2]=(a|0)<65535?a:65535}}function q1(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,k=0;a=Xa-32|0;Xa=a;h[a+28>>1]=j[62160]|j[62161]<<8;i[a+24>>2]=j[62156]|j[62157]<<8|(j[62158]<<16|j[62159]<<24);tj(a+24|1,62148,1,i[c+4>>2]);g=i[c+4>>2];f=a+ -16|0;Xa=f;k=Ud();i[a>>2]=e;g=Je(f,(g>>>9&1)+13|0,k,a+24|0,a)+f|0;k=Of(f,g,c);e=f+ -32|0;Xa=e;fc(a+8|0,c);i[114610]=0;X(2465,f|0,k|0,g|0,e|0,a+20|0,a+16|0,a+8|0);f=i[114610];i[114610]=0;if((f|0)!=1){ub(a+8|0);b=xl(b,e,i[a+20>>2],i[a+16>>2],c,d);Xa=a+32|0;return b|0}b=B()|0;A()|0;ub(a+8|0);E(b|0);x()}function mHa(a,b,c){var d=0,e=0,f=0,k=0,l=0,m=0;e=Xa-32|0;Xa=e;rg(e,1,a);oc(e+16|0,e);i[114610]=0;C(369,b+492|0,e+16|0)|0;d=i[114610];i[114610]=0;if((d|0)!=1){eb(e+16|0);d=a+378|0;if(j[d|0]|j[d+1|0]<<8){f=b+236|0;d=0;while(1){k=j[(a+d|0)+32|0];l=Mc(f,d),m=c+k|0,h[l>>1]=m;d=d+1|0;if(d>>>0<120){continue}break}}c=a+376|0;i[b>>2]=j[c|0]|j[c+1|0]<<8;ez(a,b+48|0,0);ez(a,b+68|0,1);ez(a,b+88|0,2);a=j[b+100|0];if(a&1){g[b+100|0]=a|16}if(!(i[b>>2]|g[b+60|0]&1)){i[b>>2]=32767}Xa=e+32|0;return}a=B()|0;A()|0;eb(e+16|0);E(a|0);x()}function Ika(a,b,c,d,e){var f=0,h=0,k=0;f=Xa-16|0;Xa=f;i[f+8>>2]=e;i[f+12>>2]=c;h=i[rb(f+12|0,f+8|0)>>2];a:{b:{if(!h){c=b;break b}e=h;c=b;while(1){k=j[d|0];g[c|0]=k;if(!k){break a}d=d+1|0;c=c+1|0;e=e+ -1|0;if(e){continue}break}}e=0}c:{d:{e:{switch(a+ -1|0){case 0:case 1:d=i[f+12>>2];g[f+7|0]=0;Ar(c,((c+d|0)-h|0)+e|0,f+7|0);break d;case 2:case 3:break e;default:break c}}d=i[f+12>>2];g[f+6|0]=32;Ar(c,((c+d|0)-h|0)+e|0,f+6|0)}f:{switch(a+ -1|0){case 0:case 3:break f;default:break c}}g[(i[f+12>>2]+b|0)+ -1|0]=0}Xa=f+16|0}function Ox(a,b){var c=0,d=0,e=0,f=0;c=Xa-16|0;Xa=c;a:{if(Uc(a)){break a}h[i[a>>2]>>1]=0;ze(i[a>>2]+2|0,b);e=c,f=Jb(a),i[e>>2]=f;e=c,f=Oo(c,1),i[e+8>>2]=f;e=c,f=Kb(a),i[e>>2]=f;if(!pb(c+8|0,c)){break a}while(1){d=i[c+8>>2];e=c,f=tM(c+8|0,1),i[e>>2]=f;d=k[ri(d,i[c>>2])>>1];h[i[c+8>>2]>>1]=d;ze(i[c+8>>2]+2|0,b);WS(c+8|0);e=c,f=Kb(a),i[e>>2]=f;if(pb(c+8|0,c)){continue}break}}ze(a+14|0,qb(a)+ -1&255);ze(a+13|0,j[a+14|0]);ze(a+16|0,qb(a)+ -1&255);ze(a+15|0,j[a+16|0]);if(j[a+17|0]!=255){ze(a+17|0,qb(a)+ -1&255)}Xa=c+16|0}function K8(a){var b=0,c=0,d=0,e=0;b=Xa-160|0;Xa=b;a=jm(b+16|0,a,8);c=i[i[a>>2]+ -12>>2];i[114610]=0;d=R(122)|0;e=i[114610];i[114610]=0;a:{if((e|0)==1){break a}i[114610]=0;G(123,b+8|0,c+(b+16|0)|0,d|0);c=i[114610];i[114610]=0;if((c|0)==1){break a}ub(b+8|0);i[114610]=0;c=C(178,a|0,b|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break a}d=i[i[c>>2]+ -12>>2];i[114610]=0;c=F(174,c+d|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break a}d=i[b+4>>2];e=i[b>>2];Ve(a);Xa=b+160|0;_a=c?0:d;return c?0:e}b=B()|0;A()|0;Ve(a);E(b|0);x()}function n1(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,k=0;a=Xa-32|0;Xa=a;h[a+28>>1]=j[62160]|j[62161]<<8;i[a+24>>2]=j[62156]|j[62157]<<8|(j[62158]<<16|j[62159]<<24);tj(a+24|1,62148,0,i[c+4>>2]);g=i[c+4>>2];f=a+ -16|0;Xa=f;k=Ud();i[a>>2]=e;g=Je(f,g>>>9&1|12,k,a+24|0,a)+f|0;k=Of(f,g,c);e=f+ -32|0;Xa=e;fc(a+8|0,c);i[114610]=0;X(2465,f|0,k|0,g|0,e|0,a+20|0,a+16|0,a+8|0);f=i[114610];i[114610]=0;if((f|0)!=1){ub(a+8|0);b=xl(b,e,i[a+20>>2],i[a+16>>2],c,d);Xa=a+32|0;return b|0}b=B()|0;A()|0;ub(a+8|0);E(b|0);x()}function a1(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,k=0;a=Xa-32|0;Xa=a;h[a+28>>1]=j[62160]|j[62161]<<8;i[a+24>>2]=j[62156]|j[62157]<<8|(j[62158]<<16|j[62159]<<24);tj(a+24|1,62148,0,i[c+4>>2]);g=i[c+4>>2];f=a+ -16|0;Xa=f;k=Ud();i[a>>2]=e;g=Je(f,g>>>9&1|12,k,a+24|0,a)+f|0;k=Of(f,g,c);e=f+ -96|0;Xa=e;fc(a+8|0,c);i[114610]=0;X(2474,f|0,k|0,g|0,e|0,a+20|0,a+16|0,a+8|0);f=i[114610];i[114610]=0;if((f|0)!=1){ub(a+8|0);b=Tl(b,e,i[a+20>>2],i[a+16>>2],c,d);Xa=a+32|0;return b|0}b=B()|0;A()|0;ub(a+8|0);E(b|0);x()}function Aza(a){a=a|0;var b=0,c=0,d=0,e=0;b=Xa-16|0;Xa=b;g[b+15|0]=128;d=et(a,127,b+15|0);i[114610]=0;g[b+14|0]=64;e=I(886,a+12|0,127,b+14|0)|0;c=i[114610];i[114610]=0;a:{b:{if((c|0)!=1){i[114610]=0;g[b+13|0]=0;I(976,a+24|0,127,b+13|0)|0;c=i[114610];i[114610]=0;if((c|0)==1){break b}i[a+36>>2]=-1;i[a+40>>2]=108855296;g[a+44|0]=0;g[a+45|0]=0;g[a+46|0]=0;g[a+47|0]=0;g[a+48|0]=0;g[a+49|0]=0;g[a+50|0]=0;g[a+51|0]=0;g[a+52|0]=0;g[a+53|0]=0;Xa=b+16|0;return a|0}a=B()|0;A()|0;break a}a=B()|0;A()|0;Md(e)}Md(d);E(a|0);x()}function Dca(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;f=Xa-16|0;Xa=f;i[114610]=0;L(2015,a|0);g=i[114610];i[114610]=0;a:{b:{if((g|0)!=1){c:{g=i[a+24>>2];i[114610]=0;_(2071,f|0,g|0,b|0,c|0,d|0,e|0);b=i[114610];i[114610]=0;if((b|0)==1){break c}b=Ed(xb(f));eb(f);break b}}b=H(0)|0;A()|0;M(b|0)|0;b=0;i[114610]=0;J(1989,36667,a|0,0,0);a=i[114610];i[114610]=0;if((a|0)==1){break a}O()}Xa=f+16|0;return b|0}a=B()|0;A()|0;i[114610]=0;K(20);b=i[114610];i[114610]=0;if((b|0)!=1){E(a|0);x()}a=H(0)|0;A()|0;gb(a);x()}function Bca(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;f=Xa-16|0;Xa=f;i[114610]=0;L(2015,a|0);g=i[114610];i[114610]=0;a:{b:{if((g|0)!=1){c:{g=i[a+24>>2];i[114610]=0;_(2072,f|0,g|0,b|0,c|0,d|0,e|0);b=i[114610];i[114610]=0;if((b|0)==1){break c}b=Ed(xb(f));eb(f);break b}}b=H(0)|0;A()|0;M(b|0)|0;b=0;i[114610]=0;J(1989,36717,a|0,0,0);a=i[114610];i[114610]=0;if((a|0)==1){break a}O()}Xa=f+16|0;return b|0}a=B()|0;A()|0;i[114610]=0;K(20);b=i[114610];i[114610]=0;if((b|0)!=1){E(a|0);x()}a=H(0)|0;A()|0;gb(a);x()}function zBa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=Xa-528|0;Xa=d;c=-1;a:{if(!ff(a,1468)){break a}Vj(a,1464);LO(a,d+524|0);if(!Hd(d+524|0,16010)){c=0;if(!Hd(d+524|0,16015)){break a}}Vj(a,20);b=1;while(1){c=-1;if(!IO(a,d)){break a}e=xy(d)+e|0;c=b&65535;b=b+1|0;if(c>>>0<31){continue}break}c=0;if(e>>>0>40){break a}cBa(a,d+520|0);e=Nc(d+520|0);c=0;if(j[d+520|0]>128){break a}yBa(a,d);a=d+512|0;b=d;c=j[e|0];b:{while(1){if(j[b|0]>c>>>0){break b}b=b+1|0;if((a|0)!=(b|0)){continue}break}c=1;break a}c=0}Xa=d+528|0;return c|0}function GT(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;tF(b);a:{if(!(j[a|0]|j[a+1|0]<<8)){c=a+2|0;if(!(j[c|0]|j[c+1|0]<<8)){break a}}i[b+20>>2]=((j[a|0]|j[a+1|0]<<8)>>>9|0)+80;d=b,e=Eb((j[a|0]|j[a+1|0]<<8)>>>5&15,1,12)+ -1|0,i[d+16>>2]=e;d=b,e=Eb((j[a|0]|j[a+1|0]<<8)&31,1,31),i[d+12>>2]=e;c=a+2|0;d=b,e=Eb((j[c|0]|j[c+1|0]<<8)>>>11|0,0,23),i[d+8>>2]=e;d=b,e=Eb((j[c|0]|j[c+1|0]<<8)>>>5&63,0,59),i[d+4>>2]=e;d=b,e=Eb((j[c|0]|j[c+1|0]<<8)<<1&62,0,59),i[d>>2]=e}a=a+4|0;i[b+44>>2]=j[a|0]|j[a+1|0]<<8|(j[a+2|0]<<16|j[a+3|0]<<24)}function ola(a,b){var c=0,d=0,e=0,f=0,k=0,l=0;d=Xa-16|0;Xa=d;e=a+206|0;i[b>>2]=j[e|0]|j[e+1|0]<<8;SI(a,b+48|0,j[a+192|0],j[a+200|0],j[a+194|0],j[a+195|0],j[a+196|0],0);SI(a,b+68|0,j[a+193|0],j[a+201|0],j[a+197|0],j[a+198|0],j[a+199|0],1);e=b+236|0;while(1){f=j[a+c|0];k=Mc(e,c+12|0),l=f,h[k>>1]=l;c=c+1|0;if((c|0)!=96){continue}break}if(j[a+208|0]){g[b+31|0]=j[a+209|0]+1;nla(b+31|0);c=a+210|0;h[d+14>>1]=j[c|0]|j[c+1|0]<<8;h[d+12>>1]=127;k=b,l=j[ef(d+14|0,d+12|0)|0]+1|0,g[k+30|0]=l}g[b+33|0]=j[a+212|0];Xa=d+16|0}function X0(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,k=0,l=0;a=Xa-208|0;Xa=a;h[a+204>>1]=j[62166]|j[62167]<<8;i[a+200>>2]=j[62162]|j[62163]<<8|(j[62164]<<16|j[62165]<<24);f=Ud();i[a>>2]=e;k=Je(a+176|0,20,f,a+200|0,a);e=k+(a+176|0)|0;f=Of(a+176|0,e,c);fc(a+8|0,c);i[114610]=0;g=F(2449,a+8|0)|0;l=i[114610];i[114610]=0;if((l|0)!=1){ub(a+8|0);kD(g,a+176|0,e,a+16|0);g=b;b=(a+16|0)+(k<<2)|0;b=Tl(g,a+16|0,(e|0)==(f|0)?b:((f-a<<2)+a|0)+ -688|0,b,c,d);Xa=a+208|0;return b|0}b=B()|0;A()|0;ub(a+8|0);E(b|0);x()}function yX(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;if(Nf(a,i[b+8>>2],e)){qu(b,c,d);return}a:{if(Nf(a,i[b>>2],e)){if(!(i[b+20>>2]!=(c|0)?i[b+16>>2]!=(c|0):0)){if((d|0)!=1){break a}i[b+32>>2]=1;return}i[b+32>>2]=d;b:{if(i[b+44>>2]==4){break b}h[b+52>>1]=0;a=i[a+8>>2];$a[i[i[a>>2]+20>>2]](a,b,c,c,1,e);if(j[b+53|0]){i[b+44>>2]=3;if(!j[b+52|0]){break b}break a}i[b+44>>2]=4}i[b+20>>2]=c;i[b+40>>2]=i[b+40>>2]+1;if(i[b+36>>2]!=1|i[b+24>>2]!=2){break a}g[b+54|0]=1;return}a=i[a+8>>2];$a[i[i[a>>2]+24>>2]](a,b,c,d,e)}}function VGa(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,l=0,m=0,n=0;f=Xa-32|0;Xa=f;i[f+28>>2]=c;l=wb(b,c<<2);a:{if(!l){break a}kc(f+28|0,65535);Zf(a,k[f+28>>1]);m=f,n=Jb(a),i[m+16>>2]=n;m=f,n=Kb(a),i[m+8>>2]=n;if(!pb(f+16|0,f+8|0)){break a}while(1){a=i[f+16>>2];lp(b,f+24|0);c=f+24|0;c=j[c|0]|j[c+1|0]<<8|(j[c+2|0]<<16|j[c+3|0]<<24);h[a>>1]=c;c=c&65535;g=65535;b:{c:{if((c|0)==(d|0)){break c}if((c|0)!=(e|0)){break b}g=65534}h[a>>1]=g}he(f+16|0);if(pb(f+16|0,f+8|0)){continue}break}}Xa=f+32|0;return l|0}function cm(a,b,c,d,e,f){var g=0,h=0,j=0,k=0;a:{if(f&64){c=f+ -64|0;b=c&31;if(32<=(c&63)>>>0){c=0;b=e>>>b|0}else{c=e>>>b|0;b=((1<<b)-1&e)<<32-b|d>>>b}d=0;e=0;break a}if(!f){break a}h=e;j=d;k=64-f|0;g=k&31;if(32<=(k&63)>>>0){h=j<<g;k=0}else{h=(1<<g)-1&j>>>32-g|h<<g;k=j<<g}j=b;g=f;b=g&31;if(32<=(g&63)>>>0){g=0;b=c>>>b|0}else{g=c>>>b|0;b=((1<<b)-1&c)<<32-b|j>>>b}b=k|b;c=g|h;g=d;d=f&31;if(32<=(f&63)>>>0){h=0;d=e>>>d|0}else{h=e>>>d|0;d=((1<<d)-1&e)<<32-d|g>>>d}e=h}i[a>>2]=b;i[a+4>>2]=c;i[a+8>>2]=d;i[a+12>>2]=e}function S8(a){var b=0,c=0,d=0,e=0;b=Xa-160|0;Xa=b;a=jm(b+16|0,a,8);d=i[i[a>>2]+ -12>>2];i[114610]=0;c=R(122)|0;e=i[114610];i[114610]=0;a:{if((e|0)==1){break a}i[114610]=0;G(123,b+8|0,d+(b+16|0)|0,c|0);d=i[114610];i[114610]=0;if((d|0)==1){break a}ub(b+8|0);i[114610]=0;d=C(177,a|0,b+6|0)|0;c=i[114610];i[114610]=0;if((c|0)==1){break a}c=i[i[d>>2]+ -12>>2];i[114610]=0;d=F(174,c+d|0)|0;c=i[114610];i[114610]=0;if((c|0)==1){break a}c=k[b+6>>1];Ve(a);Xa=b+160|0;return(d?0:c)&65535}b=B()|0;A()|0;Ve(a);E(b|0);x()}function sda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;i[114610]=0;L(2015,a|0);d=i[114610];i[114610]=0;a:{if((d|0)==1){break a}i[114610]=0;L(2026,c|0);d=i[114610];i[114610]=0;if((d|0)==1){break a}d=i[a+24>>2];i[114610]=0;b=C(2027,d|0,b|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break a}i[c>>2]=b;return 1}b=H(0)|0;A()|0;M(b|0)|0;i[114610]=0;J(1989,35214,a|0,0,0);a=i[114610];i[114610]=0;if((a|0)!=1){O();return 0}a=B()|0;A()|0;i[114610]=0;K(20);b=i[114610];i[114610]=0;if((b|0)!=1){E(a|0);x()}a=H(0)|0;A()|0;gb(a);x()}function Qw(a,b,c,d){var e=0,f=0,g=0,i=0,j=0,l=0;i=Xa-16|0;Xa=i;a:{if((c|0)<2){break a}l=(c+ -2|0)/2|0;f=d-a|0;if((l|0)<f>>1){break a}g=f+1|0;e=(g<<1)+a|0;f=f+2|0;if((f|0)<(c|0)){j=lo(b,k[e>>1],k[e+2>>1]);e=j?e+2|0:e;g=j?f:g}if(lo(b,k[e>>1],k[d>>1])){break a}h[i+14>>1]=k[d>>1];while(1){b:{f=e;h[d>>1]=k[e>>1];if((l|0)<(g|0)){break b}d=g<<1;g=d|1;e=(g<<1)+a|0;d=d+2|0;if((d|0)<(c|0)){j=lo(b,k[e>>1],k[e+2>>1]);e=j?e+2|0:e;g=j?d:g}d=f;if(!lo(b,k[e>>1],k[i+14>>1])){continue}}break}h[f>>1]=k[i+14>>1]}Xa=i+16|0}function vE(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0;h=-1;f=d&2147483647;i=f;g=c;a:{if(!c&(f|0)==2147418112?a|b:(f|0)==2147418112&c>>>0>0|f>>>0>2147418112){break a}f=e&2147483647;j=f;if((f|0)==2147418112?0:f>>>0>2147418112){break a}if(!(a|g|(i|j|b))){return 0}g=d&e;if((g|0)>0?1:(g|0)>=0){if(!c&(d|0)==(e|0)?!b&a>>>0<0|b>>>0<0:(d|0)<(e|0)?1:(d|0)<=(e|0)?c>>>0<0:0){break a}return(a|c)!=0|(d^e|b)!=0}if(!c&(d|0)==(e|0)?!b&a>>>0>0|b>>>0>0:(d|0)>(e|0)?1:(d|0)>=(e|0)?c>>>0>0:0){break a}h=(a|c)!=0|(d^e|b)!=0}return h}function Zqa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=Xa-16|0;Xa=e;f=Ab(a);a:{b:{c:{if(cc(b)){a=0;while(1){d:{if(!a){break d}i[114610]=0;C(1251,f|0,c|0)|0;d=i[114610];i[114610]=0;if((d|0)!=1){break d}a=B()|0;A()|0;break a}d=Yc(b,a);i[114610]=0;D(1252,e|0,d|0);d=i[114610];i[114610]=0;if((d|0)==1){break c}i[114610]=0;C(1251,f|0,e|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break b}eb(e);a=a+1|0;if(a>>>0<cc(b)>>>0){continue}break}}Xa=e+16|0;return}a=B()|0;A()|0;break a}a=B()|0;A()|0;eb(e)}eb(f);E(a|0);x()}function Wpa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,k=0,l=0,m=0;e=Xa-16|0;Xa=e;i[e+8>>2]=c>>>3;i[e+4>>2]=i[a>>2];d=i[rb(e+8|0,e+4|0)>>2];b=jb(b);if(d){a=i[a+20>>2];c=d;while(1){g=j[b+4|0]|j[b+5|0]<<8|(j[b+6|0]<<16|j[b+7|0]<<24);i[e+8>>2]=j[b|0]|j[b+1|0]<<8|(j[b+2|0]<<16|j[b+3|0]<<24);i[e+12>>2]=g;mf(e+8|0,-1,1);f=n[e+8>>3]*32768;n[e+8>>3]=f;g=a;f=xd(f);a:{if(q(f)<2147483648){k=~~f;break a}k=-2147483648}l=g,m=Bc(k),h[l>>1]=m;a=a+2|0;b=b+8|0;c=c+ -1|0;if(c){continue}break}}Xa=e+16|0;return d<<3}function Tw(a,b,c){var d=0,e=0;e=Xa-16|0;Xa=e;kb(e+8|0,a+1074308|0,21);a:{if(ib(e+8|0)){c=c&255;b:{switch((b&3)-1|0){default:d=g[c+21600|0];break a;case 0:d=64-(c+1>>>1|0)|0;break a;case 1:d=(c>>>0<128)<<6;break a;case 2:break b}}d=iJ(Am(a))+ -64|0;break a}d=g[(c>>>1&31)+20704|0];if(i[a+480180>>2]&67633152){break a}a=c&63;c:{switch((b&3)-1|0){default:d=g[a+21472|0];break a;case 0:d=(a>>>0<32?0:255)-(a<<2)|0;break a;case 1:d=a>>>0<32?127:-127;break a;case 2:break c}}d=g[a+21536|0]}a=d;Xa=e+16|0;return a}function or(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;d=Xa-32|0;Xa=d;e=a;c=i[b>>2];f=i[b+8>>2];c=c&24576?c:i[b+4>>2]?(f|0)!=-1?c&-12289|8192:c:c;b=143;a:{b:{if(c&1){break b}if(!(c&2)){break a}b=144}Wv(e,b)}c:{if(c&4096){break c}if(c&8192){g=d,h=Pe(4),i[g+24>>2]=h;rG(a,d+24|0);break c}if(!(c&16384)){break c}g=d,h=Pe(256),i[g+16>>2]=h;rG(a,d+16|0)}b=a;d:{if(c&16){e=145}else{if(!(c&32)){break d}e=146}Wv(b,e)}if((f|0)!=-1){g=d,h=Pe(f),i[g+8>>2]=h;a=i[i[a>>2]+ -12>>2]+a|0;a;i[a+8>>2]=i[d+8>>2]}Xa=d+32|0}function Zpa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=p(0),k=0,l=0,n=0;e=Xa-16|0;Xa=e;i[e+8>>2]=c>>>2;i[e+4>>2]=i[a>>2];d=i[rb(e+8|0,e+4|0)>>2];b=jb(b);if(d){c=i[a+20>>2];a=d;while(1){f=j[b|0]|j[b+1|0]<<8|(j[b+2|0]<<16|j[b+3|0]<<24);i[e+12>>2]=f<<24|f<<8&16711680|(f>>>8&65280|f>>>24);Id(e+12|0,p(-1));g=p(m[e+12>>2]*p(32768));m[e+12>>2]=g;f=c;g=Qd(g);a:{if(p(q(g))<p(2147483648)){k=~~g;break a}k=-2147483648}l=f,n=Bc(k),h[l>>1]=n;c=c+2|0;b=b+4|0;a=a+ -1|0;if(a){continue}break}}Xa=e+16|0;return d<<2}function m2(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=Xa-16|0;Xa=e;a:{b:{c:{if((a|0)!=(b|0)){g=i[114584];i[114584]=0;a=pD(a,e+12|0,d,Ud());d=_a;f=i[114584];d:{if(f){if(i[e+12>>2]!=(b|0)){break d}if((f|0)==68){break b}break c}i[114584]=g;if(i[e+12>>2]==(b|0)){break c}}}i[c>>2]=4;b=0;break a}if(((d|0)<-1?1:(d|0)<=-1?a>>>0<2147483648:0)|((d|0)>0?1:(d|0)>=0?a>>>0>2147483647:0)){break b}b=a;break a}i[c>>2]=4;b=2147483647;if((d|0)>0?1:(d|0)>=0?a>>>0>=1:0){break a}b=-2147483648}Xa=e+16|0;return b|0}function iM(a,b){var c=0,d=0,e=0,f=0,h=0,k=0,l=0,m=0,n=0;n=b?33:32;f=i[a+8>>2];c=f+ -1|0;d=i[a+12>>2];h=i[a>>2]+o(d,31)|0;k=b?1:-1;e=k;while(1){b=0;if((d|0)>0){while(1){g[b+h|0]=j[i[a+4>>2]+(o(c,d)+b|0)|0];b=b+1|0;d=i[a+12>>2];if((b|0)<(d|0)){continue}break}f=i[a+8>>2]}b=o(d,k);l=f+ -1|0;a:{if(!((l|0)!=(c|0)|(e|0)<1)){if(!j[a+16|0]){e=1;c=0;break a}e=-1;c=c-((c|0)!=0&j[a+17|0]!=0)|0;break a}if(!((e|0)>-1|c)){c=j[a+16|0];e=c?1:-1;c=c?0:l;break a}c=c+e|0}h=b+h|0;m=m+1|0;if((n|0)!=(m|0)){continue}break}}function sv(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;e=Xa-16|0;Xa=e;f=(hNa(a),dNa(2));c=f&2147483647;a:{if(c>>>0<=1305022426){g=+a;d=g*.6366197723675814+6755399441055744+ -6755399441055744;n[b>>3]=g+d*-1.5707963109016418+d*-1.5893254773528196e-8;if(q(d)<2147483648){c=~~d;break a}c=-2147483648;break a}if(c>>>0>=2139095040){n[b>>3]=p(a-a);c=0;break a}h=c;c=(c>>>23|0)+ -150|0;n[e+8>>3]=(eNa(2,h-(c<<23)|0),iNa());c=KE(e+8|0,e,c,1,0);d=n[e>>3];if((f|0)<=-1){n[b>>3]=-d;c=0-c|0;break a}n[b>>3]=d}Xa=e+16|0;return c}function g1(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,k=0,l=0;a=Xa-96|0;Xa=a;h[a+92>>1]=j[62166]|j[62167]<<8;i[a+88>>2]=j[62162]|j[62163]<<8|(j[62164]<<16|j[62165]<<24);f=Ud();i[a>>2]=e;k=Je(a- -64|0,20,f,a+88|0,a);e=k+(a- -64|0)|0;f=Of(a- -64|0,e,c);fc(a+8|0,c);i[114610]=0;g=F(21,a+8|0)|0;l=i[114610];i[114610]=0;if((l|0)!=1){ub(a+8|0);lD(g,a- -64|0,e,a+16|0);g=b;b=(a+16|0)+k|0;b=xl(g,a+16|0,(e|0)==(f|0)?b:((f-a|0)+a|0)+ -48|0,b,c,d);Xa=a+96|0;return b|0}b=B()|0;A()|0;ub(a+8|0);E(b|0);x()}function oW(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=Xa-16|0;Xa=e;f=Oc(a);a:{b:{c:{if(cc(b)){a=0;while(1){d:{if(!a){break d}i[114610]=0;C(192,f|0,c|0)|0;d=i[114610];i[114610]=0;if((d|0)!=1){break d}a=B()|0;A()|0;break a}d=Yc(b,a);i[114610]=0;D(252,e|0,d|0);d=i[114610];i[114610]=0;if((d|0)==1){break c}i[114610]=0;C(192,f|0,e|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break b}eb(e);a=a+1|0;if(a>>>0<cc(b)>>>0){continue}break}}Xa=e+16|0;return}a=B()|0;A()|0;break a}a=B()|0;A()|0;eb(e)}eb(f);E(a|0);x()}function J2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0;f=Xa-32|0;Xa=f;a:{b:{if(yD(c)){while(1){if(a>>>d&1){k=(d<<2)+c|0,l=zD(d,b),i[k>>2]=l}d=d+1|0;if((d|0)!=6){continue}break}break b}while(1){j=(f+8|0)+(d<<2)|0;e=1<<d&a;g=i[(d<<2)+c>>2];c:{if(!(e|!c)){break c}g=zD(d,e?b:58075)}e=g;i[j>>2]=e;h=((e|0)!=0)+h|0;d=d+1|0;if((d|0)!=6){continue}break}d=57920;d:{switch(h|0){case 0:break a;case 1:break d;default:break b}}if(i[f+8>>2]!=57892){break b}d=57944;break a}d=c}Xa=f+32|0;return d|0}function cG(a){var b=0,c=0,d=0,e=0;b=Xa-160|0;Xa=b;a=jm(b+16|0,a,8);d=i[i[a>>2]+ -12>>2];i[114610]=0;c=R(122)|0;e=i[114610];i[114610]=0;a:{if((e|0)==1){break a}i[114610]=0;G(123,b+8|0,d+(b+16|0)|0,c|0);d=i[114610];i[114610]=0;if((d|0)==1){break a}ub(b+8|0);i[114610]=0;d=C(173,a|0,b+4|0)|0;c=i[114610];i[114610]=0;if((c|0)==1){break a}c=i[i[d>>2]+ -12>>2];i[114610]=0;d=F(174,c+d|0)|0;c=i[114610];i[114610]=0;if((c|0)==1){break a}c=i[b+4>>2];Ve(a);Xa=b+160|0;return d?0:c}b=B()|0;A()|0;Ve(a);E(b|0);x()}function A8(a){var b=0,c=0,d=0,e=0,f=0;b=Xa-160|0;Xa=b;a=jm(b+16|0,a,8);c=i[i[a>>2]+ -12>>2];i[114610]=0;d=R(122)|0;e=i[114610];i[114610]=0;a:{if((e|0)==1){break a}i[114610]=0;G(123,b+8|0,c+(b+16|0)|0,d|0);c=i[114610];i[114610]=0;if((c|0)==1){break a}ub(b+8|0);i[114610]=0;c=C(179,a|0,b|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break a}d=i[i[c>>2]+ -12>>2];i[114610]=0;c=F(174,c+d|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break a}f=n[b>>3];Ve(a);Xa=b+160|0;return c?0:f}b=B()|0;A()|0;Ve(a);E(b|0);x()}function Zta(a,b){var c=0,d=0,e=0;kc(a,65536);kc(a+4|0,64);kc(a+8|0,256);Ag(a+28|0,16384);ze(a+30|0,128);ze(a+31|0,17);if(j[a+16|0]>=4){g[a+16|0]=0}if(j[a+17|0]>=5){g[a+17|0]=0}if(j[a+18|0]>=3){g[a+18|0]=0}ze(a+19|0,64);ze(a+20|0,100);cua(a+26|0);ze(a+23|0,64);ze(a+24|0,64);Ox(a+48|0,64);Ox(a+68|0,64);Ox(a+88|0,(b|0)==4096?255:64);c=a+108|0;b=0;while(1){a:{if(j[Nb(c,b)|0]){if(j[Nb(c,b)|0]<121){break a}}d=Nb(c,b),e=b+1|0,g[d|0]=e}b=b+1|0;if(b>>>0<128){continue}break}if(!qn(j[a+14|0])){g[a+14|0]=5}}function No(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=k[a+34>>1];if(!b){b=a;if(d&512){nM(a);d=k[a+34>>1]}h[b+34>>1]=d&65023;return}i[a>>2]=4;h[a+34>>1]=d&64958|512;Mo(a);b=j[c+8|0]|j[c+9|0]<<8|(j[c+10|0]<<16|j[c+11|0]<<24);g[a+76|0]=b;g[a+77|0]=b>>>8;g[a+78|0]=b>>>16;g[a+79|0]=b>>>24;b=j[c+4|0]|j[c+5|0]<<8|(j[c+6|0]<<16|j[c+7|0]<<24);c=j[c|0]|j[c+1|0]<<8|(j[c+2|0]<<16|j[c+3|0]<<24);g[a+68|0]=c;g[a+69|0]=c>>>8;g[a+70|0]=c>>>16;g[a+71|0]=c>>>24;g[a+72|0]=b;g[a+73|0]=b>>>8;g[a+74|0]=b>>>16;g[a+75|0]=b>>>24}function sK(a,b,c,d){var e=0,f=0,h=0;e=Xa-16|0;Xa=e;a:{b:{c:{f=!d;d=c>>31;d=d+c^d;if(f|(d|0)<224){break c}kb(e+8|0,a+1074308|0,3);if(ib(e+8|0)){break c}if(!(g[(o(b,896)+a|0)+1075856|0]&1)){break a}c=o((c>>31)+((c|0)>0)|0,d&15);c=(d|0)>239?c<<2:c;break b}if(g[(o(b,896)+a|0)+1075856|0]&1){kb(e+8|0,a+1074308|0,3);if(!ib(e+8|0)){break a}}c=c<<2}if(!c){break a}d=lx(a,b);if(!d){break a}f=d;a=i[(o(b,896)+a|0)+1075640>>2];h=13;d:{if(!a){break d}h=j[a+33|0]}$a[i[i[d>>2]+80>>2]](f,c,h<<24>>24,b)}Xa=e+16|0}function aqa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=Xa-16|0;Xa=e;i[e+12>>2]=c>>>4;i[e+8>>2]=i[a>>2];d=i[rb(e+12|0,e+8|0)>>2];b=jb(b);if(d){a=i[a+20>>2];c=d;while(1){jb(j[b|0]);jb(j[b+1|0]);jb(j[b+2|0]);jb(j[b+3|0]);jb(j[b+4|0]);jb(j[b+5|0]);f=a,g=jb(j[b+6|0])|jb(j[b+7|0])<<8,h[f>>1]=g;jb(j[b+8|0]);jb(j[b+9|0]);jb(j[b+10|0]);jb(j[b+11|0]);jb(j[b+12|0]);jb(j[b+13|0]);f=a,g=jb(j[b+14|0])|jb(j[b+15|0])<<8,h[f+2>>1]=g;a=a+4|0;b=b+16|0;c=c+ -1|0;if(c){continue}break}}Xa=e+16|0;return d<<4}function $pa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=Xa-16|0;Xa=e;i[e+12>>2]=c>>>4;i[e+8>>2]=i[a>>2];d=i[rb(e+12|0,e+8|0)>>2];b=jb(b);if(d){a=i[a+20>>2];c=d;while(1){jb(j[b+7|0]);jb(j[b+6|0]);jb(j[b+5|0]);jb(j[b+4|0]);jb(j[b+3|0]);jb(j[b+2|0]);f=a,g=jb(j[b+1|0])|jb(j[b|0])<<8,h[f>>1]=g;jb(j[b+15|0]);jb(j[b+14|0]);jb(j[b+13|0]);jb(j[b+12|0]);jb(j[b+11|0]);jb(j[b+10|0]);f=a,g=jb(j[b+9|0])|jb(j[b+8|0])<<8,h[f+2>>1]=g;a=a+4|0;b=b+16|0;c=c+ -1|0;if(c){continue}break}}Xa=e+16|0;return d<<4}function kf(a,b,c,d,e,f){var g=0,h=0,j=0,k=0;a:{if(f&64){d=b;e=f+ -64|0;b=e&31;if(32<=(e&63)>>>0){e=d<<b;d=0}else{e=(1<<b)-1&d>>>32-b|c<<b;d=d<<b}b=0;c=0;break a}if(!f){break a}g=d;j=f;d=f&31;if(32<=(f&63)>>>0){h=g<<d;k=0}else{h=(1<<d)-1&g>>>32-d|e<<d;k=g<<d}d=c;g=b;f=64-f|0;e=f&31;if(32<=(f&63)>>>0){f=0;d=d>>>e|0}else{f=d>>>e|0;d=((1<<e)-1&d)<<32-e|g>>>e}d=k|d;e=f|h;f=b;b=j&31;if(32<=(j&63)>>>0){h=f<<b;b=0}else{h=(1<<b)-1&f>>>32-b|c<<b;b=f<<b}c=h}i[a>>2]=b;i[a+4>>2]=c;i[a+8>>2]=d;i[a+12>>2]=e}function zK(a,b){var c=0,d=0,e=0;a:{b:{if(!j[b+866|0]|i[a+480180>>2]!=1){break b}d=i[b+104>>2];if(!d){break b}if(!ie(d)|(k[d+34>>1]&3)!=2){break b}c=j[b+867|0]+j[(j[b+866|0]&15)+21392|0]|0;g[b+867|0]=c;if(c<<24>>24>-1){break b}g[b+867|0]=0;c=i[b+784>>2]+1|0;i[b+784>>2]=c;i[b+784>>2]=c>>>0<i[d+8>>2]-i[d+4>>2]>>>0?c:0;c=i[d+20>>2];i[114610]=0;c=F(466,c|0)|0;e=i[114610];i[114610]=0;if((e|0)==1){break a}b=jb(c)+(i[b+784>>2]+i[d+4>>2]|0)|0;g[b|0]=j[b|0]^-1;Mx(d,a,0)}return}a=H(0)|0;A()|0;gb(a);x()}function Ipa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=p(0),g=0,k=p(0),l=0,n=0,o=0;e=Xa-16|0;Xa=e;i[e+8>>2]=c>>>2;i[e+4>>2]=i[a>>2];c=i[rb(e+8|0,e+4|0)>>2];k=m[d>>2];b=jb(b);if(c){a=i[a+20>>2];d=c;while(1){m[e+12>>2]=k*(eNa(2,j[b|0]|j[b+1|0]<<8|(j[b+2|0]<<16|j[b+3|0]<<24)),iNa());Id(e+12|0,p(-1));f=p(m[e+12>>2]*p(32768));m[e+12>>2]=f;l=a;f=Qd(f);a:{if(p(q(f))<p(2147483648)){g=~~f;break a}g=-2147483648}n=l,o=Bc(g),h[n>>1]=o;a=a+2|0;b=b+4|0;d=d+ -1|0;if(d){continue}break}}Xa=e+16|0;return c<<2}function sKa(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,l=0,m=0;f=Xa-32|0;Xa=f;i[f+28>>2]=c;g=wb(b,c<<1);a:{if(!g){break a}kc(f+28|0,65535);Zf(a,k[f+28>>1]);l=f,m=Jb(a),i[l+16>>2]=m;l=f,m=Kb(a),i[l+8>>2]=m;if(!pb(f+16|0,f+8|0)){break a}while(1){a=i[f+16>>2];Pz(b,f+24|0);c=f+24|0;c=j[c|0]|j[c+1|0]<<8;c=(c<<24|c<<8&16711680)>>>16|0;h[a>>1]=c;b:{if((c|0)==(d|0)){c=65535}else{if((c|0)!=(e|0)){break b}c=65534}h[a>>1]=c}he(f+16|0);if(pb(f+16|0,f+8|0)){continue}break}}Xa=f+32|0;return g|0}function R9(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;b=Xa-32|0;Xa=b;a:{b:{if(Mh(a)){bo(b+24|0);break b}lm(b+8|0,a);i[114610]=0;D(2175,b+24|0,b+8|0);c=i[114610];i[114610]=0;if((c|0)==1){break a}We(b+8|0)}c=a+36|0;c:{if(Mh(a)){break c}c=i[b+24>>2]}a=i[a+8>>2];d:{if((a|0)==-1){e=b,f=Jb(c),i[e+8>>2]=f;e=b,f=Kb(c),i[e>>2]=f;if(!pb(b+8|0,b)){break d}while(1){d=n[i[b+8>>2]>>3]+d;dk(b+8|0);if(pb(b+8|0,b)){continue}break}break d}d=n[wc(c,a)>>3]}Ej(b+24|0);Xa=b+32|0;return+d}a=B()|0;A()|0;We(b+8|0);E(a|0);x()}function Uoa(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;c=Xa-16|0;Xa=c;i[c+8>>2]=b;d=i[a+8>>2];a:{if((i[a+480180>>2]==16384?1e4:32e4)>>>0<=b>>>0){b=i[a+480208>>2];kb(c,a+1074308|0,92);if((ib(c)|0)==((b&4096)>>>12|0)){break a}i[c>>2]=o(i[d+24>>2],1e4);g=a+1074420|0,h=i[rb(c+8|0,c)>>2],i[g>>2]=h;break a}if(j[a+480209|0]&16){break a}e=a+1074420|0;b=(b>>>0)/1e4|0;f=o(b&15,1e4);i[e>>2]=i[e>>2]+((b&240)==16?f:0-f|0);b=i[d+20>>2];d=i[d+24>>2];kb(c,a+1074308|0,8);wn(e,o(b,1e4),ib(c)?255e4:o(d,1e4))}Xa=c+16|0}function l7(a,b,c,d,e){var f=0,g=0,j=0,k=0,l=0,m=0,o=0,p=0,r=0,s=0;j=Xa-16|0;Xa=j;if(e){m=c+16|0;while(1){k=0;if(d){while(1){g=xd(n[Ig(b,k,l)>>3]*134217728);f=Ae(c,k);o=f;f=Ui(g)+(i[f>>2]>>1)|0;p=f;f=Xq(m)+f&-4096;i[o>>2]=p-f;n[j+8>>3]=+(f|0)*7.450580596923828e-9;mf(j+8|0,-1,1);g=n[j+8>>3]*32768;n[j+8>>3]=g;g=xd(g);a:{if(q(g)<2147483648){f=~~g;break a}f=-2147483648}f=Bc(f);r=gm(a,k,l),s=f,h[r>>1]=s;k=k+1|0;if((k|0)!=(d|0)){continue}break}}l=l+1|0;if((l|0)!=(e|0)){continue}break}}Xa=j+16|0}function kS(a,b,c){var d=0,e=0,f=0;d=Xa+ -64|0;Xa=d;Ce(b);De(d+40|0,a,c);a=i[d+40>>2];i[114610]=0;e=F(412,d+40|0)|0;f=i[114610];i[114610]=0;a:{if((f|0)==1){break a}i[114610]=0;e=F(413,e|0)|0;f=i[114610];i[114610]=0;if((f|0)==1){break a}i[114610]=0;J(414,d+8|0,3,e|0,a|0);e=i[114610];i[114610]=0;if((e|0)==1){break a}i[114610]=0;D(415,d+24|0,d+8|0);e=i[114610];i[114610]=0;if((e|0)==1){break a}mb(b,d+24|0);eb(d+24|0);jc(d+40|0);Xa=d- -64|0;return!c|(a|0)!=0}a=B()|0;A()|0;jc(d+40|0);E(a|0);x()}function jM(a,b){var c=0,d=0,e=0,f=0,g=0,l=0,m=0,n=0,p=0,q=0;m=b?33:32;e=i[a+12>>2];g=i[a>>2]+o(e,62)|0;d=b?1:-1;n=o(e,d)<<1;f=i[a+8>>2]+ -1|0;c=f;while(1){if((e|0)>=1){p=o(c,e);q=i[a+4>>2];b=0;while(1){h[(b<<1)+g>>1]=k[(b+p<<1)+q>>1];b=b+1|0;if((e|0)!=(b|0)){continue}break}}a:{if(!((c|0)!=(f|0)|(d|0)<=0)){if(!j[a+16|0]){d=1;c=0;break a}d=-1;c=f-((f|0)!=0&j[a+17|0]!=0)|0;break a}if(!((d|0)>-1|c)){b=j[a+16|0];d=b?1:-1;c=b?0:f;break a}c=d+c|0}g=g+n|0;l=l+1|0;if((m|0)!=(l|0)){continue}break}}function g2(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=Xa-16|0;Xa=e;a:{b:{c:{d:{if((a|0)!=(b|0)){e:{f:{f=j[a|0];if((f|0)!=45){break f}a=a+1|0;if((b|0)!=(a|0)){break f}break e}h=i[114584];i[114584]=0;a=Qu(a,e+12|0,d,Ud());d=_a;g=i[114584];g:{if(g){if(i[e+12>>2]!=(b|0)){break g}if((g|0)==68){break c}break d}i[114584]=h;if(i[e+12>>2]==(b|0)){break d}}}}i[c>>2]=4;a=0;break a}if(!d&a>>>0<=65535|d>>>0<0){break b}}i[c>>2]=4;a=65535;break a}a=(f|0)==45?0-a|0:a}Xa=e+16|0;return a&65535}function O7(a,b,c,d,e){var f=0,g=0,j=0,k=0,l=0,m=0,o=0,p=0,r=0,s=0;j=Xa-16|0;Xa=j;if(e){m=c+16|0;while(1){k=0;if(d){while(1){g=xd(n[Ig(b,k,l)>>3]*134217728);f=Ae(c,k);o=f;f=Ui(g)+(i[f>>2]>>1)|0;p=f;f=Xq(m)+f&-4096;i[o>>2]=p-f;n[j+8>>3]=+(f|0)*7.450580596923828e-9;mf(j+8|0,-1,1);g=n[j+8>>3]*32768;n[j+8>>3]=g;g=xd(g);a:{if(q(g)<2147483648){f=~~g;break a}f=-2147483648}f=Bc(f);r=im(a,k,l),s=f,h[r>>1]=s;k=k+1|0;if((k|0)!=(d|0)){continue}break}}l=l+1|0;if((l|0)!=(e|0)){continue}break}}Xa=j+16|0}function KR(a,b,c){var d=0,e=0,f=0;d=Xa+ -64|0;Xa=d;Ce(b);De(d+40|0,a,c);a=i[d+40>>2];i[114610]=0;e=F(412,d+40|0)|0;f=i[114610];i[114610]=0;a:{if((f|0)==1){break a}i[114610]=0;e=F(413,e|0)|0;f=i[114610];i[114610]=0;if((f|0)==1){break a}i[114610]=0;J(414,d+8|0,2,e|0,a|0);e=i[114610];i[114610]=0;if((e|0)==1){break a}i[114610]=0;D(415,d+24|0,d+8|0);e=i[114610];i[114610]=0;if((e|0)==1){break a}mb(b,d+24|0);eb(d+24|0);jc(d+40|0);Xa=d- -64|0;return!c|(a|0)!=0}a=B()|0;A()|0;jc(d+40|0);E(a|0);x()}function Tl(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0;j=Xa-16|0;Xa=j;a:{b:{if(!a){break b}h=i[e+12>>2];g=c-b|0;if((g|0)>=1){g=g>>2;if((wl(a,b,g)|0)!=(g|0)){break b}}b=d-b>>2;b=(h|0)>(b|0)?h-b|0:0;if((b|0)>=1){f=iD(j,b,f);h=xb(f);i[114610]=0;h=I(2477,a|0,h|0,b|0)|0;g=i[114610];i[114610]=0;if((g|0)==1){break a}nc(f);if((b|0)!=(h|0)){break b}}b=d-c|0;if((b|0)>=1){b=b>>2;if((wl(a,c,b)|0)!=(b|0)){break b}}$x(e);k=a}Xa=j+16|0;return k|0}a=B()|0;A()|0;nc(f);E(a|0);x()}function b1(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0;a=Xa-32|0;Xa=a;i[a+24>>2]=37;i[a+28>>2]=0;tj(a+24|1,62150,1,i[c+4>>2]);h=i[c+4>>2];g=a+ -32|0;Xa=g;j=Ud();i[a>>2]=e;i[a+4>>2]=f;e=h>>>9&1;f=Je(g,e+23|0,j,a+24|0,a)+g|0;h=Of(g,f,c);e=g-((e<<3)+187&240)|0;Xa=e;fc(a+8|0,c);i[114610]=0;X(2474,g|0,h|0,f|0,e|0,a+20|0,a+16|0,a+8|0);f=i[114610];i[114610]=0;if((f|0)!=1){ub(a+8|0);b=Tl(b,e,i[a+20>>2],i[a+16>>2],c,d);Xa=a+32|0;return b|0}b=B()|0;A()|0;ub(a+8|0);E(b|0);x()}function _G(a){var b=p(0),c=p(0),d=p(0),e=p(0),f=p(0),g=0;VK(a+4208|0,m[a+4272>>2]);b=p(p(m[a+4208>>2]*p(15920))+p(80));g=we(i[a+16>>2]);c=Wd(p(10),p(p(p(m[a+4216>>2]*p(30))+p(-15))*p(.02500000037252903)));b=p(p(b*p(6.2831854820251465))/p(g>>>0));d=LE(b);e=Yn(b);d=p(d*S4(p(p(p(b*p(.02888113260269165))*p(p(m[a+4212>>2]*p(35))+p(1)))/d)));f=p(d/c);b=p(f+p(1));m[a+4236>>2]=p(p(1)-f)/b;e=p(p(e*p(-2))/b);m[a+4232>>2]=e;c=p(d*c);m[a+4228>>2]=p(p(1)-c)/b;m[a+4224>>2]=e;m[a+4220>>2]=p(c+p(1))/b}function HW(a){a=a|0;var b=0,c=0,d=0,e=0;b=Xa-32|0;Xa=b;c=Bb(b,7035);i[114610]=0;G(226,b+16|0,a|0,c|0);a=i[114610];i[114610]=0;a:{b:{c:{if((a|0)!=1){eb(c);if(cc(b+16|0)){break c}a=0;break a}d=B()|0;A()|0;eb(c);break b}a=0;while(1){d:{c=Yc(b+16|0,d);i[114610]=0;c=F(227,c|0)|0;e=i[114610];i[114610]=0;if((e|0)==1){break d}a=(c&255)<<24-(d<<3)|a;c=cc(b+16|0);if(d>>>0>2){break a}d=d+1|0;if(d>>>0<c>>>0){continue}break a}break}d=B()|0;A()|0;Ok(b+16|0)}E(d|0);x()}Ok(b+16|0);Xa=b+32|0;return a|0}function $0(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0;a=Xa-32|0;Xa=a;i[a+24>>2]=37;i[a+28>>2]=0;tj(a+24|1,62150,0,i[c+4>>2]);h=i[c+4>>2];g=a+ -32|0;Xa=g;j=Ud();i[a>>2]=e;i[a+4>>2]=f;e=h>>>9&1;f=Je(g,e+23|0,j,a+24|0,a)+g|0;h=Of(g,f,c);e=g-((e<<3)+187&240)|0;Xa=e;fc(a+8|0,c);i[114610]=0;X(2474,g|0,h|0,f|0,e|0,a+20|0,a+16|0,a+8|0);f=i[114610];i[114610]=0;if((f|0)!=1){ub(a+8|0);b=Tl(b,e,i[a+20>>2],i[a+16>>2],c,d);Xa=a+32|0;return b|0}b=B()|0;A()|0;ub(a+8|0);E(b|0);x()}function MMa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=sh(b,11882);a:{if(!e){break a}if(!wb(b,6)){break a}while(1){b:{d=Cf(b);c:{if((d|0)==(mk(11887)|0)){break c}c=j[11892]|j[11893]<<8|(j[11894]<<16|j[11895]<<24);if(!(d&1616928864)|d&-2139062144){break c}if((c|0)!=(d|0)){break b}}tg(b,4);break a}c=1;g=_f(b);if(k[a+480192>>1]){while(1){f=i[(((c&65535)<<2)+a|0)+900380>>2];if(f){OMa(f,d,g,b)}c=c+1|0;if((c&65535)>>>0<=k[a+480192>>1]){continue}break}}if(wb(b,6)){continue}break}}return e|0}function _va(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,j=0,k=0,l=0;b=Xa-16|0;Xa=b;j=i[a+24>>2];k=i[a+20>>2];l=i[a+16>>2];f=i[a+4>>2];e=f;g=i[a>>2];i[b+8>>2]=g;i[b+12>>2]=e;f=i[a+12>>2];i[b>>2]=i[a+8>>2];i[b+4>>2]=f;if(d){while(1){f=(e<<1)+l|0;e=h[f>>1];e=e+((o(h[f+2>>1]-e|0,g>>>18|0)|0)/16384|0)|0;i[c>>2]=i[c>>2]+o(e,k);i[c+4>>2]=i[c+4>>2]+o(e,j);zb(b+8|0,b);d=d+ -1|0;if(d){c=c+8|0;g=i[b+8>>2];e=i[b+12>>2];continue}break}g=i[b+8>>2];e=i[b+12>>2]}i[a>>2]=g;i[a+4>>2]=e;Xa=b+16|0}function $va(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,h=0,j=0,k=0,l=0;b=Xa-16|0;Xa=b;j=i[a+24>>2];k=i[a+20>>2];l=i[a+16>>2];f=i[a+4>>2];e=f;h=i[a>>2];i[b+8>>2]=h;i[b+12>>2]=e;f=i[a+12>>2];i[b>>2]=i[a+8>>2];i[b+4>>2]=f;if(d){while(1){f=e+l|0;e=g[f|0];e=((o(g[f+1|0]-e|0,h>>>18|0)<<8)/16384|0)+(e<<8)|0;i[c>>2]=i[c>>2]+o(e,k);i[c+4>>2]=i[c+4>>2]+o(e,j);zb(b+8|0,b);d=d+ -1|0;if(d){c=c+8|0;h=i[b+8>>2];e=i[b+12>>2];continue}break}h=i[b+8>>2];e=i[b+12>>2]}i[a>>2]=h;i[a+4>>2]=e;Xa=b+16|0}function M5(a,b,c,d,e,f){var g=0,h=0,k=0,l=p(0),n=0,o=0,q=p(0),r=p(0),s=0;h=j[c|0];if(h){s=j[d+1|0]&8?7:64;n=c;while(1){o=j[d+3|0]&32;a:{b:{if((k|0)<=i[((k>>>0)%3<<2)+e>>2]){break b}g=j[b+k|0];if(s>>>0<=g>>>0){break b}q=o?p(1.4142135381698608):p(1);c:{if(j[d+1|0]&8){g=g<<3;l=m[g+48608>>2];r=m[(g|4)+48608>>2];break c}l=Cv(p(1),g+1>>>1<<f);g=g&1;r=g?p(1):l;l=g?l:p(1)}K5(a,h,p(l*q),p(r*q));break a}if(!o){break a}eF(a,h)}a=(j[n|0]<<2)+a|0;k=k+1|0;n=k+c|0;h=j[n|0];if(h){continue}break}}}function nwa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,j=0,k=0,l=0;b=Xa-16|0;Xa=b;g=i[a+24>>2];j=i[a+20>>2];k=i[a+16>>2];e=i[a+4>>2];f=i[a>>2];i[b+8>>2]=f;i[b+12>>2]=e;l=i[a+12>>2];i[b>>2]=i[a+8>>2];i[b+4>>2]=l;if(d){while(1){e=((((e&2147483647)<<1|f>>>31)&2147483646)<<1)+k|0;f=h[e+2>>1];i[c>>2]=i[c>>2]+o(h[e>>1],j);i[c+4>>2]=i[c+4>>2]+o(f,g);zb(b+8|0,b);d=d+ -1|0;if(d){c=c+8|0;f=i[b+8>>2];e=i[b+12>>2];continue}break}f=i[b+8>>2];e=i[b+12>>2]}i[a>>2]=f;i[a+4>>2]=e;Xa=b+16|0}function nda(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0;i[114610]=0;L(2015,a|0);h=i[114610];i[114610]=0;a:{b:{if((h|0)!=1){h=i[a+24>>2];i[114610]=0;b=ga(2032,h|0,b|0,c|0,d|0,e|0,f|0,g|0)|0;c=i[114610];i[114610]=0;if((c|0)!=1){break b}}b=H(0)|0;A()|0;M(b|0)|0;i[114610]=0;J(1989,35330,a|0,0,0);a=i[114610];i[114610]=0;if((a|0)==1){break a}O();b=0}return b|0}a=B()|0;A()|0;i[114610]=0;K(20);b=i[114610];i[114610]=0;if((b|0)!=1){E(a|0);x()}a=H(0)|0;A()|0;gb(a);x()}function kda(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0;i[114610]=0;L(2015,a|0);h=i[114610];i[114610]=0;a:{b:{if((h|0)!=1){h=i[a+24>>2];i[114610]=0;b=ga(2035,h|0,b|0,c|0,d|0,e|0,f|0,g|0)|0;c=i[114610];i[114610]=0;if((c|0)!=1){break b}}b=H(0)|0;A()|0;M(b|0)|0;i[114610]=0;J(1989,35419,a|0,0,0);a=i[114610];i[114610]=0;if((a|0)==1){break a}O();b=0}return b|0}a=B()|0;A()|0;i[114610]=0;K(20);b=i[114610];i[114610]=0;if((b|0)!=1){E(a|0);x()}a=H(0)|0;A()|0;gb(a);x()}function Iqa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,h=0,k=0,l=0,m=0;d=Xa-16|0;Xa=d;i[d+12>>2]=c;i[d+8>>2]=i[a>>2];h=i[rb(d+8|0,d+12|0)>>2];i[d+8>>2]=i[a>>2];i[d+4>>2]=i[d+12>>2]-h;k=i[rb(d+8|0,d+4|0)>>2];c=jb(b);if(h){e=i[a+20>>2];f=h;while(1){l=e,m=jb(j[c|0])^128,g[l|0]=m;e=e+2|0;c=c+1|0;f=f+ -1|0;if(f){continue}break}}b=jb(b);if(k){c=b+i[a>>2]|0;e=i[a+20>>2]+1|0;f=k;while(1){l=e,m=jb(j[c|0])^128,g[l|0]=m;e=e+2|0;c=c+1|0;f=f+ -1|0;if(f){continue}break}}Xa=d+16|0;return h+k|0}function Hqa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,h=0,k=0,l=0,m=0;e=Xa-16|0;Xa=e;i[e+12>>2]=c;i[e+8>>2]=i[a>>2];k=i[rb(e+8|0,e+12|0)>>2];i[e+8>>2]=i[a>>2];i[e+4>>2]=i[e+12>>2]-k;l=i[rb(e+8|0,e+4|0)>>2];c=jb(b);if(k){f=i[a+20>>2];h=k;m=d;while(1){m=jb(j[c|0])+m|0;g[f|0]=m;f=f+2|0;c=c+1|0;h=h+ -1|0;if(h){continue}break}}b=jb(b);if(l){c=b+i[a>>2]|0;f=i[a+20>>2]+1|0;h=l;while(1){d=jb(j[c|0])+d|0;g[f|0]=d;f=f+2|0;c=c+1|0;h=h+ -1|0;if(h){continue}break}}Xa=e+16|0;return k+l|0}function owa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,h=0,j=0,k=0,l=0;b=Xa-16|0;Xa=b;h=i[a+24>>2];j=i[a+20>>2];k=i[a+16>>2];e=i[a+4>>2];f=i[a>>2];i[b+8>>2]=f;i[b+12>>2]=e;l=i[a+12>>2];i[b>>2]=i[a+8>>2];i[b+4>>2]=l;if(d){while(1){e=(((e&2147483647)<<1|f>>>31)&-2)+k|0;f=g[e+1|0];i[c>>2]=i[c>>2]+(o(g[e|0],j)<<8);i[c+4>>2]=i[c+4>>2]+(o(f,h)<<8);zb(b+8|0,b);d=d+ -1|0;if(d){c=c+8|0;f=i[b+8>>2];e=i[b+12>>2];continue}break}f=i[b+8>>2];e=i[b+12>>2]}i[a>>2]=f;i[a+4>>2]=e;Xa=b+16|0}function dca(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=+d;e=+e;var f=0,g=0;i[114610]=0;L(2088,a|0);f=i[114610];i[114610]=0;a:{b:{if((f|0)!=1){f=i[a+28>>2];g=i[i[f>>2]+72>>2];i[114610]=0;b=Pa(g|0,f|0,b|0,c|0,+d,+e)|0;c=i[114610];i[114610]=0;if((c|0)!=1){break b}}b=H(0)|0;A()|0;M(b|0)|0;i[114610]=0;J(1989,38032,a|0,0,0);a=i[114610];i[114610]=0;if((a|0)==1){break a}O();b=-1}return b|0}a=B()|0;A()|0;i[114610]=0;K(20);b=i[114610];i[114610]=0;if((b|0)!=1){E(a|0);x()}a=H(0)|0;A()|0;gb(a);x()}function o1(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0;a=Xa-32|0;Xa=a;i[a+24>>2]=37;i[a+28>>2]=0;tj(a+24|1,62150,1,i[c+4>>2]);h=i[c+4>>2];g=a+ -32|0;Xa=g;j=Ud();i[a>>2]=e;i[a+4>>2]=f;f=Je(g,(h>>>9&1)+23|0,j,a+24|0,a)+g|0;h=Of(g,f,c);e=g+ -48|0;Xa=e;fc(a+8|0,c);i[114610]=0;X(2465,g|0,h|0,f|0,e|0,a+20|0,a+16|0,a+8|0);f=i[114610];i[114610]=0;if((f|0)!=1){ub(a+8|0);b=xl(b,e,i[a+20>>2],i[a+16>>2],c,d);Xa=a+32|0;return b|0}b=B()|0;A()|0;ub(a+8|0);E(b|0);x()}function m1(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0;a=Xa-32|0;Xa=a;i[a+24>>2]=37;i[a+28>>2]=0;tj(a+24|1,62150,0,i[c+4>>2]);h=i[c+4>>2];g=a+ -32|0;Xa=g;j=Ud();i[a>>2]=e;i[a+4>>2]=f;f=Je(g,(h>>>9&1)+23|0,j,a+24|0,a)+g|0;h=Of(g,f,c);e=g+ -48|0;Xa=e;fc(a+8|0,c);i[114610]=0;X(2465,g|0,h|0,f|0,e|0,a+20|0,a+16|0,a+8|0);f=i[114610];i[114610]=0;if((f|0)!=1){ub(a+8|0);b=xl(b,e,i[a+20>>2],i[a+16>>2],c,d);Xa=a+32|0;return b|0}b=B()|0;A()|0;ub(a+8|0);E(b|0);x()}function Pq(a,b,c){var d=0,e=0;d=(c|0)!=0;a:{b:{c:{if(!c|!(a&3)){break c}e=b&255;while(1){if((e|0)==j[a|0]){break b}a=a+1|0;c=c+ -1|0;d=(c|0)!=0;if(!c){break c}if(a&3){continue}break}}if(!d){break a}}d:{if(j[a|0]==(b&255)|c>>>0<4){break d}d=o(b&255,16843009);while(1){e=d^i[a>>2];if((e^-1)&e+ -16843009&-2139062144){break d}a=a+4|0;c=c+ -4|0;if(c>>>0>3){continue}break}}if(!c){break a}b=b&255;while(1){if((b|0)==j[a|0]){return a}a=a+1|0;c=c+ -1|0;if(c){continue}break}}return 0}function s3(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,h=0;d=Xa-32|0;Xa=d;i[d+16>>2]=b;e=i[a+48>>2];i[d+20>>2]=c-((e|0)!=0);f=i[a+44>>2];i[d+28>>2]=e;i[d+24>>2]=f;a:{b:{c:{if(Jq(Ia(i[a+60>>2],d+16|0,2,d+12|0)|0)){i[d+12>>2]=-1;c=-1;break c}e=i[d+12>>2];if((e|0)>0){break b}c=e}i[a>>2]=i[a>>2]|c&48^16;break a}h=i[d+20>>2];if(e>>>0<=h>>>0){c=e;break a}f=i[a+44>>2];i[a+4>>2]=f;i[a+8>>2]=f+(e-h|0);if(!i[a+48>>2]){break a}i[a+4>>2]=f+1;g[(b+c|0)+ -1|0]=j[f|0]}Xa=d+32|0;return c|0}function O$(a,b,c){var d=0,e=0,f=0,g=0;f=Xa-16|0;Xa=f;d=lb(a);e=iq(a);g=Fs(b,c);a:{if(!g){break a}if(iz(b,xb(a),xb(a)+(lb(a)<<2)|0)){d=Xa-16|0;Xa=d;oD(f,b,c);Xa=d+16|0;b=f;c=xb(b);d=lb(b);i[114610]=0;I(2500,a|0,c|0,d|0)|0;c=i[114610];i[114610]=0;if((c|0)!=1){nc(b);break a}a=B()|0;A()|0;nc(b);E(a|0);x()}if(e-d>>>0<g>>>0){ZB(a,e,(d+g|0)-e|0,d,d)}e=xb(a)+(d<<2)|0;while(1){if((b|0)!=(c|0)){ye(e,b);b=b+4|0;e=e+4|0;continue}break}i[f>>2]=0;ye(e,f);yg(a,d+g|0)}Xa=f+16|0;return a}function xl(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0;j=Xa-16|0;Xa=j;a:{b:{if(!a){break b}g=i[e+12>>2];h=c-b|0;if((h|0)>=1){if((wl(a,b,h)|0)!=(h|0)){break b}}b=d-b|0;b=(g|0)>(b|0)?g-b|0:0;if((b|0)>=1){f=ej(j,b,f);g=xb(f);i[114610]=0;g=I(28,a|0,g|0,b|0)|0;h=i[114610];i[114610]=0;if((h|0)==1){break a}eb(f);if((b|0)!=(g|0)){break b}}b=d-c|0;if((b|0)>=1){if((wl(a,c,b)|0)!=(b|0)){break b}}$x(e);k=a}Xa=j+16|0;return k|0}a=B()|0;A()|0;eb(f);E(a|0);x()}function xba(a){var b=0,c=0,d=0;b=Xa-160|0;Xa=b;c=Bb(b+120|0,38163);i[114610]=0;D(2116,b+104|0,20665);d=i[114610];i[114610]=0;a:{b:{c:{d:{e:{if((d|0)!=1){i[114610]=0;G(3,b+136|0,c|0,b+104|0);d=i[114610];i[114610]=0;if((d|0)==1){break e}i[114610]=0;T(2117,b+88|0,a|0,1,38156,b+136|0);a=i[114610];i[114610]=0;if((a|0)==1){break d}eb(b+136|0);eb(b+104|0);break a}a=B()|0;A()|0;break b}a=B()|0;A()|0;break c}a=B()|0;A()|0;eb(b+136|0)}eb(b+104|0)}eb(c);E(a|0);x()}eb(c);Xa=b+160|0}function gma(a,b){a=a|0;b=b|0;var c=0;b=78352;ema(a);a:{while(1){b:{if(!Uc(a)){if(!Ih(i[b+8>>2],i[Qi(a)>>2])){break b}}i[114610]=0;D(1516,a|0,b+8|0);c=i[114610];i[114610]=0;if((c|0)!=1){break b}break a}b=b+12|0;if((b|0)!=78868){continue}break}b=78880;while(1){c:{if(!Uc(a)){if(!Ih(i[b+8>>2],i[Qi(a)>>2])){break c}}i[114610]=0;D(1516,a|0,b+8|0);c=i[114610];i[114610]=0;if((c|0)!=1){break c}break a}b=b+12|0;if((b|0)!=78928){continue}break}return}b=B()|0;A()|0;Nw(a);E(b|0);x()}function Y7(a,b){var c=0,d=0,e=0,f=0;c=Xa-80|0;Xa=c;d=i[a>>2];f=i[d+4>>2];e=i[d+24>>2];i[c+40>>2]=i[d+20>>2];i[c+44>>2]=e;e=i[d+16>>2];i[c+32>>2]=i[d+12>>2];i[c+36>>2]=e;gh(c- -64|0,c+32|0,f);d=Vd(c+48|0,i[i[a+4>>2]>>2],i[i[a+8>>2]>>2],i[i[a+12>>2]>>2]);f=i[i[a+12>>2]>>2];a=i[i[a+8>>2]>>2];e=i[c+76>>2];i[c+24>>2]=i[c+72>>2];i[c+28>>2]=e;e=i[c+68>>2];i[c+16>>2]=i[c+64>>2];i[c+20>>2]=e;i[c+8>>2]=i[d+8>>2];e=i[d+4>>2];i[c>>2]=i[d>>2];i[c+4>>2]=e;W7(c+16|0,c,b,a,f);Xa=c+80|0}function X7(a,b){var c=0,d=0,e=0,f=0;c=Xa-80|0;Xa=c;d=i[a>>2];f=i[d+4>>2];e=i[d+24>>2];i[c+40>>2]=i[d+20>>2];i[c+44>>2]=e;e=i[d+16>>2];i[c+32>>2]=i[d+12>>2];i[c+36>>2]=e;gh(c- -64|0,c+32|0,f);d=Vd(c+48|0,i[i[a+4>>2]>>2],i[i[a+8>>2]>>2],i[i[a+12>>2]>>2]);f=i[i[a+12>>2]>>2];a=i[i[a+8>>2]>>2];e=i[c+76>>2];i[c+24>>2]=i[c+72>>2];i[c+28>>2]=e;e=i[c+68>>2];i[c+16>>2]=i[c+64>>2];i[c+20>>2]=e;i[c+8>>2]=i[d+8>>2];e=i[d+4>>2];i[c>>2]=i[d>>2];i[c+4>>2]=e;U7(c+16|0,c,b,a,f);Xa=c+80|0}function Wq(a,b){var c=0,d=0,e=0,f=0;c=Xa-80|0;Xa=c;d=i[a>>2];f=i[d+4>>2];e=i[d+24>>2];i[c+40>>2]=i[d+20>>2];i[c+44>>2]=e;e=i[d+16>>2];i[c+32>>2]=i[d+12>>2];i[c+36>>2]=e;gh(c- -64|0,c+32|0,f);d=Vd(c+48|0,i[i[a+4>>2]>>2],i[i[a+8>>2]>>2],i[i[a+12>>2]>>2]);f=i[i[a+12>>2]>>2];a=i[i[a+8>>2]>>2];e=i[c+76>>2];i[c+24>>2]=i[c+72>>2];i[c+28>>2]=e;e=i[c+68>>2];i[c+16>>2]=i[c+64>>2];i[c+20>>2]=e;i[c+8>>2]=i[d+8>>2];e=i[d+4>>2];i[c>>2]=i[d>>2];i[c+4>>2]=e;I7(c+16|0,c,b,a,f);Xa=c+80|0}function S7(a,b){var c=0,d=0,e=0,f=0;c=Xa-80|0;Xa=c;d=i[a>>2];f=i[d+4>>2];e=i[d+24>>2];i[c+40>>2]=i[d+20>>2];i[c+44>>2]=e;e=i[d+16>>2];i[c+32>>2]=i[d+12>>2];i[c+36>>2]=e;gh(c- -64|0,c+32|0,f);d=Vd(c+48|0,i[i[a+4>>2]>>2],i[i[a+8>>2]>>2],i[i[a+12>>2]>>2]);f=i[i[a+12>>2]>>2];a=i[i[a+8>>2]>>2];e=i[c+76>>2];i[c+24>>2]=i[c+72>>2];i[c+28>>2]=e;e=i[c+68>>2];i[c+16>>2]=i[c+64>>2];i[c+20>>2]=e;i[c+8>>2]=i[d+8>>2];e=i[d+4>>2];i[c>>2]=i[d>>2];i[c+4>>2]=e;Q7(c+16|0,c,b,a,f);Xa=c+80|0}function R7(a,b){var c=0,d=0,e=0,f=0;c=Xa-80|0;Xa=c;d=i[a>>2];f=i[d+4>>2];e=i[d+24>>2];i[c+40>>2]=i[d+20>>2];i[c+44>>2]=e;e=i[d+16>>2];i[c+32>>2]=i[d+12>>2];i[c+36>>2]=e;gh(c- -64|0,c+32|0,f);d=Vd(c+48|0,i[i[a+4>>2]>>2],i[i[a+8>>2]>>2],i[i[a+12>>2]>>2]);f=i[i[a+12>>2]>>2];a=i[i[a+8>>2]>>2];e=i[c+76>>2];i[c+24>>2]=i[c+72>>2];i[c+28>>2]=e;e=i[c+68>>2];i[c+16>>2]=i[c+64>>2];i[c+20>>2]=e;i[c+8>>2]=i[d+8>>2];e=i[d+4>>2];i[c>>2]=i[d>>2];i[c+4>>2]=e;O7(c+16|0,c,b,a,f);Xa=c+80|0}function Ov(a,b){var c=0,d=0,e=0,f=0;c=Xa-80|0;Xa=c;d=i[a>>2];f=i[d+4>>2];e=i[d+24>>2];i[c+40>>2]=i[d+20>>2];i[c+44>>2]=e;e=i[d+16>>2];i[c+32>>2]=i[d+12>>2];i[c+36>>2]=e;gh(c- -64|0,c+32|0,f);d=Vd(c+48|0,i[i[a+4>>2]>>2],i[i[a+8>>2]>>2],i[i[a+12>>2]>>2]);f=i[i[a+12>>2]>>2];a=i[i[a+8>>2]>>2];e=i[c+76>>2];i[c+24>>2]=i[c+72>>2];i[c+28>>2]=e;e=i[c+68>>2];i[c+16>>2]=i[c+64>>2];i[c+20>>2]=e;i[c+8>>2]=i[d+8>>2];e=i[d+4>>2];i[c>>2]=i[d>>2];i[c+4>>2]=e;V7(c+16|0,c,b,a,f);Xa=c+80|0}function Nv(a,b){var c=0,d=0,e=0,f=0;c=Xa-80|0;Xa=c;d=i[a>>2];f=i[d+4>>2];e=i[d+24>>2];i[c+40>>2]=i[d+20>>2];i[c+44>>2]=e;e=i[d+16>>2];i[c+32>>2]=i[d+12>>2];i[c+36>>2]=e;gh(c- -64|0,c+32|0,f);d=Vd(c+48|0,i[i[a+4>>2]>>2],i[i[a+8>>2]>>2],i[i[a+12>>2]>>2]);f=i[i[a+12>>2]>>2];a=i[i[a+8>>2]>>2];e=i[c+76>>2];i[c+24>>2]=i[c+72>>2];i[c+28>>2]=e;e=i[c+68>>2];i[c+16>>2]=i[c+64>>2];i[c+20>>2]=e;i[c+8>>2]=i[d+8>>2];e=i[d+4>>2];i[c>>2]=i[d>>2];i[c+4>>2]=e;P7(c+16|0,c,b,a,f);Xa=c+80|0}function Mv(a,b){var c=0,d=0,e=0,f=0;c=Xa-80|0;Xa=c;d=i[a>>2];f=i[d+4>>2];e=i[d+24>>2];i[c+40>>2]=i[d+20>>2];i[c+44>>2]=e;e=i[d+16>>2];i[c+32>>2]=i[d+12>>2];i[c+36>>2]=e;gh(c- -64|0,c+32|0,f);d=Vd(c+48|0,i[i[a+4>>2]>>2],i[i[a+8>>2]>>2],i[i[a+12>>2]>>2]);f=i[i[a+12>>2]>>2];a=i[i[a+8>>2]>>2];e=i[c+76>>2];i[c+24>>2]=i[c+72>>2];i[c+28>>2]=e;e=i[c+68>>2];i[c+16>>2]=i[c+64>>2];i[c+20>>2]=e;i[c+8>>2]=i[d+8>>2];e=i[d+4>>2];i[c>>2]=i[d>>2];i[c+4>>2]=e;C7(c+16|0,c,b,a,f);Xa=c+80|0}function J7(a,b){var c=0,d=0,e=0,f=0;c=Xa-80|0;Xa=c;d=i[a>>2];f=i[d+4>>2];e=i[d+24>>2];i[c+40>>2]=i[d+20>>2];i[c+44>>2]=e;e=i[d+16>>2];i[c+32>>2]=i[d+12>>2];i[c+36>>2]=e;gh(c- -64|0,c+32|0,f);d=Vd(c+48|0,i[i[a+4>>2]>>2],i[i[a+8>>2]>>2],i[i[a+12>>2]>>2]);f=i[i[a+12>>2]>>2];a=i[i[a+8>>2]>>2];e=i[c+76>>2];i[c+24>>2]=i[c+72>>2];i[c+28>>2]=e;e=i[c+68>>2];i[c+16>>2]=i[c+64>>2];i[c+20>>2]=e;i[c+8>>2]=i[d+8>>2];e=i[d+4>>2];i[c>>2]=i[d>>2];i[c+4>>2]=e;H7(c+16|0,c,b,a,f);Xa=c+80|0}function G7(a,b){var c=0,d=0,e=0,f=0;c=Xa-80|0;Xa=c;d=i[a>>2];f=i[d+4>>2];e=i[d+24>>2];i[c+40>>2]=i[d+20>>2];i[c+44>>2]=e;e=i[d+16>>2];i[c+32>>2]=i[d+12>>2];i[c+36>>2]=e;gh(c- -64|0,c+32|0,f);d=Vd(c+48|0,i[i[a+4>>2]>>2],i[i[a+8>>2]>>2],i[i[a+12>>2]>>2]);f=i[i[a+12>>2]>>2];a=i[i[a+8>>2]>>2];e=i[c+76>>2];i[c+24>>2]=i[c+72>>2];i[c+28>>2]=e;e=i[c+68>>2];i[c+16>>2]=i[c+64>>2];i[c+20>>2]=e;i[c+8>>2]=i[d+8>>2];e=i[d+4>>2];i[c>>2]=i[d>>2];i[c+4>>2]=e;D7(c+16|0,c,b,a,f);Xa=c+80|0}function F7(a,b){var c=0,d=0,e=0,f=0;c=Xa-80|0;Xa=c;d=i[a>>2];f=i[d+4>>2];e=i[d+24>>2];i[c+40>>2]=i[d+20>>2];i[c+44>>2]=e;e=i[d+16>>2];i[c+32>>2]=i[d+12>>2];i[c+36>>2]=e;gh(c- -64|0,c+32|0,f);d=Vd(c+48|0,i[i[a+4>>2]>>2],i[i[a+8>>2]>>2],i[i[a+12>>2]>>2]);f=i[i[a+12>>2]>>2];a=i[i[a+8>>2]>>2];e=i[c+76>>2];i[c+24>>2]=i[c+72>>2];i[c+28>>2]=e;e=i[c+68>>2];i[c+16>>2]=i[c+64>>2];i[c+20>>2]=e;i[c+8>>2]=i[d+8>>2];e=i[d+4>>2];i[c>>2]=i[d>>2];i[c+4>>2]=e;B7(c+16|0,c,b,a,f);Xa=c+80|0}function Jqa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,h=0,k=0,l=0,m=0;d=Xa-16|0;Xa=d;i[d+12>>2]=c;i[d+8>>2]=i[a>>2];h=i[rb(d+8|0,d+12|0)>>2];i[d+8>>2]=i[a>>2];i[d+4>>2]=i[d+12>>2]-h;k=i[rb(d+8|0,d+4|0)>>2];c=jb(b);if(h){e=i[a+20>>2];f=h;while(1){l=e,m=Em(j[c|0]),g[l|0]=m;e=e+2|0;c=c+1|0;f=f+ -1|0;if(f){continue}break}}b=jb(b);if(k){c=b+i[a>>2]|0;e=i[a+20>>2]+1|0;f=k;while(1){l=e,m=Em(j[c|0]),g[l|0]=m;e=e+2|0;c=c+1|0;f=f+ -1|0;if(f){continue}break}}Xa=d+16|0;return h+k|0}function xQ(a,b){a=a|0;b=b|0;var c=0,d=0;d=j[a+3|0];a:{if(d>>>0>18){break a}d=1<<d;b:{if(!(d&126991)){if(d&396800){break b}break a}if(!j[a|0]){break a}}c:{d:{switch(j[a+3|0]){case 10:case 17:case 18:c=8;break c;case 0:case 1:case 2:case 3:case 12:case 13:case 14:case 15:case 16:c=j[a|0];if(!(c&7)){break c};case 11:c=j[a+3|0];return o(bz(a),b+1>>>1|0)+(((c|0)==11)<<4)|0;case 9:break d;default:break c}}c=16}d=j[a+3|0];c=o(bz(a),o(c>>>3|0,b))+(((d|0)==11)<<4)|0}return c|0}function nna(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=Xa-32|0;Xa=c;a:{if((b+ -1&65535)>>>0>3998){break a}f=1;e=(o(b,104)+a|0)+484380|0;if(!ie(e)){break a}g=a+1304360|0;d=a+1074984|0;while(1){if(i[d+104>>2]==(e|0)){i[d+76>>2]=0;i[d>>2]=0;i[d+4>>2]=0;i[d+16>>2]=0}d=d+896|0;if((g|0)!=(d|0)){continue}break}Om(e);i[e>>2]=0;a=(o(b,104)+a|0)+484414|0;h[a>>1]=k[a>>1]&65470;i[c+24>>2]=0;i[c+8>>2]=0;i[c+16>>2]=0;i[c+20>>2]=0;i[c>>2]=0;i[c+4>>2]=0;No(e,0,c)}Xa=c+32|0;return f|0}function mD(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=Xa-16|0;Xa=e;a:{b:{c:{d:{if((a|0)!=(b|0)){e:{f:{f=j[a|0];if((f|0)!=45){break f}a=a+1|0;if((b|0)!=(a|0)){break f}break e}h=i[114584];i[114584]=0;a=Qu(a,e+12|0,d,Ud());d=_a;g=i[114584];g:{if(g){if(i[e+12>>2]!=(b|0)){break g}if((g|0)==68){break c}break d}i[114584]=h;if(i[e+12>>2]==(b|0)){break d}}}}i[c>>2]=4;a=0;break a}if(!d|d>>>0<0){break b}}i[c>>2]=4;a=-1;break a}a=(f|0)==45?0-a|0:a}Xa=e+16|0;return a|0}function qN(a){var b=0;a:{if((j[a+44|0]|j[a+45|0]<<8|(j[a+46|0]<<16|j[a+47|0]<<24))!=1179472976|j[a+28|0]!=26|j[a+30|0]>2){break a}b=a+40|0;if(j[b|0]|j[b+1|0]<<8){break a}b=a+38|0;if(!(j[b|0]|j[b+1|0]<<8)|(j[b|0]|j[b+1|0]<<8)>>>0>32){break a}b=a+32|0;if(!(j[b|0]|j[b+1|0]<<8)|(j[b|0]|j[b+1|0]<<8)>>>0>256){break a}b=a+34|0;if(!(j[b|0]|j[b+1|0]<<8)|(j[b|0]|j[b+1|0]<<8)>>>0>255){break a}a=a+36|0;if(!(j[a|0]|j[a+1|0]<<8)){break a}return(j[a|0]|j[a+1|0]<<8)>>>0<129}return 0}function m7(a,b,c,d,e){var f=0,g=0,i=0,j=0,k=0,l=0,m=0,o=0,p=0;g=Xa-16|0;Xa=g;if(e){l=c+4|0;while(1){i=0;if(d){while(1){f=n[Ig(b,i,j)>>3];Nb(c,i);m=g,o=+(Ui(xd(f*134217728))-1024+((Yq(l)^-2147483648)>>>21)|0)*7.450580596923828e-9,n[m+8>>3]=o;mf(g+8|0,-1,1);f=n[g+8>>3]*32768;n[g+8>>3]=f;f=xd(f);a:{if(q(f)<2147483648){k=~~f;break a}k=-2147483648}k=Bc(k);m=gm(a,i,j),p=k,h[m>>1]=p;i=i+1|0;if((i|0)!=(d|0)){continue}break}}j=j+1|0;if((j|0)!=(e|0)){continue}break}}Xa=g+16|0}function P7(a,b,c,d,e){var f=0,g=0,i=0,j=0,k=0,l=0,m=0,o=0,p=0;g=Xa-16|0;Xa=g;if(e){l=c+4|0;while(1){i=0;if(d){while(1){f=n[Ig(b,i,j)>>3];Nb(c,i);m=g,o=+(Ui(xd(f*134217728))-1024+((Yq(l)^-2147483648)>>>21)|0)*7.450580596923828e-9,n[m+8>>3]=o;mf(g+8|0,-1,1);f=n[g+8>>3]*32768;n[g+8>>3]=f;f=xd(f);a:{if(q(f)<2147483648){k=~~f;break a}k=-2147483648}k=Bc(k);m=im(a,i,j),p=k,h[m>>1]=p;i=i+1|0;if((i|0)!=(d|0)){continue}break}}j=j+1|0;if((j|0)!=(e|0)){continue}break}}Xa=g+16|0}function Y5(a,b,c,d){var e=0,f=0,k=0,l=0,m=0,n=0,o=0;f=Xa-16|0;Xa=f;m=j[c+14|0];k=m+j[c+13|0]|0;N5(a+2304|0,i[c>>2],k,f+4|0);if(j[c+13|0]){e=i[f+12>>2];l=i[f+8>>2];n=i[f+4>>2];l=(n|0)<(l|0)?l:n;e=(l|0)<(e|0)?e:l;i[f+12>>2]=e;i[f+8>>2]=e;i[f+4>>2]=e}m=m?3:1;l=k-m|0;e=0;while(1){n=e+l|0;k=n-m|0;o=j[d+1|0]<<28>>31&3;a:{if(i[(f+4|0)+(e<<2)>>2]>=(k|0)){break a}o=j[b+k|0]}k=o;g[b+n|0]=k;e=e+1|0;if((m|0)!=(e|0)){continue}break}M5(a,b,i[c>>2],d,f+4|0,h[c+36>>1]&1);Xa=f+16|0}function hca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;i[114610]=0;L(2088,a|0);e=i[114610];i[114610]=0;a:{b:{if((e|0)!=1){e=i[a+28>>2];f=i[i[e>>2]+12>>2];i[114610]=0;b=N(f|0,e|0,b|0,c|0,d|0)|0;c=i[114610];i[114610]=0;if((c|0)!=1){break b}}b=H(0)|0;A()|0;M(b|0)|0;i[114610]=0;J(1989,37716,a|0,0,0);a=i[114610];i[114610]=0;if((a|0)==1){break a}O();b=-1}return b|0}a=B()|0;A()|0;i[114610]=0;K(20);b=i[114610];i[114610]=0;if((b|0)!=1){E(a|0);x()}a=H(0)|0;A()|0;gb(a);x()}function fca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;i[114610]=0;L(2088,a|0);e=i[114610];i[114610]=0;a:{b:{if((e|0)!=1){e=i[a+28>>2];f=i[i[e>>2]+8>>2];i[114610]=0;b=N(f|0,e|0,b|0,c|0,d|0)|0;c=i[114610];i[114610]=0;if((c|0)!=1){break b}}b=H(0)|0;A()|0;M(b|0)|0;i[114610]=0;J(1989,37673,a|0,0,0);a=i[114610];i[114610]=0;if((a|0)==1){break a}O();b=-1}return b|0}a=B()|0;A()|0;i[114610]=0;K(20);b=i[114610];i[114610]=0;if((b|0)!=1){E(a|0);x()}a=H(0)|0;A()|0;gb(a);x()}function wE(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0;h=i[a+104>>2];b=(h<<3)+a|0;c=((h+7>>>0)%12<<3)+a|0;f=i[c>>2];e=i[c+4>>2];j=i[a+96>>2];k=i[a+100>>2];a:{if(!(j|k)){g=i[b+4>>2];d=g;c=i[b>>2];l=(d|0)==(e|0)&f>>>0<c>>>0|e>>>0<d>>>0;break a}g=i[b+4>>2];d=g;c=i[b>>2];l=(d|0)==(e|0)&f>>>0<=c>>>0|e>>>0<d>>>0}d=f-j|0;i[b>>2]=d-c;i[b+4>>2]=e-((f>>>0<j>>>0)+k|0)-((d>>>0<c>>>0)+g)&65535;i[a+104>>2]=(h+1>>>0)%12;i[a+96>>2]=l;i[a+100>>2]=0;_a=i[b+4>>2];return i[b>>2]}function bca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;i[114610]=0;L(2088,a|0);d=i[114610];i[114610]=0;e=1;a:{b:{if((d|0)!=1){d=i[a+28>>2];f=i[i[d>>2]+64>>2];i[114610]=0;G(f|0,d|0,b|0,(c|0)!=0|0);b=i[114610];i[114610]=0;if((b|0)!=1){break b}}b=H(0)|0;A()|0;M(b|0)|0;i[114610]=0;J(1989,37978,a|0,0,0);a=i[114610];i[114610]=0;if((a|0)==1){break a}O();e=0}return e|0}a=B()|0;A()|0;i[114610]=0;K(20);b=i[114610];i[114610]=0;if((b|0)!=1){E(a|0);x()}a=H(0)|0;A()|0;gb(a);x()}function Aj(a,b,c){a=a|0;b=b|0;c=c|0;a:{if(a){if(b>>>0<=127){break a}b:{if(!i[i[21199]>>2]){if((b&-128)==57216){break a}break b}if(b>>>0<=2047){g[a+1|0]=b&63|128;g[a|0]=b>>>6|192;return 2}if(!((b&-8192)!=57344?b>>>0>=55296:0)){g[a+2|0]=b&63|128;g[a|0]=b>>>12|224;g[a+1|0]=b>>>6&63|128;return 3}if(b+ -65536>>>0<=1048575){g[a+3|0]=b&63|128;g[a|0]=b>>>18|240;g[a+2|0]=b>>>6&63|128;g[a+1|0]=b>>>12&63|128;return 4}}i[114584]=25;a=-1}else{a=1}return a|0}g[a|0]=b;return 1}function $ba(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;i[114610]=0;L(2088,a|0);d=i[114610];i[114610]=0;e=1;a:{b:{if((d|0)!=1){d=i[a+28>>2];f=i[i[d>>2]+56>>2];i[114610]=0;G(f|0,d|0,b|0,(c|0)!=0|0);b=i[114610];i[114610]=0;if((b|0)!=1){break b}}b=H(0)|0;A()|0;M(b|0)|0;i[114610]=0;J(1989,37930,a|0,0,0);a=i[114610];i[114610]=0;if((a|0)==1){break a}O();e=0}return e|0}a=B()|0;A()|0;i[114610]=0;K(20);b=i[114610];i[114610]=0;if((b|0)!=1){E(a|0);x()}a=H(0)|0;A()|0;gb(a);x()}function zfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;b=Ph(a,b,c,d);i[a>>2]=80928;d=Gj(a+4208|0);i[a+4240>>2]=0;i[a+4244>>2]=0;c=we(c);i[a+4260>>2]=0;i[a+4256>>2]=c;i[a+4236>>2]=0;c=a+4228|0;i[c>>2]=1048576e3;i[c+4>>2]=1048576e3;i[a+4220>>2]=1056964608;i[a+4224>>2]=1056964608;i[114610]=0;I(1639,a+44|0,2,2)|0;c=i[114610];i[114610]=0;a:{if((c|0)==1){break a}i[114610]=0;L(1640,b|0);c=i[114610];i[114610]=0;if((c|0)==1){break a}return a|0}a=B()|0;A()|0;uf(d);ve(b);E(a|0);x()}function zJ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,j=0;d=Xa-560|0;Xa=d;h[d+558>>1]=b;a:{b:{if((b+ -1&65535)>>>0>254){break b}f=((b<<2)+a|0)+900380|0;e=i[f>>2];c:{if(e){b=sM(d,c);ana(e,b);Is(b);break c}b=hg(556);if(!b){e=0;i[f>>2]=0;break b}i[114610]=0;e=C(1435,b|0,c|0)|0;c=i[114610];i[114610]=0;if((c|0)==1){break a}i[((k[d+558>>1]<<2)+a|0)+900380>>2]=b}g=a,j=k[ri(a+480192|0,d+558|0)>>1],h[g+480192>>1]=j}Xa=d+560|0;return e|0}a=B()|0;A()|0;Cb(b);E(a|0);x()}function lLa(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,l=0,m=0;f=Xa-32|0;Xa=f;i[f+28>>2]=c;g=wb(b,c<<1);a:{if(!g){break a}kc(f+28|0,65535);Zf(a,k[f+28>>1]);l=f,m=Jb(a),i[l+16>>2]=m;l=f,m=Kb(a),i[l+8>>2]=m;if(!pb(f+16|0,f+8|0)){break a}while(1){a=i[f+16>>2];Pz(b,f+24|0);c=f+24|0;c=j[c|0]|j[c+1|0]<<8;h[a>>1]=c;b:{if((c|0)==(d|0)){c=65535}else{if((c|0)!=(e|0)){break b}c=65534}h[a>>1]=c}he(f+16|0);if(pb(f+16|0,f+8|0)){continue}break}}Xa=f+32|0;return g|0}function mIa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=Xa-32|0;Xa=d;UHa(a);e=a;a:{b:{c:{d:{while(1){i[114610]=0;a=C(258,b|0,8)|0;f=i[114610];i[114610]=0;if((f|0)==1){break b}if(!a){break c}i[114610]=0;G(602,d+8|0,b|0,c|0);a=i[114610];i[114610]=0;if((a|0)!=1){i[114610]=0;D(603,e|0,d+8|0);a=i[114610];i[114610]=0;if((a|0)==1){break d}re(d+8|0);continue}break}a=B()|0;A()|0;break a}a=B()|0;A()|0;re(d+8|0);break a}Xa=d+32|0;return}a=B()|0;A()|0}kz(e);E(a|0);x()}



function OEa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=Xa-32|0;Xa=d;VDa(a);e=a;a:{b:{c:{d:{while(1){i[114610]=0;a=C(258,b|0,6)|0;f=i[114610];i[114610]=0;if((f|0)==1){break b}if(!a){break c}i[114610]=0;G(761,d+8|0,b|0,c|0);a=i[114610];i[114610]=0;if((a|0)!=1){i[114610]=0;D(762,e|0,d+8|0);a=i[114610];i[114610]=0;if((a|0)==1){break d}re(d+8|0);continue}break}a=B()|0;A()|0;break a}a=B()|0;A()|0;re(d+8|0);break a}Xa=d+32|0;return}a=B()|0;A()|0}Ly(e);E(a|0);x()}



function _pa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=p(0),g=0,k=0,l=0,n=0;e=Xa-16|0;Xa=e;i[e+8>>2]=c>>>2;i[e+4>>2]=i[a>>2];d=i[rb(e+8|0,e+4|0)>>2];b=jb(b);if(d){a=i[a+20>>2];c=d;while(1){i[e+12>>2]=j[b|0]|j[b+1|0]<<8|(j[b+2|0]<<16|j[b+3|0]<<24);Id(e+12|0,p(-1));f=p(m[e+12>>2]*p(32768));m[e+12>>2]=f;k=a;f=Qd(f);a:{if(p(q(f))<p(2147483648)){g=~~f;break a}g=-2147483648}l=k,n=Bc(g),h[l>>1]=n;a=a+2|0;b=b+4|0;c=c+ -1|0;if(c){continue}break}}Xa=e+16|0;return d<<2}function xKa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=Xa-32|0;Xa=d;QJa(a);e=a;a:{b:{c:{d:{while(1){i[114610]=0;a=C(258,b|0,8)|0;f=i[114610];i[114610]=0;if((f|0)==1){break b}if(!a){break c}i[114610]=0;G(513,d+8|0,b|0,c|0);a=i[114610];i[114610]=0;if((a|0)!=1){i[114610]=0;D(514,e|0,d+8|0);a=i[114610];i[114610]=0;if((a|0)==1){break d}re(d+8|0);continue}break}a=B()|0;A()|0;break a}a=B()|0;A()|0;re(d+8|0);break a}Xa=d+32|0;return}a=B()|0;A()|0}Cz(e);E(a|0);x()}function nJa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=Xa-32|0;Xa=d;DIa(a);e=a;a:{b:{c:{d:{while(1){i[114610]=0;a=C(258,b|0,8)|0;f=i[114610];i[114610]=0;if((f|0)==1){break b}if(!a){break c}i[114610]=0;G(553,d+8|0,b|0,c|0);a=i[114610];i[114610]=0;if((a|0)!=1){i[114610]=0;D(554,e|0,d+8|0);a=i[114610];i[114610]=0;if((a|0)==1){break d}re(d+8|0);continue}break}a=B()|0;A()|0;break a}a=B()|0;A()|0;re(d+8|0);break a}Xa=d+32|0;return}a=B()|0;A()|0}uz(e);E(a|0);x()}function vGa(a,b){var c=0,d=0,e=0,f=0,g=0;e=Xa-16|0;Xa=e;a:{if(Ms(a)){i[b>>2]=0;a=0;break a}f=qg(a,e,16);d=jb(j[e|0]);c=d&127;i[b>>2]=c;d=d<<24>>24;b:{if(!(f>>>0<2|(d|0)>-1)){d=c?32-r(c)|0:0;c=1;while(1){g=jb(j[c+e|0]);i[b>>2]=g&127|i[b>>2]<<7;d=d+7|0;c=c+1|0;if((f|0)==(c|0)){Ib(a,f);f=qg(a,e,16);c=0}g=g<<24>>24;if((g|0)<0?c>>>0<f>>>0:0){continue}break}Ib(a,c);a=(g|0)<0;if(d>>>0<33){break b}i[b>>2]=-1;a=0;break a}Ib(a,1);a=(d|0)<0}a=a^1}Xa=e+16|0;return a}function qH(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;b=Ph(a,b,c,d);i[a>>2]=80288;c=Gj(a+4260|0);i[a+4232>>2]=1061997773;d=a+4224|0;i[d>>2]=1061158912;i[d+4>>2]=1059082943;d=a+4216|0;i[d>>2]=1038174126;i[d+4>>2]=1065353216;i[a+4208>>2]=1056964608;i[a+4212>>2]=1036831949;i[114610]=0;I(1639,a+44|0,2,2)|0;d=i[114610];i[114610]=0;a:{if((d|0)==1){break a}i[114610]=0;L(1640,b|0);d=i[114610];i[114610]=0;if((d|0)==1){break a}return a|0}a=B()|0;A()|0;uf(c);ve(b);E(a|0);x()}function ela(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=Xa-32|0;Xa=d;e=Iw(a);a:{b:{c:{d:{while(1){i[114610]=0;a=C(258,b|0,8)|0;f=i[114610];i[114610]=0;if((f|0)==1){break b}if(!a){break c}i[114610]=0;G(1554,d+8|0,b|0,c|0);a=i[114610];i[114610]=0;if((a|0)!=1){i[114610]=0;D(1555,e|0,d+8|0);a=i[114610];i[114610]=0;if((a|0)==1){break d}re(d+8|0);continue}break}a=B()|0;A()|0;break a}a=B()|0;A()|0;re(d+8|0);break a}Xa=d+32|0;return}a=B()|0;A()|0}Wk(e);E(a|0);x()}function Zba(a,b,c){a=a|0;b=b|0;c=+c;var d=0,e=0,f=0;i[114610]=0;L(2088,a|0);d=i[114610];i[114610]=0;e=1;a:{b:{if((d|0)!=1){d=i[a+28>>2];f=i[i[d>>2]+48>>2];i[114610]=0;Ra(f|0,d|0,b|0,+c);b=i[114610];i[114610]=0;if((b|0)!=1){break b}}b=H(0)|0;A()|0;M(b|0)|0;i[114610]=0;J(1989,37892,a|0,0,0);a=i[114610];i[114610]=0;if((a|0)==1){break a}O();e=0}return e|0}a=B()|0;A()|0;i[114610]=0;K(20);b=i[114610];i[114610]=0;if((b|0)!=1){E(a|0);x()}a=H(0)|0;A()|0;gb(a);x()}function oda(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;i[114610]=0;L(2015,a|0);f=i[114610];i[114610]=0;a:{b:{if((f|0)!=1){f=i[a+24>>2];i[114610]=0;b=S(2031,f|0,b|0,c|0,d|0,e|0)|0;c=i[114610];i[114610]=0;if((c|0)!=1){break b}}b=H(0)|0;A()|0;M(b|0)|0;i[114610]=0;J(1989,35303,a|0,0,0);a=i[114610];i[114610]=0;if((a|0)==1){break a}O();b=0}return b|0}a=B()|0;A()|0;i[114610]=0;K(20);b=i[114610];i[114610]=0;if((b|0)!=1){E(a|0);x()}a=H(0)|0;A()|0;gb(a);x()}function lda(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;i[114610]=0;L(2015,a|0);f=i[114610];i[114610]=0;a:{b:{if((f|0)!=1){f=i[a+24>>2];i[114610]=0;b=S(2034,f|0,b|0,c|0,d|0,e|0)|0;c=i[114610];i[114610]=0;if((c|0)!=1){break b}}b=H(0)|0;A()|0;M(b|0)|0;i[114610]=0;J(1989,35386,a|0,0,0);a=i[114610];i[114610]=0;if((a|0)==1){break a}O();b=0}return b|0}a=B()|0;A()|0;i[114610]=0;K(20);b=i[114610];i[114610]=0;if((b|0)!=1){E(a|0);x()}a=H(0)|0;A()|0;gb(a);x()}function Eca(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;i[114610]=0;L(2015,a|0);f=i[114610];i[114610]=0;a:{b:{if((f|0)!=1){f=i[a+24>>2];i[114610]=0;b=S(2070,f|0,b|0,c|0,d|0,e|0)|0;c=i[114610];i[114610]=0;if((c|0)!=1){break b}}b=H(0)|0;A()|0;M(b|0)|0;i[114610]=0;J(1989,36620,a|0,0,0);a=i[114610];i[114610]=0;if((a|0)==1){break a}O();b=0}return b|0}a=B()|0;A()|0;i[114610]=0;K(20);b=i[114610];i[114610]=0;if((b|0)!=1){E(a|0);x()}a=H(0)|0;A()|0;gb(a);x()}function Pv(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;a:{if(!$q(b)){break a}a=a+24|0;if(!pg(i[a>>2]+484344|0,b&65535)){break a}b=Fb(i[a>>2]+484344|0,b);if((d|0)<0|i[b+12>>2]<=(c|0)|(c|0)<0|(k[i[a>>2]+480188>>1]<=(d|0)|e>>>0>5)){break a}a=Qe(b,c,d&65535);b:{switch(e|0){case 0:f=j[a|0];break a;case 1:f=j[a+1|0];break a;case 2:f=j[a+2|0];break a;case 3:f=j[a+3|0];break a;case 4:f=j[a+4|0];break a;case 5:break b;default:break a}}f=j[a+5|0]}return f|0}function Bza(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=Xa-32|0;Xa=d;e=hy(a);a:{b:{c:{d:{while(1){i[114610]=0;a=C(258,b|0,8)|0;f=i[114610];i[114610]=0;if((f|0)==1){break b}if(!a){break c}i[114610]=0;G(974,d+8|0,b|0,c|0);a=i[114610];i[114610]=0;if((a|0)!=1){i[114610]=0;D(975,e|0,d+8|0);a=i[114610];i[114610]=0;if((a|0)==1){break d}re(d+8|0);continue}break}a=B()|0;A()|0;break a}a=B()|0;A()|0;re(d+8|0);break a}Xa=d+32|0;return}a=B()|0;A()|0}gl(e);E(a|0);x()}function Le(a,b,c,d){var e=0,f=0,g=0,h=0,j=0,k=0;e=Xa-16|0;Xa=e;g=vm(a);f=e;j=e;a:{if(b){k=i[b+4>>2];h=i[b>>2];break a}h=vm(a)}i[j+8>>2]=h;i[f+12>>2]=k;f=i[a+12>>2];a=1;b:{if(!b){break b}a=c+f|0;if(a>>>0<c>>>0){d=d+1|0}b=a;i[e>>2]=2048;i[e+4>>2]=0;a=$z(e+8|0,e);c=i[a>>2];a=i[a+4>>2];c:{if(!a&c>>>0>g>>>0|a>>>0>0){a=-1;if(!d&b>>>0<=g>>>0|d>>>0<0){break c}break b}a=0;c=i[e+12>>2];if((c|0)==(d|0)&l[e+8>>2]<b>>>0|c>>>0<d>>>0){break b}}a=1}Xa=e+16|0;return a}function X$(a,b,c){var d=0,e=0,f=0,h=0;f=Xa-32|0;Xa=f;d=lb(a);e=qc(a);h=pi(b,c);a:{if(!h){break a}if(iz(b,xb(a),xb(a)+lb(a)|0)){b=Uh(f+16|0,b,c);c=xb(b);d=lb(b);i[114610]=0;I(2492,a|0,c|0,d|0)|0;c=i[114610];i[114610]=0;if((c|0)!=1){eb(b);break a}a=B()|0;A()|0;eb(b);E(a|0);x()}if(e-d>>>0<h>>>0){rl(a,e,(d+h|0)-e|0,d,d,0,0)}e=xb(a)+d|0;while(1){if((b|0)!=(c|0)){Rd(e,b);b=b+1|0;e=e+1|0;continue}break}g[f+15|0]=0;Rd(e,f+15|0);yg(a,d+h|0)}Xa=f+32|0;return a}function lR(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,j=0;a:{b=i[a+1060>>2];if((b|0)>255){break a}while(1){f=(o(b,6)+a|0)+1068|0,j=gj(a,7),g[f|0]=j;d=gj(a,1);e=gj(a,1);c=i[a+1056>>2];if((c|0)>255){break a}b=i[a+1060>>2]+1|0;i[a+1056>>2]=b;i[a+1060>>2]=b;b:{if(d){h[(o(c,6)+a|0)+1064>>1]=b;lR(a);b=i[a+1060>>2];break b}h[(o(c,6)+a|0)+1064>>1]=65535}i[a+1056>>2]=b;if(e){h[(o(c,6)+a|0)+1066>>1]=b;if((b|0)<=255){continue}break a}break}h[(o(c,6)+a|0)+1066>>1]=65535}}function V2(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,j=0;e=Xa-16|0;Xa=e;f=(hNa(b),dNa(2));c=f&2147483647;a:{if(c+ -8388608>>>0<=2130706431){d=c;c=c>>>7|0;d=d<<25;c=c+1065353216|0;g=d;c=d>>>0<0?c+1|0:c;break a}if(c>>>0>=2139095040){c=f;d=c>>>7|0;g=c<<25;c=d|2147418112;break a}if(!c){c=0;break a}d=c;c=r(c);kf(e,d,0,0,0,c+81|0);h=i[e>>2];j=i[e+4>>2];g=i[e+8>>2];c=i[e+12>>2]^65536|16265-c<<16}i[a>>2]=h;i[a+4>>2]=j;i[a+8>>2]=g;i[a+12>>2]=f&-2147483648|c;Xa=e+16|0}function Rb(a,b){var c=0,d=0,e=0;a:{b:{c=i[a+1396>>2];if((c|0)>=0){c:{if((c|0)<(b|0)){if((b|0)>=25){break b}if(!c){i[a+1392>>2]=0}while(1){c=-1;e=Sq(a);d=0;if((e|0)==-1){break c}d=i[a+1396>>2];c=d+8|0;i[a+1396>>2]=c;i[a+1392>>2]=i[a+1392>>2]+(e<<d);if((c|0)<(b|0)){continue}break}}if((c|0)<(b|0)){break a}d=i[a+1392>>2];i[a+1392>>2]=d>>>b;c=c-b|0;d=d&(-1<<b^-1)}i[a+1396>>2]=c}return d}return Rb(a,24)+(Rb(a,b+ -24|0)<<24)|0}V(50502,50448,1617,50521);x()}function _B(a,b,c,d,e,f,g,h){var j=0,k=0,l=0;j=Xa-16|0;Xa=j;if((b^-1)+1073741807>>>0>=c>>>0){k=xb(a);a:{if(536870887>b>>>0){i[j+8>>2]=b<<1;i[j+12>>2]=b+c;c=Nl(i[Jc(j+12|0,j+8|0)>>2]);break a}c=1073741806}l=c+1|0;c=Ak(l);if(e){Gh(c,k,e)}if(g){Gh(c+(e<<2)|0,h,g)}d=d-f|0;h=d-e|0;if(h){e=e<<2;Gh((e+c|0)+(g<<2)|0,(e+k|0)+(f<<2)|0,h)}b=b+1|0;if((b|0)!=2){Ln(k,b)}gf(a,c);fg(a,l);b=a;a=d+g|0;ce(b,a);i[j+4>>2]=0;ye(c+(a<<2)|0,j+4|0);Xa=j+16|0;return}gg();x()}function lla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,k=0,l=0,m=0,n=0;c=Xa-32|0;Xa=c;ola(a+33|0,b);l=b+236|0;e=a+27|0;while(1){f=0;k=(a+d|0)+33|0;if((j[e|0]|j[e+1|0]<<8)>>>0>j[k|0]){f=j[k|0]}m=Mc(l,d+12|0),n=f,h[m>>1]=n;d=d+1|0;if((d|0)!=96){continue}break}on(c,3,a+4|0);oc(c+16|0,c);i[114610]=0;C(369,b+492|0,c+16|0)|0;d=i[114610];i[114610]=0;if((d|0)!=1){eb(c+16|0);if(!j[a+241|0]){g[b+30|0]=j[a+26|0]}Xa=c+32|0;return}a=B()|0;A()|0;eb(c+16|0);E(a|0);x()}function zja(a,b){var c=0,d=0,e=0,f=0,g=0;c=Xa-144|0;Xa=c;d=Kg(c+8|0);e=i[i[d>>2]+ -12>>2];i[114610]=0;f=R(122)|0;g=i[114610];i[114610]=0;a:{if((g|0)==1){break a}i[114610]=0;G(123,c|0,e+(c+8|0)|0,f|0);e=i[114610];i[114610]=0;if((e|0)==1){break a}ub(c);i[114610]=0;D(130,d|0,b|0);b=i[114610];i[114610]=0;if((b|0)==1){break a}i[114610]=0;D(125,a|0,d|0);a=i[114610];i[114610]=0;if((a|0)==1){break a}Fd(d);Xa=c+144|0;return}a=B()|0;A()|0;Fd(d);E(a|0);x()}function sia(a,b){var c=0,d=0,e=0,f=0,g=0;c=Xa-144|0;Xa=c;d=Kg(c+8|0);e=i[i[d>>2]+ -12>>2];i[114610]=0;f=R(122)|0;g=i[114610];i[114610]=0;a:{if((g|0)==1){break a}i[114610]=0;G(123,c|0,e+(c+8|0)|0,f|0);e=i[114610];i[114610]=0;if((e|0)==1){break a}ub(c);i[114610]=0;D(134,d|0,b|0);b=i[114610];i[114610]=0;if((b|0)==1){break a}i[114610]=0;D(125,a|0,d|0);a=i[114610];i[114610]=0;if((a|0)==1){break a}Fd(d);Xa=c+144|0;return}a=B()|0;A()|0;Fd(d);E(a|0);x()}function mja(a,b){var c=0,d=0,e=0,f=0,g=0;c=Xa-144|0;Xa=c;d=Kg(c+8|0);e=i[i[d>>2]+ -12>>2];i[114610]=0;f=R(122)|0;g=i[114610];i[114610]=0;a:{if((g|0)==1){break a}i[114610]=0;G(123,c|0,e+(c+8|0)|0,f|0);e=i[114610];i[114610]=0;if((e|0)==1){break a}ub(c);i[114610]=0;D(131,d|0,b|0);b=i[114610];i[114610]=0;if((b|0)==1){break a}i[114610]=0;D(125,a|0,d|0);a=i[114610];i[114610]=0;if((a|0)==1){break a}Fd(d);Xa=c+144|0;return}a=B()|0;A()|0;Fd(d);E(a|0);x()}function iia(a,b){var c=0,d=0,e=0,f=0,g=0;c=Xa-144|0;Xa=c;d=Kg(c+8|0);e=i[i[d>>2]+ -12>>2];i[114610]=0;f=R(122)|0;g=i[114610];i[114610]=0;a:{if((g|0)==1){break a}i[114610]=0;G(123,c|0,e+(c+8|0)|0,f|0);e=i[114610];i[114610]=0;if((e|0)==1){break a}ub(c);i[114610]=0;D(135,d|0,b|0);b=i[114610];i[114610]=0;if((b|0)==1){break a}i[114610]=0;D(125,a|0,d|0);a=i[114610];i[114610]=0;if((a|0)==1){break a}Fd(d);Xa=c+144|0;return}a=B()|0;A()|0;Fd(d);E(a|0);x()}function Tha(a,b){var c=0,d=0,e=0,f=0,g=0;c=Xa-144|0;Xa=c;d=Kg(c+8|0);e=i[i[d>>2]+ -12>>2];i[114610]=0;f=R(122)|0;g=i[114610];i[114610]=0;a:{if((g|0)==1){break a}i[114610]=0;G(123,c|0,e+(c+8|0)|0,f|0);e=i[114610];i[114610]=0;if((e|0)==1){break a}ub(c);i[114610]=0;D(136,d|0,b|0);b=i[114610];i[114610]=0;if((b|0)==1){break a}i[114610]=0;D(125,a|0,d|0);a=i[114610];i[114610]=0;if((a|0)==1){break a}Fd(d);Xa=c+144|0;return}a=B()|0;A()|0;Fd(d);E(a|0);x()}function Iia(a,b){var c=0,d=0,e=0,f=0,g=0;c=Xa-144|0;Xa=c;d=Kg(c+8|0);e=i[i[d>>2]+ -12>>2];i[114610]=0;f=R(122)|0;g=i[114610];i[114610]=0;a:{if((g|0)==1){break a}i[114610]=0;G(123,c|0,e+(c+8|0)|0,f|0);e=i[114610];i[114610]=0;if((e|0)==1){break a}ub(c);i[114610]=0;D(133,d|0,b|0);b=i[114610];i[114610]=0;if((b|0)==1){break a}i[114610]=0;D(125,a|0,d|0);a=i[114610];i[114610]=0;if((a|0)==1){break a}Fd(d);Xa=c+144|0;return}a=B()|0;A()|0;Fd(d);E(a|0);x()}function gI(a,b){var c=0,d=0,e=0,f=0,g=0;c=Xa-144|0;Xa=c;d=Kg(c+8|0);e=i[i[d>>2]+ -12>>2];i[114610]=0;f=R(122)|0;g=i[114610];i[114610]=0;a:{if((g|0)==1){break a}i[114610]=0;G(123,c|0,e+(c+8|0)|0,f|0);e=i[114610];i[114610]=0;if((e|0)==1){break a}ub(c);i[114610]=0;D(132,d|0,b|0);b=i[114610];i[114610]=0;if((b|0)==1){break a}i[114610]=0;D(125,a|0,d|0);a=i[114610];i[114610]=0;if((a|0)==1){break a}Fd(d);Xa=c+144|0;return}a=B()|0;A()|0;Fd(d);E(a|0);x()}function e5(a,b,c,d,e,f){var g=0,h=0,i=0,j=0,k=0,l=p(0);g=e-c|0;i=d-b|0;e=(g|0)/(i|0)|0;f=(d|0)>(f|0)?f:d;a:{if((f|0)<=(b|0)){break a}d=(b<<2)+a|0;m[d>>2]=m[d>>2]*m[((c&255)<<2)+50832>>2];d=b+1|0;if((d|0)>=(f|0)){break a}b=0;j=g>>31;j=o((e|0)<0?e:0-e|0,i)+(j+g^j)|0;g=(g|0)<0?-1:1;while(1){h=(d<<2)+a|0;k=h;l=m[h>>2];b=b+j|0;h=(b|0)<(i|0);c=(c+e|0)+(h?0:g)|0;m[k>>2]=l*m[((c&255)<<2)+50832>>2];b=b-(h?0:i)|0;d=d+1|0;if((f|0)!=(d|0)){continue}break}}}function Aw(a,b){var c=0,d=0,e=0,f=0,g=0;c=Xa-144|0;Xa=c;d=Kg(c+8|0);e=i[i[d>>2]+ -12>>2];i[114610]=0;f=R(122)|0;g=i[114610];i[114610]=0;a:{if((g|0)==1){break a}i[114610]=0;G(123,c|0,e+(c+8|0)|0,f|0);e=i[114610];i[114610]=0;if((e|0)==1){break a}ub(c);i[114610]=0;D(124,d|0,b|0);b=i[114610];i[114610]=0;if((b|0)==1){break a}i[114610]=0;D(125,a|0,d|0);a=i[114610];i[114610]=0;if((a|0)==1){break a}Fd(d);Xa=c+144|0;return}a=B()|0;A()|0;Fd(d);E(a|0);x()}function eca(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;i[114610]=0;L(2088,a|0);c=i[114610];i[114610]=0;d=1;a:{b:{if((c|0)!=1){c=i[a+28>>2];e=i[i[c>>2]+76>>2];i[114610]=0;D(e|0,c|0,b|0);b=i[114610];i[114610]=0;if((b|0)!=1){break b}}b=H(0)|0;A()|0;M(b|0)|0;i[114610]=0;J(1989,38042,a|0,0,0);a=i[114610];i[114610]=0;if((a|0)==1){break a}O();d=0}return d|0}a=B()|0;A()|0;i[114610]=0;K(20);b=i[114610];i[114610]=0;if((b|0)!=1){E(a|0);x()}a=H(0)|0;A()|0;gb(a);x()}function Sba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;i[114610]=0;L(2088,a|0);c=i[114610];i[114610]=0;d=1;a:{b:{if((c|0)!=1){c=i[a+28>>2];e=i[i[c>>2]+20>>2];i[114610]=0;D(e|0,c|0,b|0);b=i[114610];i[114610]=0;if((b|0)!=1){break b}}b=H(0)|0;A()|0;M(b|0)|0;i[114610]=0;J(1989,37770,a|0,0,0);a=i[114610];i[114610]=0;if((a|0)==1){break a}O();d=0}return d|0}a=B()|0;A()|0;i[114610]=0;K(20);b=i[114610];i[114610]=0;if((b|0)!=1){E(a|0);x()}a=H(0)|0;A()|0;gb(a);x()}function Rba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;i[114610]=0;L(2088,a|0);c=i[114610];i[114610]=0;d=1;a:{b:{if((c|0)!=1){c=i[a+28>>2];e=i[i[c>>2]+16>>2];i[114610]=0;D(e|0,c|0,b|0);b=i[114610];i[114610]=0;if((b|0)!=1){break b}}b=H(0)|0;A()|0;M(b|0)|0;i[114610]=0;J(1989,37752,a|0,0,0);a=i[114610];i[114610]=0;if((a|0)==1){break a}O();d=0}return d|0}a=B()|0;A()|0;i[114610]=0;K(20);b=i[114610];i[114610]=0;if((b|0)!=1){E(a|0);x()}a=H(0)|0;A()|0;gb(a);x()}function Xba(a,b){a=a|0;b=+b;var c=0,d=0,e=0;i[114610]=0;L(2088,a|0);c=i[114610];i[114610]=0;d=1;a:{b:{if((c|0)!=1){c=i[a+28>>2];e=i[i[c>>2]+40>>2];i[114610]=0;da(e|0,c|0,+b);c=i[114610];i[114610]=0;if((c|0)!=1){break b}}d=H(0)|0;A()|0;M(d|0)|0;i[114610]=0;J(1989,37856,a|0,0,0);a=i[114610];i[114610]=0;if((a|0)==1){break a}O();d=0}return d|0}a=B()|0;A()|0;i[114610]=0;K(20);d=i[114610];i[114610]=0;if((d|0)!=1){E(a|0);x()}a=H(0)|0;A()|0;gb(a);x()}function Vba(a,b){a=a|0;b=+b;var c=0,d=0,e=0;i[114610]=0;L(2088,a|0);c=i[114610];i[114610]=0;d=1;a:{b:{if((c|0)!=1){c=i[a+28>>2];e=i[i[c>>2]+32>>2];i[114610]=0;da(e|0,c|0,+b);c=i[114610];i[114610]=0;if((c|0)!=1){break b}}d=H(0)|0;A()|0;M(d|0)|0;i[114610]=0;J(1989,37822,a|0,0,0);a=i[114610];i[114610]=0;if((a|0)==1){break a}O();d=0}return d|0}a=B()|0;A()|0;i[114610]=0;K(20);d=i[114610];i[114610]=0;if((d|0)!=1){E(a|0);x()}a=H(0)|0;A()|0;gb(a);x()}function Tba(a,b){a=a|0;b=+b;var c=0,d=0,e=0;i[114610]=0;L(2088,a|0);c=i[114610];i[114610]=0;d=1;a:{b:{if((c|0)!=1){c=i[a+28>>2];e=i[i[c>>2]+24>>2];i[114610]=0;da(e|0,c|0,+b);c=i[114610];i[114610]=0;if((c|0)!=1){break b}}d=H(0)|0;A()|0;M(d|0)|0;i[114610]=0;J(1989,37788,a|0,0,0);a=i[114610];i[114610]=0;if((a|0)==1){break a}O();d=0}return d|0}a=B()|0;A()|0;i[114610]=0;K(20);d=i[114610];i[114610]=0;if((d|0)!=1){E(a|0);x()}a=H(0)|0;A()|0;gb(a);x()}function Kw(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;f=Xa-48|0;Xa=f;a:{if(!c){c=_b(a,b);a=i[d+12>>2];i[c+8>>2]=i[d+8>>2];i[c+12>>2]=a;a=i[d+4>>2];i[c>>2]=i[d>>2];i[c+4>>2]=a;break a}e=i[d+12>>2];i[f+24>>2]=i[d+8>>2];i[f+28>>2]=e;g=i[d+4>>2];e=f;i[e+16>>2]=i[d>>2];i[e+20>>2]=g;g=c>>>1|0;Kw(a,b,g,e+16|0);lh(e+32|0,d,_b(a,c));d=i[e+44>>2];i[e+8>>2]=i[e+40>>2];i[e+12>>2]=d;d=i[e+36>>2];i[e>>2]=i[e+32>>2];i[e+4>>2]=d;Kw(a,b|c,g,e)}Xa=f+48|0}function pla(a,b,c){var d=0,e=0,f=0,g=0,i=0,j=0,k=0,l=0,m=0;f=Xa+ -64|0;Xa=f;while(1){i=+(g+ -4096|0)*.0001220703125;e=0;d=0;while(1){j=qla(d,i,b,c);n[(d<<3)+f>>3]=j;e=j+e;d=d+1|0;if((d|0)!=8){continue}break}e=1/e;l=g<<3;d=0;while(1){m=(d+l<<1)+a|0;i=t(s(u(n[(d<<3)+f>>3]*32768*e+.5),32768),-32768);a:{if(q(i)<2147483648){k=~~i;break a}k=-2147483648}h[m>>1]=k;d=d+1|0;if((d|0)!=8){continue}break}g=g+1|0;if((g|0)!=8193){continue}break}Xa=f- -64|0}function pda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;i[114610]=0;L(2015,a|0);e=i[114610];i[114610]=0;a:{b:{if((e|0)!=1){e=i[a+24>>2];i[114610]=0;b=N(2030,e|0,b|0,c|0,d|0)|0;c=i[114610];i[114610]=0;if((c|0)!=1){break b}}b=H(0)|0;A()|0;M(b|0)|0;i[114610]=0;J(1989,35278,a|0,0,0);a=i[114610];i[114610]=0;if((a|0)==1){break a}O();b=0}return b|0}a=B()|0;A()|0;i[114610]=0;K(20);b=i[114610];i[114610]=0;if((b|0)!=1){E(a|0);x()}a=H(0)|0;A()|0;gb(a);x()}function mda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;i[114610]=0;L(2015,a|0);e=i[114610];i[114610]=0;a:{b:{if((e|0)!=1){e=i[a+24>>2];i[114610]=0;b=N(2033,e|0,b|0,c|0,d|0)|0;c=i[114610];i[114610]=0;if((c|0)!=1){break b}}b=H(0)|0;A()|0;M(b|0)|0;i[114610]=0;J(1989,35355,a|0,0,0);a=i[114610];i[114610]=0;if((a|0)==1){break a}O();b=0}return b|0}a=B()|0;A()|0;i[114610]=0;K(20);b=i[114610];i[114610]=0;if((b|0)!=1){E(a|0);x()}a=H(0)|0;A()|0;gb(a);x()}function jda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;i[114610]=0;L(2015,a|0);e=i[114610];i[114610]=0;a:{b:{if((e|0)!=1){e=i[a+24>>2];i[114610]=0;b=N(2036,e|0,b|0,c|0,d|0)|0;c=i[114610];i[114610]=0;if((c|0)!=1){break b}}b=H(0)|0;A()|0;M(b|0)|0;i[114610]=0;J(1989,35450,a|0,0,0);a=i[114610];i[114610]=0;if((a|0)==1){break a}O();b=0}return b|0}a=B()|0;A()|0;i[114610]=0;K(20);b=i[114610];i[114610]=0;if((b|0)!=1){E(a|0);x()}a=H(0)|0;A()|0;gb(a);x()}function ida(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;i[114610]=0;L(2015,a|0);e=i[114610];i[114610]=0;a:{b:{if((e|0)!=1){e=i[a+24>>2];i[114610]=0;b=N(2037,e|0,b|0,c|0,d|0)|0;c=i[114610];i[114610]=0;if((c|0)!=1){break b}}b=H(0)|0;A()|0;M(b|0)|0;i[114610]=0;J(1989,35489,a|0,0,0);a=i[114610];i[114610]=0;if((a|0)==1){break a}O();b=0}return b|0}a=B()|0;A()|0;i[114610]=0;K(20);b=i[114610];i[114610]=0;if((b|0)!=1){E(a|0);x()}a=H(0)|0;A()|0;gb(a);x()}function hda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;i[114610]=0;L(2015,a|0);e=i[114610];i[114610]=0;a:{b:{if((e|0)!=1){e=i[a+24>>2];i[114610]=0;b=N(2038,e|0,b|0,c|0,d|0)|0;c=i[114610];i[114610]=0;if((c|0)!=1){break b}}b=H(0)|0;A()|0;M(b|0)|0;i[114610]=0;J(1989,35526,a|0,0,0);a=i[114610];i[114610]=0;if((a|0)==1){break a}O();b=0}return b|0}a=B()|0;A()|0;i[114610]=0;K(20);b=i[114610];i[114610]=0;if((b|0)!=1){E(a|0);x()}a=H(0)|0;A()|0;gb(a);x()}function gda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;i[114610]=0;L(2015,a|0);e=i[114610];i[114610]=0;a:{b:{if((e|0)!=1){e=i[a+24>>2];i[114610]=0;b=N(2039,e|0,b|0,c|0,d|0)|0;c=i[114610];i[114610]=0;if((c|0)!=1){break b}}b=H(0)|0;A()|0;M(b|0)|0;i[114610]=0;J(1989,35571,a|0,0,0);a=i[114610];i[114610]=0;if((a|0)==1){break a}O();b=0}return b|0}a=B()|0;A()|0;i[114610]=0;K(20);b=i[114610];i[114610]=0;if((b|0)!=1){E(a|0);x()}a=H(0)|0;A()|0;gb(a);x()}function _ba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;i[114610]=0;L(2088,a|0);c=i[114610];i[114610]=0;a:{b:{if((c|0)!=1){c=i[a+28>>2];e=i[i[c>>2]+52>>2];i[114610]=0;d=+Qa(e|0,c|0,b|0);b=i[114610];i[114610]=0;if((b|0)!=1){break b}}b=H(0)|0;A()|0;M(b|0)|0;i[114610]=0;J(1989,37911,a|0,0,0);a=i[114610];i[114610]=0;if((a|0)==1){break a}O();d=0}return+d}a=B()|0;A()|0;i[114610]=0;K(20);b=i[114610];i[114610]=0;if((b|0)!=1){E(a|0);x()}a=H(0)|0;A()|0;gb(a);x()}function Z9(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0;h=Xa-16|0;Xa=h;a:{b:{c:{if(!(g?!(!f|(!d|!e)):0)){b=P(8)|0;i[114610]=0;c=C(85,h|0,38642)|0;a=i[114610];i[114610]=0;if((a|0)==1){break c}Ub(b,c);i[114610]=0;G(2009,b|0,83568,2017);a=i[114610];i[114610]=0;if((a|0)!=1){break a}a=B()|0;A()|0;eb(c);break b}Nh(a,b,4);c=Uv(a,c,d,e,f,g);n[a+16>>3]=+(c>>>0)/+(b|0)+n[a+16>>3];Xa=h+16|0;return c|0}a=B()|0;A()|0;Q(b|0)}E(a|0)}x()}function W9(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0;h=Xa-16|0;Xa=h;a:{b:{c:{if(!(g?!(!f|(!d|!e)):0)){b=P(8)|0;i[114610]=0;c=C(85,h|0,38642)|0;a=i[114610];i[114610]=0;if((a|0)==1){break c}Ub(b,c);i[114610]=0;G(2009,b|0,83568,2017);a=i[114610];i[114610]=0;if((a|0)!=1){break a}a=B()|0;A()|0;eb(c);break b}Nh(a,b,4);c=Tv(a,c,d,e,f,g);n[a+16>>3]=+(c>>>0)/+(b|0)+n[a+16>>3];Xa=h+16|0;return c|0}a=B()|0;A()|0;Q(b|0)}E(a|0)}x()}function hma(a,b){var c=0,d=0,e=0,f=0;c=Xa-16|0;Xa=c;i[c+12>>2]=i[a+4>>2];i[c+8>>2]=i[b+4>>2];a:{b:{if(!i[rb(c+12|0,c+8|0)>>2]){break b}while(1){e=mo(g[dc(a,d)|0]);f=mo(g[dc(b,d)|0]);if((e|0)!=(f|0)){d=(e&255)>>>0<(f&255)>>>0?-1:1;break a}if(e){i[c+12>>2]=i[a+4>>2];i[c+8>>2]=i[b+4>>2];d=d+1|0;if(d>>>0>=l[rb(c+12|0,c+8|0)>>2]){break b}continue}break}d=0;break a}d=0;if(i[a+4>>2]==i[b+4>>2]){break a}d=l[a+4>>2]<l[b+4>>2]?-1:1}Xa=c+16|0;return d}function cca(a,b){a=a|0;b=b|0;var c=0,d=0;i[114610]=0;L(2088,a|0);c=i[114610];i[114610]=0;a:{b:{if((c|0)!=1){c=i[a+28>>2];d=i[i[c>>2]+68>>2];i[114610]=0;b=C(d|0,c|0,b|0)|0;c=i[114610];i[114610]=0;if((c|0)!=1){break b}}b=H(0)|0;A()|0;M(b|0)|0;i[114610]=0;J(1989,38005,a|0,0,0);a=i[114610];i[114610]=0;if((a|0)==1){break a}O();b=-1}return b|0}a=B()|0;A()|0;i[114610]=0;K(20);b=i[114610];i[114610]=0;if((b|0)!=1){E(a|0);x()}a=H(0)|0;A()|0;gb(a);x()}function aca(a,b){a=a|0;b=b|0;var c=0,d=0;i[114610]=0;L(2088,a|0);c=i[114610];i[114610]=0;a:{b:{if((c|0)!=1){c=i[a+28>>2];d=i[i[c>>2]+60>>2];i[114610]=0;b=C(d|0,c|0,b|0)|0;c=i[114610];i[114610]=0;if((c|0)!=1){break b}}b=H(0)|0;A()|0;M(b|0)|0;i[114610]=0;J(1989,37954,a|0,0,0);a=i[114610];i[114610]=0;if((a|0)==1){break a}O();b=-1}return b|0}a=B()|0;A()|0;i[114610]=0;K(20);b=i[114610];i[114610]=0;if((b|0)!=1){E(a|0);x()}a=H(0)|0;A()|0;gb(a);x()}function Zja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=Xa-16|0;Xa=d;fc(a,b);i[114610]=0;G(128,d+8|0,b|0,c|0);e=i[114610];i[114610]=0;a:{if((e|0)==1){break a}ub(d+8|0);i[114610]=0;e=F(27,b|0)|0;f=i[114610];i[114610]=0;if((f|0)==1){break a}if(e){i[114610]=0;b=F(27,b|0)|0;e=i[114610];i[114610]=0;if((e|0)==1){break a}i[114610]=0;G(129,d|0,b|0,c|0);b=i[114610];i[114610]=0;if((b|0)==1){break a}ub(d)}Xa=d+16|0;return}b=B()|0;A()|0;ub(a);E(b|0);x()}function hp(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,l=0,m=0;f=Xa-32|0;Xa=f;i[f+28>>2]=c;g=wb(b,c);a:{if(!g){break a}kc(f+28|0,65535);Zf(a,k[f+28>>1]);l=f,m=Jb(a),i[l+16>>2]=m;l=f,m=Kb(a),i[l+8>>2]=m;if(!pb(f+16|0,f+8|0)){break a}while(1){a=i[f+16>>2];RHa(b,f+27|0);c=j[f+27|0];h[a>>1]=c;b:{if((c|0)==(d|0)){c=65535}else{if((c|0)!=(e|0)){break b}c=65534}h[a>>1]=c}he(f+16|0);if(pb(f+16|0,f+8|0)){continue}break}}Xa=f+32|0;return g|0}function OI(a){var b=0;a:{if((j[a|0]|j[a+1|0]<<8|(j[a+2|0]<<16|j[a+3|0]<<24))!=1163089229){break a}b=a+4|0;if((j[b|0]|j[b+1|0]<<8|(j[b+2|0]<<16|j[b+3|0]<<24))!=-1095062050?(j[b|0]|j[b+1|0]<<8|(j[b+2|0]<<16|j[b+3|0]<<24))!=-1346458146:0){break a}b=a+16|0;if(!(j[b|0]|j[b+1|0]<<8|(j[b+2|0]<<16|j[b+3|0]<<24))){break a}a=a+8|0;return((j[b|0]|j[b+1|0]<<8|(j[b+2|0]<<16|j[b+3|0]<<24))+24|0)==(j[a|0]|j[a+1|0]<<8|(j[a+2|0]<<16|j[a+3|0]<<24))}return 0}function UH(a){var b=0,c=0,d=0,e=0;c=Xa-32|0;Xa=c;a:{b:{if(Fj(a)>>>0<=Re(a)>>>0){break b}b=fb(a);d=Re(a);e=Re(a);i[114610]=0;b=N(1643,c+8|0,d|0,e|0,b|0)|0;d=i[114610];i[114610]=0;c:{d:{if((d|0)!=1){i[114610]=0;D(1644,a|0,b|0);a=i[114610];i[114610]=0;if((a|0)==1){break d}ur(b);break b}a=H(0)|0;A()|0;break c}a=H(0)|0;A()|0;ur(b)}M(a|0)|0;i[114610]=0;K(20);a=i[114610];i[114610]=0;if((a|0)==1){break a}}Xa=c+32|0;return}a=H(0)|0;A()|0;gb(a);x()}function SH(a){var b=0,c=0,d=0,e=0;c=Xa-32|0;Xa=c;a:{b:{if(gd(a)>>>0<=qb(a)>>>0){break b}b=fb(a);d=qb(a);e=qb(a);i[114610]=0;b=N(1645,c+8|0,d|0,e|0,b|0)|0;d=i[114610];i[114610]=0;c:{d:{if((d|0)!=1){i[114610]=0;D(1646,a|0,b|0);a=i[114610];i[114610]=0;if((a|0)==1){break d}tr(b);break b}a=H(0)|0;A()|0;break c}a=H(0)|0;A()|0;tr(b)}M(a|0)|0;i[114610]=0;K(20);a=i[114610];i[114610]=0;if((a|0)==1){break a}}Xa=c+32|0;return}a=H(0)|0;A()|0;gb(a);x()}function uEa(a,b){var c=0,d=0,e=0,f=0;d=Xa-16|0;Xa=d;g[b+12|0]=0;CP(b);aEa(b);c=j[a+1|0];a:{if(!c){break a}f=0-c|0;while(1){g[d+7|0]=64;f=(f<<16>>16)+c|0;$Da(b,ap(d+8|0,f&65535,j[Xb(((e<<1)+a|0)+2|0,d+7|0)|0]));e=e+1|0;if((e|0)==15){break a}c=j[((e<<1)+a|0)+1|0];if(c){continue}break}}c=j[a+32|0];g[b+14|0]=c>>>4;g[b+13|0]=c&15;a=j[a+31|0];c=a&15;g[b+15|0]=c;g[b+16|0]=c;if(a&16){g[b+12|0]=j[b+12|0]|4}if(a&32){g[b+12|0]=j[b+12|0]|2}Xa=d+16|0}function Ph(a,b,c,d){var e=0,f=0;i[a+20>>2]=d;i[a+16>>2]=c;i[a+12>>2]=b;i[a+4>>2]=0;i[a+8>>2]=0;i[a>>2]=79824;c=a+24|0;i[c>>2]=0;i[c+4>>2]=0;i[c+16>>2]=0;i[c+8>>2]=0;i[c+12>>2]=0;Pga(a+44|0);i[a+4196>>2]=1065353216;i[a+4200>>2]=0;b=0;h[a+4204>>1]=0;i[c>>2]=a+99&-8;e=i[a+20>>2];d=i[a+16>>2];if((e|0)!=(d+906300|0)){f=a+4200|0;while(1){a:{c=b+1|0;if(b>>>0>247){break a}b=c;if((e|0)!=((o(c,160)+d|0)+906300|0)){continue}}break}g[f|0]=c}return a}function zW(a,b){a=a|0;b=b|0;var c=0;a=Oc(a);a:{if(j[b+16|0]){i[114610]=0;C(235,a|0,7065)|0;c=i[114610];i[114610]=0;if((c|0)==1){break a}}if(j[b+17|0]){i[114610]=0;C(235,a|0,7072)|0;c=i[114610];i[114610]=0;if((c|0)==1){break a}}if(Cc(a)){i[114610]=0;C(235,a|0,7079)|0;c=i[114610];i[114610]=0;if((c|0)==1){break a}}if(j[b+18|0]){i[114610]=0;C(235,a|0,7085)|0;b=i[114610];i[114610]=0;if((b|0)==1){break a}}return}b=B()|0;A()|0;eb(a);E(b|0);x()}function A$(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=Xa-160|0;Xa=e;i[e+152>>2]=b;f=e+144|0;a:{b:while(1){if(c>>>0<d>>>0){i[e+8>>2]=c;if(($a[i[i[a>>2]+16>>2]](a,e+144|0,c,(d-c|0)>32?c+32|0:d,e+8|0,e+16|0,f,e+12|0)|0)==2){break a}b=e+16|0;if(i[e+8>>2]==(c|0)){break a}while(1)if(b>>>0>=l[e+12>>2]){c=i[e+8>>2];continue b}else{i[e+4>>2]=i[b>>2];YB(i[e+152>>2],i[e+4>>2]);b=b+4|0;continue}}break}Xa=e+160|0;return i[e+152>>2]}Pl(62932);x()}function uga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,h=0,k=0,l=0,m=0;d=Xa-32|0;Xa=d;f=i[c+12>>2];a:{if(!f){break a}h=g[c+16|0];e=lb(b);if(!e){break a}k=e+ -1|0;c=0;while(1){b:{if(!c|(c>>>0)%(f>>>0)){break b}if((c|0)==(k|0)){if(j[Sb(b,0)|0]==43){break b}if(j[Sb(b,0)|0]==45){break b}}l=d,m=ld(b),i[l+8>>2]=m;l=d,m=Ze(d+8|0,e-c|0),i[l+16>>2]=m;Ad(d+24|0,d+16|0);Sv(b,i[d+24>>2],1,h)}c=c+1|0;if((e|0)!=(c|0)){continue}break}}Lc(a,b);Xa=d+32|0}function b5(a,b,c,d){var e=0,f=0,g=p(0);f=QE(a,b);a:{if((f|0)<0){break a}e=i[b>>2];a=(e|0)<(d|0)?e:d;f=o(e,f);if(j[b+22|0]){e=1;if((a|0)<1){break a}d=0;while(1){e=(d<<2)+c|0;g=p(m[i[b+28>>2]+(d+f<<2)>>2]+g);m[e>>2]=m[e>>2]+g;g=p(m[b+12>>2]+g);e=1;d=d+1|0;if((a|0)!=(d|0)){continue}break}break a}e=1;if((a|0)<1){break a}d=0;while(1){e=(d<<2)+c|0;m[e>>2]=m[e>>2]+m[i[b+28>>2]+(d+f<<2)>>2];e=1;d=d+1|0;if((a|0)!=(d|0)){continue}break}}return e}function NO(a,b,c,d){var e=0,f=0;f=Xa-16|0;Xa=f;e=k[c>>1];while(1){a:{e=e<<1;h[c>>1]=e;g[b|0]=(e&65534)>>>0>255;e=j[c|0];h[c>>1]=e;if(!e){if(!pe(a,f+15|0)){break a}e=j[f+15|0];h[c>>1]=e<<1|1;g[b|0]=e>>>7;h[c>>1]=j[c|0]}g[d|0]=j[b|0]+(j[d|0]<<1);e=k[c>>1]<<1;h[c>>1]=e;g[b|0]=(e&65534)>>>0>255;e=j[c|0];h[c>>1]=e;if(!e){if(!pe(a,f+14|0)){break a}e=j[f+14|0];h[c>>1]=e<<1|1;g[b|0]=e>>>7;e=j[c|0];h[c>>1]=e}if(j[b|0]){continue}}break}Xa=f+16|0}function DM(a,b){var c=0,d=0,e=0,f=0;c=Xa-16|0;Xa=c;a=Ab(a);d=lb(b);i[114610]=0;D(111,a|0,d|0);d=i[114610];i[114610]=0;if((d|0)!=1){a:{e=c,f=ld(b),i[e+8>>2]=f;e=c,f=Ye(b),i[e>>2]=f;if(pb(c+8|0,c)){while(1){b=j[i[c+8>>2]];b:{if((b|0)==13){i[114610]=0;D(110,a|0,10);break b}i[114610]=0;D(110,a|0,b<<24>>24)}b=i[114610];i[114610]=0;if((b|0)==1){break a}Tf(c+8|0);if(pb(c+8|0,c)){continue}break}}Xa=c+16|0;return}}b=B()|0;A()|0;eb(a);E(b|0);x()}function qR(a){var b=0,c=0,d=0,e=0;c=Xa-32|0;Xa=c;a:{b:{if(xf(a)>>>0<=rc(a)>>>0){break b}b=fb(a);d=rc(a);e=rc(a);i[114610]=0;b=N(39,c+8|0,d|0,e|0,b|0)|0;d=i[114610];i[114610]=0;c:{d:{if((d|0)!=1){i[114610]=0;D(40,a|0,b|0);a=i[114610];i[114610]=0;if((a|0)==1){break d}vt(b);break b}a=H(0)|0;A()|0;break c}a=H(0)|0;A()|0;vt(b)}M(a|0)|0;i[114610]=0;K(20);a=i[114610];i[114610]=0;if((a|0)==1){break a}}Xa=c+32|0;return}a=H(0)|0;A()|0;gb(a);x()}function qda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;i[114610]=0;L(2015,a|0);d=i[114610];i[114610]=0;e=1;a:{b:{if((d|0)!=1){d=i[a+24>>2];i[114610]=0;G(2029,d|0,b|0,c|0);b=i[114610];i[114610]=0;if((b|0)!=1){break b}}b=H(0)|0;A()|0;M(b|0)|0;i[114610]=0;J(1989,35246,a|0,0,0);a=i[114610];i[114610]=0;if((a|0)==1){break a}O();e=0}return e|0}a=B()|0;A()|0;i[114610]=0;K(20);b=i[114610];i[114610]=0;if((b|0)!=1){E(a|0);x()}a=H(0)|0;A()|0;gb(a);x()}function uba(a){var b=0,c=0,d=0;b=Xa-48|0;Xa=b;vB(b+16|0);i[114610]=0;c=C(2,b|0,39521)|0;d=i[114610];i[114610]=0;a:{b:{c:{d:{if((d|0)!=1){i[114610]=0;G(251,b+32|0,b+16|0,c|0);d=i[114610];i[114610]=0;if((d|0)==1){break d}i[114610]=0;G(9,a|0,0,b+32|0);a=i[114610];i[114610]=0;if((a|0)==1){break c}eb(b+32|0);eb(c);eb(b+16|0);Xa=b+48|0;return}a=B()|0;A()|0;break a}a=B()|0;A()|0;break b}a=B()|0;A()|0;eb(b+32|0)}eb(c)}eb(b+16|0);E(a|0);x()}function tda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;i[114610]=0;L(2015,a|0);d=i[114610];i[114610]=0;a:{b:{if((d|0)!=1){d=i[a+24>>2];i[114610]=0;e=+aa(2025,d|0,b|0,c|0);b=i[114610];i[114610]=0;if((b|0)!=1){break b}}b=H(0)|0;A()|0;M(b|0)|0;i[114610]=0;J(1989,35176,a|0,0,0);a=i[114610];i[114610]=0;if((a|0)==1){break a}O();e=0}return+e}a=B()|0;A()|0;i[114610]=0;K(20);b=i[114610];i[114610]=0;if((b|0)!=1){E(a|0);x()}a=H(0)|0;A()|0;gb(a);x()}function pn(a,b,c){var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;d=Xa-32|0;Xa=d;i[d+24>>2]=0;i[d+28>>2]=0;i[d+16>>2]=0;i[d+20>>2]=0;i[d+12>>2]=c;a:{if(c){while(1){i[d+8>>2]=16;e=i[rb(d+8|0,d+12|0)>>2];f=i[a>>2];if((e|0)!=((k=f,l=jb(d+16|0),m=i[a+8>>2]+g|0,n=e,j=i[i[f>>2]+28>>2],$a[j](k|0,l|0,m|0,n|0)|0)|0)){break a}if(Xc(d+16|0,b+g|0,e)){break a}f=i[d+12>>2]-e|0;i[d+12>>2]=f;g=e+g|0;if(f){continue}break}}Ib(a,c);h=1}Xa=d+32|0;return h}function Ufa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;b=Ph(a,b,c,d);i[a>>2]=80520;c=Gj(a+4256|0);d=a+4224|0;i[d>>2]=1017370378;i[d+4>>2]=1065353216;d=a+4216|0;i[d>>2]=1028670828;i[d+4>>2]=1059760811;i[a+4208>>2]=1056964608;i[a+4212>>2]=1017370378;i[114610]=0;I(1639,a+44|0,2,2)|0;d=i[114610];i[114610]=0;a:{if((d|0)==1){break a}i[114610]=0;L(1640,b|0);d=i[114610];i[114610]=0;if((d|0)==1){break a}return a|0}a=B()|0;A()|0;uf(c);ve(b);E(a|0);x()}function Yca(a,b){a=a|0;b=b|0;var c=0,d=p(0);i[114610]=0;L(2015,a|0);c=i[114610];i[114610]=0;a:{b:{if((c|0)!=1){c=i[a+24>>2];i[114610]=0;d=p(ba(2050,c|0,b|0));b=i[114610];i[114610]=0;if((b|0)!=1){break b}}b=H(0)|0;A()|0;M(b|0)|0;i[114610]=0;J(1989,35925,a|0,0,0);a=i[114610];i[114610]=0;if((a|0)==1){break a}O();d=p(0)}return p(d)}a=B()|0;A()|0;i[114610]=0;K(20);b=i[114610];i[114610]=0;if((b|0)!=1){E(a|0);x()}a=H(0)|0;A()|0;gb(a);x()}function Xca(a,b){a=a|0;b=b|0;var c=0,d=p(0);i[114610]=0;L(2015,a|0);c=i[114610];i[114610]=0;a:{b:{if((c|0)!=1){c=i[a+24>>2];i[114610]=0;d=p(ba(2051,c|0,b|0));b=i[114610];i[114610]=0;if((b|0)!=1){break b}}b=H(0)|0;A()|0;M(b|0)|0;i[114610]=0;J(1989,35968,a|0,0,0);a=i[114610];i[114610]=0;if((a|0)==1){break a}O();d=p(0)}return p(d)}a=B()|0;A()|0;i[114610]=0;K(20);b=i[114610];i[114610]=0;if((b|0)!=1){E(a|0);x()}a=H(0)|0;A()|0;gb(a);x()}function Wca(a,b){a=a|0;b=b|0;var c=0,d=p(0);i[114610]=0;L(2015,a|0);c=i[114610];i[114610]=0;a:{b:{if((c|0)!=1){c=i[a+24>>2];i[114610]=0;d=p(ba(2052,c|0,b|0));b=i[114610];i[114610]=0;if((b|0)!=1){break b}}b=H(0)|0;A()|0;M(b|0)|0;i[114610]=0;J(1989,36011,a|0,0,0);a=i[114610];i[114610]=0;if((a|0)==1){break a}O();d=p(0)}return p(d)}a=B()|0;A()|0;i[114610]=0;K(20);b=i[114610];i[114610]=0;if((b|0)!=1){E(a|0);x()}a=H(0)|0;A()|0;gb(a);x()}function Vca(a,b){a=a|0;b=b|0;var c=0,d=p(0);i[114610]=0;L(2015,a|0);c=i[114610];i[114610]=0;a:{b:{if((c|0)!=1){c=i[a+24>>2];i[114610]=0;d=p(ba(2053,c|0,b|0));b=i[114610];i[114610]=0;if((b|0)!=1){break b}}b=H(0)|0;A()|0;M(b|0)|0;i[114610]=0;J(1989,36055,a|0,0,0);a=i[114610];i[114610]=0;if((a|0)==1){break a}O();d=p(0)}return p(d)}a=B()|0;A()|0;i[114610]=0;K(20);b=i[114610];i[114610]=0;if((b|0)!=1){E(a|0);x()}a=H(0)|0;A()|0;gb(a);x()}function Uw(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=Xa-16|0;Xa=e;f=e;a:{if(!Vi(b)){c=gK(a,c,i[b+704>>2],d);break a}c=i[b+700>>2]}i[f+12>>2]=c;b=i[b+656>>2];b:{if(!b){break b}f=i[b+40>>2];if(!f){break b}d=(f|0)/2|0;b=i[a+1074420>>2];b=XMa(b,b>>31,c,c>>31);c=d+b|0;d=_a+(d>>31)|0;g=e,h=gc(YMa(c,c>>>0<b>>>0?d+1|0:d,f,f>>31),_a),i[g+12>>2]=h}kc(e+12|0,2147483647);a=YMa(0,i[e+12>>2],i[a+24620>>2]<<4,0);Xa=e+16|0;return a|0}function Uca(a,b){a=a|0;b=b|0;var c=0,d=p(0);i[114610]=0;L(2015,a|0);c=i[114610];i[114610]=0;a:{b:{if((c|0)!=1){c=i[a+24>>2];i[114610]=0;d=p(ba(2054,c|0,b|0));b=i[114610];i[114610]=0;if((b|0)!=1){break b}}b=H(0)|0;A()|0;M(b|0)|0;i[114610]=0;J(1989,36103,a|0,0,0);a=i[114610];i[114610]=0;if((a|0)==1){break a}O();d=p(0)}return p(d)}a=B()|0;A()|0;i[114610]=0;K(20);b=i[114610];i[114610]=0;if((b|0)!=1){E(a|0);x()}a=H(0)|0;A()|0;gb(a);x()}function PE(a){var b=p(0),c=0,d=p(0),e=p(0),f=p(0),g=p(0),h=0,i=p(0),j=0,k=0,l=p(0),n=p(0),o=p(0),q=p(0),r=0;j=a+ -24|0;b=m[j>>2];c=a+ -8|0;d=m[c>>2];e=p(b+d);k=a+ -16|0;f=m[k>>2];l=m[a>>2];g=p(f+l);m[a>>2]=e+g;m[c>>2]=g-e;c=a+ -28|0;g=m[c>>2];h=a+ -12|0;n=m[h>>2];e=p(g+n);r=h;h=a+ -20|0;i=m[h>>2];a=a+ -4|0;o=m[a>>2];q=p(i+o);m[r>>2]=q-e;i=p(o-i);b=p(d-b);m[c>>2]=i+b;d=p(n-g);f=p(l-f);m[k>>2]=d+f;m[j>>2]=f-d;m[a>>2]=q+e;m[h>>2]=i-b}function Yba(a){a=a|0;var b=0,c=0,d=0;i[114610]=0;L(2088,a|0);b=i[114610];i[114610]=0;a:{b:{if((b|0)!=1){b=i[a+28>>2];d=i[i[b>>2]+44>>2];i[114610]=0;c=+Z(d|0,b|0);b=i[114610];i[114610]=0;if((b|0)!=1){break b}}b=H(0)|0;A()|0;M(b|0)|0;i[114610]=0;J(1989,37874,a|0,0,0);a=i[114610];i[114610]=0;if((a|0)==1){break a}O();c=0}return+c}a=B()|0;A()|0;i[114610]=0;K(20);b=i[114610];i[114610]=0;if((b|0)!=1){E(a|0);x()}a=H(0)|0;A()|0;gb(a);x()}function Wba(a){a=a|0;var b=0,c=0,d=0;i[114610]=0;L(2088,a|0);b=i[114610];i[114610]=0;a:{b:{if((b|0)!=1){b=i[a+28>>2];d=i[i[b>>2]+36>>2];i[114610]=0;c=+Z(d|0,b|0);b=i[114610];i[114610]=0;if((b|0)!=1){break b}}b=H(0)|0;A()|0;M(b|0)|0;i[114610]=0;J(1989,37839,a|0,0,0);a=i[114610];i[114610]=0;if((a|0)==1){break a}O();c=0}return+c}a=B()|0;A()|0;i[114610]=0;K(20);b=i[114610];i[114610]=0;if((b|0)!=1){E(a|0);x()}a=H(0)|0;A()|0;gb(a);x()}function Uba(a){a=a|0;var b=0,c=0,d=0;i[114610]=0;L(2088,a|0);b=i[114610];i[114610]=0;a:{b:{if((b|0)!=1){b=i[a+28>>2];d=i[i[b>>2]+28>>2];i[114610]=0;c=+Z(d|0,b|0);b=i[114610];i[114610]=0;if((b|0)!=1){break b}}b=H(0)|0;A()|0;M(b|0)|0;i[114610]=0;J(1989,37805,a|0,0,0);a=i[114610];i[114610]=0;if((a|0)==1){break a}O();c=0}return+c}a=B()|0;A()|0;i[114610]=0;K(20);b=i[114610];i[114610]=0;if((b|0)!=1){E(a|0);x()}a=H(0)|0;A()|0;gb(a);x()}function rL(a,b){var c=0,d=0,e=0,f=0;h[a+24>>1]=0;i[a+20>>2]=0;i[a>>2]=0;i[a+4>>2]=0;i[a+8>>2]=0;i[a+12>>2]=0;e=a;d=3546895/+(b>>>0);c=d*.25;a:{if(q(c)<2147483648){b=~~c;break a}b=-2147483648}i[e+16>>2]=b;c=(d- +(b<<2))*4294967296;b:{if(q(c)<0x8000000000000000){f=~~c>>>0;b=q(c)>=1?c>0?~~s(u(c/4294967296),4294967295)>>>0:~~v((c- +(~~c>>>0>>>0))/4294967296)>>>0:0;break b}b=-2147483648}i[a>>2]=0;i[a+4>>2]=0;i[a+8>>2]=f;i[a+12>>2]=b}function yna(a){var b=0,c=0;while(1){Pm((o(b,896)+a|0)+1074984|0,a,b&65535);b=b+1|0;if((b|0)!=256){continue}break}Ri(a+1304360|0,1);i[a+1074444>>2]=i[a+480200>>2];b=a+1074416|0;i[b>>2]=i[a+480196>>2];i[a+1074420>>2]=i[a+480204>>2];i[a+480208>>2]=i[a+480208>>2]&-769;qx(a+1074376|0);h[a+1074440>>1]=0;c=a+1074428|0;i[c>>2]=0;i[c+4>>2]=0;c=a+1074396|0;i[c>>2]=0;i[c+4>>2]=0;i[a+1074376>>2]=0;i[a+1074380>>2]=0;i[a+1074392>>2]=i[b>>2]}function cea(a){a=a|0;var b=0,c=0;b=Xa-16|0;Xa=b;a:{b:{if(!a){break b}a=Zb(b+8|0,a);i[114610]=0;c=i[a+4>>2];i[b>>2]=i[a>>2];i[b+4>>2]=c;a=F(1996,b|0)|0;c=i[114610];i[114610]=0;if((c|0)!=1){break a}a=H(0)|0;A()|0;M(a|0)|0;i[114610]=0;J(1989,34188,0,0,0);a=i[114610];i[114610]=0;if((a|0)!=1){O();break b}a=B()|0;A()|0;i[114610]=0;K(20);b=i[114610];i[114610]=0;if((b|0)!=1){E(a|0);x()}a=H(0)|0;A()|0;gb(a);x()}a=0}Xa=b+16|0;return a|0}function Qoa(a,b,c,d,e){var f=0,h=0;if(j[a+480209|0]&16){if((c&255)>>>0>=16){g[b+869|0]=(c&240)>>>4}a=c&15;if(a){g[b+870|0]=a}g[b+868|0]=j[b+869|0];return}c=j[b+868|0]+ -1|0;g[b+868|0]=c;a:{if(c&255){break a}g[b+868|0]=j[b+869|0];c=j[b+870|0];c=d?c:0-c|0;b:{if(Vi(b)){i[b+876>>2]=i[b+876>>2]+o(c,i[i[i[b+656>>2]+44>>2]+36>>2]);break b}f=b,h=Vf(a,Lr(a,i[b+700>>2],0,0)+c|0,8363,0),i[f+700>>2]=h}if(!e){break a}i[b>>2]=0;i[b+4>>2]=0}}function vea(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,h=0;g[a+4202|0]=1;b=_h(p(p(we(i[a+16>>2])>>>0)*p(.04500000178813934)));c=_h(p(p(b>>>0)*p(1.1892070770263672)));d=_h(p(p(c>>>0)*p(1.1892070770263672)));h=_h(p(p(d>>>0)*p(1.1892070770263672)));e=_h(p(p(b+d>>>0)*p(.11546666920185089)));f=_h(p(p(c+h>>>0)*p(.11546666920185089)));i[a+4292>>2]=f;i[a+4288>>2]=e;i[a+4276>>2]=d-e;i[a+4272>>2]=b-e;i[a+4284>>2]=h-f;i[a+4280>>2]=c-f;XG(a);VG(a)}function Yha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;b=Ph(a,b,c,d);i[a>>2]=79416;d=Gj(a+4208|0);i[a+4220>>2]=0;i[a+4224>>2]=0;e=a,f=we(c),i[e+4232>>2]=f;i[114610]=0;L(1638,a+4260|0);c=i[114610];i[114610]=0;a:{if((c|0)==1){break a}i[114610]=0;I(1639,a+44|0,2,2)|0;c=i[114610];i[114610]=0;if((c|0)==1){break a}i[114610]=0;L(1640,b|0);c=i[114610];i[114610]=0;if((c|0)==1){break a}return a|0}a=B()|0;A()|0;uf(d);ve(b);E(a|0);x()}function As(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,h=0,i=0;d=(j[Nb(a,0)|0]&15)<<8|j[Nb(a,1)|0];a:{if(!d|(d|0)==4095){break a}e=108;while(1){f=k[(c<<1)+20832>>1];if(d>>>0>=f>>>0){if(!(!c|(d|0)==(f|0)|(k[(c<<1)+20830>>1]-d|0)>=(d-f|0))){e=c+24|0;break a}e=c+25|0;break a}c=c+1|0;if(c>>>0<84){continue}break}}g[b|0]=e;c=j[Nb(a,2)|0];h=b,i=j[Nb(a,0)|0]&16|c>>>4,g[h+1|0]=i;h=b,i=j[Nb(a,2)|0]&15,g[h+3|0]=i;h=b,i=j[Nb(a,3)|0],g[h+5|0]=i}function q5(a){var b=0,c=0,d=0,e=0;yb(a+36|0,255,2048);b=i[(j[a+23|0]?2092:4)+a>>2];if((b|0)>=1){b=(b|0)<32767?b:32767;e=(b|0)>1?b:1;d=i[a+8>>2];while(1){a:{if(j[c+d|0]>10){break a}b:{if(j[a+23|0]){b=Mk(i[i[a+2084>>2]+(c<<2)>>2]);break b}b=i[i[a+32>>2]+(c<<2)>>2]}if(b>>>0>1023){break a}while(1){h[((b<<1)+a|0)+36>>1]=c;d=i[a+8>>2];b=(1<<j[d+c|0])+b|0;if(b>>>0<1024){continue}break}}c=c+1|0;if((e|0)!=(c|0)){continue}break}}}



function Iz(a,b,c){var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;d=Xa-32|0;Xa=d;i[d+24>>2]=0;i[d+28>>2]=0;i[d+16>>2]=0;i[d+20>>2]=0;i[d+12>>2]=c;a:{if(c){while(1){i[d+8>>2]=16;e=i[rb(d+8|0,d+12|0)>>2];if((e|0)!=((k=a,l=jb(d+16|0),m=i[a+12>>2]+f|0,n=e,j=i[i[a>>2]+28>>2],$a[j](k|0,l|0,m|0,n|0)|0)|0)){break a}if(Xc(d+16|0,b+f|0,e)){break a}g=i[d+12>>2]-e|0;i[d+12>>2]=g;f=e+f|0;if(g){continue}break}}Dc(a,c);h=1}Xa=d+32|0;return h}function yda(a,b){a=a|0;b=b|0;var c=0,d=0;i[114610]=0;L(2015,a|0);c=i[114610];i[114610]=0;d=1;a:{b:{if((c|0)!=1){c=i[a+24>>2];i[114610]=0;D(2020,c|0,b|0);b=i[114610];i[114610]=0;if((b|0)!=1){break b}}b=H(0)|0;A()|0;M(b|0)|0;i[114610]=0;J(1989,35004,a|0,0,0);a=i[114610];i[114610]=0;if((a|0)==1){break a}O();d=0}return d|0}a=B()|0;A()|0;i[114610]=0;K(20);b=i[114610];i[114610]=0;if((b|0)!=1){E(a|0);x()}a=H(0)|0;A()|0;gb(a);x()}function i4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=Xa-16|0;Xa=e;while(1){a:{if((f|0)>=(c|0)){break a}d=i[a+12>>2];g=i[a+16>>2];b:{if(d>>>0<g>>>0){i[e+12>>2]=2147483647;i[e+8>>2]=g-d>>2;i[e+4>>2]=c-f;d=i[Nd(e+12|0,Nd(e+8|0,e+4|0))>>2];Gh(b,i[a+12>>2],d);i[a+12>>2]=i[a+12>>2]+(d<<2);b=(d<<2)+b|0;break b}d=$a[i[i[a>>2]+40>>2]](a)|0;if((d|0)==-1){break a}i[b>>2]=d;d=1;b=b+4|0}f=d+f|0;continue}break}Xa=e+16|0;return f|0}function gxa(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0;g=Xa-48|0;Xa=g;a:{b:{if(c>>>0>d>>>0){break b}if(ke(b)>>>0<=d>>>0){break b}while(1){f=c&65535;if(rh(se(b,f))){h=Jb(se(b,f));j=Kb(se(b,f));f=SM(g,e);i[114610]=0;J(1032,g+24|0,h|0,j|0,f|0);h=i[114610];i[114610]=0;if((h|0)==1){break a}Td(g+24|0);Td(f)}c=c+1|0;if((c&65535)>>>0<=d>>>0){continue}break}}RM(a,e);Xa=g+48|0;return}a=B()|0;A()|0;Td(f);E(a|0);x()}function CHa(a,b){var c=0;kd(b,0);c=a+32|0;i[b>>2]=j[c|0]|j[c+1|0]<<8|(j[c+2|0]<<16|j[c+3|0]<<24);c=a+38|0;i[b+4>>2]=j[c|0]|j[c+1|0]<<8|(j[c+2|0]<<16|j[c+3|0]<<24);c=a+42|0;c=j[c|0]|j[c+1|0]<<8|(j[c+2|0]<<16|j[c+3|0]<<24);i[b+24>>2]=16726;i[b+8>>2]=c;h[b+30>>1]=j[a+37|0]<<4;if(g[a+46|0]&1){i[b>>2]=i[b>>2]>>>1;i[b+4>>2]=i[b+4>>2]>>>1;i[b+8>>2]=i[b+8>>2]>>>1}if(!(!(j[a+47|0]&8)|l[b+8>>2]<=l[b+4>>2])){h[b+34>>1]=k[b+34>>1]|2}}function Bda(a,b){a=a|0;b=b|0;var c=0,d=0;i[114610]=0;L(2015,a|0);c=i[114610];i[114610]=0;d=1;a:{b:{if((c|0)!=1){c=i[a+24>>2];i[114610]=0;D(2018,c|0,b|0);b=i[114610];i[114610]=0;if((b|0)!=1){break b}}b=H(0)|0;A()|0;M(b|0)|0;i[114610]=0;J(1989,34938,a|0,0,0);a=i[114610];i[114610]=0;if((a|0)==1){break a}O();d=0}return d|0}a=B()|0;A()|0;i[114610]=0;K(20);b=i[114610];i[114610]=0;if((b|0)!=1){E(a|0);x()}a=H(0)|0;A()|0;gb(a);x()}function T7(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=a+32|0;vi(c,b);i[a+44>>2]=0;b=i[a+48>>2];if(b&8){d=a,e=xb(c)+lb(c)|0,i[d+44>>2]=e;pm(a,xb(c),xb(c),i[a+44>>2]);b=i[a+48>>2]}a:{if(!(b&16)){break a}b=lb(c);d=a,e=b+xb(c)|0,i[d+44>>2]=e;mm(c,qc(c));aw(a,xb(c),xb(c)+lb(c)|0);if(!(j[a+48|0]&3)){break a}b:{if((b|0)<=-1){c=b+ -2147483647|0;while(1){b=c;fr(a,2147483647);c=1;if((b|0)<0){continue}break}break b}if(!b){break a}}fr(a,b)}}function n4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,h=0,j=0,k=0;e=Xa-16|0;Xa=e;while(1){a:{if((f|0)>=(c|0)){break a}d=i[a+12>>2];h=i[a+16>>2];b:{if(d>>>0<h>>>0){i[e+12>>2]=2147483647;i[e+8>>2]=h-d;i[e+4>>2]=c-f;d=i[Nd(e+12|0,Nd(e+8|0,e+4|0))>>2];jh(b,i[a+12>>2],d);i[a+12>>2]=i[a+12>>2]+d;break b}d=$a[i[i[a>>2]+40>>2]](a)|0;if((d|0)==-1){break a}j=b,k=om(d),g[j|0]=k;d=1}b=b+d|0;f=d+f|0;continue}break}Xa=e+16|0;return f|0}function mba(a){var b=0,c=0,d=0;b=Xa-48|0;Xa=b;c=Bb(b+16|0,39526);i[114610]=0;D(2121,b|0,2);d=i[114610];i[114610]=0;a:{b:{c:{d:{if((d|0)!=1){i[114610]=0;G(3,b+32|0,c|0,b|0);d=i[114610];i[114610]=0;if((d|0)==1){break d}i[114610]=0;G(9,a|0,0,b+32|0);a=i[114610];i[114610]=0;if((a|0)==1){break c}eb(b+32|0);eb(b);eb(c);Xa=b+48|0;return}a=B()|0;A()|0;break a}a=B()|0;A()|0;break b}a=B()|0;A()|0;eb(b+32|0)}eb(b)}eb(c);E(a|0);x()}function ZH(a,b,c){var d=0,e=0;d=Xa-16|0;Xa=d;a:{if(qb(a)>>>0>511){break a}if(!hf(i[i[b>>2]+ -12>>2]+b|0)){break a}hia(d+8|0,b,c);b:{c:{if(!$c(d+8|0)){i[114610]=0;G(1631,d|0,b|0,c|0);b=i[114610];i[114610]=0;if((b|0)==1){break c}iQ(d+8|0,sd(d));Hf(d)}if(!$c(d+8|0)){break b}e=i[d+8>>2];i[114610]=0;D(1632,a|0,d+8|0);a=i[114610];i[114610]=0;if((a|0)!=1){break b}}a=B()|0;A()|0;Hf(d+8|0);E(a|0);x()}Hf(d+8|0)}Xa=d+16|0;return e}function w7(a,b){var c=0,d=0,e=0,f=0;c=Xa-80|0;Xa=c;d=i[a>>2];f=i[d+4>>2];i[c+40>>2]=i[d+20>>2];e=i[d+16>>2];i[c+32>>2]=i[d+12>>2];i[c+36>>2]=e;hm(c- -64|0,c+32|0,f);d=Vd(c+48|0,i[i[a+4>>2]>>2],i[i[a+8>>2]>>2],i[i[a+12>>2]>>2]);f=i[i[a+12>>2]>>2];a=i[i[a+8>>2]>>2];i[c+24>>2]=i[c+72>>2];e=i[c+68>>2];i[c+16>>2]=i[c+64>>2];i[c+20>>2]=e;i[c+8>>2]=i[d+8>>2];e=i[d+4>>2];i[c>>2]=i[d>>2];i[c+4>>2]=e;t7(c+16|0,c,b,a,f);Xa=c+80|0}function u7(a,b){var c=0,d=0,e=0,f=0;c=Xa-80|0;Xa=c;d=i[a>>2];f=i[d+4>>2];i[c+40>>2]=i[d+20>>2];e=i[d+16>>2];i[c+32>>2]=i[d+12>>2];i[c+36>>2]=e;hm(c- -64|0,c+32|0,f);d=Vd(c+48|0,i[i[a+4>>2]>>2],i[i[a+8>>2]>>2],i[i[a+12>>2]>>2]);f=i[i[a+12>>2]>>2];a=i[i[a+8>>2]>>2];i[c+24>>2]=i[c+72>>2];e=i[c+68>>2];i[c+16>>2]=i[c+64>>2];i[c+20>>2]=e;i[c+8>>2]=i[d+8>>2];e=i[d+4>>2];i[c>>2]=i[d>>2];i[c+4>>2]=e;r7(c+16|0,c,b,a,f);Xa=c+80|0}function p7(a,b){var c=0,d=0,e=0,f=0;c=Xa-80|0;Xa=c;d=i[a>>2];f=i[d+4>>2];i[c+40>>2]=i[d+20>>2];e=i[d+16>>2];i[c+32>>2]=i[d+12>>2];i[c+36>>2]=e;hm(c- -64|0,c+32|0,f);d=Vd(c+48|0,i[i[a+4>>2]>>2],i[i[a+8>>2]>>2],i[i[a+12>>2]>>2]);f=i[i[a+12>>2]>>2];a=i[i[a+8>>2]>>2];i[c+24>>2]=i[c+72>>2];e=i[c+68>>2];i[c+16>>2]=i[c+64>>2];i[c+20>>2]=e;i[c+8>>2]=i[d+8>>2];e=i[d+4>>2];i[c>>2]=i[d>>2];i[c+4>>2]=e;n7(c+16|0,c,b,a,f);Xa=c+80|0}function o7(a,b){var c=0,d=0,e=0,f=0;c=Xa-80|0;Xa=c;d=i[a>>2];f=i[d+4>>2];i[c+40>>2]=i[d+20>>2];e=i[d+16>>2];i[c+32>>2]=i[d+12>>2];i[c+36>>2]=e;hm(c- -64|0,c+32|0,f);d=Vd(c+48|0,i[i[a+4>>2]>>2],i[i[a+8>>2]>>2],i[i[a+12>>2]>>2]);f=i[i[a+12>>2]>>2];a=i[i[a+8>>2]>>2];i[c+24>>2]=i[c+72>>2];e=i[c+68>>2];i[c+16>>2]=i[c+64>>2];i[c+20>>2]=e;i[c+8>>2]=i[d+8>>2];e=i[d+4>>2];i[c>>2]=i[d>>2];i[c+4>>2]=e;l7(c+16|0,c,b,a,f);Xa=c+80|0}function f7(a,b){var c=0,d=0,e=0,f=0;c=Xa-80|0;Xa=c;d=i[a>>2];f=i[d+4>>2];i[c+40>>2]=i[d+20>>2];e=i[d+16>>2];i[c+32>>2]=i[d+12>>2];i[c+36>>2]=e;ao(c- -64|0,c+32|0,f);d=Vd(c+48|0,i[i[a+4>>2]>>2],i[i[a+8>>2]>>2],i[i[a+12>>2]>>2]);f=i[i[a+12>>2]>>2];a=i[i[a+8>>2]>>2];i[c+24>>2]=i[c+72>>2];e=i[c+68>>2];i[c+16>>2]=i[c+64>>2];i[c+20>>2]=e;i[c+8>>2]=i[d+8>>2];e=i[d+4>>2];i[c>>2]=i[d>>2];i[c+4>>2]=e;d7(c+16|0,c,b,a,f);Xa=c+80|0}function b7(a,b){var c=0,d=0,e=0,f=0;c=Xa-80|0;Xa=c;d=i[a>>2];f=i[d+4>>2];i[c+40>>2]=i[d+20>>2];e=i[d+16>>2];i[c+32>>2]=i[d+12>>2];i[c+36>>2]=e;ao(c- -64|0,c+32|0,f);d=Vd(c+48|0,i[i[a+4>>2]>>2],i[i[a+8>>2]>>2],i[i[a+12>>2]>>2]);f=i[i[a+12>>2]>>2];a=i[i[a+8>>2]>>2];i[c+24>>2]=i[c+72>>2];e=i[c+68>>2];i[c+16>>2]=i[c+64>>2];i[c+20>>2]=e;i[c+8>>2]=i[d+8>>2];e=i[d+4>>2];i[c>>2]=i[d>>2];i[c+4>>2]=e;$6(c+16|0,c,b,a,f);Xa=c+80|0}function a7(a,b){var c=0,d=0,e=0,f=0;c=Xa-80|0;Xa=c;d=i[a>>2];f=i[d+4>>2];i[c+40>>2]=i[d+20>>2];e=i[d+16>>2];i[c+32>>2]=i[d+12>>2];i[c+36>>2]=e;ao(c- -64|0,c+32|0,f);d=Vd(c+48|0,i[i[a+4>>2]>>2],i[i[a+8>>2]>>2],i[i[a+12>>2]>>2]);f=i[i[a+12>>2]>>2];a=i[i[a+8>>2]>>2];i[c+24>>2]=i[c+72>>2];e=i[c+68>>2];i[c+16>>2]=i[c+64>>2];i[c+20>>2]=e;i[c+8>>2]=i[d+8>>2];e=i[d+4>>2];i[c>>2]=i[d>>2];i[c+4>>2]=e;Z6(c+16|0,c,b,a,f);Xa=c+80|0}function Vq(a,b){var c=0,d=0,e=0,f=0;c=Xa-80|0;Xa=c;d=i[a>>2];f=i[d+4>>2];i[c+40>>2]=i[d+20>>2];e=i[d+16>>2];i[c+32>>2]=i[d+12>>2];i[c+36>>2]=e;ao(c- -64|0,c+32|0,f);d=Vd(c+48|0,i[i[a+4>>2]>>2],i[i[a+8>>2]>>2],i[i[a+12>>2]>>2]);f=i[i[a+12>>2]>>2];a=i[i[a+8>>2]>>2];i[c+24>>2]=i[c+72>>2];e=i[c+68>>2];i[c+16>>2]=i[c+64>>2];i[c+20>>2]=e;i[c+8>>2]=i[d+8>>2];e=i[d+4>>2];i[c>>2]=i[d>>2];i[c+4>>2]=e;e7(c+16|0,c,b,a,f);Xa=c+80|0}function Lv(a,b){var c=0,d=0,e=0,f=0;c=Xa-80|0;Xa=c;d=i[a>>2];f=i[d+4>>2];i[c+40>>2]=i[d+20>>2];e=i[d+16>>2];i[c+32>>2]=i[d+12>>2];i[c+36>>2]=e;hm(c- -64|0,c+32|0,f);d=Vd(c+48|0,i[i[a+4>>2]>>2],i[i[a+8>>2]>>2],i[i[a+12>>2]>>2]);f=i[i[a+12>>2]>>2];a=i[i[a+8>>2]>>2];i[c+24>>2]=i[c+72>>2];e=i[c+68>>2];i[c+16>>2]=i[c+64>>2];i[c+20>>2]=e;i[c+8>>2]=i[d+8>>2];e=i[d+4>>2];i[c>>2]=i[d>>2];i[c+4>>2]=e;s7(c+16|0,c,b,a,f);Xa=c+80|0}function Kv(a,b){var c=0,d=0,e=0,f=0;c=Xa-80|0;Xa=c;d=i[a>>2];f=i[d+4>>2];i[c+40>>2]=i[d+20>>2];e=i[d+16>>2];i[c+32>>2]=i[d+12>>2];i[c+36>>2]=e;hm(c- -64|0,c+32|0,f);d=Vd(c+48|0,i[i[a+4>>2]>>2],i[i[a+8>>2]>>2],i[i[a+12>>2]>>2]);f=i[i[a+12>>2]>>2];a=i[i[a+8>>2]>>2];i[c+24>>2]=i[c+72>>2];e=i[c+68>>2];i[c+16>>2]=i[c+64>>2];i[c+20>>2]=e;i[c+8>>2]=i[d+8>>2];e=i[d+4>>2];i[c>>2]=i[d>>2];i[c+4>>2]=e;m7(c+16|0,c,b,a,f);Xa=c+80|0}function Jv(a,b){var c=0,d=0,e=0,f=0;c=Xa-80|0;Xa=c;d=i[a>>2];f=i[d+4>>2];i[c+40>>2]=i[d+20>>2];e=i[d+16>>2];i[c+32>>2]=i[d+12>>2];i[c+36>>2]=e;ao(c- -64|0,c+32|0,f);d=Vd(c+48|0,i[i[a+4>>2]>>2],i[i[a+8>>2]>>2],i[i[a+12>>2]>>2]);f=i[i[a+12>>2]>>2];a=i[i[a+8>>2]>>2];i[c+24>>2]=i[c+72>>2];e=i[c+68>>2];i[c+16>>2]=i[c+64>>2];i[c+20>>2]=e;i[c+8>>2]=i[d+8>>2];e=i[d+4>>2];i[c>>2]=i[d>>2];i[c+4>>2]=e;_6(c+16|0,c,b,a,f);Xa=c+80|0}function kd(a,b){a=a|0;b=b|0;var c=0,d=0;d=Xa-16|0;Xa=d;Om(a);i[a+16>>2]=0;i[a+8>>2]=0;i[a+12>>2]=0;i[a>>2]=0;i[a+4>>2]=0;h[a+32>>1]=64;i[a+24>>2]=8363;i[a+28>>2]=16777344;i[a+36>>2]=0;g[a+39|0]=0;g[a+40|0]=0;g[a+41|0]=0;g[a+42|0]=0;c=k[a+34>>1]&-25151;h[a+34>>1]=(b|0)==4?c|32:c;b=Bb(d,18516);i[114610]=0;C(370,a+43|0,b|0)|0;c=i[114610];i[114610]=0;if((c|0)!=1){eb(b);nM(a);Xa=d+16|0;return}a=B()|0;A()|0;eb(b);E(a|0);x()}function Gca(a,b){a=a|0;b=b|0;var c=0;i[114610]=0;L(2015,a|0);c=i[114610];i[114610]=0;a:{b:{if((c|0)!=1){c=i[a+24>>2];i[114610]=0;b=C(2068,c|0,b|0)|0;c=i[114610];i[114610]=0;if((c|0)!=1){break b}}b=H(0)|0;A()|0;M(b|0)|0;i[114610]=0;J(1989,36551,a|0,0,0);a=i[114610];i[114610]=0;if((a|0)==1){break a}O();b=0}return b|0}a=B()|0;A()|0;i[114610]=0;K(20);b=i[114610];i[114610]=0;if((b|0)!=1){E(a|0);x()}a=H(0)|0;A()|0;gb(a);x()}function Fca(a,b){a=a|0;b=b|0;var c=0;i[114610]=0;L(2015,a|0);c=i[114610];i[114610]=0;a:{b:{if((c|0)!=1){c=i[a+24>>2];i[114610]=0;b=C(2069,c|0,b|0)|0;c=i[114610];i[114610]=0;if((c|0)!=1){break b}}b=H(0)|0;A()|0;M(b|0)|0;i[114610]=0;J(1989,36584,a|0,0,0);a=i[114610];i[114610]=0;if((a|0)==1){break a}O();b=0}return b|0}a=B()|0;A()|0;i[114610]=0;K(20);b=i[114610];i[114610]=0;if((b|0)!=1){E(a|0);x()}a=H(0)|0;A()|0;gb(a);x()}function yAa(a){var b=0;b=Xa-16|0;Xa=b;g[a|0]=0;g[a+1|0]=0;g[a+2|0]=0;g[a+3|0]=0;g[a+4|0]=0;g[a+5|0]=0;g[a+6|0]=0;g[a+7|0]=0;g[a+24|0]=0;g[a+25|0]=0;g[a+26|0]=0;g[a+27|0]=0;g[a+28|0]=0;g[a+29|0]=0;g[a+30|0]=0;g[a+31|0]=0;g[a+16|0]=0;g[a+17|0]=0;g[a+18|0]=0;g[a+19|0]=0;g[a+20|0]=0;g[a+21|0]=0;g[a+22|0]=0;g[a+23|0]=0;g[a+8|0]=0;g[a+9|0]=0;g[a+10|0]=0;g[a+11|0]=0;g[a+12|0]=0;g[a+13|0]=0;g[a+14|0]=0;g[a+15|0]=0;Xa=b+16|0}function pwa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,j=0,k=0,l=0;b=Xa-16|0;Xa=b;g=i[a+24>>2];j=i[a+20>>2];k=i[a+16>>2];e=i[a+4>>2];f=i[a>>2];i[b+8>>2]=f;i[b+12>>2]=e;l=i[a+12>>2];i[b>>2]=i[a+8>>2];i[b+4>>2]=l;if(d){while(1){e=h[(e<<1)+k>>1];i[c>>2]=i[c>>2]+o(e,j);i[c+4>>2]=i[c+4>>2]+o(e,g);zb(b+8|0,b);d=d+ -1|0;if(d){c=c+8|0;e=i[b+12>>2];continue}break}f=i[b+8>>2];e=i[b+12>>2]}i[a>>2]=f;i[a+4>>2]=e;Xa=b+16|0}function wO(a){var b=0;b=Xa-16|0;Xa=b;g[a|0]=0;g[a+1|0]=0;g[a+2|0]=0;g[a+3|0]=0;g[a+4|0]=0;g[a+5|0]=0;g[a+6|0]=0;g[a+7|0]=0;g[a+22|0]=0;g[a+23|0]=0;g[a+24|0]=0;g[a+25|0]=0;g[a+26|0]=0;g[a+27|0]=0;g[a+28|0]=0;g[a+29|0]=0;g[a+16|0]=0;g[a+17|0]=0;g[a+18|0]=0;g[a+19|0]=0;g[a+20|0]=0;g[a+21|0]=0;g[a+22|0]=0;g[a+23|0]=0;g[a+8|0]=0;g[a+9|0]=0;g[a+10|0]=0;g[a+11|0]=0;g[a+12|0]=0;g[a+13|0]=0;g[a+14|0]=0;g[a+15|0]=0;Xa=b+16|0}function qo(a,b,c){var d=0,e=0;a=Ke(a);d=lb(b);i[114610]=0;D(113,a|0,d|0);d=i[114610];i[114610]=0;if((d|0)!=1){a:{if(lb(b)){while(1){d=j[Sb(b,e)|0];b:{if(256>d>>>0){d=i[(d<<2)+c>>2];i[114610]=0;D(112,a|0,d|0);d=i[114610];i[114610]=0;if((d|0)!=1){break b}break a}i[114610]=0;D(112,a|0,65533);d=i[114610];i[114610]=0;if((d|0)==1){break a}}e=e+1|0;if(e>>>0<lb(b)>>>0){continue}break}}return}}b=B()|0;A()|0;nc(a);E(b|0);x()}function vda(a,b){a=a|0;b=+b;var c=0;i[114610]=0;L(2015,a|0);c=i[114610];i[114610]=0;a:{b:{if((c|0)!=1){c=i[a+24>>2];i[114610]=0;b=+Ta(2023,c|0,+b);c=i[114610];i[114610]=0;if((c|0)!=1){break b}}c=H(0)|0;A()|0;M(c|0)|0;i[114610]=0;J(1989,35104,a|0,0,0);a=i[114610];i[114610]=0;if((a|0)==1){break a}O();b=0}return+b}a=B()|0;A()|0;i[114610]=0;K(20);c=i[114610];i[114610]=0;if((c|0)!=1){E(a|0);x()}a=H(0)|0;A()|0;gb(a);x()}function _9(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=Xa-16|0;Xa=f;a:{b:{c:{if(!(e?d:0)){b=P(8)|0;i[114610]=0;c=C(85,f|0,38642)|0;a=i[114610];i[114610]=0;if((a|0)==1){break c}Ub(b,c);i[114610]=0;G(2009,b|0,83568,2017);a=i[114610];i[114610]=0;if((a|0)!=1){break a}a=B()|0;A()|0;eb(c);break b}Nh(a,b,2);c=Uv(a,c,d,e,0,0);n[a+16>>3]=+(c>>>0)/+(b|0)+n[a+16>>3];Xa=f+16|0;return c|0}a=B()|0;A()|0;Q(b|0)}E(a|0)}x()}function X9(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=Xa-16|0;Xa=f;a:{b:{c:{if(!(e?d:0)){b=P(8)|0;i[114610]=0;c=C(85,f|0,38642)|0;a=i[114610];i[114610]=0;if((a|0)==1){break c}Ub(b,c);i[114610]=0;G(2009,b|0,83568,2017);a=i[114610];i[114610]=0;if((a|0)!=1){break a}a=B()|0;A()|0;eb(c);break b}Nh(a,b,2);c=Tv(a,c,d,e,0,0);n[a+16>>3]=+(c>>>0)/+(b|0)+n[a+16>>3];Xa=f+16|0;return c|0}a=B()|0;A()|0;Q(b|0)}E(a|0)}x()}function Roa(a,b,c){var d=0,e=0,f=0,h=0,k=0;a:{if(c){g[b+836|0]=c;break a}c=j[b+836|0]}b:{c:{d:{e=c&240;d=c&15;if(!(!e|(d|0)!=15)){if(!(j[a+480209|0]&16)){break b}break d}f=i[a+480208>>2]&4096;if(!(!d|(e|0)!=240)){if(!f){break b}c=0-d|0;break c}if(f){break b}if(!d){break d}c=0-d|0;if(!e){break c}if(i[a+480180>>2]&25690144){break b}break c}c=(c&255)>>>4|0;if(!c){break b}}h=b,k=Eb(i[b+760>>2]+c|0,0,64),i[h+760>>2]=k}}function Rca(a){a=a|0;var b=0,c=0;i[114610]=0;L(2015,a|0);b=i[114610];i[114610]=0;a:{b:{if((b|0)!=1){b=i[a+24>>2];i[114610]=0;b=F(2057,b|0)|0;c=i[114610];i[114610]=0;if((c|0)!=1){break b}}b=H(0)|0;A()|0;M(b|0)|0;i[114610]=0;J(1989,36216,a|0,0,0);a=i[114610];i[114610]=0;if((a|0)==1){break a}O();b=0}return b|0}a=B()|0;A()|0;i[114610]=0;K(20);b=i[114610];i[114610]=0;if((b|0)!=1){E(a|0);x()}a=H(0)|0;A()|0;gb(a);x()}



function MX(){var a=0,b=0,c=0,d=0,e=0,f=0;a=Xa-48|0;Xa=a;a:{b=i[115917];if(b){c=b+48|0;if(RB(c)){d=a;if(i[c>>2]==1126902529&i[c+4>>2]==1129074247){c=i[b+44>>2]}else{c=b+80|0}i[d+44>>2]=c;d=i[b>>2];b=i[d+4>>2];if($a[i[i[17831]+16>>2]](71324,d,a+44|0)|0){break a}i[a+20>>2]=b;i[a+16>>2]=i[21328];x()}i[a+32>>2]=i[21328];x()}x()}c=i[21328];d=i[a+44>>2];e=a,f=$a[i[i[d>>2]+8>>2]](d)|0,i[e+8>>2]=f;i[a+4>>2]=b;i[a>>2]=c;x()}function GA(a){var b=0;a:{if((j[a|0]|j[a+1|0]<<8|(j[a+2|0]<<16|j[a+3|0]<<24))!=1179340888|(j[a+8|0]|j[a+9|0]<<8|(j[a+10|0]<<16|j[a+11|0]<<24))!=1213419859){break a}b=a+4|0;if(!(j[b|0]|j[b+1|0]<<8|(j[b+2|0]<<16|j[b+3|0]<<24))){break a}a=a+12|0;if(!(j[a|0]|j[a+1|0]<<8|(j[a+2|0]<<16|j[a+3|0]<<24))){break a}a=j[b|0]|j[b+1|0]<<8|(j[b+2|0]<<16|j[b+3|0]<<24);return(a<<24|a<<8&16711680|(a>>>8&65280|a>>>24))>>>0>27}return 0}function qwa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,h=0,j=0,k=0,l=0;b=Xa-16|0;Xa=b;h=i[a+24>>2];j=i[a+20>>2];k=i[a+16>>2];e=i[a+4>>2];f=i[a>>2];i[b+8>>2]=f;i[b+12>>2]=e;l=i[a+12>>2];i[b>>2]=i[a+8>>2];i[b+4>>2]=l;if(d){while(1){e=g[e+k|0]<<8;i[c>>2]=i[c>>2]+o(e,j);i[c+4>>2]=i[c+4>>2]+o(e,h);zb(b+8|0,b);d=d+ -1|0;if(d){c=c+8|0;e=i[b+12>>2];continue}break}f=i[b+8>>2];e=i[b+12>>2]}i[a>>2]=f;i[a+4>>2]=e;Xa=b+16|0}function R5(a,b){var c=0,d=0,e=0;a:{b:{c:{c=j[a+3|0];e=c>>>6|0;switch(e+ -1|0){case 2:break a;case 0:break c;default:break b}}d=(c>>>2&12)+4|0;break a}d=32}c=j[a+1|0];d:{if((c&6)==6){a=32;c=50140;break d}if(!(c&8)){a=30;c=50143;break d}c=j[a+2|0]>>>2&3;a=Ev(a)>>>((e|0)!=3)|0;a=a?a:192;if(a>>>0<=55){a=(c|0)==2?12:8;c=50164;break d}a=(c|0)!=1?a>>>0>95?30:27:27;c=50152}g[b+768|0]=a;g[b+769|0]=(d|0)>(a|0)?a:d;return c}function ku(a,b,c,d,e,f,h,j){var k=0,l=0,m=0;k=Xa-16|0;Xa=k;if((b^-1)+ -17>>>0>=c>>>0){l=xb(a);a:{if(2147483623>b>>>0){i[k+8>>2]=b<<1;i[k+12>>2]=b+c;c=Dk(i[Jc(k+12|0,k+8|0)>>2]);break a}c=-18}m=c+1|0;c=Ii(m);if(e){jh(c,l,e)}if(h){jh(c+e|0,j,h)}d=d-f|0;j=d-e|0;if(j){jh((c+e|0)+h|0,(e+l|0)+f|0,j)}b=b+1|0;if((b|0)!=11){Uf(a,l,b)}gf(a,c);fg(a,m);b=a;a=d+h|0;ce(b,a);g[k+7|0]=0;Rd(a+c|0,k+7|0);Xa=k+16|0;return}gg();x()}function zCa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=Xa-48|0;Xa=e;ai(e+24|0,e+16|0,c);i[114610]=0;G(874,e+36|0,e+8|0,d|0);c=i[114610];i[114610]=0;a:{b:{if((c|0)!=1){i[114610]=0;D(672,e|0,e+24|0);c=i[114610];i[114610]=0;if((c|0)==1){break b}i[114610]=0;G(518,a|0,b|0,e|0);a=i[114610];i[114610]=0;if((a|0)==1){break b}Me(e+24|0);Xa=e+48|0;return}c=B()|0;A()|0;eb(e+24|0);break a}c=B()|0;A()|0;Me(e+24|0)}E(c|0);x()}function wv(a){var b=0,c=0,d=0;a:{b:{if(!i[a+1384>>2]){b=i[a+1380>>2];if((b|0)==-1){i[a+1388>>2]=i[a+1116>>2]+ -1;if(!Rq(a)){i[a+1384>>2]=1;return 0}if(!(g[a+1375|0]&1)){break b}b=i[a+1380>>2]}d=b+1|0;i[a+1380>>2]=d;c=j[(a+b|0)+1120|0];if((c|0)!=255){i[a+1388>>2]=b;i[a+1384>>2]=1}if((d|0)>=i[a+1116>>2]){i[a+1380>>2]=-1}if(j[a+1376|0]){break a}g[a+1376|0]=c}return c}Lb(a,32);return 0}V(50566,50448,1549,50587);x()}function jta(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=Xa-48|0;Xa=e;az(e+24|0,e+16|0,c);i[114610]=0;G(671,e+36|0,e+8|0,d|0);c=i[114610];i[114610]=0;a:{b:{if((c|0)!=1){i[114610]=0;D(672,e|0,e+24|0);c=i[114610];i[114610]=0;if((c|0)==1){break b}i[114610]=0;G(518,a|0,b|0,e|0);a=i[114610];i[114610]=0;if((a|0)==1){break b}Me(e+24|0);Xa=e+48|0;return}c=B()|0;A()|0;eb(e+24|0);break a}c=B()|0;A()|0;Me(e+24|0)}E(c|0);x()}function Ada(a){a=a|0;var b=0,c=0;i[114610]=0;L(2015,a|0);b=i[114610];i[114610]=0;a:{b:{if((b|0)!=1){b=i[a+24>>2];i[114610]=0;b=F(2019,b|0)|0;c=i[114610];i[114610]=0;if((c|0)!=1){break b}}b=H(0)|0;A()|0;M(b|0)|0;i[114610]=0;J(1989,34968,a|0,0,0);a=i[114610];i[114610]=0;if((a|0)==1){break a}O();b=-1}return b|0}a=B()|0;A()|0;i[114610]=0;K(20);b=i[114610];i[114610]=0;if((b|0)!=1){E(a|0);x()}a=H(0)|0;A()|0;gb(a);x()}function $ka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,k=0,l=0;d=Xa-32|0;Xa=d;Ws(d,2,a+2|0);oc(d+16|0,d);i[114610]=0;C(369,b+492|0,d+16|0)|0;e=i[114610];i[114610]=0;if((e|0)!=1){eb(d+16|0);e=b+236|0;f=c+1|0;c=0;while(1){g=j[(a+c|0)+31|0];k=Mc(e,c),l=f+g|0,h[k>>1]=l;c=c+1|0;if(c>>>0<120){continue}break}c=a+223|0;i[b>>2]=(j[c|0]|j[c+1|0]<<8)<<5;Rka(a+158|0,b);Xa=d+32|0;return}a=B()|0;A()|0;eb(d+16|0);E(a|0);x()}function xda(a){a=a|0;var b=0,c=0;i[114610]=0;L(2015,a|0);b=i[114610];i[114610]=0;a:{b:{if((b|0)!=1){b=i[a+24>>2];i[114610]=0;b=F(2021,b|0)|0;c=i[114610];i[114610]=0;if((c|0)!=1){break b}}b=H(0)|0;A()|0;M(b|0)|0;i[114610]=0;J(1989,35036,a|0,0,0);a=i[114610];i[114610]=0;if((a|0)==1){break a}O();b=0}return b|0}a=B()|0;A()|0;i[114610]=0;K(20);b=i[114610];i[114610]=0;if((b|0)!=1){E(a|0);x()}a=H(0)|0;A()|0;gb(a);x()}function jea(a,b,c,d){var e=0,f=0,g=0,h=0,j=0,k=0;f=i[a+4160>>2];g=i[a+4156>>2];if(d){k=i[a+4164>>2];e=i[a+4168>>2];while(1){h=i[b>>2];j=i[b+4>>2];e=e-j|0;f=(((e|0)/1024|0)-e|0)+f|0;i[c+4>>2]=f+i[c+4>>2];e=k-h|0;e=(((e|0)/1024|0)-e|0)+g|0;i[c>>2]=e+i[c>>2];f=f+((f|0)/-512|0)|0;g=e+((e|0)/-512|0)|0;c=c+8|0;b=b+8|0;e=j;k=h;d=d+ -1|0;if(d){continue}break}}i[a+4168>>2]=j;i[a+4164>>2]=h;i[a+4160>>2]=f;i[a+4156>>2]=g}function cda(a){a=a|0;var b=0,c=0;i[114610]=0;L(2015,a|0);b=i[114610];i[114610]=0;a:{b:{if((b|0)!=1){b=i[a+24>>2];i[114610]=0;b=F(2044,b|0)|0;c=i[114610];i[114610]=0;if((c|0)!=1){break b}}b=H(0)|0;A()|0;M(b|0)|0;i[114610]=0;J(1989,35716,a|0,0,0);a=i[114610];i[114610]=0;if((a|0)==1){break a}O();b=0}return b|0}a=B()|0;A()|0;i[114610]=0;K(20);b=i[114610];i[114610]=0;if((b|0)!=1){E(a|0);x()}a=H(0)|0;A()|0;gb(a);x()}function bda(a){a=a|0;var b=0,c=0;i[114610]=0;L(2015,a|0);b=i[114610];i[114610]=0;a:{b:{if((b|0)!=1){b=i[a+24>>2];i[114610]=0;b=F(2045,b|0)|0;c=i[114610];i[114610]=0;if((c|0)!=1){break b}}b=H(0)|0;A()|0;M(b|0)|0;i[114610]=0;J(1989,35749,a|0,0,0);a=i[114610];i[114610]=0;if((a|0)==1){break a}O();b=0}return b|0}a=B()|0;A()|0;i[114610]=0;K(20);b=i[114610];i[114610]=0;if((b|0)!=1){E(a|0);x()}a=H(0)|0;A()|0;gb(a);x()}function ada(a){a=a|0;var b=0,c=0;i[114610]=0;L(2015,a|0);b=i[114610];i[114610]=0;a:{b:{if((b|0)!=1){b=i[a+24>>2];i[114610]=0;b=F(2046,b|0)|0;c=i[114610];i[114610]=0;if((c|0)!=1){break b}}b=H(0)|0;A()|0;M(b|0)|0;i[114610]=0;J(1989,35782,a|0,0,0);a=i[114610];i[114610]=0;if((a|0)==1){break a}O();b=0}return b|0}a=B()|0;A()|0;i[114610]=0;K(20);b=i[114610];i[114610]=0;if((b|0)!=1){E(a|0);x()}a=H(0)|0;A()|0;gb(a);x()}function _ca(a){a=a|0;var b=0,c=0;i[114610]=0;L(2015,a|0);b=i[114610];i[114610]=0;a:{b:{if((b|0)!=1){b=i[a+24>>2];i[114610]=0;b=F(2048,b|0)|0;c=i[114610];i[114610]=0;if((c|0)!=1){break b}}b=H(0)|0;A()|0;M(b|0)|0;i[114610]=0;J(1989,35850,a|0,0,0);a=i[114610];i[114610]=0;if((a|0)==1){break a}O();b=0}return b|0}a=B()|0;A()|0;i[114610]=0;K(20);b=i[114610];i[114610]=0;if((b|0)!=1){E(a|0);x()}a=H(0)|0;A()|0;gb(a);x()}function Zca(a){a=a|0;var b=0,c=0;i[114610]=0;L(2015,a|0);b=i[114610];i[114610]=0;a:{b:{if((b|0)!=1){b=i[a+24>>2];i[114610]=0;b=F(2049,b|0)|0;c=i[114610];i[114610]=0;if((c|0)!=1){break b}}b=H(0)|0;A()|0;M(b|0)|0;i[114610]=0;J(1989,35881,a|0,0,0);a=i[114610];i[114610]=0;if((a|0)==1){break a}O();b=0}return b|0}a=B()|0;A()|0;i[114610]=0;K(20);b=i[114610];i[114610]=0;if((b|0)!=1){E(a|0);x()}a=H(0)|0;A()|0;gb(a);x()}function Tca(a){a=a|0;var b=0,c=0;i[114610]=0;L(2015,a|0);b=i[114610];i[114610]=0;a:{b:{if((b|0)!=1){b=i[a+24>>2];i[114610]=0;b=F(2055,b|0)|0;c=i[114610];i[114610]=0;if((c|0)!=1){break b}}b=H(0)|0;A()|0;M(b|0)|0;i[114610]=0;J(1989,36152,a|0,0,0);a=i[114610];i[114610]=0;if((a|0)==1){break a}O();b=0}return b|0}a=B()|0;A()|0;i[114610]=0;K(20);b=i[114610];i[114610]=0;if((b|0)!=1){E(a|0);x()}a=H(0)|0;A()|0;gb(a);x()}function Sca(a){a=a|0;var b=0,c=0;i[114610]=0;L(2015,a|0);b=i[114610];i[114610]=0;a:{b:{if((b|0)!=1){b=i[a+24>>2];i[114610]=0;b=F(2056,b|0)|0;c=i[114610];i[114610]=0;if((c|0)!=1){break b}}b=H(0)|0;A()|0;M(b|0)|0;i[114610]=0;J(1989,36184,a|0,0,0);a=i[114610];i[114610]=0;if((a|0)==1){break a}O();b=0}return b|0}a=B()|0;A()|0;i[114610]=0;K(20);b=i[114610];i[114610]=0;if((b|0)!=1){E(a|0);x()}a=H(0)|0;A()|0;gb(a);x()}function Qca(a){a=a|0;var b=0,c=0;i[114610]=0;L(2015,a|0);b=i[114610];i[114610]=0;a:{b:{if((b|0)!=1){b=i[a+24>>2];i[114610]=0;b=F(2058,b|0)|0;c=i[114610];i[114610]=0;if((c|0)!=1){break b}}b=H(0)|0;A()|0;M(b|0)|0;i[114610]=0;J(1989,36246,a|0,0,0);a=i[114610];i[114610]=0;if((a|0)==1){break a}O();b=0}return b|0}a=B()|0;A()|0;i[114610]=0;K(20);b=i[114610];i[114610]=0;if((b|0)!=1){E(a|0);x()}a=H(0)|0;A()|0;gb(a);x()}function Pca(a){a=a|0;var b=0,c=0;i[114610]=0;L(2015,a|0);b=i[114610];i[114610]=0;a:{b:{if((b|0)!=1){b=i[a+24>>2];i[114610]=0;b=F(2059,b|0)|0;c=i[114610];i[114610]=0;if((c|0)!=1){break b}}b=H(0)|0;A()|0;M(b|0)|0;i[114610]=0;J(1989,36278,a|0,0,0);a=i[114610];i[114610]=0;if((a|0)==1){break a}O();b=0}return b|0}a=B()|0;A()|0;i[114610]=0;K(20);b=i[114610];i[114610]=0;if((b|0)!=1){E(a|0);x()}a=H(0)|0;A()|0;gb(a);x()}function Oca(a){a=a|0;var b=0,c=0;i[114610]=0;L(2015,a|0);b=i[114610];i[114610]=0;a:{b:{if((b|0)!=1){b=i[a+24>>2];i[114610]=0;b=F(2060,b|0)|0;c=i[114610];i[114610]=0;if((c|0)!=1){break b}}b=H(0)|0;A()|0;M(b|0)|0;i[114610]=0;J(1989,36313,a|0,0,0);a=i[114610];i[114610]=0;if((a|0)==1){break a}O();b=0}return b|0}a=B()|0;A()|0;i[114610]=0;K(20);b=i[114610];i[114610]=0;if((b|0)!=1){E(a|0);x()}a=H(0)|0;A()|0;gb(a);x()}function $ca(a){a=a|0;var b=0,c=0;i[114610]=0;L(2015,a|0);b=i[114610];i[114610]=0;a:{b:{if((b|0)!=1){b=i[a+24>>2];i[114610]=0;b=F(2047,b|0)|0;c=i[114610];i[114610]=0;if((c|0)!=1){break b}}b=H(0)|0;A()|0;M(b|0)|0;i[114610]=0;J(1989,35815,a|0,0,0);a=i[114610];i[114610]=0;if((a|0)==1){break a}O();b=0}return b|0}a=B()|0;A()|0;i[114610]=0;K(20);b=i[114610];i[114610]=0;if((b|0)!=1){E(a|0);x()}a=H(0)|0;A()|0;gb(a);x()}function yJa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=Xa-48|0;Xa=e;Il(e+24|0,e+16|0,c);i[114610]=0;G(240,e+36|0,e+8|0,d|0);c=i[114610];i[114610]=0;a:{b:{if((c|0)!=1){i[114610]=0;D(78,e|0,e+24|0);c=i[114610];i[114610]=0;if((c|0)==1){break b}i[114610]=0;G(72,a|0,b|0,e|0);a=i[114610];i[114610]=0;if((a|0)==1){break b}Me(e+24|0);Xa=e+48|0;return}c=B()|0;A()|0;eb(e+24|0);break a}c=B()|0;A()|0;Me(e+24|0)}E(c|0);x()}function vLa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=Xa-48|0;Xa=e;Vz(e+24|0,e+16|0,c);i[114610]=0;G(444,e+36|0,e+8|0,d|0);c=i[114610];i[114610]=0;a:{b:{if((c|0)!=1){i[114610]=0;D(78,e|0,e+24|0);c=i[114610];i[114610]=0;if((c|0)==1){break b}i[114610]=0;G(72,a|0,b|0,e|0);a=i[114610];i[114610]=0;if((a|0)==1){break b}Me(e+24|0);Xa=e+48|0;return}c=B()|0;A()|0;eb(e+24|0);break a}c=B()|0;A()|0;Me(e+24|0)}E(c|0);x()}function as(a,b,c){var d=0,e=0,f=0,g=0,h=0,j=0;d=Xa-16|0;Xa=d;i[b+40>>2]=0;i[b+44>>2]=0;e=b- -64|0;i[e>>2]=0;i[e+4>>2]=0;i[b+56>>2]=0;i[b+60>>2]=0;i[b+48>>2]=0;i[b+52>>2]=0;while(1){tL(b,n[uk(c,0)>>3]);f=f+1|0;if((f|0)!=1e4){continue}break}g=d,h=Jb(c),i[g+8>>2]=h;g=d,h=Kb(c),i[g>>2]=h;if(pb(d+8|0,d)){while(1){e=i[d+8>>2];g=e,j=tL(b,n[e>>3]),n[g>>3]=j;Dx(d+8|0);if(pb(d+8|0,d)){continue}break}}Vra(a,c);Xa=d+16|0}function NGa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=Xa-48|0;Xa=e;Il(e+24|0,e+16|0,c);i[114610]=0;G(224,e+36|0,e+8|0,d|0);c=i[114610];i[114610]=0;a:{b:{if((c|0)!=1){i[114610]=0;D(78,e|0,e+24|0);c=i[114610];i[114610]=0;if((c|0)==1){break b}i[114610]=0;G(72,a|0,b|0,e|0);a=i[114610];i[114610]=0;if((a|0)==1){break b}Me(e+24|0);Xa=e+48|0;return}c=B()|0;A()|0;eb(e+24|0);break a}c=B()|0;A()|0;Me(e+24|0)}E(c|0);x()}function JW(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=Xa-48|0;Xa=e;ai(e+24|0,e+16|0,c);i[114610]=0;G(224,e+36|0,e+8|0,d|0);c=i[114610];i[114610]=0;a:{b:{if((c|0)!=1){i[114610]=0;D(78,e|0,e+24|0);c=i[114610];i[114610]=0;if((c|0)==1){break b}i[114610]=0;G(72,a|0,b|0,e|0);a=i[114610];i[114610]=0;if((a|0)==1){break b}Me(e+24|0);Xa=e+48|0;return}c=B()|0;A()|0;eb(e+24|0);break a}c=B()|0;A()|0;Me(e+24|0)}E(c|0);x()}function BAa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=Xa-48|0;Xa=e;eO(e+24|0,e+16|0,c);i[114610]=0;G(77,e+36|0,e+8|0,d|0);c=i[114610];i[114610]=0;a:{b:{if((c|0)!=1){i[114610]=0;D(78,e|0,e+24|0);c=i[114610];i[114610]=0;if((c|0)==1){break b}i[114610]=0;G(72,a|0,b|0,e|0);a=i[114610];i[114610]=0;if((a|0)==1){break b}Me(e+24|0);Xa=e+48|0;return}c=B()|0;A()|0;eb(e+24|0);break a}c=B()|0;A()|0;Me(e+24|0)}E(c|0);x()}function wda(a){a=a|0;var b=0,c=0;i[114610]=0;L(2015,a|0);b=i[114610];i[114610]=0;a:{b:{if((b|0)!=1){b=i[a+24>>2];i[114610]=0;c=+Z(2022,b|0);b=i[114610];i[114610]=0;if((b|0)!=1){break b}}b=H(0)|0;A()|0;M(b|0)|0;i[114610]=0;J(1989,35068,a|0,0,0);a=i[114610];i[114610]=0;if((a|0)==1){break a}O();c=0}return+c}a=B()|0;A()|0;i[114610]=0;K(20);b=i[114610];i[114610]=0;if((b|0)!=1){E(a|0);x()}a=H(0)|0;A()|0;gb(a);x()}function uda(a){a=a|0;var b=0,c=0;i[114610]=0;L(2015,a|0);b=i[114610];i[114610]=0;a:{b:{if((b|0)!=1){b=i[a+24>>2];i[114610]=0;c=+Z(2024,b|0);b=i[114610];i[114610]=0;if((b|0)!=1){break b}}b=H(0)|0;A()|0;M(b|0)|0;i[114610]=0;J(1989,35140,a|0,0,0);a=i[114610];i[114610]=0;if((a|0)==1){break a}O();c=0}return+c}a=B()|0;A()|0;i[114610]=0;K(20);b=i[114610];i[114610]=0;if((b|0)!=1){E(a|0);x()}a=H(0)|0;A()|0;gb(a);x()}function dda(a){a=a|0;var b=0,c=0;i[114610]=0;L(2015,a|0);b=i[114610];i[114610]=0;a:{b:{if((b|0)!=1){b=i[a+24>>2];i[114610]=0;c=+Z(2043,b|0);b=i[114610];i[114610]=0;if((b|0)!=1){break b}}b=H(0)|0;A()|0;M(b|0)|0;i[114610]=0;J(1989,35675,a|0,0,0);a=i[114610];i[114610]=0;if((a|0)==1){break a}O();c=0}return+c}a=B()|0;A()|0;i[114610]=0;K(20);b=i[114610];i[114610]=0;if((b|0)!=1){E(a|0);x()}a=H(0)|0;A()|0;gb(a);x()}function Q1(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0;e=Xa-32|0;Xa=e;a:{if((b|0)!=(c|0)){k=i[114584];i[114584]=0;DY(e,b,e+28|0);b=i[e+8>>2];f=i[e+12>>2];g=i[e>>2];h=i[e+4>>2];j=i[114584];b:{if(j){if(i[e+28>>2]!=(c|0)){break b}if((j|0)!=68){break a}i[d>>2]=4;break a}i[114584]=k;if(i[e+28>>2]==(c|0)){break a}}}i[d>>2]=4;g=0;h=0;b=0;f=0}i[a>>2]=g;i[a+4>>2]=h;i[a+8>>2]=b;i[a+12>>2]=f;Xa=e+32|0}function laa(a,b,c){a=a|0;b=+b;c=c|0;var d=0,e=0,f=0,g=0;d=Xa+ -64|0;Xa=d;e=i[a>>2];f=i[a+4>>2];g=i[a+12>>2];a=i[a+8>>2];i[d+16>>2]=a;i[d+20>>2]=g;i[d+40>>2]=a;i[d+44>>2]=g;i[d+32>>2]=e;i[d+36>>2]=f;i[d+8>>2]=e;i[d+12>>2]=f;lG(d+48|0,d+8|0);a=co(d+24|0,c);i[114610]=0;b=+ja(2161,d+48|0,+b,a|0);c=i[114610];i[114610]=0;if((c|0)!=1){Ec(a);hb(d+48|0);Xa=d- -64|0;return+b}c=B()|0;A()|0;Ec(a);hb(d+48|0);E(c|0);x()}function tla(a,b,c,d){var e=0,f=0,g=0,h=0,j=0,k=0;e=Xa-32|0;Xa=e;a:{b:{if(0>c>>>0){break b}if(ke(b)>>>0<=c>>>0){break b}f=i[d>>2];g=i[d+4>>2];while(1){d=h&65535;if(rh(se(b,d))){j=Jb(se(b,d));k=Kb(se(b,d));d=e;i[d+24>>2]=f;i[d+28>>2]=g;i[d+8>>2]=f;i[d+12>>2]=g;sla(d+16|0,j,k,d+8|0)}h=h+1|0;if((h&65535)>>>0<=c>>>0){continue}break}i[a>>2]=f;i[a+4>>2]=g;break a}b=i[d+4>>2];i[a>>2]=i[d>>2];i[a+4>>2]=b}Xa=e+32|0}function qF(a,b){a=a|0;b=b|0;var c=0;c=Xa-16|0;Xa=c;a:{b:{c:{d:{if((b|0)>=0){if((Rk(a+8|0)|0)>(b|0)){break d}}a=P(8)|0;i[114610]=0;c=C(85,c|0,40609)|0;b=i[114610];i[114610]=0;if((b|0)==1){break c}Ub(a,c);i[114610]=0;G(2009,a|0,83568,2017);a=i[114610];i[114610]=0;if((a|0)!=1){break a}b=B()|0;A()|0;eb(c);break b}Xa=c+16|0;return+(+i[(i[a+32>>2]+o(b,896)|0)+1075744>>2]*.015625)}b=B()|0;A()|0;Q(a|0)}E(b|0)}x()}function MGa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=Xa-48|0;Xa=e;sia(e+24|0,c);i[114610]=0;G(671,e+36|0,e+8|0,d|0);c=i[114610];i[114610]=0;a:{b:{if((c|0)!=1){i[114610]=0;D(672,e|0,e+24|0);c=i[114610];i[114610]=0;if((c|0)==1){break b}i[114610]=0;G(518,a|0,b|0,e|0);a=i[114610];i[114610]=0;if((a|0)==1){break b}Me(e+24|0);Xa=e+48|0;return}c=B()|0;A()|0;eb(e+24|0);break a}c=B()|0;A()|0;Me(e+24|0)}E(c|0);x()}function qka(a,b,c,d){var e=0,f=0,g=0,h=0,j=0,k=0;g=Xa-16|0;Xa=g;j=i[a+4>>2];d=o((j-d|0)/6|0,6)+b|0;e=jp(g,a,(c-d|0)/6|0);a:{if(c>>>0>d>>>0){f=d;while(1){h=fb(a);k=i[e+4>>2];i[114610]=0;G(1566,h|0,k|0,f|0);h=i[114610];i[114610]=0;if((h|0)==1){break a}i[e+4>>2]=i[e+4>>2]+6;f=f+6|0;if(f>>>0<c>>>0){continue}break}}sb(e);a=d-b|0;if(a){yi(o((a|0)/-6|0,6)+j|0,b,a)}Xa=g+16|0;return}a=B()|0;A()|0;sb(e);E(a|0);x()}function l4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,h=0,j=0,k=0,l=0;e=Xa-16|0;Xa=e;while(1){a:{if((f|0)>=(c|0)){break a}d=i[a+24>>2];h=i[a+28>>2];if(d>>>0>=h>>>0){if(((k=a,l=cg(g[b|0]),j=i[i[a>>2]+52>>2],$a[j](k|0,l|0)|0)|0)==-1){break a}f=f+1|0;b=b+1|0}else{i[e+12>>2]=h-d;i[e+8>>2]=c-f;d=i[Nd(e+12|0,e+8|0)>>2];jh(i[a+24>>2],b,d);i[a+24>>2]=d+i[a+24>>2];f=f+d|0;b=b+d|0}continue}break}Xa=e+16|0;return f|0}function iaa(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;b=Xa-32|0;Xa=b;i[b+24>>2]=e;i[b+28>>2]=f;a:{a=Er(a,ml(b+16|0,jb(c),d),b+24|0);if(a+1>>>0>=3){a=P(8)|0;i[114610]=0;b=C(85,b|0,38585)|0;c=i[114610];i[114610]=0;b:{if((c|0)!=1){Ub(a,b);i[114610]=0;G(2009,a|0,83568,2017);a=i[114610];i[114610]=0;if((a|0)!=1){break a}d=B()|0;A()|0;eb(b);break b}d=B()|0;A()|0;Q(a|0)}E(d|0);x()}Xa=b+32|0;return a|0}x()}function ee(a){var b=0,c=0,d=0;b=Xa-16|0;Xa=b;gNa(+a);d=dNa(1)|0;dNa(0)|0;d=d&2147483647;a:{if(d>>>0<=1072243195){c=1;if(d>>>0<1044816030){break a}c=Wn(a,0);break a}c=a-a;if(d>>>0>=2146435072){break a}b:{switch(JE(a,b)&3){case 0:c=Wn(n[b>>3],n[b+8>>3]);break a;case 1:c=-Xn(n[b>>3],n[b+8>>3],1);break a;case 2:c=-Wn(n[b>>3],n[b+8>>3]);break a;default:break b}}c=Xn(n[b>>3],n[b+8>>3],1)}a=c;Xa=b+16|0;return a}function kca(a){a=a|0;var b=0;i[114610]=0;L(2088,a|0);b=i[114610];i[114610]=0;if((b|0)!=1){i[a+24>>2]=0;b=i[a+28>>2];if(b){$a[i[i[b>>2]+4>>2]](b)}i[a+28>>2]=0;b=i[a+20>>2];if(b){Cb(b)}Cb(a);return}b=H(0)|0;A()|0;M(b|0)|0;i[114610]=0;J(1989,37245,a|0,0,0);a=i[114610];i[114610]=0;if((a|0)!=1){O();return}a=B()|0;A()|0;i[114610]=0;K(20);b=i[114610];i[114610]=0;if((b|0)!=1){E(a|0);x()}a=H(0)|0;A()|0;gb(a);x()}function Pu(a,b,c,d){var e=0,f=0,g=0,h=0,j=0,k=0,l=0;e=Xa-160|0;Xa=e;yb(e+16|0,0,144);i[e+92>>2]=-1;i[e+60>>2]=b;i[e+24>>2]=-1;i[e+20>>2]=b;Gg(e+16|0,0,0);GD(e,e+16|0,d,1);d=i[e+8>>2];g=i[e+12>>2];h=i[e>>2];j=i[e+4>>2];if(c){k=c;f=b;b=i[e+20>>2]-i[e+24>>2]|0;l=b;c=b+i[e+136>>2]|0;b=i[e+140>>2]+(b>>31)|0;b=c>>>0<l>>>0?b+1|0:b;i[k>>2]=!(b|c)?f:f+c|0}i[a>>2]=h;i[a+4>>2]=j;i[a+8>>2]=d;i[a+12>>2]=g;Xa=e+160|0}function poa(a,b){var c=0,d=0;a=Ab(a);c=lb(b);i[114610]=0;D(111,a|0,c|0);c=i[114610];i[114610]=0;if((c|0)!=1){a:{if(lb(b)){while(1){c=i[Ki(b,d)>>2];b:{if(c>>>0<=127){i[114610]=0;D(110,a|0,c<<24>>24);c=i[114610];i[114610]=0;if((c|0)!=1){break b}break a}i[114610]=0;D(110,a|0,63);c=i[114610];i[114610]=0;if((c|0)==1){break a}}d=d+1|0;if(d>>>0<lb(b)>>>0){continue}break}}return}}b=B()|0;A()|0;eb(a);E(b|0);x()}function oF(a,b){a=a|0;b=b|0;var c=0;c=Xa-16|0;Xa=c;a:{b:{c:{d:{if((b|0)>=0){if((Rk(a+8|0)|0)>(b|0)){break d}}a=P(8)|0;i[114610]=0;c=C(85,c|0,40609)|0;b=i[114610];i[114610]=0;if((b|0)==1){break c}Ub(a,c);i[114610]=0;G(2009,a|0,83568,2017);a=i[114610];i[114610]=0;if((a|0)!=1){break a}b=B()|0;A()|0;eb(c);break b}Xa=c+16|0;return(j[(i[a+32>>2]+o(b,896)|0)+1075073|0]&4)>>>2|0}b=B()|0;A()|0;Q(a|0)}E(b|0)}x()}function jga(a){var b=0,c=0,d=0,e=0,f=0,g=0;b=Xa-16|0;Xa=b;f=b,g=Jb(a),i[f+8>>2]=g;f=b,g=Kb(a),i[f>>2]=g;if(pb(b+8|0,b)){while(1){e=i[b+8>>2];a:{while(1){c=i[e>>2];d=i[c>>2];if(!d){break a}c=i[i[d>>2]+8>>2];i[114610]=0;L(c|0,d|0);c=i[114610];i[114610]=0;if((c|0)!=1){continue}break}b=H(0)|0;A()|0;iw(a);gb(b);x()}ob(c+20|0);ob(c+8|0);Cb(c);Gd(b+8|0);if(pb(b+8|0,b)){continue}break}}iw(a);Xa=b+16|0;return a}function hoa(a,b){var c=0,d=0;a=Ab(a);c=lb(b);i[114610]=0;D(111,a|0,c|0);c=i[114610];i[114610]=0;if((c|0)!=1){a:{if(lb(b)){while(1){c=i[Ki(b,d)>>2];b:{if(c>>>0<=255){i[114610]=0;D(110,a|0,c<<24>>24);c=i[114610];i[114610]=0;if((c|0)!=1){break b}break a}i[114610]=0;D(110,a|0,63);c=i[114610];i[114610]=0;if((c|0)==1){break a}}d=d+1|0;if(d>>>0<lb(b)>>>0){continue}break}}return}}b=B()|0;A()|0;eb(a);E(b|0);x()}function aLa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=Xa-48|0;Xa=e;mS(e+24|0,c);i[114610]=0;G(224,e+36|0,e+8|0,d|0);c=i[114610];i[114610]=0;a:{b:{if((c|0)!=1){i[114610]=0;D(78,e|0,e+24|0);c=i[114610];i[114610]=0;if((c|0)==1){break b}i[114610]=0;G(72,a|0,b|0,e|0);a=i[114610];i[114610]=0;if((a|0)==1){break b}Me(e+24|0);Xa=e+48|0;return}c=B()|0;A()|0;eb(e+24|0);break a}c=B()|0;A()|0;Me(e+24|0)}E(c|0);x()}function WJa(a,b){var c=0,d=0,e=0;op(a);g[a+8|0]=0;i[a+4>>2]=b;i[a>>2]=76400;b=ni(a+12|0);g[a+24|0]=0;i[114610]=0;C(35,a+28|0,0)|0;c=i[114610];i[114610]=0;if((c|0)!=1){b=a+40|0;c=b+192|0;while(1){i[b>>2]=0;i[b+4>>2]=0;g[b+8|0]=0;b=b+12|0;if((c|0)!=(b|0)){continue}break}if(j[a+24|0]){a=a+232|0;b=0;while(1){d=Ae(a,b),e=b,i[d>>2]=e;b=b+1|0;if((b|0)!=16){continue}break}}return}a=B()|0;A()|0;ug(b);E(a|0);x()}function S4(a){var b=p(0),c=p(0),d=0;c=(eNa(2,(hNa(a),dNa(2))&-2147483648|1056964608),iNa());d=(hNa(a),dNa(2))&2147483647;b=(eNa(2,d),iNa());a:{if(d>>>0<=1118925334){b=P4(b);if(d>>>0<=1065353215){if(d>>>0<964689920){break a}return p(c*p(p(b+b)-p(p(b*b)/p(b+p(1)))))}return p(c*p(b+p(b/p(b+p(1)))))}a=p(p(c+c)*p(p(T4(p(b+p(-162.88958740234375)))*p(1.661534994731145e+35))*p(1.661534994731145e+35)))}return a}function vk(a){var b=0,c=0;$p(a,1,10879);i[114610]=0;b=R(228)|0;c=i[114610];i[114610]=0;a:{if((c|0)==1){break a}i[a+12>>2]=b;i[114610]=0;b=R(229)|0;c=i[114610];i[114610]=0;if((c|0)==1){break a}g[a+16|0]=b;i[114610]=0;b=R(230)|0;c=i[114610];i[114610]=0;if((c|0)==1){break a}g[a+18|0]=0;g[a+17|0]=b;i[114610]=0;L(231,a+20|0);b=i[114610];i[114610]=0;if((b|0)==1){break a}return}b=B()|0;A()|0;eb(a);E(b|0);x()}function naa(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;b=Xa-32|0;Xa=b;i[b+24>>2]=e;i[b+28>>2]=f;a:{a=Er(a,ml(b+16|0,c,d),b+24|0);if(a+1>>>0>=3){a=P(8)|0;i[114610]=0;b=C(85,b|0,38585)|0;c=i[114610];i[114610]=0;b:{if((c|0)!=1){Ub(a,b);i[114610]=0;G(2009,a|0,83568,2017);a=i[114610];i[114610]=0;if((a|0)!=1){break a}d=B()|0;A()|0;eb(b);break b}d=B()|0;A()|0;Q(a|0)}E(d|0);x()}Xa=b+32|0;return a|0}x()}function Y9(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=Xa-16|0;Xa=e;a:{b:{c:{if(!d){b=P(8)|0;i[114610]=0;c=C(85,e|0,38642)|0;a=i[114610];i[114610]=0;if((a|0)==1){break c}Ub(b,c);i[114610]=0;G(2009,b|0,83568,2017);a=i[114610];i[114610]=0;if((a|0)!=1){break a}a=B()|0;A()|0;eb(c);break b}Nh(a,b,1);c=Tv(a,c,d,0,0,0);n[a+16>>3]=+(c>>>0)/+(b|0)+n[a+16>>3];Xa=e+16|0;return c|0}a=B()|0;A()|0;Q(b|0)}E(a|0)}x()}function $9(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=Xa-16|0;Xa=e;a:{b:{c:{if(!d){b=P(8)|0;i[114610]=0;c=C(85,e|0,38642)|0;a=i[114610];i[114610]=0;if((a|0)==1){break c}Ub(b,c);i[114610]=0;G(2009,b|0,83568,2017);a=i[114610];i[114610]=0;if((a|0)!=1){break a}a=B()|0;A()|0;eb(c);break b}Nh(a,b,1);c=Uv(a,c,d,0,0,0);n[a+16>>3]=+(c>>>0)/+(b|0)+n[a+16>>3];Xa=e+16|0;return c|0}a=B()|0;A()|0;Q(b|0)}E(a|0)}x()}function pO(a){var b=0;a:{if((j[a|0]|j[a+1|0]<<8|(j[a+2|0]<<16|j[a+3|0]<<24))!=808604749){break a}b=a+8|0;if((j[b|0]|j[b+1|0]<<8)>>>0<512|(j[b|0]|j[b+1|0]<<8)>>>0>767){break a}b=a+112|0;if(!(j[b|0]|j[b+1|0]<<8)|(j[b|0]|j[b+1|0]<<8)>>>0>64){break a}b=a+106|0;if((j[b|0]|j[b+1|0]<<8)>>>0>256){break a}b=a+122|0;if((j[b|0]|j[b+1|0]<<8)>>>0>255){break a}a=a+124|0;return(j[a|0]|j[a+1|0]<<8)>>>0<4e3}return 0}function QE(a,b){var c=0,d=0,e=0;if(!j[b+21|0]){Lb(a,21);return-1}if(i[a+1396>>2]<=9){Bj(a)}c=i[a+1392>>2];e=h[(((c&1023)<<1)+b|0)+36>>1];a:{if((e|0)>=0){d=c;c=j[e+i[b+8>>2]|0];i[a+1392>>2]=d>>>c;c=i[a+1396>>2]-c|0;d=(c|0)<0;i[a+1396>>2]=d?0:c;c=d?-1:e;break a}c=Nk(a,b)}if(!((c|0)>=i[b+2092>>2]?j[b+23|0]:0)){if(!((c|0)>-1|(i[a+1384>>2]?!j[a+1376|0]:0))){Lb(a,21)}return c}V(50776,50448,1778,50798);x()}function lna(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=Xa-16|0;Xa=c;kna(a,b);b=0;a:{b:{c:{while(1){d=i[a>>2];i[114610]=0;h[c+14>>1]=b;e=C(2,c|0,(b<<2)+20752|0)|0;f=i[114610];i[114610]=0;if((f|0)==1){break c}i[114610]=0;G(1426,d|0,c+14|0,e|0);d=i[114610];i[114610]=0;if((d|0)==1){break b}eb(e);b=b+1|0;if((b|0)!=12){continue}break}Xa=c+16|0;return}b=B()|0;A()|0;break a}b=B()|0;A()|0;eb(e)}Hf(a);E(b|0);x()}function Vna(a,b){var c=0,d=0;a=Ke(a);c=lb(b);i[114610]=0;D(113,a|0,c|0);c=i[114610];i[114610]=0;if((c|0)!=1){a:{if(lb(b)){while(1){c=g[Sb(b,d)|0];b:{if((c|0)>=0){i[114610]=0;D(112,a|0,c&255);c=i[114610];i[114610]=0;if((c|0)!=1){break b}break a}i[114610]=0;D(112,a|0,65533);c=i[114610];i[114610]=0;if((c|0)==1){break a}}d=d+1|0;if(d>>>0<lb(b)>>>0){continue}break}}return}}b=B()|0;A()|0;nc(a);E(b|0);x()}function V9(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=Xa-16|0;Xa=e;a:{b:{c:{if(!d){b=P(8)|0;i[114610]=0;c=C(85,e|0,38642)|0;a=i[114610];i[114610]=0;if((a|0)==1){break c}Ub(b,c);i[114610]=0;G(2009,b|0,83568,2017);a=i[114610];i[114610]=0;if((a|0)!=1){break a}a=B()|0;A()|0;eb(c);break b}Nh(a,b,2);c=nG(a,c,2,d);n[a+16>>3]=+(c>>>0)/+(b|0)+n[a+16>>3];Xa=e+16|0;return c|0}a=B()|0;A()|0;Q(b|0)}E(a|0)}x()}function Uaa(a){var b=0,c=0;c=Xa-16|0;Xa=c;b=3;a:{b:{if(!a|(a|0)>7){break b}b=2;if((a|0)>2){break b}b=1;if((a|0)==2){break b}b=0;if((a|0)>0){break b}b=P(8)|0;i[114610]=0;c=C(85,c|0,39836)|0;a=i[114610];i[114610]=0;c:{if((a|0)!=1){Ub(b,c);i[114610]=0;G(2009,b|0,83568,2017);a=i[114610];i[114610]=0;if((a|0)!=1){break a}a=B()|0;A()|0;eb(c);break c}a=B()|0;A()|0;Q(b|0)}E(a|0);x()}Xa=c+16|0;return b}x()}function U9(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=Xa-16|0;Xa=e;a:{b:{c:{if(!d){b=P(8)|0;i[114610]=0;c=C(85,e|0,38642)|0;a=i[114610];i[114610]=0;if((a|0)==1){break c}Ub(b,c);i[114610]=0;G(2009,b|0,83568,2017);a=i[114610];i[114610]=0;if((a|0)!=1){break a}a=B()|0;A()|0;eb(c);break b}Nh(a,b,4);c=nG(a,c,4,d);n[a+16>>3]=+(c>>>0)/+(b|0)+n[a+16>>3];Xa=e+16|0;return c|0}a=B()|0;A()|0;Q(b|0)}E(a|0)}x()}function T9(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=Xa-16|0;Xa=e;a:{b:{c:{if(!d){b=P(8)|0;i[114610]=0;c=C(85,e|0,38642)|0;a=i[114610];i[114610]=0;if((a|0)==1){break c}Ub(b,c);i[114610]=0;G(2009,b|0,83568,2017);a=i[114610];i[114610]=0;if((a|0)!=1){break a}a=B()|0;A()|0;eb(c);break b}Nh(a,b,2);c=mG(a,c,2,d);n[a+16>>3]=+(c>>>0)/+(b|0)+n[a+16>>3];Xa=e+16|0;return c|0}a=B()|0;A()|0;Q(b|0)}E(a|0)}x()}function S9(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=Xa-16|0;Xa=e;a:{b:{c:{if(!d){b=P(8)|0;i[114610]=0;c=C(85,e|0,38642)|0;a=i[114610];i[114610]=0;if((a|0)==1){break c}Ub(b,c);i[114610]=0;G(2009,b|0,83568,2017);a=i[114610];i[114610]=0;if((a|0)!=1){break a}a=B()|0;A()|0;eb(c);break b}Nh(a,b,4);c=mG(a,c,4,d);n[a+16>>3]=+(c>>>0)/+(b|0)+n[a+16>>3];Xa=e+16|0;return c|0}a=B()|0;A()|0;Q(b|0)}E(a|0)}x()}function vr(a){var b=0,c=0,d=0;b=j[a+4266|0];m[a+4236>>2]=p(b>>>0)*p(.00390625);i[a+4228>>2]=(o(i[a+4232>>2],j[a+4264|0])+250>>>0)/500;m[a+4240>>2]=p(256-b|0)*p(.00390625);c=j[a+4267|0];b=j[a+4265|0];m[a+4244>>2]=p(o(c,b)|0)*p(152587890625e-16);d=c|-256;m[a+4256>>2]=p(o(d,b|-256)|0)*p(152587890625e-16);m[a+4252>>2]=p(o(b,d)|0)*p(152587890625e-16);m[a+4248>>2]=p(o(256-b|0,c)|0)*p(152587890625e-16)}function X4(a,b){var c=0;a:{b:{if((a^b)&3){break b}if(b&3){while(1){c=j[b|0];g[a|0]=c;if(!c){break a}a=a+1|0;b=b+1|0;if(b&3){continue}break}}c=i[b>>2];if((c^-1)&c+ -16843009&-2139062144){break b}while(1){i[a>>2]=c;c=i[b+4>>2];a=a+4|0;b=b+4|0;if(!(c+ -16843009&(c^-1)&-2139062144)){continue}break}}c=j[b|0];g[a|0]=c;if(!c){break a}while(1){c=j[b+1|0];g[a+1|0]=c;a=a+1|0;b=b+1|0;if(c){continue}break}}}function kM(){var a=0,b=0;a=Xa-240|0;Xa=a;a:{b:{if(g[85480]&1){break b}if(!cd(85480)){break b}i[114610]=0;R(102)|0;b=i[114610];i[114610]=0;if((b|0)==1){break a}i[114610]=0;D(103,a+120|0,85328);b=i[114610];i[114610]=0;if((b|0)==1){break a}i[114610]=0;C(104,85360,Tb(a,a+120|0,120)|0)|0;b=i[114610];i[114610]=0;if((b|0)==1){break a}bd(85480)}Xa=a+240|0;return 85360}a=B()|0;A()|0;Xd(85480);E(a|0);x()}function Rx(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=Xa-32|0;Xa=f;i[f+8>>2]=c;g=f,h=cf(b),i[g+28>>2]=h;De(f+8|0,b,i[rb(f+8|0,f+28|0)>>2]);i[114610]=0;b=F(412,f+8|0)|0;c=i[114610];i[114610]=0;a:{if((c|0)==1){break a}c=i[f+8>>2];i[114610]=0;a=S(440,a|0,b|0,c|0,d|0,e|0)|0;b=i[114610];i[114610]=0;if((b|0)==1){break a}jc(f+8|0);Xa=f+32|0;return a|0}a=B()|0;A()|0;jc(f+8|0);E(a|0);x()}function Hh(a){var b=0,c=0;b=Xa-16|0;Xa=b;gNa(+a);c=dNa(1)|0;dNa(0)|0;c=c&2147483647;a:{if(c>>>0<=1072243195){if(c>>>0<1045430272){break a}a=Xn(a,0,0);break a}if(c>>>0>=2146435072){a=a-a;break a}b:{switch(JE(a,b)&3){case 0:a=Xn(n[b>>3],n[b+8>>3],1);break a;case 1:a=Wn(n[b>>3],n[b+8>>3]);break a;case 2:a=-Xn(n[b>>3],n[b+8>>3],1);break a;default:break b}}a=-Wn(n[b>>3],n[b+8>>3])}Xa=b+16|0;return a}function S6(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;c=Xa-16|0;Xa=c;d=i[b+4>>2];b=i[b>>2];i[c+12>>2]=0;i[c+8>>2]=0;i[c+4>>2]=0;L6(Iv(1970,1,1)+YMa(b,d,86400,0)|0,c+12|0,c+8|0,c+4|0);tF(a);i[a+20>>2]=i[c+12>>2]+ -1900;i[a+16>>2]=i[c+8>>2]+ -1;e=i[c+4>>2];g=a,h=ZMa(YMa(b,d,3600,0),_a,24),i[g+8>>2]=h;i[a+12>>2]=e;d=YMa(b,d,60,0);e=_a;g=a,h=ZMa(d,e,60),i[g+4>>2]=h;f=a;a=XMa(d,e,60,0);i[f>>2]=b-a;Xa=c+16|0}function Mw(a,b,c){var d=0,e=0,f=0,g=0,i=0,j=0,k=0,l=0;d=s(c,.999);c=d*32768;i=d*3.141592653589793;j=Br(b);while(1){k=a;l=c;e=((f<<12^-1)&28672)+(f>>>3|0)|0;if((e|0)!=16384){g=+(e+ -16384|0);d=g*.000244140625;g=Br(w(g*-152587890625e-16*d+1)*b);d=i*d;d=g*Hh(d)/(d*j)}else{d=1}d=u(l*d+.5);a:{if(q(d)<2147483648){e=~~d;break a}e=-2147483648}h[k>>1]=e;a=a+2|0;f=f+1|0;if((f|0)!=32768){continue}break}}function K2(a){var b=0,c=0;a:{if(a&3){while(1){b=j[a|0];if(!b|(b|0)==61){break a}a=a+1|0;if(a&3){continue}break}}b=i[a>>2];b:{if((b^-1)&b+ -16843009&-2139062144){break b}while(1){b=b^1027423549;if((b^-1)&b+ -16843009&-2139062144){break b}b=i[a+4>>2];a=a+4|0;if(!(b+ -16843009&(b^-1)&-2139062144)){continue}break}}while(1){b=a;c=j[b|0];if(c){a=b+1|0;if((c|0)!=61){continue}}break}return b}return a}function IN(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=Xa-16|0;Xa=d;e=gp(a);f=d,g=Jb(b),i[f+8>>2]=g;f=d,g=Kb(b),i[f>>2]=g;a:{if(pb(d+8|0,d)){while(1){a=i[d+8>>2];if((j[a|0]|j[a+1|0]<<8|(j[a+2|0]<<16|j[a+3|0]<<24))==(c|0)){a=fb(a);i[114610]=0;D(604,e|0,a|0);a=i[114610];i[114610]=0;if((a|0)==1){break a}}dk(d+8|0);if(pb(d+8|0,d)){continue}break}}Xa=d+16|0;return}a=B()|0;A()|0;Qc(e);E(a|0);x()}function sGa(a,b){a=a|0;b=b|0;var c=0,d=0;c=Xa-48|0;Xa=c;UEa(c+24|0,b);i[114610]=0;D(705,c+8|0,c+24|0);b=i[114610];i[114610]=0;a:{if((b|0)==1){break a}i[114610]=0;D(706,c+16|0,c+8|0);b=i[114610];i[114610]=0;if((b|0)==1){break a}b=i[c+16>>2];d=i[c+20>>2];i[114610]=0;I(707,a|0,b|0,d|0)|0;a=i[114610];i[114610]=0;if((a|0)==1){break a}jc(c+24|0);Xa=c+48|0;return}a=B()|0;A()|0;jc(c+24|0);E(a|0);x()}function yF(a,b){a=a|0;b=+b;var c=0,d=0;c=Xa-16|0;Xa=c;a:{b:{c:{if(!(b<=4?!(b<=0):0)){d=P(8)|0;i[114610]=0;c=C(85,c|0,40545)|0;a=i[114610];i[114610]=0;if((a|0)==1){break c}Ub(d,c);i[114610]=0;G(2009,d|0,83568,2017);a=i[114610];i[114610]=0;if((a|0)!=1){break a}a=B()|0;A()|0;eb(c);break b}d=Wj(65536/b);a=a+32|0;i[i[a>>2]+480244>>2]=d;oo(i[a>>2]);Xa=c+16|0;return}a=B()|0;A()|0;Q(d|0)}E(a|0)}x()}function wF(a,b){a=a|0;b=+b;var c=0,d=0;c=Xa-16|0;Xa=c;a:{b:{c:{if(!(b<=4?!(b<=0):0)){d=P(8)|0;i[114610]=0;c=C(85,c|0,40566)|0;a=i[114610];i[114610]=0;if((a|0)==1){break c}Ub(d,c);i[114610]=0;G(2009,d|0,83568,2017);a=i[114610];i[114610]=0;if((a|0)!=1){break a}a=B()|0;A()|0;eb(c);break b}d=Wj(b*65536);a=a+32|0;i[i[a>>2]+480240>>2]=d;oo(i[a>>2]);Xa=c+16|0;return}a=B()|0;A()|0;Q(d|0)}E(a|0)}x()}function NP(a){var b=0,c=0,d=0,e=0,f=0,g=0;a:{b=i[a>>2];b:{if(!b){break b}e=i[a+8>>2];if(!e){break b}c=i[a+12>>2];if(!c){break b}a=$a[c|0](b)|0;d=_a;f=d;if((d|0)<0?1:(d|0)<=0?a>>>0<0:0){break b}if(($a[e|0](b,0,0,0)|0)<=-1){break a}if(($a[e|0](b,0,0,2)|0)<=-1){break a}d=$a[c|0](b)|0;c=_a;$a[e|0](b,a,f,0)|0;if((c|0)<0?1:(c|0)<=0?d>>>0<0:0){break b}g=BQ(d,c)}return g}$a[e|0](b,a,f,0)|0;return 0}function VE(a,b,c){var d=0,e=0,f=0,g=0,h=0,j=0,k=0;d=(b<<2)+a|0;e=d+1068|0;g=c<<1&-4;j=e,k=yd(a,g),i[j>>2]=k;f=d+1076|0;j=f,k=yd(a,g),i[j>>2]=k;h=d+1084|0;d=yd(a,c&-4);i[h>>2]=d;a:{b:{e=i[e>>2];if(!(!e|!d)){f=i[f>>2];if(f){break b}}break a}_4(c,e,f,d);d=(b<<2)+a|0;b=yd(a,g);i[d+1092>>2]=b;if(!b){break a}Z4(c,b);b=yd(a,c>>3<<1);i[d+1100>>2]=b;if(!b){break a}Y4(c,b);return 1}Lb(a,3);return 0}function gF(a,b,c,d,e,f){var g=0,h=0;if((d|0)>=1){while(1){T5(o(g,2304)+b|0,c);g=g+1|0;if((g|0)!=(d|0)){continue}break}}f=Tb(f,a,3840);if((c|0)>=1){h=d<<5;g=0;while(1){S5((g<<2)+b|0,(o(g,h)<<1)+e|0,d,f+(g<<8)|0);g=g+2|0;if((g|0)<(c|0)){continue}break}}b=c<<6;a:{if((d|0)==1){g=0;while(1){m[(g<<2)+a>>2]=m[f+(b+g<<2)>>2];c=g>>>0<958;g=g+2|0;if(c){continue}break}break a}Tb(a,f+(b<<2)|0,3840)}}function CW(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=Xa-32|0;Xa=c;a:{b:{c:{d:{if(!(d=!Cc(b),e=0,f=i[b+12>>2],f?d:e)){Oc(a);break d}BW(c+16|0,b);i[114610]=0;D(234,c|0,b+12|0);b=i[114610];i[114610]=0;if((b|0)==1){break c}i[114610]=0;G(3,a|0,c+16|0,c|0);a=i[114610];i[114610]=0;if((a|0)==1){break b}eb(c);eb(c+16|0)}Xa=c+32|0;return}b=B()|0;A()|0;break a}b=B()|0;A()|0;eb(c)}eb(c+16|0);E(b|0);x()}function yT(a,b){var c=0,d=0,e=0;d=Xa-16|0;Xa=d;i[d+12>>2]=b;c=i[a+4>>2];a:{if(!c){c=i[a>>2];break a}i[d+8>>2]=32-c;b=rb(d+8|0,d+12|0);c=i[a>>2];b=i[b>>2];i[c>>2]=i[c>>2]&(-1<<i[a+4>>2]&-1>>>i[d+8>>2]-b^-1);b=i[d+12>>2]-b|0;i[d+12>>2]=b;c=c+4|0;i[a>>2]=c}e=c;c=b>>>5<<2;yb(e,0,c);b=i[d+12>>2]-(b&-32)|0;i[d+12>>2]=b;if(b){e=a;a=c+i[a>>2]|0;i[e>>2]=a;i[a>>2]=i[a>>2]&(-1>>>32-b^-1)}Xa=d+16|0}function yL(a,b){a=a|0;b=+b;var c=0,d=0,e=0,f=0,g=0,h=0,j=0;e=Br(b);d=Zra(a);a=0;a:{while(1){c=1;if((a|0)!=1024){i[114610]=0;c=+(a+ -1024|0);f=+Va(1215,+(w(c*c*-9.5367431640625e-7+1)*b));g=i[114610];i[114610]=0;if((g|0)==1){break a}c=c*.0372006759294457;c=f*Hh(c)/(c*e)}h=uk(d,a),j=c*.011841342921061943,n[h>>3]=j;a=a+1|0;if((a|0)!=2048){continue}break}return}a=B()|0;A()|0;pf(d);E(a|0);x()}function Dp(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,h=0,j=0;c=Xa-16|0;Xa=c;e=i[a+4>>2];d=i[a>>2];g[c+12|0]=0;Ar(d,d+e|0,c+12|0);d=xb(b);e=xb(b);h=c,j=lb(b),i[h+12>>2]=j;i[c+8>>2]=i[a+4>>2]+ -1;Oe(d,e+i[rb(c+12|0,c+8|0)>>2]|0,i[a>>2]);d=i[a>>2];h=c,j=lb(b),i[h+12>>2]=j;i[c+8>>2]=i[a+4>>2]+ -1;b=i[rb(c+12|0,c+8|0)>>2];e=i[a+4>>2];f=i[a>>2];g[c+7|0]=0;Ar(b+d|0,e+f|0,c+7|0);Xa=c+16|0;return a|0}function Dda(a,b){a=a|0;b=b|0;var c=0;i[114610]=0;L(2015,a|0);c=i[114610];i[114610]=0;a:{b:{if((c|0)!=1){i[a+16>>2]=b;b=i[a+20>>2];if(!b){break b}Cb(b);i[a+20>>2]=0;return}b=H(0)|0;A()|0;M(b|0)|0;i[114610]=0;J(1989,34881,a|0,0,0);a=i[114610];i[114610]=0;if((a|0)==1){break a}O()}return}a=B()|0;A()|0;i[114610]=0;K(20);b=i[114610];i[114610]=0;if((b|0)!=1){E(a|0);x()}a=H(0)|0;A()|0;gb(a);x()}function B$(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=Xa+ -64|0;Xa=e;i[e+56>>2]=b;f=e+48|0;a:{b:while(1){if(c>>>0<d>>>0){i[e+8>>2]=c;if(($a[i[i[a>>2]+12>>2]](a,e+48|0,c,d,e+8|0,e+16|0,f,e+12|0)|0)==2){break a}b=e+16|0;if(i[e+8>>2]==(c|0)){break a}while(1)if(b>>>0>=l[e+12>>2]){c=i[e+8>>2];continue b}else{PC(e+56|0,b);b=b+1|0;continue}}break}Xa=e- -64|0;return i[e+56>>2]}Pl(62932);x()}function ou(a,b,c){var d=0,e=0,f=0;d=i[c+16>>2];a:{if(!d){if(mX(c)){break a}d=i[c+16>>2]}f=i[c+20>>2];if(d-f>>>0<b>>>0){return $a[i[c+36>>2]](c,a,b)|0}b:{if(g[c+75|0]<0){d=0;break b}e=b;while(1){d=e;if(!d){d=0;break b}e=d+ -1|0;if(j[e+a|0]!=10){continue}break}e=$a[i[c+36>>2]](c,a,d)|0;if(e>>>0<d>>>0){break a}a=a+d|0;b=b-d|0;f=i[c+20>>2]}Tb(f,a,b);i[c+20>>2]=i[c+20>>2]+b;e=b+d|0}return e}function Gy(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;sP(a,b);e=b+8|0;e=j[e|0]|j[e+1|0]<<8|(j[e+2|0]<<16|j[e+3|0]<<24);vc(a,(e<<24|e<<8&16711680|(e>>>8&65280|e>>>24))+504|0);rP(a,d);a:{b=b+32|0;if(!(j[b|0]|j[b+1|0]<<8|(j[b+2|0]<<16|j[b+3|0]<<24))){break a}b=j[b|0]|j[b+1|0]<<8|(j[b+2|0]<<16|j[b+3|0]<<24);if(!vc(a,b<<24|b<<8&16711680|(b>>>8&65280|b>>>24))){break a}an(a,c);return}yb(c,0,80)}function fqa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=Xa-16|0;Xa=e;i[e+12>>2]=c>>>3;i[e+8>>2]=i[a>>2];d=i[rb(e+12|0,e+8|0)>>2];b=jb(b);if(d){a=i[a+20>>2];c=d;while(1){jb(j[b|0]);jb(j[b+1|0]);f=a,g=jb(j[b+2|0])|jb(j[b+3|0])<<8,h[f>>1]=g;jb(j[b+4|0]);jb(j[b+5|0]);f=a,g=jb(j[b+6|0])|jb(j[b+7|0])<<8,h[f+2>>1]=g;a=a+4|0;b=b+8|0;c=c+ -1|0;if(c){continue}break}}Xa=e+16|0;return d<<3}function eqa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=Xa-16|0;Xa=e;i[e+12>>2]=c>>>3;i[e+8>>2]=i[a>>2];d=i[rb(e+12|0,e+8|0)>>2];b=jb(b);if(d){a=i[a+20>>2];c=d;while(1){jb(j[b+3|0]);jb(j[b+2|0]);f=a,g=jb(j[b+1|0])|jb(j[b|0])<<8,h[f>>1]=g;jb(j[b+7|0]);jb(j[b+6|0]);f=a,g=jb(j[b+5|0])|jb(j[b+4|0])<<8,h[f+2>>1]=g;a=a+4|0;b=b+8|0;c=c+ -1|0;if(c){continue}break}}Xa=e+16|0;return d<<3}function UB(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=Xa-32|0;Xa=d;c=Bb(d,c);i[114610]=0;G(2842,d+16|0,b|0,c|0);e=i[114610];i[114610]=0;a:{b:{if((e|0)!=1){i[114610]=0;C(2843,a|0,d+16|0)|0;e=i[114610];i[114610]=0;if((e|0)==1){break b}eb(d+16|0);eb(c);i[a>>2]=70676;c=i[b+4>>2];i[a+8>>2]=i[b>>2];i[a+12>>2]=c;Xa=d+32|0;return a|0}a=B()|0;A()|0;break a}a=B()|0;A()|0;eb(d+16|0)}eb(c);E(a|0);x()}function Hfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;b=Ph(a,b,c,d);i[a+4224>>2]=1049951732;c=a+4216|0;i[c>>2]=1065353216;i[c+4>>2]=1049951732;i[a+4208>>2]=1060320051;i[a+4212>>2]=1041865114;i[a>>2]=80724;i[114610]=0;I(1639,a+44|0,2,2)|0;c=i[114610];i[114610]=0;a:{if((c|0)==1){break a}i[114610]=0;L(1640,b|0);c=i[114610];i[114610]=0;if((c|0)==1){break a}return a|0}a=B()|0;A()|0;ve(b);E(a|0);x()}function Oya(a,b){var c=0,d=0,e=0;c=xN(a,b);i[114610]=0;e=C(991,a+12|0,b+12|0)|0;d=i[114610];i[114610]=0;a:{b:{if((d|0)!=1){i[114610]=0;C(992,a+24|0,b+24|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break b}c=i[b+40>>2];i[a+36>>2]=i[b+36>>2];i[a+40>>2]=c;h[a+52>>1]=k[b+52>>1];c=i[b+48>>2];i[a+44>>2]=i[b+44>>2];i[a+48>>2]=c;return}a=B()|0;A()|0;break a}a=B()|0;A()|0;Md(e)}Md(c);E(a|0);x()}function hw(a){var b=p(0),c=p(0),d=0,e=p(0),f=0;b=p(we(i[a+16>>2])>>>0);c=p(p($a[i[i[a>>2]+200>>2]](a))*b);d=a,e=p(p(c*p(2.0480000972747803))*p($a[i[i[a>>2]+192>>2]](a))),m[d+4248>>2]=e;d=a,f=oh(p(p(c*p(4.0960001945495605))+p(8192))),i[d+4256>>2]=f;c=p($a[i[i[a>>2]+204>>2]](a));m[a+4252>>2]=c;b=p(c/b);if(!($a[i[i[a>>2]+188>>2]](a)|0)){b=LE(p(b*p(3.1415927410125732)))}m[a+4244>>2]=b+b}function Rha(a){a=a|0;var b=0,c=0;b=i[a+20>>2];i[b+148>>2]=-1;i[114610]=0;D(508,b+4|0,8);b=i[114610];i[114610]=0;if((b|0)!=1){c=i[i[a+20>>2]+4>>2];b=i[a+4264>>2];a=i[a+4260>>2];g[c|0]=a;g[c+1|0]=a>>>8;g[c+2|0]=a>>>16;g[c+3|0]=a>>>24;g[c+4|0]=b;g[c+5|0]=b>>>8;g[c+6|0]=b>>>16;g[c+7|0]=b>>>24;return}b=H(71348)|0;if((A()|0)==(U(71348)|0)){M(b|0)|0;Vr(i[a+20>>2]+4|0);O();return}E(b|0);x()}function vZ(){var a=0;a:{if(g[462216]&1){break a}if(!cd(462216)){break a}a=462048;while(1){a=Ab(a)+12|0;if((a|0)!=462216){continue}break}bd(462216)}tc(462048,67120);tc(462060,67127);tc(462072,67134);tc(462084,67142);tc(462096,67152);tc(462108,67161);tc(462120,67168);tc(462132,67177);tc(462144,67181);tc(462156,67185);tc(462168,67189);tc(462180,67193);tc(462192,67197);tc(462204,67201)}function sZ(){var a=0;a:{if(g[462392]&1){break a}if(!cd(462392)){break a}a=462224;while(1){a=Ke(a)+12|0;if((a|0)!=462392){continue}break}bd(462392)}Gc(462224,67208);Gc(462236,67236);Gc(462248,67264);Gc(462260,67296);Gc(462272,67336);Gc(462284,67372);Gc(462296,67400);Gc(462308,67436);Gc(462320,67452);Gc(462332,67468);Gc(462344,67484);Gc(462356,67500);Gc(462368,67516);Gc(462380,67532)}function kF(a,b){a=a|0;b=b|0;var c=0;c=Xa-16|0;Xa=c;a:{b:{c:{if(b>>>0>=256){a=P(8)|0;i[114610]=0;c=C(85,c|0,40609)|0;b=i[114610];i[114610]=0;if((b|0)==1){break c}Ub(a,c);i[114610]=0;G(2009,a|0,83568,2017);a=i[114610];i[114610]=0;if((a|0)!=1){break a}b=B()|0;A()|0;eb(c);break b}a=i[a+32>>2]+o(b,896)|0;i[a+1075e3>>2]=0;i[a+1075060>>2]=0;Xa=c+16|0;return}b=B()|0;A()|0;Q(a|0)}E(b|0)}x()}function q6(a,b,c){a=a|0;b=b|0;c=c|0;a=a^-1;if(c>>>0>3){while(1){a=i[((j[b|0]^a&255)<<2)+40768>>2]^a>>>8;a=a>>>8^i[((j[b+1|0]^a&255)<<2)+40768>>2];a=a>>>8^i[((j[b+2|0]^a&255)<<2)+40768>>2];a=a>>>8^i[((j[b+3|0]^a&255)<<2)+40768>>2];b=b+4|0;c=c+ -4|0;if(c>>>0>3){continue}break}}if(c){while(1){a=i[((j[b|0]^a&255)<<2)+40768>>2]^a>>>8;b=b+1|0;c=c+ -1|0;if(c){continue}break}}return a^-1}function g4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=Xa-16|0;Xa=d;while(1){a:{if((e|0)>=(c|0)){break a}f=i[a+24>>2];g=i[a+28>>2];if(f>>>0>=g>>>0){if(($a[i[i[a>>2]+52>>2]](a,i[b>>2])|0)==-1){break a}e=e+1|0;b=b+4|0}else{i[d+12>>2]=g-f>>2;i[d+8>>2]=c-e;f=i[Nd(d+12|0,d+8|0)>>2];Gh(i[a+24>>2],b,f);g=f<<2;i[a+24>>2]=g+i[a+24>>2];e=e+f|0;b=b+g|0}continue}break}Xa=d+16|0;return e|0}function Sx(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=Xa-32|0;Xa=e;i[e+8>>2]=c;f=e,g=cf(b),i[f+28>>2]=g;De(e+8|0,b,i[rb(e+8|0,e+28|0)>>2]);i[114610]=0;b=F(412,e+8|0)|0;c=i[114610];i[114610]=0;a:{if((c|0)==1){break a}c=i[e+8>>2];i[114610]=0;N(1063,a|0,b|0,c|0,d|0)|0;a=i[114610];i[114610]=0;if((a|0)==1){break a}jc(e+8|0);Xa=e+32|0;return 1}a=B()|0;A()|0;jc(e+8|0);E(a|0);x()}function zT(a,b){var c=0,d=0,e=0;d=Xa-16|0;Xa=d;i[d+12>>2]=b;c=i[a+4>>2];a:{if(!c){c=i[a>>2];break a}i[d+8>>2]=32-c;b=rb(d+8|0,d+12|0);c=i[a>>2];b=i[b>>2];i[c>>2]=i[c>>2]|-1<<i[a+4>>2]&-1>>>i[d+8>>2]-b;b=i[d+12>>2]-b|0;i[d+12>>2]=b;c=c+4|0;i[a>>2]=c}e=c;c=b>>>5<<2;yb(e,255,c);b=i[d+12>>2]-(b&-32)|0;i[d+12>>2]=b;if(b){e=a;a=c+i[a>>2]|0;i[e>>2]=a;i[a>>2]=i[a>>2]|-1>>>32-b}Xa=d+16|0}function oGa(a,b){var c=0,d=0;c=Xa-48|0;Xa=c;Wy(c+24|0,b);i[114610]=0;D(705,c+8|0,c+24|0);b=i[114610];i[114610]=0;a:{if((b|0)==1){break a}i[114610]=0;D(706,c+16|0,c+8|0);b=i[114610];i[114610]=0;if((b|0)==1){break a}b=i[c+16>>2];d=i[c+20>>2];i[114610]=0;I(707,a|0,b|0,d|0)|0;a=i[114610];i[114610]=0;if((a|0)==1){break a}jc(c+24|0);Xa=c+48|0;return}a=B()|0;A()|0;jc(c+24|0);E(a|0);x()}function nL(a,b,c){var d=0,e=0,f=0,g=0;d=Xa-32|0;Xa=d;i[a+4>>2]=0;a:{if(b){b:{if(us(a)>>>0>=b>>>0){i[a+4>>2]=b;break b}fb(a);e=jy(d+16|0);i[114610]=0;f=C(933,a|0,b|0)|0;g=i[114610];i[114610]=0;if((g|0)==1){break a}i[114610]=0;D(934,e|0,f|0);f=i[114610];i[114610]=0;if((f|0)==1){break a}i[e+4>>2]=b;iy(a,e);Td(e)}Wi(d,a);Bp(d,b,j[c|0])}Xa=d+32|0;return}a=B()|0;A()|0;Td(e);E(a|0);x()}function Cda(a){a=a|0;var b=0;i[114610]=0;L(2015,a|0);b=i[114610];i[114610]=0;a:{b:{if((b|0)!=1){i[a+16>>2]=0;b=i[a+20>>2];if(!b){break b}Cb(b);i[a+20>>2]=0;return}b=H(0)|0;A()|0;M(b|0)|0;i[114610]=0;J(1989,34911,a|0,0,0);a=i[114610];i[114610]=0;if((a|0)==1){break a}O()}return}a=B()|0;A()|0;i[114610]=0;K(20);b=i[114610];i[114610]=0;if((b|0)!=1){E(a|0);x()}a=H(0)|0;A()|0;gb(a);x()}function mW(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=Xa-48|0;Xa=d;a:{b:{e=iW(xb(b),lb(b),xb(c),lb(c));if((e|0)!=-1){f=d,g=ld(b),i[f+32>>2]=g;c=Ad(d+40|0,d+32|0);f=d,g=ld(b),i[f+8>>2]=g;f=d,g=Ze(d+8|0,e),i[f+16>>2]=g;e=Ad(d+24|0,d+16|0);yx(b,i[c>>2],i[e>>2]);break b}if(!lb(b)){break b}if((hW(xb(b),lb(b),xb(c),lb(c))|0)!=(lb(b)+ -1|0)){break b}Oc(a);break a}Lc(a,b)}Xa=d+48|0}function Kda(a){a=a|0;var b=0;i[114610]=0;L(2015,a|0);b=i[114610];i[114610]=0;if((b|0)!=1){b=i[a+24>>2];if(b){Cb(br(b))}i[a+24>>2]=0;b=i[a+20>>2];if(b){Cb(b)}Cb(a);return}b=H(0)|0;A()|0;M(b|0)|0;i[114610]=0;J(1989,34732,a|0,0,0);a=i[114610];i[114610]=0;if((a|0)!=1){O();return}a=B()|0;A()|0;i[114610]=0;K(20);b=i[114610];i[114610]=0;if((b|0)!=1){E(a|0);x()}a=H(0)|0;A()|0;gb(a);x()}function g7(a){var b=0,c=0,d=0,e=0;e=Xa-16|0;Xa=e;b=Iv(i[a+20>>2]+1900|0,i[a+16>>2]+1|0,i[a+12>>2])-Iv(1970,1,1)|0;c=XMa(b,b>>31,86400,0);b=o(i[a+8>>2],3600);d=b;c=c+b|0;b=_a+(b>>31)|0;b=c>>>0<d>>>0?b+1|0:b;d=o(i[a+4>>2],60);c=d+c|0;b=(d>>31)+b|0;b=c>>>0<d>>>0?b+1|0:b;a=i[a>>2];d=a;c=a+c|0;a=(a>>31)+b|0;a=GF(e+8|0,c,c>>>0<d>>>0?a+1|0:a);b=i[a>>2];Xa=e+16|0;_a=i[a+4>>2];return b}function GQ(a){var b=0,c=0,d=0;a:{if((j[a+60|0]|j[a+61|0]<<8|(j[a+62|0]<<16|j[a+63|0]<<24))!=808537417){break a}b=a+32|0;if((j[b|0]|j[b+1|0]<<8)>>>0>256){break a}b=a+36|0;if((j[b|0]|j[b+1|0]<<8)>>>0>255){break a}b=a+576|0;a=a- -64|0;while(1){c=0;b:{switch(j[a+15|0]){case 0:case 1:d=1;break;case 2:break b;default:break a}}c=d;a=a+16|0;if((b|0)!=(a|0)){continue}break}}return c&1}function Eza(a,b){a=a|0;b=b|0;var c=0;b=Xa-32|0;Xa=b;c=-1;a:{if(!oz(a,b+16|0)){break a}c=0;if(!JN(b+16|0)){break a}c=-1;if(!fj(a,b+8|0)){break a}a=b+8|4;c=0;if(!(j[a|0]|j[a+1|0]<<8|(j[a+2|0]<<16|j[a+3|0]<<24))){break a}a=b+8|0;c=j[a|0]|j[a+1|0]<<8|(j[a+2|0]<<16|j[a+3|0]<<24);a=b+8|0;c=(c|0)==((j[a|0]|j[a+1|0]<<8|(j[a+2|0]<<16|j[a+3|0]<<24))&2139062143)}a=c;Xa=b+32|0;return a|0}function Eda(a){a=a|0;var b=0;i[114610]=0;L(2015,a|0);b=i[114610];i[114610]=0;a:{b:{if((b|0)!=1){a=i[a+20>>2];if(!a){break b}return Ed(a)|0}b=H(0)|0;A()|0;M(b|0)|0;i[114610]=0;J(1989,34843,a|0,0,0);a=i[114610];i[114610]=0;if((a|0)==1){break a}O();return 0}return Ed(34133)|0}a=B()|0;A()|0;i[114610]=0;K(20);b=i[114610];i[114610]=0;if((b|0)!=1){E(a|0);x()}a=H(0)|0;A()|0;gb(a);x()}function Ch(a,b,c,d,e){var f=0,g=0;f=Xa-16|0;Xa=f;i[f+8>>2]=b;a:{if(Fi(a,f+8|0)){i[c>>2]=i[c>>2]|6;b=0;break a}b=zj(a);if(!jg(d,2048,b)){i[c>>2]=i[c>>2]|4;b=0;break a}b=Sl(d,b);while(1){b:{Jk(a);b=b+ -48|0;if(!Tn(a,f+8|0)|(e|0)<2){break b}g=zj(a);if(!jg(d,2048,g)){break a}e=e+ -1|0;b=Sl(d,g)+o(b,10)|0;continue}break}if(!Fi(a,f+8|0)){break a}i[c>>2]=i[c>>2]|2}Xa=f+16|0;return b}function Bh(a,b,c,d,e){var f=0,g=0;f=Xa-16|0;Xa=f;i[f+8>>2]=b;a:{if(wj(a,f+8|0)){i[c>>2]=i[c>>2]|6;b=0;break a}b=Gk(a);if(!xj(d,2048,b)){i[c>>2]=i[c>>2]|4;b=0;break a}b=Rl(d,b);while(1){b:{_l(a);b=b+ -48|0;if(!Dq(a,f+8|0)|(e|0)<2){break b}g=Gk(a);if(!xj(d,2048,g)){break a}e=e+ -1|0;b=Rl(d,g)+o(b,10)|0;continue}break}if(!wj(a,f+8|0)){break a}i[c>>2]=i[c>>2]|2}Xa=f+16|0;return b}function Nh(a,b,c){var d=0,e=0,f=0,h=0,k=0;d=Xa-48|0;Xa=d;e=a+24|0;f=i[i[e>>2]+24620>>2];a:{if(!((f|0)!=(b|0)|i[i[e>>2]+24624>>2]!=(c|0))){if(j[a+29|0]){break a}rJ(i[e>>2],1);break a}Tb(d+8|0,i[e>>2]+24604|0,40);h=i[d+40>>2];k=i[d+44>>2];i[d+28>>2]=c;i[d+24>>2]=b;Xk(d+8|0,h);Km(d+8|0,k);Ww(i[e>>2],d+8|0);if((b|0)==(f|0)){break a}xna(i[e>>2]);wna(i[e>>2])}g[a+29|0]=1;Xa=d+48|0}function Cw(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,h=0,i=0;f=Xa-16|0;Xa=f;a:{while(1){i=h&255;if(Ew(b,c,i>>>0>1)){g[f+15|0]=0;g[f+14|0]=0;EI(a,f+15|0,f+14|0);break a}Sg(b,d);Sg(c,e);h=h+1|0;if(i>>>0<3){continue}break}if(tm(j[b|0])>>>0>tm(j[d|0])>>>0){Sg(b,d);Sg(c,e)}g[f+11|0]=j[b|0];EI(f+12|0,f+11|0,c);g[b|0]=0;g[c|0]=0;b=k[f+12>>1];g[a|0]=b;g[a+1|0]=b>>>8}Xa=f+16|0}function Apa(a,b,c){var d=0,e=p(0),f=p(0),g=0,h=0;d=Xa-16|0;Xa=d;e=p(o(c+256|0,b)>>>0);b=d;a:{if(i[a+480180>>2]!=33554432){f=p(110);e=p(p(e/(j[a+480209|0]&128?p(10240):p(12288)))+p(.25));break a}f=p(125);e=p(e*p(9227362170349807e-20))}g=b,h=oh(p(Wd(p(2),e)*f)),i[g+12>>2]=h;Kd(d+12|0,120,2e4);b=i[d+12>>2];a=i[a+24620>>2];if(b<<1>(a|0)){b=a>>>1|0;i[d+12>>2]=b}Xa=d+16|0;return b}function gia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=Xa-16|0;Xa=e;d=te(64);i[114610]=0;f=F(1427,d|0)|0;g=i[114610];i[114610]=0;a:{if((g|0)!=1){d=ax(e+8|0,f);f=i[d>>2];i[114610]=0;b=I(1634,f|0,b|0,c|0)|0;c=i[114610];i[114610]=0;b:{c:{if((c|0)!=1){if((b|0)==1){break c}$w(a);break b}a=B()|0;A()|0;Hf(d);break a}dp(a,d)}Hf(d);Xa=e+16|0;return}a=B()|0;A()|0;Cb(d)}E(a|0);x()}function ZQ(a){var b=0,c=0;a:{if((j[a|0]|j[a+1|0]<<8|(j[a+2|0]<<16|j[a+3|0]<<24))!=777268804){break a}b=a+4|0;c=j[b|0]|j[b+1|0]<<8|(j[b+2|0]<<16|j[b+3|0]<<24);if((c<<24|c<<8&16711680|(c>>>8&65280|c>>>24))>>>0<14){break a}b=j[b|0]|j[b+1|0]<<8|(j[b+2|0]<<16|j[b+3|0]<<24);if((b<<24|b<<8&16711680|(b>>>8&65280|b>>>24))>>>0>256){break a}a=a+8|0;return!(j[a|0]|j[a+1|0]<<8)}return 0}function Wta(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=Xa-32|0;Xa=d;i[d+24>>2]=b;a:{b=th(d+8|0,a+8|0,Vta(b,c));if(i[b>>2]!=i[b+4>>2]){while(1){c=i[a+16>>2];e=i[b>>2];f=i[d+24>>2];i[114610]=0;G(770,c|0,e|0,f|0);c=i[114610];i[114610]=0;if((c|0)==1){break a}i[b>>2]=i[b>>2]+4;Gd(d+24|0);if(i[b>>2]!=i[b+4>>2]){continue}break}}ac(b);Xa=d+32|0;return}a=B()|0;A()|0;ac(b);E(a|0);x()}function IJa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=Xa-32|0;Xa=d;i[d+24>>2]=b;a:{b=tl(d+8|0,a+8|0,zz(b,c));if(i[b>>2]!=i[b+4>>2]){while(1){c=i[a+16>>2];e=i[b>>2];f=i[d+24>>2];i[114610]=0;G(522,c|0,e|0,f|0);c=i[114610];i[114610]=0;if((c|0)==1){break a}i[b>>2]=i[b>>2]+2;he(d+24|0);if(i[b>>2]!=i[b+4>>2]){continue}break}}ac(b);Xa=d+32|0;return}a=B()|0;A()|0;ac(b);E(a|0);x()}function sta(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=Xa-16|0;Xa=d;i[d+12>>2]=b;a:{if(Yg(a)>>>0>=b>>>0){g=d,h=be(a),i[g+8>>2]=h;e=i[a>>2];b=c;f=i[rb(d+12|0,d+8|0)>>2];if(f){while(1){e=Hta(e,b)+32|0;f=f+ -1|0;if(f){continue}break}}b=i[d+12>>2];e=i[d+8>>2];if(b>>>0>e>>>0){Jx(a,b-e|0,c);break a}bM(a,i[a>>2]+(b<<5)|0);break a}qta(a);pta(a,Bl(a,b));Jx(a,b,c)}Xa=d+16|0}function uF(a,b){a=a|0;b=+b;var c=0,d=0;c=Xa-16|0;Xa=c;a:{b:{c:{if(!(b<=1?!(b<0):0)){d=P(8)|0;i[114610]=0;c=C(85,c|0,40587)|0;a=i[114610];i[114610]=0;if((a|0)==1){break c}Ub(d,c);i[114610]=0;G(2009,d|0,83568,2017);a=i[114610];i[114610]=0;if((a|0)!=1){break a}a=B()|0;A()|0;eb(c);break b}d=Wj(b*256);i[i[a+32>>2]+1074444>>2]=d;Xa=c+16|0;return}a=B()|0;A()|0;Q(d|0)}E(a|0)}x()}function fha(a,b){a=a|0;b=b|0;var c=p(0);a:{switch(b|0){case 0:return p(m[a+4220>>2]);case 1:return p(m[a+4224>>2]);case 2:return p(m[a+4228>>2]);case 3:return p(j[a+4240|0]?p(1):p(0));case 4:return p(p(p(i[a+4232>>2])*p(.03125)));case 5:return p(j[a+4241|0]?p(1):p(0));case 6:return p(j[a+4242|0]?p(1):p(0));case 7:c=j[a+4244|0]?p(1):p(0);break;default:break a}}return p(c)}function hsa(a){var b=0;b=Xa-16|0;Xa=b;g[a|0]=0;g[a+1|0]=0;g[a+2|0]=0;g[a+3|0]=0;g[a+4|0]=0;g[a+5|0]=0;g[a+6|0]=0;g[a+7|0]=0;g[a+23|0]=0;g[a+24|0]=0;g[a+25|0]=0;g[a+26|0]=0;g[a+16|0]=0;g[a+17|0]=0;g[a+18|0]=0;g[a+19|0]=0;g[a+20|0]=0;g[a+21|0]=0;g[a+22|0]=0;g[a+23|0]=0;g[a+8|0]=0;g[a+9|0]=0;g[a+10|0]=0;g[a+11|0]=0;g[a+12|0]=0;g[a+13|0]=0;g[a+14|0]=0;g[a+15|0]=0;Xa=b+16|0}function fI(a,b){var c=0,d=0,e=0,f=p(0),g=0,h=p(0);c=Xa-16|0;Xa=c;e=0;a:{if(!hf(i[i[a>>2]+ -12>>2]+a|0)){break a}i[c+12>>2]=0;di(a,c+12|0);d=i[c+12>>2];e=0;if(d>>>0>65535){break a}Tk(b,d);if(i[c+12>>2]){d=0;while(1){i[c+8>>2]=0;fo(a,c+8|0);f=m[c+8>>2];g=vb(b,d),h=f,m[g>>2]=h;d=d+1|0;if(d>>>0<l[c+12>>2]){continue}break}}e=hf(i[i[a>>2]+ -12>>2]+a|0)}d=e;Xa=c+16|0;return d}function eI(a,b){var c=0,d=0,e=0,f=p(0),g=0,j=p(0);c=Xa-16|0;Xa=c;e=0;a:{if(!hf(i[i[a>>2]+ -12>>2]+a|0)){break a}h[c+14>>1]=0;af(a,c+14|0);d=k[c+14>>1];e=0;if(d>>>0>65535){break a}Tk(b,d);if(k[c+14>>1]){d=0;while(1){i[c+8>>2]=0;fo(a,c+8|0);f=m[c+8>>2];g=vb(b,d),j=f,m[g>>2]=j;d=d+1|0;if(d>>>0<k[c+14>>1]){continue}break}}e=hf(i[i[a>>2]+ -12>>2]+a|0)}a=e;Xa=c+16|0;return a}function ox(a,b,c,d){a:{if(i[a+1074392>>2]!=(c|0)){break a}b:{if(d){c=o(b,896)+a|0;i[c+1075680>>2]=0;d=c+1074992|0;i[d>>2]=0;i[d+4>>2]=0;d=c+1075072|0;c=i[d>>2]|4096;i[d>>2]=c;break b}c=o(b,896)+a|0;i[c+1075672>>2]=0;c=i[c+1075072>>2]}d=o(b,896)+a|0;i[d+1075072>>2]=c|2097152;Kj(a,b,255,0);if(!(j[d+1075073|0]&2)){break a}a=a+1304392|0;if(!$c(a)){break a}Zh(i[a>>2],b,0)}}function n7(a,b,c,d,e){var f=0,g=0,i=0,j=0,k=0,l=0,m=0;g=Xa-16|0;Xa=g;if(e){while(1){i=0;if(d){while(1){f=n[Ig(b,i,j)>>3];Nb(c,i);n[g+8>>3]=f;mf(g+8|0,-1,1);f=n[g+8>>3]*32768;n[g+8>>3]=f;f=xd(f);a:{if(q(f)<2147483648){k=~~f;break a}k=-2147483648}k=Bc(k);l=gm(a,i,j),m=k,h[l>>1]=m;i=i+1|0;if((i|0)!=(d|0)){continue}break}}j=j+1|0;if((j|0)!=(e|0)){continue}break}}Xa=g+16|0}function ch(a,b,c,d,e){var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;k=e;e=0;l=e;h=c;c=0;g=XMa(k,e,h,c);e=_a;m=g;g=g>>>0<0?e+1|0:e;f=d;e=0;j=b;d=XMa(f,e,b,0);b=_a;f=XMa(f,e,h,c);c=b+f|0;b=_a;b=c>>>0<f>>>0?b+1|0:b;h=b;f=b+m|0;b=g;b=f>>>0<h>>>0?b+1|0:b;g=b;b=XMa(j,n,k,l)+c|0;e=_a;e=b>>>0<c>>>0?e+1|0:e;j=e;f=e+f|0;e=g;i[a+8>>2]=f;i[a+12>>2]=f>>>0<j>>>0?e+1|0:e;i[a>>2]=d;i[a+4>>2]=b}function Q7(a,b,c,d,e){var f=0,g=0,i=0,j=0,k=0,l=0,m=0;g=Xa-16|0;Xa=g;if(e){while(1){i=0;if(d){while(1){f=n[Ig(b,i,j)>>3];Nb(c,i);n[g+8>>3]=f;mf(g+8|0,-1,1);f=n[g+8>>3]*32768;n[g+8>>3]=f;f=xd(f);a:{if(q(f)<2147483648){k=~~f;break a}k=-2147483648}k=Bc(k);l=im(a,i,j),m=k,h[l>>1]=m;i=i+1|0;if((i|0)!=(d|0)){continue}break}}j=j+1|0;if((j|0)!=(e|0)){continue}break}}Xa=g+16|0}function jqa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=Xa-16|0;Xa=e;i[e+12>>2]=(c>>>0)/6;i[e+8>>2]=i[a>>2];d=i[rb(e+12|0,e+8|0)>>2];b=jb(b);if(d){a=i[a+20>>2];c=d;while(1){jb(j[b|0]);f=a,g=jb(j[b+1|0])|jb(j[b+2|0])<<8,h[f>>1]=g;jb(j[b+3|0]);f=a,g=jb(j[b+4|0])|jb(j[b+5|0])<<8,h[f+2>>1]=g;a=a+4|0;b=b+6|0;c=c+ -1|0;if(c){continue}break}}Xa=e+16|0;return o(d,6)|0}function jCa(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=p(0),i=0,j=0,k=0,l=0;f=Xa-16|0;Xa=f;if(d){a=(e<<1)+a|0;e=0;c=c<<1;while(1){m[f+12>>2]=m[b>>2];Id(f+12|0,p(-1));g=p(m[f+12>>2]*p(32768));m[f+12>>2]=g;j=a;g=Qd(g);a:{if(p(q(g))<p(2147483648)){i=~~g;break a}i=-2147483648}k=j,l=Bc(i),h[k>>1]=l;b=b+4|0;a=a+c|0;e=e+1|0;if((e|0)!=(d|0)){continue}break}}Xa=f+16|0}function iqa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=Xa-16|0;Xa=e;i[e+12>>2]=(c>>>0)/6;i[e+8>>2]=i[a>>2];d=i[rb(e+12|0,e+8|0)>>2];b=jb(b);if(d){a=i[a+20>>2];c=d;while(1){jb(j[b+2|0]);f=a,g=jb(j[b+1|0])|jb(j[b|0])<<8,h[f>>1]=g;jb(j[b+5|0]);f=a,g=jb(j[b+4|0])|jb(j[b+3|0])<<8,h[f+2>>1]=g;a=a+4|0;b=b+6|0;c=c+ -1|0;if(c){continue}break}}Xa=e+16|0;return o(d,6)|0}function P5(a,b,c,d,e,f){var h=0,i=0,k=0,l=0,m=0,n=0;while(1){h=j[d+k|0];if(h){a:{if(f&8){Tb(a,b,h);break a}l=j[c+k|0];if(!l){yb(a,0,h);yb(b,0,h);break a}n=(f|0)>-1?-1:-1<<l^-1;i=0;while(1){m=zd(e,l);g[b+i|0]=(m|0)==(n|0)?-1:m;g[a+i|0]=m;i=i+1|0;if((i|0)!=(h|0)){continue}break}}f=f<<1;a=a+h|0;b=b+h|0;k=k+1|0;if((k|0)!=4){continue}}break}g[a+2|0]=0;g[a|0]=0;g[a+1|0]=0}function pq(a,b,c){var d=0,e=0;if(c&2048){g[a|0]=43;a=a+1|0}if(c&1024){g[a|0]=35;a=a+1|0}d=c&260;if((d|0)!=260){g[a|0]=10798;g[a+1|0]=42;a=a+2|0}c=c&16384;while(1){e=j[b|0];if(e){g[a|0]=e;a=a+1|0;b=b+1|0;continue}break}a:{b:{if((d|0)!=256){if((d|0)!=4){break b}b=c?70:102;break a}b=c?69:101;break a}b=c?65:97;if((d|0)==260){break a}b=c?71:103}g[a|0]=b;return(d|0)!=260}function ME(a,b){a:{if((b|0)>=128){a=p(a*p(1.7014118346046923e+38));if((b|0)<255){b=b+ -127|0;break a}a=p(a*p(1.7014118346046923e+38));b=((b|0)<381?b:381)+ -254|0;break a}if((b|0)>-127){break a}a=p(a*p(1.1754943508222875e-38));if((b|0)>-253){b=b+126|0;break a}a=p(a*p(1.1754943508222875e-38));b=((b|0)>-378?b:-378)+252|0}return p(a*(eNa(2,(b<<23)+1065353216|0),iNa()))}function dqa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=Xa-16|0;Xa=e;i[e+12>>2]=c>>>3;i[e+8>>2]=i[a>>2];d=i[rb(e+12|0,e+8|0)>>2];b=jb(b);if(d){a=i[a+20>>2];c=d;while(1){jb(j[b|0]);jb(j[b+1|0]);jb(j[b+2|0]);jb(j[b+3|0]);jb(j[b+4|0]);jb(j[b+5|0]);f=a,g=jb(j[b+6|0])|jb(j[b+7|0])<<8,h[f>>1]=g;a=a+2|0;b=b+8|0;c=c+ -1|0;if(c){continue}break}}Xa=e+16|0;return d<<3}function bqa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=Xa-16|0;Xa=e;i[e+12>>2]=c>>>3;i[e+8>>2]=i[a>>2];d=i[rb(e+12|0,e+8|0)>>2];b=jb(b);if(d){a=i[a+20>>2];c=d;while(1){jb(j[b+7|0]);jb(j[b+6|0]);jb(j[b+5|0]);jb(j[b+4|0]);jb(j[b+3|0]);jb(j[b+2|0]);f=a,g=jb(j[b+1|0])|jb(j[b|0])<<8,h[f>>1]=g;a=a+2|0;b=b+8|0;c=c+ -1|0;if(c){continue}break}}Xa=e+16|0;return d<<3}function Pk(a){if((a|0)>=0){if((a|0)<=16383){if((a|0)<=15){return g[a+50608|0]}if((a|0)<=511){return g[(a>>>5|0)+50608|0]+5|0}return g[(a>>>10|0)+50608|0]+10|0}if((a|0)<=16777215){if((a|0)<=524287){return g[(a>>>15|0)+50608|0]+15|0}return g[(a>>>20|0)+50608|0]+20|0}if((a|0)<=536870911){return g[(a>>>25|0)+50608|0]+25|0}a=g[(a>>>30|0)+50608|0]+30|0}else{a=0}return a}function p5(a,b){var c=0,d=0,e=p(0),f=0;d=u(tv(+p(p(Vn(+p(a|0)))/p(b|0))));a:{if(q(d)<2147483648){c=~~d;break a}c=-2147483648}f=c;d=u(ov(+p(p(c|0)+p(1)),b));b:{if(q(d)<2147483648){c=~~d;break b}c=-2147483648}c=f+((c|0)<=(a|0))|0;e=p(c|0);if(!(ov(+p(e+p(1)),b)<=+(a|0))){d=u(ov(+e,b));c:{if(q(d)<2147483648){b=~~d;break c}b=-2147483648}return(b|0)>(a|0)?-1:c}return-1}function n6(a){var b=0;if(!a){return-2}i[a+44>>2]=0;i[a+48>>2]=0;i[a+52>>2]=0;i[a+20>>2]=0;i[a+24>>2]=0;i[a+8>>2]=0;b=i[a+32>>2];if(!b){i[a+32>>2]=2299;b=2299}if(!i[a+36>>2]){i[a+36>>2]=2300}b=$a[b|0](i[a+40>>2],1,43784)|0;if(!b){return-4}i[a+28>>2]=b;i[b+43780>>2]=1;i[b+10992>>2]=0;i[b+10996>>2]=0;i[b>>2]=0;i[b+11008>>2]=15;i[b+11e3>>2]=1;i[b+11004>>2]=0;return 0}function zF(a,b){a=a|0;b=b|0;var c=0;c=Xa-16|0;Xa=c;a:{b:{c:{if(b+ -32>>>0>=481){a=P(8)|0;i[114610]=0;c=C(85,c|0,40531)|0;b=i[114610];i[114610]=0;if((b|0)==1){break c}Ub(a,c);i[114610]=0;G(2009,a|0,83568,2017);a=i[114610];i[114610]=0;if((a|0)!=1){break a}b=B()|0;A()|0;eb(c);break b}i[i[a+32>>2]+1074420>>2]=o(b,1e4);Xa=c+16|0;return}b=B()|0;A()|0;Q(a|0)}E(b|0)}x()}function YC(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,j=0;e=Xa-16|0;Xa=e;f=i[Pb(a)>>2];d=i[c>>2]-i[a>>2]|0;a:{if(d>>>0<2147483647){d=d<<1;break a}d=-1}d=d?d:4;h=i[b>>2];j=i[a>>2];g=dq((f|0)==2482?0:i[a>>2],d);if(g){if((f|0)!=2482){sd(a)}i[e+4>>2]=2420;f=wd(e+8|0,g,e+4|0);VC(a,f);lc(f);i[b>>2]=i[a>>2]+(h-j|0);i[c>>2]=i[a>>2]+(d&-4);Xa=e+16|0;return}zu();x()}function f5(a,b,c,d,e,f){var g=0,h=0;a:{if(f){g=1;if((e|0)<1){break a}f=0;while(1){if(!b5(a,b,(d<<2)+c|0,e-f|0)){return 0}h=i[b>>2];d=h+d|0;f=f+h|0;if((f|0)<(e|0)){continue}break}break a}g=1;f=(e|0)/i[b>>2]|0;if((f|0)<1){break a}c=(d<<2)+c|0;e=e-d|0;g=0;d=0;while(1){if(!a5(a,b,c+(d<<2)|0,e-d|0,f)){break a}d=d+1|0;if((f|0)!=(d|0)){continue}break}return 1}return g}function vM(a,b,c,d){var e=0,f=0,g=0,h=0;f=Xa-16|0;Xa=f;if(Vi(a)){e=j[(Jd(j[a+819|0])?819:821)+a|0];kb(f+8|0,d+1074308|0,34);a:{if(!ib(f+8|0)){break a}if(e){if(e>>>0>120){break a}e=j[Nb(i[a+656>>2]+108|0,e+ -1|0)|0];break a}e=0}g=a,h=_h(p(p(p(i[a+704>>2]<<4)*b)*$ia(i[i[a+656>>2]+44>>2],(c+e<<16)+ -3997696>>16,i[a+876>>2]+i[a+768>>2]|0))),i[g+700>>2]=h}Xa=f+16|0}function haa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;b=Xa-32|0;Xa=b;a:{a=Er(a,ml(b+24|0,jb(c),d),0);if(a+1>>>0>=3){a=P(8)|0;i[114610]=0;b=C(85,b+8|0,38585)|0;c=i[114610];i[114610]=0;b:{if((c|0)!=1){Ub(a,b);i[114610]=0;G(2009,a|0,83568,2017);a=i[114610];i[114610]=0;if((a|0)!=1){break a}d=B()|0;A()|0;eb(b);break b}d=B()|0;A()|0;Q(a|0)}E(d|0);x()}Xa=b+32|0;return a|0}x()}function Oja(a,b,c){var d=0,e=0;e=Xa-32|0;Xa=e;a:{b:{if((i[fb(a)>>2]-i[a+4>>2]|0)/52>>>0>=b>>>0){xw(a,b,c);break b}d=fb(a);d=Dja(e+8|0,vI(a,bf(a)+b|0),bf(a),d);i[114610]=0;G(1585,d|0,b|0,c|0);b=i[114610];i[114610]=0;if((b|0)==1){break a}i[114610]=0;D(1586,a|0,d|0);a=i[114610];i[114610]=0;if((a|0)==1){break a}nI(d)}Xa=e+32|0;return}a=B()|0;A()|0;nI(d);E(a|0);x()}function Gja(a,b){var c=0,d=0,e=0;e=Fja(a,b);i[a+20>>2]=i[b+20>>2];c=i[b+16>>2];i[a+12>>2]=i[b+12>>2];i[a+16>>2]=c;i[114610]=0;c=C(1589,a+24|0,b+24|0)|0;d=i[114610];i[114610]=0;a:{b:{if((d|0)!=1){i[114610]=0;C(120,a+36|0,b+36|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break b}i[a+48>>2]=i[b+48>>2];return}a=B()|0;A()|0;break a}a=B()|0;A()|0;Sd(c)}kl(e);E(a|0);x()}function ara(a,b,c,d){var e=0,f=0,g=0,h=0,j=0,k=0;g=Xa-16|0;Xa=g;j=i[a+4>>2];d=(j-d|0)+b|0;e=vh(g,a,c-d>>1);a:{if(c>>>0>d>>>0){f=d;while(1){h=fb(a);k=i[e+4>>2];i[114610]=0;G(1249,h|0,k|0,f|0);h=i[114610];i[114610]=0;if((h|0)==1){break a}i[e+4>>2]=i[e+4>>2]+2;f=f+2|0;if(f>>>0<c>>>0){continue}break}}sb(e);Zs(b,d,j);Xa=g+16|0;return}a=B()|0;A()|0;sb(e);E(a|0);x()}function Gda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;i[114610]=0;L(2015,a|0);d=i[114610];i[114610]=0;if((d|0)!=1){i[a+16>>2]=0;i[a+12>>2]=c;i[a+8>>2]=b;return}b=H(0)|0;A()|0;M(b|0)|0;i[114610]=0;J(1989,34783,a|0,0,0);a=i[114610];i[114610]=0;if((a|0)!=1){O();return}a=B()|0;A()|0;i[114610]=0;K(20);b=i[114610];i[114610]=0;if((b|0)!=1){E(a|0);x()}a=H(0)|0;A()|0;gb(a);x()}function $Ja(a,b,c,d){var e=0,f=0,g=0,h=0,j=0,k=0;g=Xa-16|0;Xa=g;j=i[a+4>>2];d=(j-d|0)+b|0;e=vh(g,a,c-d>>1);a:{if(c>>>0>d>>>0){f=d;while(1){h=fb(a);k=i[e+4>>2];i[114610]=0;G(522,h|0,k|0,f|0);h=i[114610];i[114610]=0;if((h|0)==1){break a}i[e+4>>2]=i[e+4>>2]+2;f=f+2|0;if(f>>>0<c>>>0){continue}break}}sb(e);HJa(b,d,j);Xa=g+16|0;return}a=B()|0;A()|0;sb(e);E(a|0);x()}function eua(a,b,c,d){var e=0,f=0,g=0,h=0,j=0,k=0;g=Xa-16|0;Xa=g;j=i[a+4>>2];d=(j-d|0)+b|0;e=Yd(g,a,c-d>>2);a:{if(c>>>0>d>>>0){f=d;while(1){h=fb(a);k=i[e+4>>2];i[114610]=0;G(770,h|0,k|0,f|0);h=i[114610];i[114610]=0;if((h|0)==1){break a}i[e+4>>2]=i[e+4>>2]+4;f=f+4|0;if(f>>>0<c>>>0){continue}break}}sb(e);Zs(b,d,j);Xa=g+16|0;return}a=B()|0;A()|0;sb(e);E(a|0);x()}function L5(a,b,c){var d=0,e=0,f=0,g=0,h=0;f=Xa-80|0;Xa=f;if((c|0)>=1){g=f|8;h=f|4;while(1){d=Tb(f,a,72);e=i[b+20>>2];i[a+16>>2]=i[b+16>>2];i[a+20>>2]=e;e=i[b+12>>2];i[a+8>>2]=i[b+8>>2];i[a+12>>2]=e;e=i[b+4>>2];i[a>>2]=i[b>>2];i[a+4>>2]=e;e=d;d=b+24|0;Bv(e,a+24|0,d);Bv(h,a+48|0,d);Bv(g,b,d);a=a+72|0;b=b+36|0;d=(c|0)>1;c=c+ -1|0;if(d){continue}break}}Xa=f+80|0}function Hea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;b=Ph(a,b,c,d);i[a+4272>>2]=1065353216;i[a+4216>>2]=1056964608;i[a+4208>>2]=1056880300;i[a+4212>>2]=1050733080;i[a>>2]=81772;i[114610]=0;I(1639,a+44|0,2,2)|0;c=i[114610];i[114610]=0;a:{if((c|0)==1){break a}i[114610]=0;L(1640,b|0);c=i[114610];i[114610]=0;if((c|0)==1){break a}return a|0}a=B()|0;A()|0;ve(b);E(a|0);x()}function Ao(a,b,c,d){a:{if(i[a+480180>>2]==4){if(c){g[b+830|0]=j[b+830|0]&15|c<<4;break a}c=j[b+830|0]>>>4|0;break a}if(d){if(c){g[b+854|0]=c;break a}c=j[b+854|0];break a}if(c){g[b+830|0]=c;break a}c=j[b+830|0]}b:{if(!(g[b+872|0]&1)){break b}c=i[b+688>>2]+((c&255)<<2)|0;i[b+688>>2]=(c|0)<256?c:256;if(!(i[a+480180>>2]&1)){break b}i[b+88>>2]=i[b+88>>2]|2097152}}function dN(a){var b=0;a:{if((j[a|0]|j[a+1|0]<<8|(j[a+2|0]<<16|j[a+3|0]<<24))!=860902483){break a}b=a+4|0;b=j[b|0]|j[b+1|0]<<8;if((b<<24|b<<8&16711680)>>>16>>>0>2|j[a+6|0]>128){break a}b=a+200|0;b=j[b|0]|j[b+1|0]<<8;if((b<<24|b<<8&16711680)>>>16>>>0>3999){break a}b=a+140|0;if(!(j[b|0]|j[b+1|0]<<8)){break a}a=a+148|0;return(j[a|0]|j[a+1|0]<<8)==12800}return 0}function T6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=Xa-32|0;Xa=e;c=co(e+24|0,c);i[114610]=0;f=i[b+12>>2];i[e+16>>2]=i[b+8>>2];i[e+20>>2]=f;f=i[b+4>>2];i[e+8>>2]=i[b>>2];i[e+12>>2]=f;N(2013,a+8|0,e+8|0,c|0,d|0)|0;b=i[114610];i[114610]=0;if((b|0)!=1){Ec(c);DF(a);b=CF(a+88|0);i[a>>2]=84280;i[b>>2]=84368;Xa=e+32|0;return a|0}a=B()|0;A()|0;Ec(c);E(a|0);x()}function $$(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,j=0;e=Xa-16|0;Xa=e;f=i[Pb(a)>>2];d=i[c>>2]-i[a>>2]|0;a:{if(d>>>0<2147483647){d=d<<1;break a}d=-1}d=d?d:1;h=i[b>>2];j=i[a>>2];g=dq((f|0)==2482?0:i[a>>2],d);if(g){if((f|0)!=2482){sd(a)}i[e+4>>2]=2420;f=wd(e+8|0,g,e+4|0);VC(a,f);lc(f);i[b>>2]=i[a>>2]+(h-j|0);i[c>>2]=d+i[a>>2];Xa=e+16|0;return}zu();x()}function pGa(a,b,c){var d=0,e=0;e=Xa-32|0;Xa=e;a:{b:{if((i[fb(a)>>2]-i[a+4>>2]|0)/6>>>0>=b>>>0){Yy(a,b,c);break b}d=fb(a);d=SP(e+8|0,Ny(a,If(a)+b|0),If(a),d);i[114610]=0;G(710,d|0,b|0,c|0);b=i[114610];i[114610]=0;if((b|0)==1){break a}i[114610]=0;D(711,a|0,d|0);a=i[114610];i[114610]=0;if((a|0)==1){break a}Ls(d)}Xa=e+32|0;return}a=B()|0;A()|0;Ls(d);E(a|0);x()}function hia(a,b,c){var d=0,e=0,f=0,g=0;e=Xa-16|0;Xa=e;d=te(64);i[114610]=0;f=F(1427,d|0)|0;g=i[114610];i[114610]=0;a:{if((g|0)!=1){d=ax(e+8|0,f);f=i[d>>2];i[114610]=0;b=I(1633,f|0,b|0,c|0)|0;c=i[114610];i[114610]=0;b:{c:{if((c|0)!=1){if((b|0)==1){break c}$w(a);break b}a=B()|0;A()|0;Hf(d);break a}dp(a,d)}Hf(d);Xa=e+16|0;return}a=B()|0;A()|0;Cb(d)}E(a|0);x()}function AF(a,b){a=a|0;b=b|0;var c=0;c=Xa-16|0;Xa=c;a:{b:{c:{if(b+ -1>>>0>=65535){a=P(8)|0;i[114610]=0;c=C(85,c|0,40512)|0;b=i[114610];i[114610]=0;if((b|0)==1){break c}Ub(a,c);i[114610]=0;G(2009,a|0,83568,2017);a=i[114610];i[114610]=0;if((a|0)!=1){break a}b=B()|0;A()|0;eb(c);break b}i[i[a+32>>2]+1074416>>2]=b;Xa=c+16|0;return}b=B()|0;A()|0;Q(a|0)}E(b|0)}x()}function tja(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;b=Xa-16|0;Xa=b;h[a>>1]=0;c=Gj(a+4|0);d=Gj(a+16|0);i[a+36>>2]=0;e=Oc(a+40|0);f=sja(a+52|0);Sh(c);h[a+28>>1]=65472;i[114610]=0;i[b+12>>2]=1065353216;G(1592,c|0,128,b+12|0);g=i[114610];i[114610]=0;if((g|0)!=1){i[a+32>>2]=0;h[a+30>>1]=0;Sh(d);Xa=b+16|0;return a|0}a=B()|0;A()|0;eQ(f);eb(e);uf(d);uf(c);E(a|0);x()}function pJ(a,b){var c=0,d=0;a:{if(k[a+480188>>1]<=b>>>0){break a}b:{c:{c=o(b,896)+a|0;d=j[c+1075797|0];switch(d+ -31|0){case 1:break b;case 0:break c;default:break a}}if(!(j[a+480209|0]&16)){break a}}c=g[c+1075799|0];if((c|0)>=0){iK(a,b,(d|0)==32,((j[(o(b,896)+a|0)+1075848|0]<<5)+a|0)+901692|0,c&255);return}iK(a,b,(d|0)==32,(((c&127)<<5)+a|0)+902204|0,0)}}function oja(a,b,c){var d=0,e=0;e=Xa-32|0;Xa=e;a:{b:{if(i[fb(a)>>2]-i[a+4>>2]>>2>>>0>=b>>>0){sw(a,b,c);break b}d=fb(a);d=uw(e+8|0,ge(a,qb(a)+b|0),qb(a),d);i[114610]=0;G(1596,d|0,b|0,c|0);b=i[114610];i[114610]=0;if((b|0)==1){break a}i[114610]=0;D(1597,a|0,d|0);a=i[114610];i[114610]=0;if((a|0)==1){break a}rm(d)}Xa=e+32|0;return}a=B()|0;A()|0;rm(d);E(a|0);x()}function Zsa(a,b,c){var d=0,e=0;e=Xa-32|0;Xa=e;a:{b:{if(i[fb(a)>>2]-i[a+4>>2]>>5>>>0>=b>>>0){Jx(a,b,c);break b}d=fb(a);d=TL(e+8|0,Bl(a,be(a)+b|0),be(a),d);i[114610]=0;G(1194,d|0,b|0,c|0);b=i[114610];i[114610]=0;if((b|0)==1){break a}i[114610]=0;D(1181,a|0,d|0);a=i[114610];i[114610]=0;if((a|0)==1){break a}cs(d)}Xa=e+32|0;return}a=B()|0;A()|0;cs(d);E(a|0);x()}function uq(a,b,c,d){var e=0,f=0;e=Xa-160|0;Xa=e;Tb(e+8|0,58080,144);a:{b:{if(b+ -1>>>0>=2147483647){if(b){break b}b=1;a=e+159|0}i[e+52>>2]=a;i[e+28>>2]=a;f=-2-a|0;b=b>>>0>f>>>0?f:b;i[e+56>>2]=b;a=a+b|0;i[e+36>>2]=a;i[e+24>>2]=a;a=EE(e+8|0,c,d,2303,2304);if(!b){break a}b=i[e+28>>2];g[b-((b|0)==i[e+24>>2])|0]=0;break a}i[114584]=61;a=-1}Xa=e+160|0;return a}function r7(a,b,c,d,e){var f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0;if(e){l=c+16|0;while(1){g=0;if(d){while(1){f=i[rf(b,g,j)>>2];k=Ae(c,g);f=f+(i[k>>2]>>1)|0;m=f;f=Xq(l)+f&-4096;i[k>>2]=m-f;f=f+ -2147481600>>>12|0;f=f>>>0>491520?f:491520;n=gm(a,g,j),o=(f|0)<557055?f:557055,h[n>>1]=o;g=g+1|0;if((g|0)!=(d|0)){continue}break}}j=j+1|0;if((j|0)!=(e|0)){continue}break}}}function Ul(a,b,c){var d=0,e=0,f=0;d=Xa-16|0;Xa=d;fc(d+8|0,b);i[114610]=0;b=F(2450,d+8|0)|0;e=i[114610];i[114610]=0;a:{if((e|0)==1){break a}i[114610]=0;e=F(2460,b|0)|0;f=i[114610];i[114610]=0;if((f|0)==1){break a}i[c>>2]=e;i[114610]=0;D(2461,a|0,b|0);a=i[114610];i[114610]=0;if((a|0)==1){break a}ub(d+8|0);Xa=d+16|0;return}a=B()|0;A()|0;ub(d+8|0);E(a|0);x()}function U7(a,b,c,d,e){var f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0;if(e){l=c+16|0;while(1){g=0;if(d){while(1){f=i[rf(b,g,j)>>2];k=Ae(c,g);f=f+(i[k>>2]>>1)|0;m=f;f=Xq(l)+f&-4096;i[k>>2]=m-f;f=f+ -2147481600>>>12|0;f=f>>>0>491520?f:491520;n=im(a,g,j),o=(f|0)<557055?f:557055,h[n>>1]=o;g=g+1|0;if((g|0)!=(d|0)){continue}break}}j=j+1|0;if((j|0)!=(e|0)){continue}break}}}function Sda(a,b,c,d,e,f,g,h,j,k){i[114610]=0;a=va(2006,a|0,b|0,c|0,d|0)|0;b=i[114610];i[114610]=0;a:{if((b|0)==1){a=H(0)|0;A()|0;M(a|0)|0;i[114610]=0;X(2e3,34593,e|0,f|0,g|0,h|0,j|0,k|0);a=i[114610];i[114610]=0;if((a|0)==1){break a}O();a=-255}return a}a=B()|0;A()|0;i[114610]=0;K(20);b=i[114610];i[114610]=0;if((b|0)!=1){E(a|0);x()}a=H(0)|0;A()|0;gb(a);x()}function yra(a,b){var c=0,d=0;d=Xa-32|0;Xa=d;a:{b:{if((i[fb(a)>>2]-i[a+4>>2]|0)/12>>>0>=b>>>0){nra(a,b);break b}c=fb(a);c=mra(d+8|0,$l(a,cc(a)+b|0),cc(a),c);i[114610]=0;D(1235,c|0,b|0);b=i[114610];i[114610]=0;if((b|0)==1){break a}i[114610]=0;D(1236,a|0,c|0);a=i[114610];i[114610]=0;if((a|0)==1){break a}eL(c)}Xa=d+32|0;return}a=B()|0;A()|0;eL(c);E(a|0);x()}function iCa(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,h=p(0),i=0,j=0,k=0,l=0;f=Xa-16|0;Xa=f;if(d){a=a+e|0;e=0;while(1){m[f+12>>2]=m[b>>2];Id(f+12|0,p(-1));h=p(m[f+12>>2]*p(128));m[f+12>>2]=h;j=a;h=Qd(h);a:{if(p(q(h))<p(2147483648)){i=~~h;break a}i=-2147483648}k=j,l=_Ba(i),g[k|0]=l;a=a+c|0;b=b+4|0;e=e+1|0;if((e|0)!=(d|0)){continue}break}}Xa=f+16|0}function Wl(a,b,c){var d=0,e=0,f=0;d=Xa-16|0;Xa=d;fc(d+8|0,b);i[114610]=0;b=F(2416,d+8|0)|0;e=i[114610];i[114610]=0;a:{if((e|0)==1){break a}i[114610]=0;e=F(2431,b|0)|0;f=i[114610];i[114610]=0;if((f|0)==1){break a}g[c|0]=e;i[114610]=0;D(2432,a|0,b|0);a=i[114610];i[114610]=0;if((a|0)==1){break a}ub(d+8|0);Xa=d+16|0;return}a=B()|0;A()|0;ub(d+8|0);E(a|0);x()}function Dw(a,b,c,d){var e=0,f=0;a:{e=j[a|0];f=j[c|0];b:{if(!(j[d|0]|((e|0)!=11|(f+ -5&255)>>>0>1))){g[a|0]=(f|0)==5?7:6;break b}if((f|0)==11){if(j[b|0]|(e+ -5&255)>>>0>1){break a}g[a|0]=(e|0)==5?7:6;g[b|0]=j[d|0];break b}if(!((e|0)!=10|(f|0)!=20|j[d|0]!=159)){g[a|0]=39;break b}if((f|0)!=10|(e|0)!=20|j[b|0]!=159){break a}g[a|0]=39;g[b|0]=j[d|0]}g[c|0]=0}}function AMa(a,b,c){var d=0,e=0;e=Xa-32|0;Xa=e;a:{b:{if(i[fb(a)>>2]-i[a+4>>2]>>1>>>0>=b>>>0){ut(a,b,c);break b}d=fb(a);d=tt(e+8|0,qi(a,Wb(a)+b|0),Wb(a),d);i[114610]=0;G(379,d|0,b|0,c|0);b=i[114610];i[114610]=0;if((b|0)==1){break a}i[114610]=0;D(380,a|0,d|0);a=i[114610];i[114610]=0;if((a|0)==1){break a}kk(d)}Xa=e+32|0;return}a=B()|0;A()|0;kk(d);E(a|0);x()}function zea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;b=Ph(a,b,c,d);c=a+4216|0;i[c>>2]=1051372203;i[c+4>>2]=0;i[a+4208>>2]=1065353216;i[a+4212>>2]=1065353216;i[a>>2]=81976;i[114610]=0;I(1639,a+44|0,2,2)|0;c=i[114610];i[114610]=0;a:{if((c|0)==1){break a}i[114610]=0;L(1640,b|0);c=i[114610];i[114610]=0;if((c|0)==1){break a}return a|0}a=B()|0;A()|0;ve(b);E(a|0);x()}function qEa(a,b){var c=0,d=0;d=Xa-32|0;Xa=d;a:{b:{if((i[fb(a)>>2]-i[a+4>>2]|0)/33>>>0>=b>>>0){oEa(a,b);break b}c=fb(a);c=mEa(d+8|0,nEa(a,Yj(a)+b|0),Yj(a),c);i[114610]=0;D(766,c|0,b|0);b=i[114610];i[114610]=0;if((b|0)==1){break a}i[114610]=0;D(767,a|0,c|0);a=i[114610];i[114610]=0;if((a|0)==1){break a}GP(c)}Xa=d+32|0;return}a=B()|0;A()|0;GP(c);E(a|0);x()}function Tda(a,b,c,d,e,f,g,h,j,k,l,m){i[114610]=0;a=KB(2005,a,b,c,d,e,f);b=i[114610];i[114610]=0;a:{if((b|0)==1){a=H(0)|0;A()|0;M(a|0)|0;i[114610]=0;X(2e3,34567,g|0,h|0,j|0,k|0,l|0,m|0);a=i[114610];i[114610]=0;if((a|0)==1){break a}O();a=-255}return a}a=B()|0;A()|0;i[114610]=0;K(20);b=i[114610];i[114610]=0;if((b|0)!=1){E(a|0);x()}a=H(0)|0;A()|0;gb(a);x()}function Pxa(a,b){var c=0,d=0;d=Xa-32|0;Xa=d;a:{b:{if((i[fb(a)>>2]-i[a+4>>2]|0)/12>>>0>=b>>>0){Dxa(a,b);break b}c=fb(a);c=_x(d+8|0,$l(a,cc(a)+b|0),cc(a),c);i[114610]=0;D(1020,c|0,b|0);b=i[114610];i[114610]=0;if((b|0)==1){break a}i[114610]=0;D(1021,a|0,c|0);a=i[114610];i[114610]=0;if((a|0)==1){break a}XM(c)}Xa=d+32|0;return}a=B()|0;A()|0;XM(c);E(a|0);x()}function CFa(a,b,c){var d=0,e=0;e=Xa-32|0;Xa=e;a:{b:{if(i[fb(a)>>2]-i[a+4>>2]>>2>>>0>=b>>>0){TS(a,b,c);break b}d=fb(a);d=Zr(e+8|0,ge(a,qb(a)+b|0),qb(a),d);i[114610]=0;G(738,d|0,b|0,c|0);b=i[114610];i[114610]=0;if((b|0)==1){break a}i[114610]=0;D(96,a|0,d|0);a=i[114610];i[114610]=0;if((a|0)==1){break a}Nj(d)}Xa=e+32|0;return}a=B()|0;A()|0;Nj(d);E(a|0);x()}function hIa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=Xa-16|0;Xa=d;a=gp(a);e=d,f=Jb(b),i[e+8>>2]=f;e=d,f=Kb(b),i[e>>2]=f;a:{if(pb(d+8|0,d)){while(1){b=i[d+8>>2];if((mk(b)|0)==(c|0)){b=fb(b);i[114610]=0;D(604,a|0,b|0);b=i[114610];i[114610]=0;if((b|0)==1){break a}}dk(d+8|0);if(pb(d+8|0,d)){continue}break}}Xa=d+16|0;return}b=B()|0;A()|0;Qc(a);E(b|0);x()}function zGa(a,b){var c=0,d=0;d=Xa-32|0;Xa=d;a:{b:{if((i[fb(a)>>2]-i[a+4>>2]|0)/48>>>0>=b>>>0){oFa(a,b);break b}c=fb(a);c=eR(d+8|0,fR(a,ii(a)+b|0),ii(a),c);i[114610]=0;D(700,c|0,b|0);b=i[114610];i[114610]=0;if((b|0)==1){break a}i[114610]=0;D(561,a|0,c|0);a=i[114610];i[114610]=0;if((a|0)==1){break a}Ys(c)}Xa=d+32|0;return}a=B()|0;A()|0;Ys(c);E(a|0);x()}function uGa(a,b,c){var d=0,e=0;e=Xa-32|0;Xa=e;a:{b:{if(i[fb(a)>>2]-i[a+4>>2]>>>0>=b>>>0){at(a,b,c);break b}d=fb(a);d=wA(e+8|0,pl(a,rc(a)+b|0),rc(a),d);i[114610]=0;G(704,d|0,b|0,c|0);b=i[114610];i[114610]=0;if((b|0)==1){break a}i[114610]=0;D(364,a|0,d|0);a=i[114610];i[114610]=0;if((a|0)==1){break a}Fp(d)}Xa=e+32|0;return}a=B()|0;A()|0;Fp(d);E(a|0);x()}function tS(a){var b=0,c=0,d=0,e=0,f=0;b=a+9|0;d=j[b|0]|j[b+1|0]<<8;c=XMa(j[a+3|0],0,18,0);d=d+c|0;b=_a;b=d>>>0<c>>>0?b+1|0:b;c=d;d=b;f=c;b=a+6|0;c=j[b|0]|j[b+1|0]<<8;b=c>>>31|0;e=c<<1;c=f+e|0;b=b+d|0;b=c>>>0<e>>>0?b+1|0:b;d=b;a=a+4|0;a=j[a|0]|j[a+1|0]<<8;b=a>>>30|0;e=a<<2;c=e+c|0;a=b+d|0;a=c>>>0<e>>>0?a+1|0:a;b=c+3|0;if(b>>>0<3){a=a+1|0}_a=a;return b}function saa(a){a=a|0;var b=0,c=0,d=0,e=0;b=Xa-32|0;Xa=b;a=Mg(a);i[114610]=0;D(2156,b+16|0,0);c=i[114610];i[114610]=0;a:{b:{if((c|0)!=1){c=Jb(b+16|0);d=Kb(b+16|0);e=i[yc(b+8|0,a)>>2];i[114610]=0;I(2157,c|0,d|0,e|0)|0;c=i[114610];i[114610]=0;if((c|0)==1){break b}Nw(b+16|0);Xa=b+32|0;return}c=B()|0;A()|0;break a}c=B()|0;A()|0;Nw(b+16|0)}Sc(a);E(c|0);x()}function Hda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;i[114610]=0;L(2015,a|0);d=i[114610];i[114610]=0;if((d|0)!=1){i[a+4>>2]=c;i[a>>2]=b?b:1997;return}b=H(0)|0;A()|0;M(b|0)|0;i[114610]=0;J(1989,34755,a|0,0,0);a=i[114610];i[114610]=0;if((a|0)!=1){O();return}a=B()|0;A()|0;i[114610]=0;K(20);b=i[114610];i[114610]=0;if((b|0)!=1){E(a|0);x()}a=H(0)|0;A()|0;gb(a);x()}function Cha(a,b){var c=0,d=0;d=Xa-32|0;Xa=d;a:{b:{if(i[fb(a)>>2]-i[a+4>>2]>>11>>>0>=b>>>0){yha(a,b);break b}c=fb(a);c=NH(d+8|0,xha(a,Re(a)+b|0),Re(a),c);i[114610]=0;D(1648,c|0,b|0);b=i[114610];i[114610]=0;if((b|0)==1){break a}i[114610]=0;D(1644,a|0,c|0);a=i[114610];i[114610]=0;if((a|0)==1){break a}ur(c)}Xa=d+32|0;return}a=B()|0;A()|0;ur(c);E(a|0);x()}function j3(){var a=0;i[114610]=0;F(2392,460712)|0;a=i[114610];i[114610]=0;a:{if((a|0)==1){break a}i[114610]=0;F(2393,460796)|0;a=i[114610];i[114610]=0;if((a|0)==1){break a}i[114610]=0;F(2392,461048)|0;a=i[114610];i[114610]=0;if((a|0)==1){break a}i[114610]=0;F(2393,461132)|0;a=i[114610];i[114610]=0;if((a|0)==1){break a}return}a=H(0)|0;A()|0;gb(a);x()}function fN(a){var b=0,c=0;a:{if(j[a+29|0]!=2){break a}b=j[a+28|0];if(j[a+30|0]!=2|((b|0)!=2?(b|0)!=26:0)){break a}b=j[a+31|0];if(b>>>0>21|!(1<<b&3146753)|j[a+33|0]>64){break a}b=j[a+34|0];if((b|0)!=88?b>>>0>=65:0){break a}b=a+28|0;a=a+20|0;while(1){c=j[a|0]+ -32|0;if((c&255)>>>0<=94){a=a+1|0;if((b|0)!=(a|0)){continue}}break}c=(c&255)>>>0<95}return c}function RP(a){var b=0,c=0,d=0,e=0,f=0,g=0;a:{b=i[a>>2];b:{if(!b){break b}c=i[a+8>>2];if(!c){break b}d=i[a+12>>2];if(!d){break b}a=$a[d|0](b)|0;e=_a;f=e;if((e|0)<0?1:(e|0)<=0?a>>>0<0:0){break b}if(($a[c|0](b,0,0,0)|0)<=-1){break a}if(($a[c|0](b,0,0,2)|0)<=-1){break a}$a[d|0](b)|0;d=_a;$a[c|0](b,a,f,0)|0;g=(d|0)>-1}return g}$a[c|0](b,a,f,0)|0;return 0}function yh(a,b){a:{if((b|0)>=1024){a=a*8.98846567431158e+307;if((b|0)<2047){b=b+ -1023|0;break a}a=a*8.98846567431158e+307;b=((b|0)<3069?b:3069)+ -2046|0;break a}if((b|0)>-1023){break a}a=a*2.2250738585072014e-308;if((b|0)>-2045){b=b+1022|0;break a}a=a*2.2250738585072014e-308;b=((b|0)>-3066?b:-3066)+2044|0}eNa(0,0);eNa(1,b+1023<<20);return a*+fNa()}function uAa(a,b){var c=0,d=0;d=Xa-32|0;Xa=d;a:{b:{if(i[fb(a)>>2]-i[a+4>>2]>>3>>>0>=b>>>0){tAa(a,b);break b}c=fb(a);c=rAa(d+8|0,sAa(a,bg(a)+b|0),bg(a),c);i[114610]=0;D(925,c|0,b|0);b=i[114610];i[114610]=0;if((b|0)==1){break a}i[114610]=0;D(926,a|0,c|0);a=i[114610];i[114610]=0;if((a|0)==1){break a}dO(c)}Xa=d+32|0;return}a=B()|0;A()|0;dO(c);E(a|0);x()}function kja(a,b){var c=0,d=0;d=Xa-32|0;Xa=d;a:{b:{if(i[fb(a)>>2]-i[a+4>>2]>>2>>>0>=b>>>0){Eia(a,b);break b}c=fb(a);c=uw(d+8|0,ge(a,qb(a)+b|0),qb(a),c);i[114610]=0;D(1598,c|0,b|0);b=i[114610];i[114610]=0;if((b|0)==1){break a}i[114610]=0;D(1597,a|0,c|0);a=i[114610];i[114610]=0;if((a|0)==1){break a}rm(c)}Xa=d+32|0;return}a=B()|0;A()|0;rm(c);E(a|0);x()}function Bha(a,b){var c=0,d=0;d=Xa-32|0;Xa=d;a:{b:{if(i[fb(a)>>2]-i[a+4>>2]>>2>>>0>=b>>>0){nha(a,b);break b}c=fb(a);c=LH(d+8|0,ge(a,qb(a)+b|0),qb(a),c);i[114610]=0;D(1649,c|0,b|0);b=i[114610];i[114610]=0;if((b|0)==1){break a}i[114610]=0;D(1646,a|0,c|0);a=i[114610];i[114610]=0;if((a|0)==1){break a}tr(c)}Xa=d+32|0;return}a=B()|0;A()|0;tr(c);E(a|0);x()}function uFa(a,b){var c=0,d=0;d=Xa-32|0;Xa=d;a:{b:{if(i[fb(a)>>2]-i[a+4>>2]>>2>>>0>=b>>>0){tFa(a,b);break b}c=fb(a);c=sFa(d+8|0,ge(a,qb(a)+b|0),qb(a),c);i[114610]=0;D(741,c|0,b|0);b=i[114610];i[114610]=0;if((b|0)==1){break a}i[114610]=0;D(742,a|0,c|0);a=i[114610];i[114610]=0;if((a|0)==1){break a}XP(c)}Xa=d+32|0;return}a=B()|0;A()|0;XP(c);E(a|0);x()}function eoa(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;c=Xa-192|0;Xa=c;Tb(c+144|0,b,44);d=i[b+44>>2];if(d){Tb(c+44|0,b,44);g=c,h=g7(c+44|0),i[g+96>>2]=h;i[c+100>>2]=_a;b=i[c+100>>2];f=i[c+96>>2];e=Yqa(xd(+(d>>>0)*.054945054945054944));d=f+e|0;b=_a+b|0;S6(c+96|0,GF(c+88|0,d,d>>>0<e>>>0?b+1|0:b));Tb(c+144|0,c+96|0,44)}b=a;a=Tb(c,c+144|0,44);A6(b,a);Xa=a+192|0}function _Ca(a,b){var c=0,d=0;d=Xa-32|0;Xa=d;a:{b:{if(i[fb(a)>>2]-i[a+4>>2]>>2>>>0>=b>>>0){ZCa(a,b);break b}c=fb(a);c=YCa(d+8|0,ge(a,qb(a)+b|0),qb(a),c);i[114610]=0;D(823,c|0,b|0);b=i[114610];i[114610]=0;if((b|0)==1){break a}i[114610]=0;D(824,a|0,c|0);a=i[114610];i[114610]=0;if((a|0)==1){break a}dP(c)}Xa=d+32|0;return}a=B()|0;A()|0;dP(c);E(a|0);x()}function QCa(a,b){var c=0,d=0;d=Xa-32|0;Xa=d;a:{b:{if(i[fb(a)>>2]-i[a+4>>2]>>1>>>0>=b>>>0){PCa(a,b);break b}c=fb(a);c=OCa(d+8|0,qi(a,Wb(a)+b|0),Wb(a),c);i[114610]=0;D(830,c|0,b|0);b=i[114610];i[114610]=0;if((b|0)==1){break a}i[114610]=0;D(831,a|0,c|0);a=i[114610];i[114610]=0;if((a|0)==1){break a}_O(c)}Xa=d+32|0;return}a=B()|0;A()|0;_O(c);E(a|0);x()}function GLa(a,b){var c=0,d=0;d=Xa-32|0;Xa=d;a:{b:{if(i[fb(a)>>2]-i[a+4>>2]>>1>>>0>=b>>>0){FLa(a,b);break b}c=fb(a);c=ELa(d+8|0,qi(a,Wb(a)+b|0),Wb(a),c);i[114610]=0;D(423,c|0,b|0);b=i[114610];i[114610]=0;if((b|0)==1){break a}i[114610]=0;D(424,a|0,c|0);a=i[114610];i[114610]=0;if((a|0)==1){break a}AS(c)}Xa=d+32|0;return}a=B()|0;A()|0;AS(c);E(a|0);x()}function DX(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=Xa+ -64|0;Xa=d;e=1;a:{if(Nf(a,b,0)){break a}e=0;if(!b){break a}b=NB(b,71928);e=0;if(!b){break a}i[d+20>>2]=-1;i[d+16>>2]=a;i[d+12>>2]=0;i[d+8>>2]=b;yb(d+24|0,0,39);i[d+56>>2]=1;$a[i[i[b>>2]+28>>2]](b,d+8|0,i[c>>2],1);a=i[d+32>>2];if((a|0)==1){i[c>>2]=i[d+24>>2]}e=(a|0)==1}a=e;Xa=d- -64|0;return a|0}function Bta(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=Xa-32|0;Xa=d;i[d+16>>2]=b;e=d,f=sy(a,b,c),i[e+24>>2]=f;a:{if(!pb(d+24|0,d+16|0)){break a}i[d+8>>2]=i[d+24>>2];if(!pb(he(d+8|0),d+16|0)){break a}while(1){if(k[i[d+8>>2]>>1]!=k[c>>1]){h[i[d+24>>2]>>1]=k[i[d+8>>2]>>1];he(d+24|0)}if(pb(he(d+8|0),d+16|0)){continue}break}}Xa=d+32|0;return i[d+24>>2]}function Kza(a,b){var c=0,d=0;d=Xa-32|0;Xa=d;a:{b:{if(i[fb(a)>>2]-i[a+4>>2]>>2>>>0>=b>>>0){SN(a,b);break b}c=fb(a);c=Jza(d+8|0,ge(a,qb(a)+b|0),qb(a),c);i[114610]=0;D(951,c|0,b|0);b=i[114610];i[114610]=0;if((b|0)==1){break a}i[114610]=0;D(952,a|0,c|0);a=i[114610];i[114610]=0;if((a|0)==1){break a}LN(c)}Xa=d+32|0;return}a=B()|0;A()|0;LN(c);E(a|0);x()}function Dga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=Xa-16|0;Xa=d;a:{if(!(j[c+1|0]&4)){break a}c=i[c+4>>2];g=d,h=ld(b),i[g+8>>2]=h;b:{if(!lb(b)){break b}if(j[Sb(b,0)|0]==43){Tf(d+8|0);c=c+1|0;break b}if(j[Sb(b,0)|0]!=45){break b}Tf(d+8|0);c=c+1|0}if(lb(b)>>>0>=c>>>0){break a}e=Ad(d,d+8|0);f=lb(b);Sv(b,i[e>>2],c-f|0,48)}Lc(a,b);Xa=d+16|0}function D_(a,b){var c=0,d=0;d=Xa-32|0;Xa=d;a:{b:{if(i[hq(a)>>2]-i[a+4>>2]>>2>>>0>=b>>>0){JC(a,b);break b}c=Ck(a);c=JY(d+8|0,KY(a,qb(a)+b|0),qb(a),c);i[114610]=0;D(2562,c|0,b|0);b=i[114610];i[114610]=0;if((b|0)==1){break a}i[114610]=0;D(2563,a|0,c|0);a=i[114610];i[114610]=0;if((a|0)==1){break a}eC(c)}Xa=d+32|0;return}a=B()|0;A()|0;eC(c);E(a|0);x()}function wAa(a){var b=0;b=Xa-16|0;Xa=b;g[a|0]=0;g[a+1|0]=0;g[a+2|0]=0;g[a+3|0]=0;g[a+4|0]=0;g[a+5|0]=0;g[a+6|0]=0;g[a+7|0]=0;g[a+24|0]=0;g[a+25|0]=0;g[a+16|0]=0;g[a+17|0]=0;g[a+18|0]=0;g[a+19|0]=0;g[a+20|0]=0;g[a+21|0]=0;g[a+22|0]=0;g[a+23|0]=0;g[a+8|0]=0;g[a+9|0]=0;g[a+10|0]=0;g[a+11|0]=0;g[a+12|0]=0;g[a+13|0]=0;g[a+14|0]=0;g[a+15|0]=0;Xa=b+16|0}function tEa(a,b){var c=0,d=0;d=Xa-32|0;Xa=d;a:{b:{if(i[fb(a)>>2]-i[a+4>>2]>>4>>>0>=b>>>0){RS(a,b);break b}c=fb(a);c=TQ(d+8|0,bq(a,Wc(a)+b|0),Wc(a),c);i[114610]=0;D(764,c|0,b|0);b=i[114610];i[114610]=0;if((b|0)==1){break a}i[114610]=0;D(612,a|0,c|0);a=i[114610];i[114610]=0;if((a|0)==1){break a}Vs(c)}Xa=d+32|0;return}a=B()|0;A()|0;Vs(c);E(a|0);x()}function sl(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=Xa-16|0;Xa=d;g[d+15|0]=b;a:{b:{c:{d:{if(oe(a)){c=Jj(a)+ -1|0;e=i[a+4>>2];if((c|0)==(e|0)){break d}break b}e=10;c=10;b=j[a+11|0];if((b|0)!=10){break c}}rl(a,c,1,c,c,0,0);b=e;if(oe(a)){break b}}c=a;Te(a,b+1|0);break a}c=i[a>>2];ce(a,e+1|0);b=e}a=b+c|0;Rd(a,d+15|0);g[d+14|0]=0;Rd(a+1|0,d+14|0);Xa=d+16|0}function qqa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=Xa-16|0;Xa=d;i[d+12>>2]=c>>>2;i[d+8>>2]=i[a>>2];e=i[rb(d+12|0,d+8|0)>>2];b=jb(b);if(e){a=i[a+20>>2];c=e;while(1){f=a,g=(jb(j[b|0])|jb(j[b+1|0])<<8)^32768,h[f>>1]=g;f=a,g=(jb(j[b+2|0])|jb(j[b+3|0])<<8)^32768,h[f+2>>1]=g;a=a+4|0;b=b+4|0;c=c+ -1|0;if(c){continue}break}}Xa=d+16|0;return e<<2}function nqa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=Xa-16|0;Xa=d;i[d+12>>2]=c>>>2;i[d+8>>2]=i[a>>2];e=i[rb(d+12|0,d+8|0)>>2];b=jb(b);if(e){a=i[a+20>>2];c=e;while(1){f=a,g=(jb(j[b+1|0])|jb(j[b|0])<<8)^32768,h[f>>1]=g;f=a,g=(jb(j[b+3|0])|jb(j[b+2|0])<<8)^32768,h[f+2>>1]=g;a=a+4|0;b=b+4|0;c=c+ -1|0;if(c){continue}break}}Xa=d+16|0;return e<<2}function kY(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=Xa-16|0;Xa=f;i[f+8>>2]=e;i[f+12>>2]=c;c=lb(a);if(!((e|0)==-1|c>>>0<b>>>0)){i[f>>2]=c-b;g=f,h=i[rb(f+12|0,f)>>2],i[g+4>>2]=h;b=xm(xb(a)+b|0,d,i[rb(f+4|0,f+8|0)>>2]);a:{if(b){break a}b=-1;a=i[f+4>>2];c=i[f+8>>2];if(a>>>0<c>>>0){break a}b=a>>>0>c>>>0}Xa=f+16|0;return b|0}Ml();x()}function kMa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=Xa-48|0;Xa=d;a:{b:{e=$M(b,c);if((e|0)!=-1){f=d,g=ld(b),i[f+16>>2]=g;f=d,g=Ze(d+16|0,e),i[f+24>>2]=g;f=d,g=Ze(d+24|0,1),i[f+32>>2]=g;c=Ad(d+40|0,d+32|0);f=d,g=Ye(b),i[f>>2]=g;e=Ad(d+8|0,d);yx(b,i[c>>2],i[e>>2]);break b}if(!lb(b)){break b}if(XK(b,c)){break b}Oc(a);break a}Lc(a,b)}Xa=d+48|0}function cMa(a,b){var c=0,d=0;d=Xa-32|0;Xa=d;a:{b:{if(i[fb(a)>>2]-i[a+4>>2]>>1>>>0>=b>>>0){FS(a,b);break b}c=fb(a);c=tt(d+8|0,qi(a,Wb(a)+b|0),Wb(a),c);i[114610]=0;D(410,c|0,b|0);b=i[114610];i[114610]=0;if((b|0)==1){break a}i[114610]=0;D(380,a|0,c|0);a=i[114610];i[114610]=0;if((a|0)==1){break a}kk(c)}Xa=d+32|0;return}a=B()|0;A()|0;kk(c);E(a|0);x()}function Qka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=Xa-48|0;Xa=d;a:{b:{e=$M(b,c);if((e|0)!=-1){f=d,g=ld(b),i[f+16>>2]=g;f=d,g=Ze(d+16|0,e),i[f+24>>2]=g;f=d,g=Ze(d+24|0,1),i[f+32>>2]=g;c=Ad(d+40|0,d+32|0);f=d,g=Ye(b),i[f>>2]=g;e=Ad(d+8|0,d);yx(b,i[c>>2],i[e>>2]);break b}if(!lb(b)){break b}if(XK(b,c)){break b}Ab(a);break a}Lc(a,b)}Xa=d+48|0}function Qha(a,b){a=a|0;b=b|0;var c=0;a:{b:{if((rc(i[a+20>>2]+4|0)|0)!=8){break b}c=i[i[a+20>>2]+4>>2];if((j[c|0]|j[c+1|0]<<8|(j[c+2|0]<<16|j[c+3|0]<<24))!=1869112133){break b}b=i[i[a+20>>2]+4>>2];c=j[b|0]|j[b+1|0]<<8|(j[b+2|0]<<16|j[b+3|0]<<24);b=j[b+4|0]|j[b+5|0]<<8|(j[b+6|0]<<16|j[b+7|0]<<24);i[a+4260>>2]=c;i[a+4264>>2]=b;break a}vH(a,b)}vr(a)}function $qa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=Xa-16|0;Xa=e;a:{c=tl(e,a+8|0,xx(b,c));if(i[c>>2]!=i[c+4>>2]){while(1){d=i[a+16>>2];f=i[c>>2];i[114610]=0;G(1250,d|0,f|0,b|0);d=i[114610];i[114610]=0;if((d|0)==1){break a}d=i[c>>2]+2|0;i[c>>2]=d;b=b+2|0;if((d|0)!=i[c+4>>2]){continue}break}}ac(c);Xa=e+16|0;return}a=B()|0;A()|0;ac(c);E(a|0);x()}function zo(a,b,c,d){a:{if(i[a+480180>>2]==4){d=j[b+830|0];if(c){g[b+830|0]=d&240|c;break a}c=d&15;break a}if(d){if(c){g[b+854|0]=c;break a}c=j[b+854|0];break a}if(c){g[b+830|0]=c;break a}c=j[b+830|0]}b:{if(!(g[b+872|0]&1)){break b}c=i[b+688>>2]-((c&255)<<2)|0;i[b+688>>2]=(c|0)>0?c:0;if(!(i[a+480180>>2]&1)){break b}i[b+88>>2]=i[b+88>>2]|2097152}}function uY(a,b){var c=0,d=0;d=Xa-32|0;Xa=d;a:{b:{if(i[fb(a)>>2]-i[a+4>>2]>>4>>>0>=b>>>0){TW(a,b);break b}c=fb(a);c=SW(d+8|0,bq(a,Wc(a)+b|0),Wc(a),c);i[114610]=0;D(211,c|0,b|0);b=i[114610];i[114610]=0;if((b|0)==1){break a}i[114610]=0;D(212,a|0,c|0);a=i[114610];i[114610]=0;if((a|0)==1){break a}HB(c)}Xa=d+32|0;return}a=B()|0;A()|0;HB(c);E(a|0);x()}function RT(a,b){var c=0,d=0;d=Xa-32|0;Xa=d;a:{b:{if(i[fb(a)>>2]-i[a+4>>2]>>2>>>0>=b>>>0){ET(a,b);break b}c=fb(a);c=sn(d+8|0,ge(a,qb(a)+b|0),qb(a),c);i[114610]=0;D(367,c|0,b|0);b=i[114610];i[114610]=0;if((b|0)==1){break a}i[114610]=0;D(368,a|0,c|0);a=i[114610];i[114610]=0;if((a|0)==1){break a}uh(c)}Xa=d+32|0;return}a=B()|0;A()|0;uh(c);E(a|0);x()}function je(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;a:{if(!lb(a)|(c-b|0)<5){break a}On(b,c);e=c+ -4|0;c=xb(a);f=c+lb(a)|0;while(1){b:{a=g[c|0];if(b>>>0>=e>>>0){break b}if((a|0)<1|(a|0)>=127|i[b>>2]==g[c|0]){c=(f-c|0)>1?c+1|0:c;b=b+4|0;continue}else{i[d>>2]=4;return}}break}if((a|0)<1|(a|0)>=127|i[e>>2]+ -1>>>0<g[c|0]>>>0){break a}i[d>>2]=4}}function gca(a,b){a=a|0;b=b|0;var c=0;if(l[a+44>>2]<l[a+24>>2]){i[a+44>>2]=i[a+24>>2]}a:{if(l[a+8>>2]>=l[a+12>>2]){break a}if(ae(b,-1)){pm(a,i[a+8>>2],i[a+12>>2]+ -1|0,i[a+44>>2]);return er(b)|0}if(!(j[a+48|0]&16)){if(!ae(om(b),g[i[a+12>>2]+ -1|0])){break a}}pm(a,i[a+8>>2],i[a+12>>2]+ -1|0,i[a+44>>2]);c=om(b);g[i[a+12>>2]]=c;return b|0}return-1}function YB(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=Xa-16|0;Xa=d;i[d+12>>2]=b;a:{b:{c:{d:{if(oe(a)){c=Jj(a)+ -1|0;e=i[a+4>>2];if((c|0)==(e|0)){break d}break b}e=1;c=1;b=j[a+11|0];if((b|0)!=1){break c}}ZB(a,c,1,c,c);b=e;if(oe(a)){break b}}c=a;Te(a,b+1|0);break a}c=i[a>>2];ce(a,e+1|0);b=e}a=(b<<2)+c|0;ye(a,d+12|0);i[d+8>>2]=0;ye(a+4|0,d+8|0);Xa=d+16|0}function VEa(a,b){var c=0,d=0,e=0,f=0;c=Xa-16|0;Xa=c;a:{if(!b){break a}if(!wb(a,b)){break a}while(1){g[c+11|0]=0;b:{if(d>>>0<b>>>0){Bf(a,c+11|0);e=g[c+11|0];f=e>>>31|0;break b}e=0-f|0;g[c+11|0]=e}g[(c+12|0)+d|0]=e;d=d+1|0;if((d|0)!=4){continue}break}i[c+4>>2]=i[c+12>>2];a=c+4|0;d=j[a|0]|j[a+1|0]<<8|(j[a+2|0]<<16|j[a+3|0]<<24)}Xa=c+16|0;return d}function soa(a,b,c,d){var e=0,f=0,h=0,j=0,k=0;e=Xa-16|0;Xa=e;b=Pb(b);a=roa(a,Yb(20,4),Zj(e+8|0,b));f=i[a>>2];i[114610]=0;f=F(1380,f+14|0)|0;h=i[114610];i[114610]=0;a:{if((h|0)==1){break a}i[114610]=0;T(1383,b|0,f|0,20469,c|0,d|0);b=i[114610];i[114610]=0;if((b|0)==1){break a}j=Pb(a),k=1,g[j+4|0]=k;Xa=e+16|0;return}b=B()|0;A()|0;_J(a);E(b|0);x()}function bO(a){var b=0,c=0,d=0,e=0,f=0;b=a+28|0;e=j[b|0]|j[b+1|0]<<8;b=XMa(j[a+30|0],0,37,0);c=_a;d=b;b=a+24|0;b=XMa(j[b|0]|j[b+1|0]<<8,0,192,0);d=d+b|0;c=_a+c|0;c=d>>>0<b>>>0?c+1|0:c;b=c;f=e;e=d;a=j[a+26|0];c=a>>>26|0;d=a<<6;e=e+d|0;a=b+c|0;a=e>>>0<d>>>0?a+1|0:a;b=e;c=f+b|0;if(c>>>0<b>>>0){a=a+1|0}b=c+192|0;if(b>>>0<192){a=a+1|0}_a=a;return b}function Q5(a,b,c,d,e){var f=0,g=0,h=0,i=p(0),k=0,l=0,n=0;if((d|0)>=1){while(1){f=j[b|0];g=0;a:{if(!f){break a}g=19>>>j[c+h|0]&3|4}b=b+1|0;n=o(f,3)+ -6|0;f=4;i=p(0);while(1){if(f&g){k=zd(a,6);l=(k|0)/3|0;i=p(m[((k-o(l,3)|0)+n<<2)+50176>>2]*p(2097152>>>l|0))}m[e>>2]=i;e=e+4|0;f=f>>1;if(f){continue}break}h=h+1|0;if((h|0)!=(d|0)){continue}break}}}function Lba(a,b,c,d){var e=0,f=0,h=0,j=0,k=0;e=Xa-16|0;Xa=e;b=Pb(b);a=Sqa(a,Yb(40,4),Zj(e+8|0,b));f=i[a>>2];i[114610]=0;f=F(1257,f+16|0)|0;h=i[114610];i[114610]=0;a:{if((h|0)==1){break a}i[114610]=0;T(2108,b|0,f|0,38079,c|0,d|0);b=i[114610];i[114610]=0;if((b|0)==1){break a}j=Pb(a),k=1,g[j+4|0]=k;Xa=e+16|0;return}b=B()|0;A()|0;aL(a);E(b|0);x()}function IMa(a,b){if(!DMa(a,b)){a=Xa-16|0;Xa=a;g[b|0]=0;g[b+1|0]=0;g[b+2|0]=0;g[b+3|0]=0;g[b+4|0]=0;g[b+5|0]=0;g[b+6|0]=0;g[b+7|0]=0;g[b+24|0]=0;g[b+16|0]=0;g[b+17|0]=0;g[b+18|0]=0;g[b+19|0]=0;g[b+20|0]=0;g[b+21|0]=0;g[b+22|0]=0;g[b+23|0]=0;g[b+8|0]=0;g[b+9|0]=0;g[b+10|0]=0;g[b+11|0]=0;g[b+12|0]=0;g[b+13|0]=0;g[b+14|0]=0;g[b+15|0]=0;Xa=a+16|0}}function pqa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=Xa-16|0;Xa=e;i[e+12>>2]=c>>>2;i[e+8>>2]=i[a>>2];f=i[rb(e+12|0,e+8|0)>>2];b=jb(b);if(f){a=i[a+20>>2];c=f;g=d;while(1){g=(jb(j[b|0])|jb(j[b+1|0])<<8)+g|0;h[a>>1]=g;d=(jb(j[b+2|0])|jb(j[b+3|0])<<8)+d|0;h[a+2>>1]=d;a=a+4|0;b=b+4|0;c=c+ -1|0;if(c){continue}break}}Xa=e+16|0;return f<<2}function pY(a,b){var c=0,d=0;d=Xa-32|0;Xa=d;a:{b:{if(i[fb(a)>>2]-i[a+4>>2]>>>0>=b>>>0){NW(a,b);break b}c=fb(a);c=Iu(d+8|0,pl(a,rc(a)+b|0),rc(a),c);i[114610]=0;D(213,c|0,b|0);b=i[114610];i[114610]=0;if((b|0)==1){break a}i[114610]=0;D(209,a|0,c|0);a=i[114610];i[114610]=0;if((a|0)==1){break a}Ql(c)}Xa=d+32|0;return}a=B()|0;A()|0;Ql(c);E(a|0);x()}function mqa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=Xa-16|0;Xa=e;i[e+12>>2]=c>>>2;i[e+8>>2]=i[a>>2];f=i[rb(e+12|0,e+8|0)>>2];b=jb(b);if(f){a=i[a+20>>2];c=f;g=d;while(1){g=(jb(j[b+1|0])|jb(j[b|0])<<8)+g|0;h[a>>1]=g;d=(jb(j[b+3|0])|jb(j[b+2|0])<<8)+d|0;h[a+2>>1]=d;a=a+4|0;b=b+4|0;c=c+ -1|0;if(c){continue}break}}Xa=e+16|0;return f<<2}function aJ(a,b){var c=0,d=0,e=0,f=0;if(b){bsa(a+327720|0);Mw(a+131112|0,9.6377,.97);Mw(a+196648|0,8.5,.5);Mw(a+262184|0,2.7625,.425)}c=a+368680|0;if(!(d=0,e=$I(c,a),f=b,f?d:e)){pla(a+24|0,n[a+8>>3],j[a+16|0]);b=i[a+20>>2];i[c+16>>2]=i[a+16>>2];i[c+20>>2]=b;b=i[a+12>>2];i[c+8>>2]=i[a+8>>2];i[c+12>>2]=b;b=i[a+4>>2];i[c>>2]=i[a>>2];i[c+4>>2]=b}}function XT(a,b){var c=0,d=0;d=Xa-32|0;Xa=d;a:{b:{if(i[fb(a)>>2]-i[a+4>>2]>>>0>=b>>>0){vA(a,b);break b}c=fb(a);c=wA(d+8|0,pl(a,rc(a)+b|0),rc(a),c);i[114610]=0;D(363,c|0,b|0);b=i[114610];i[114610]=0;if((b|0)==1){break a}i[114610]=0;D(364,a|0,c|0);a=i[114610];i[114610]=0;if((a|0)==1){break a}Fp(c)}Xa=d+32|0;return}a=B()|0;A()|0;Fp(c);E(a|0);x()}function Aia(a,b,c,d){var e=0,f=0,h=0,j=0,k=0;e=Xa-16|0;Xa=e;b=Pb(b);a=zia(a,Yb(32,4),Zj(e+8|0,b));f=i[a>>2];i[114610]=0;f=F(735,f+16|0)|0;h=i[114610];i[114610]=0;a:{if((h|0)==1){break a}i[114610]=0;T(1622,b|0,f|0,32514,c|0,d|0);b=i[114610];i[114610]=0;if((b|0)==1){break a}j=Pb(a),k=1,g[j+4|0]=k;Xa=e+16|0;return}b=B()|0;A()|0;$H(a);E(b|0);x()}function _Ia(a,b){var c=0,d=0;d=Xa-32|0;Xa=d;a:{b:{if(i[fb(a)>>2]-i[a+4>>2]>>>0>=b>>>0){xR(a,b);break b}c=fb(a);c=oT(d+8|0,pl(a,rc(a)+b|0),rc(a),c);i[114610]=0;D(41,c|0,b|0);b=i[114610];i[114610]=0;if((b|0)==1){break a}i[114610]=0;D(40,a|0,c|0);a=i[114610];i[114610]=0;if((a|0)==1){break a}vt(c)}Xa=d+32|0;return}a=B()|0;A()|0;vt(c);E(a|0);x()}function LFa(a,b,c,d){var e=0,f=0,h=0,j=0,k=0;e=Xa-16|0;Xa=e;b=Pb(b);a=KFa(a,Yb(32,4),Zj(e+8|0,b));f=i[a>>2];i[114610]=0;f=F(731,f+16|0)|0;h=i[114610];i[114610]=0;a:{if((h|0)==1){break a}i[114610]=0;T(732,b|0,f|0,14646,c|0,d|0);b=i[114610];i[114610]=0;if((b|0)==1){break a}j=Pb(a),k=1,g[j+4|0]=k;Xa=e+16|0;return}b=B()|0;A()|0;fQ(a);E(b|0);x()}function JCa(a,b,c,d){var e=0,f=0,h=0,j=0,k=0;e=Xa-16|0;Xa=e;b=Pb(b);a=ICa(a,Yb(20,4),Zj(e+8|0,b));f=i[a>>2];i[114610]=0;f=F(827,f+14|0)|0;h=i[114610];i[114610]=0;a:{if((h|0)==1){break a}i[114610]=0;T(833,b|0,f|0,15161,c|0,d|0);b=i[114610];i[114610]=0;if((b|0)==1){break a}j=Pb(a),k=1,g[j+4|0]=k;Xa=e+16|0;return}b=B()|0;A()|0;ZO(a);E(b|0);x()}function koa(a,b,c,d){var e=0,f=0,h=0,j=0,k=0;e=Xa-16|0;Xa=e;b=Pb(b);a=joa(a,$J(1),Zj(e+8|0,b));f=i[a>>2];i[114610]=0;f=F(1385,f+16|0)|0;h=i[114610];i[114610]=0;a:{if((h|0)==1){break a}i[114610]=0;T(1387,b|0,f|0,20469,c|0,d|0);b=i[114610];i[114610]=0;if((b|0)==1){break a}j=Pb(a),k=1,g[j+4|0]=k;Xa=e+16|0;return}b=B()|0;A()|0;YJ(a);E(b|0);x()}function baa(a){var b=0,c=0;b=Xa-16|0;Xa=b;a:{b:{c:{if(a>>>0>=6){c=P(8)|0;i[114610]=0;b=C(85,b|0,39785)|0;a=i[114610];i[114610]=0;if((a|0)==1){break c}Ub(c,b);i[114610]=0;G(2009,c|0,83568,2017);a=i[114610];i[114610]=0;if((a|0)!=1){break a}a=B()|0;A()|0;eb(b);break b}Xa=b+16|0;return i[(a<<24>>24<<2)+40488>>2]}a=B()|0;A()|0;Q(c|0)}E(a|0)}x()}function uma(a,b){var c=0,d=0,e=0,f=0,g=0;c=Xa-16|0;Xa=c;a:{if(!Sw(a,b,1)){break a}e=i[b+656>>2];d=a+1074308|0;kb(c+8|0,d,31);b:{if(ib(c+8|0)){a=i[b+740>>2];if(a){break b}break a}a=i[b+740>>2]}kb(c+8|0,d,31);d=Po(e+68|0,a-ib(c+8|0)|0,64,64)+ -32|0;a=i[b+684>>2];f=b,g=Eb(((o(d,(a|0)>127?256-a|0:a)|0)/32|0)+a|0,0,256),i[f+684>>2]=g}Xa=c+16|0}function N5(a,b,c,d){var e=0,f=0,g=0,h=0,k=0;i[d+8>>2]=-1;i[d>>2]=-1;i[d+4>>2]=-1;if((c|0)>=1){while(1){h=b+e|0;f=j[h|0];a:{if(!f){f=0;break a}g=0;while(1){k=g<<2;if(!(m[k+a>>2]!=p(0)|m[(k|4)+a>>2]!=p(0))){g=g+2|0;if(g>>>0<f>>>0){continue}break a}break}i[((e>>>0)%3<<2)+d>>2]=e;f=j[h|0]}a=(f<<2)+a|0;e=e+1|0;if((e|0)!=(c|0)){continue}break}}}function ru(a,b,c,d){g[a+53|0]=1;a:{if(i[a+4>>2]!=(c|0)){break a}g[a+52|0]=1;c=i[a+16>>2];if(!c){i[a+36>>2]=1;i[a+24>>2]=d;i[a+16>>2]=b;if((d|0)!=1|i[a+48>>2]!=1){break a}g[a+54|0]=1;return}if((b|0)==(c|0)){c=i[a+24>>2];if((c|0)==2){i[a+24>>2]=d;c=d}if(i[a+48>>2]!=1|(c|0)!=1){break a}g[a+54|0]=1;return}g[a+54|0]=1;i[a+36>>2]=i[a+36>>2]+1}}function jEa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;if(j[a+40|0]){e=0}else{a:{b:{d=i[a+28>>2];if(d){if(!c){break a}d=$a[d|0](i[a+24>>2],b,c)|0;if(!d){break b}while(1){e=d+e|0;if(e>>>0<d>>>0){f=f+1|0}c=c-d|0;if(!c){break a}b=b+d|0;d=$a[i[a+28>>2]](i[a+24>>2],b,c)|0;if(d){continue}break}break b}g[a+40|0]=1;return 0}g[a+40|0]=1}}return e|0}function hz(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,l=0,m=0,n=0;f=Xa-16|0;Xa=f;i[f+12>>2]=c;kc(f+12|0,256);kc(f+12|0,65535);l=k[f+12>>1];Zf(a,l);if(l){c=0;while(1){g=j[b+c|0];a:{if((g|0)==(d|0)){g=65535;break a}if((e|0)!=(g|0)){break a}g=65534}m=lk(a,c),n=g,h[m>>1]=n;c=c+1|0;if((l|0)!=(c|0)){continue}break}}Xa=f+16|0;return 1}function rl(a,b,c,d,e,f,g){var h=0,j=0,k=0;h=Xa-16|0;Xa=h;if(-17-b>>>0>=c>>>0){j=xb(a);a:{if(2147483623>b>>>0){i[h+8>>2]=b<<1;i[h+12>>2]=b+c;c=Dk(i[Jc(h+12|0,h+8|0)>>2]);break a}c=-18}k=c+1|0;c=Ii(k);if(e){jh(c,j,e)}d=(d-f|0)-e|0;if(d){jh((c+e|0)+g|0,(e+j|0)+f|0,d)}b=b+1|0;if((b|0)!=11){Uf(a,j,b)}gf(a,c);fg(a,k);Xa=h+16|0;return}gg();x()}function gpa(a,b){var c=0,d=0,e=0,f=0;d=Xa-32|0;Xa=d;e=fb(a);c=yoa(d+8|0,Bl(a,be(a)+1|0),be(a),e);f=i[c+8>>2];i[114610]=0;G(1371,e|0,f|0,b|0);b=i[114610];i[114610]=0;a:{if((b|0)==1){break a}i[c+8>>2]=i[c+8>>2]+32;i[114610]=0;D(1372,a|0,c|0);a=i[114610];i[114610]=0;if((a|0)==1){break a}aK(c);Xa=d+32|0;return}a=B()|0;A()|0;aK(c);E(a|0);x()}function Uy(a,b,c){var d=0,e=0,f=0,h=0,k=0,m=0;a:{if(j[a+20|0]){break a}b=(-1-b>>>0<c>>>0?-1-b|0:c)+b|0;if(b>>>0<=l[a+16>>2]){break a}b=$y(b,4096);tQ(a,b-i[a+16>>2]|0);d=a,e=(h=a,k=dc(a+4|0,i[a+16>>2]),m=b-i[a+16>>2]|0,f=i[i[a>>2]+48>>2],$a[f](h|0,k|0,m|0)|0)+i[a+16>>2]|0,i[d+16>>2]=e;if(!($a[i[i[a>>2]+44>>2]](a)|0)){break a}g[a+20|0]=1}}function Hka(a,b){var c=0,d=0,e=0,f=0;d=Xa-32|0;Xa=d;e=fb(a);c=Gka(d+8|0,ek(a,nd(a)+1|0),nd(a),e);f=i[c+8>>2];i[114610]=0;G(1561,e|0,f|0,b|0);b=i[114610];i[114610]=0;a:{if((b|0)==1){break a}i[c+8>>2]=i[c+8>>2]+24;i[114610]=0;D(1562,a|0,c|0);a=i[114610];i[114610]=0;if((a|0)==1){break a}LI(c);Xa=d+32|0;return}a=B()|0;A()|0;LI(c);E(a|0);x()}function zna(a,b){var c=0,d=0,e=0,f=0;d=Xa-32|0;Xa=d;e=fb(a);c=Jma(d+8|0,ge(a,qb(a)+1|0),qb(a),e);f=i[c+8>>2];i[114610]=0;G(1421,e|0,f|0,b|0);b=i[114610];i[114610]=0;a:{if((b|0)==1){break a}i[c+8>>2]=i[c+8>>2]+4;i[114610]=0;D(1422,a|0,c|0);a=i[114610];i[114610]=0;if((a|0)==1){break a}tJ(c);Xa=d+32|0;return}a=B()|0;A()|0;tJ(c);E(a|0);x()}function lta(a,b){var c=0,d=0,e=0,f=0;d=Xa-32|0;Xa=d;e=fb(a);c=TL(d+8|0,Bl(a,be(a)+1|0),be(a),e);f=i[c+8>>2];i[114610]=0;G(1180,e|0,f|0,b|0);b=i[114610];i[114610]=0;a:{if((b|0)==1){break a}i[c+8>>2]=i[c+8>>2]+32;i[114610]=0;D(1181,a|0,c|0);a=i[114610];i[114610]=0;if((a|0)==1){break a}cs(c);Xa=d+32|0;return}a=B()|0;A()|0;cs(c);E(a|0);x()}function kza(a,b){var c=0,d=0,e=0,f=0;d=Xa-32|0;Xa=d;e=fb(a);c=Qya(d+8|0,Rya(a,Tj(a)+1|0),Tj(a),e);f=i[c+8>>2];i[114610]=0;G(979,e|0,f|0,b|0);b=i[114610];i[114610]=0;a:{if((b|0)==1){break a}i[c+8>>2]=i[c+8>>2]+56;i[114610]=0;D(980,a|0,c|0);a=i[114610];i[114610]=0;if((a|0)==1){break a}yN(c);Xa=d+32|0;return}a=B()|0;A()|0;yN(c);E(a|0);x()}function dia(a,b){var c=0,d=0,e=0,f=0;d=Xa-32|0;Xa=d;e=fb(a);c=cia(d+8|0,ge(a,qb(a)+1|0),qb(a),e);f=i[c+8>>2];i[114610]=0;G(1635,e|0,f|0,b|0);b=i[114610];i[114610]=0;a:{if((b|0)==1){break a}i[c+8>>2]=i[c+8>>2]+4;i[114610]=0;D(1636,a|0,c|0);a=i[114610];i[114610]=0;if((a|0)==1){break a}WH(c);Xa=d+32|0;return}a=B()|0;A()|0;WH(c);E(a|0);x()}function cma(a,b){var c=0,d=0,e=0,f=0;d=Xa-32|0;Xa=d;e=fb(a);c=Vla(d+8|0,ge(a,qb(a)+1|0),qb(a),e);f=i[c+8>>2];i[114610]=0;G(1518,e|0,f|0,b|0);b=i[114610];i[114610]=0;a:{if((b|0)==1){break a}i[c+8>>2]=i[c+8>>2]+4;i[114610]=0;D(1519,a|0,c|0);a=i[114610];i[114610]=0;if((a|0)==1){break a}ZI(c);Xa=d+32|0;return}a=B()|0;A()|0;ZI(c);E(a|0);x()}function cAa(a,b){a=a|0;b=b|0;var c=0,d=0;c=Xa-48|0;Xa=c;a:{if(us(a)>>>0<b>>>0){fb(a);d=jy(c+32|0);i[114610]=0;D(937,d|0,b|0);b=i[114610];i[114610]=0;if((b|0)==1){break a}Wi(c+16|0,a);Uj(c+8|0,a);i[114610]=0;G(938,d|0,c+16|0,c+8|0);b=i[114610];i[114610]=0;if((b|0)==1){break a}iy(a,d);Td(d)}Xa=c+48|0;return}a=B()|0;A()|0;Td(d);E(a|0);x()}function Zaa(a,b){var c=0,d=0,e=0,f=0;d=Xa-32|0;Xa=d;e=fb(a);c=o8(d+8|0,bq(a,Wc(a)+1|0),Wc(a),e);f=i[c+8>>2];i[114610]=0;G(2127,e|0,f|0,b|0);b=i[114610];i[114610]=0;a:{if((b|0)==1){break a}i[c+8>>2]=i[c+8>>2]+16;i[114610]=0;D(2128,a|0,c|0);a=i[114610];i[114610]=0;if((a|0)==1){break a}RF(c);Xa=d+32|0;return}a=B()|0;A()|0;RF(c);E(a|0);x()}function Vqa(a,b){var c=0,d=0,e=0,f=0;d=Xa-32|0;Xa=d;e=fb(a);c=_K(d+8|0,$l(a,cc(a)+1|0),cc(a),e);f=i[c+8>>2];i[114610]=0;G(1255,e|0,f|0,b|0);b=i[114610];i[114610]=0;a:{if((b|0)==1){break a}i[c+8>>2]=i[c+8>>2]+12;i[114610]=0;D(1256,a|0,c|0);a=i[114610];i[114610]=0;if((a|0)==1){break a}Wr(c);Xa=d+32|0;return}a=B()|0;A()|0;Wr(c);E(a|0);x()}function Pwa(a,b){var c=0,d=0,e=0,f=0;d=Xa-32|0;Xa=d;e=fb(a);c=Gwa(d+8|0,ge(a,qb(a)+1|0),qb(a),e);f=i[c+8>>2];i[114610]=0;G(1058,e|0,f|0,b|0);b=i[114610];i[114610]=0;a:{if((b|0)==1){break a}i[c+8>>2]=i[c+8>>2]+4;i[114610]=0;D(1059,a|0,c|0);a=i[114610];i[114610]=0;if((a|0)==1){break a}KM(c);Xa=d+32|0;return}a=B()|0;A()|0;KM(c);E(a|0);x()}function Oaa(a,b){var c=0,d=0,e=0,f=0;d=Xa-32|0;Xa=d;e=fb(a);c=i8(d+8|0,ek(a,nd(a)+1|0),nd(a),e);f=i[c+8>>2];i[114610]=0;G(2132,e|0,f|0,b|0);b=i[114610];i[114610]=0;a:{if((b|0)==1){break a}i[c+8>>2]=i[c+8>>2]+24;i[114610]=0;D(2133,a|0,c|0);a=i[114610];i[114610]=0;if((a|0)==1){break a}PF(c);Xa=d+32|0;return}a=B()|0;A()|0;PF(c);E(a|0);x()}function Mxa(a,b){var c=0,d=0,e=0,f=0;d=Xa-32|0;Xa=d;e=fb(a);c=_x(d+8|0,$l(a,cc(a)+1|0),cc(a),e);f=i[c+8>>2];i[114610]=0;G(1022,e|0,f|0,b|0);b=i[114610];i[114610]=0;a:{if((b|0)==1){break a}i[c+8>>2]=i[c+8>>2]+12;i[114610]=0;D(1017,a|0,c|0);a=i[114610];i[114610]=0;if((a|0)==1){break a}ns(c);Xa=d+32|0;return}a=B()|0;A()|0;ns(c);E(a|0);x()}function CL(a){g[a|0]=0;g[a+1|0]=0;g[a+2|0]=0;g[a+3|0]=0;g[a+4|0]=0;g[a+5|0]=0;g[a+6|0]=0;g[a+7|0]=0;g[a+23|0]=0;g[a+24|0]=0;g[a+25|0]=0;g[a+26|0]=0;g[a+16|0]=0;g[a+17|0]=0;g[a+18|0]=0;g[a+19|0]=0;g[a+20|0]=0;g[a+21|0]=0;g[a+22|0]=0;g[a+23|0]=0;g[a+8|0]=0;g[a+9|0]=0;g[a+10|0]=0;g[a+11|0]=0;g[a+12|0]=0;g[a+13|0]=0;g[a+14|0]=0;g[a+15|0]=0}function mP(a,b,c,d){var e=0,f=0,g=0;e=Xa-16|0;Xa=e;i[e+12>>2]=a;f=+(o(a,d)>>>0)*2500;a:{if(c){break a}b:{if(!(!a|!b)){kc(e+12|0,10);a=j[i[e+12>>2]+15150|0];i[e+12>>2]=a;break b}if(a+ -1>>>0>9){break b}f=7338401.379310345/+(a>>>0);break a}f=+(a>>>0)*37878.78787878787}g=f;c:{if(f<4294967296&f>=0){a=~~g>>>0;break c}a=0}Xa=e+16|0;return a}function kga(a,b){var c=0,d=0,e=0,f=0;d=Xa-32|0;Xa=d;e=fb(a);c=sH(d+8|0,ge(a,qb(a)+1|0),qb(a),e);f=i[c+8>>2];i[114610]=0;G(1762,e|0,f|0,b|0);b=i[114610];i[114610]=0;a:{if((b|0)==1){break a}i[c+8>>2]=i[c+8>>2]+4;i[114610]=0;D(1759,a|0,c|0);a=i[114610];i[114610]=0;if((a|0)==1){break a}nr(c);Xa=d+32|0;return}a=B()|0;A()|0;nr(c);E(a|0);x()}function Xya(a,b){var c=0,d=0,e=0,f=0;d=Xa-32|0;Xa=d;e=fb(a);c=Wya(d+8|0,ek(a,nd(a)+1|0),nd(a),e);f=i[c+8>>2];i[114610]=0;G(988,e|0,f|0,b|0);b=i[114610];i[114610]=0;a:{if((b|0)==1){break a}i[c+8>>2]=i[c+8>>2]+24;i[114610]=0;D(989,a|0,c|0);a=i[114610];i[114610]=0;if((a|0)==1){break a}AN(c);Xa=d+32|0;return}a=B()|0;A()|0;AN(c);E(a|0);x()}function WDa(a,b){var c=0,d=0,e=0,f=0;d=Xa-32|0;Xa=d;e=fb(a);c=UDa(d+8|0,ek(a,nd(a)+1|0),nd(a),e);f=i[c+8>>2];i[114610]=0;G(772,e|0,f|0,b|0);b=i[114610];i[114610]=0;a:{if((b|0)==1){break a}i[c+8>>2]=i[c+8>>2]+24;i[114610]=0;D(773,a|0,c|0);a=i[114610];i[114610]=0;if((a|0)==1){break a}wP(c);Xa=d+32|0;return}a=B()|0;A()|0;wP(c);E(a|0);x()}function VHa(a,b){var c=0,d=0,e=0,f=0;d=Xa-32|0;Xa=d;e=fb(a);c=THa(d+8|0,ek(a,nd(a)+1|0),nd(a),e);f=i[c+8>>2];i[114610]=0;G(608,e|0,f|0,b|0);b=i[114610];i[114610]=0;a:{if((b|0)==1){break a}i[c+8>>2]=i[c+8>>2]+24;i[114610]=0;D(609,a|0,c|0);a=i[114610];i[114610]=0;if((a|0)==1){break a}UQ(c);Xa=d+32|0;return}a=B()|0;A()|0;UQ(c);E(a|0);x()}function SJa(a,b){var c=0,d=0,e=0,f=0;d=Xa-32|0;Xa=d;e=fb(a);c=PJa(d+8|0,ek(a,nd(a)+1|0),nd(a),e);f=i[c+8>>2];i[114610]=0;G(529,e|0,f|0,b|0);b=i[114610];i[114610]=0;a:{if((b|0)==1){break a}i[c+8>>2]=i[c+8>>2]+24;i[114610]=0;D(530,a|0,c|0);a=i[114610];i[114610]=0;if((a|0)==1){break a}ER(c);Xa=d+32|0;return}a=B()|0;A()|0;ER(c);E(a|0);x()}function Lia(a,b){var c=0,d=0,e=0,f=0;d=Xa-32|0;Xa=d;e=fb(a);c=uw(d+8|0,ge(a,qb(a)+1|0),qb(a),e);f=i[c+8>>2];i[114610]=0;G(1604,e|0,f|0,b|0);b=i[114610];i[114610]=0;a:{if((b|0)==1){break a}i[c+8>>2]=i[c+8>>2]+4;i[114610]=0;D(1597,a|0,c|0);a=i[114610];i[114610]=0;if((a|0)==1){break a}rm(c);Xa=d+32|0;return}a=B()|0;A()|0;rm(c);E(a|0);x()}function KD(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;b=Xa-16|0;Xa=b;e=b+16|0;a:{while(1){c=i[a+36>>2];f=$a[i[i[c>>2]+20>>2]](c,i[a+40>>2],b+8|0,e,b+4|0)|0;c=-1;d=i[b+4>>2]-(b+8|0)|0;if((d|0)!=(xi(b+8|0,1,d,i[a+32>>2])|0)){break a}b:{switch(f+ -1|0){case 1:break a;case 0:continue;default:break b}}break}c=Nq(i[a+32>>2])?-1:0}Xa=b+16|0;return c|0}function Hsa(a,b,c){var d=0,e=0,f=0,g=0;e=i[a>>2];d=i[a+4>>2];if((e|0)<=(d|0)){f=a+14|0;g=a+12|0;while(1){i[a+8>>2]=i[a+12>>2];Gsa(a,g,f);e=i[a>>2];d=i[a+4>>2]-e|0;i[a+4>>2]=d;if((e|0)<=(d|0)){continue}break}}f=b;b=e-d|0;h[f>>1]=(o(h[a+12>>1],d)+o(b,h[a+8>>1])|0)/(e|0);h[c>>1]=(o(h[a+14>>1],d)+o(b,h[a+10>>1])|0)/(e|0);i[a+4>>2]=d+49716}function EIa(a,b){var c=0,d=0,e=0,f=0;d=Xa-32|0;Xa=d;e=fb(a);c=CIa(d+8|0,ek(a,nd(a)+1|0),nd(a),e);f=i[c+8>>2];i[114610]=0;G(574,e|0,f|0,b|0);b=i[114610];i[114610]=0;a:{if((b|0)==1){break a}i[c+8>>2]=i[c+8>>2]+24;i[114610]=0;D(575,a|0,c|0);a=i[114610];i[114610]=0;if((a|0)==1){break a}bR(c);Xa=d+32|0;return}a=B()|0;A()|0;bR(c);E(a|0);x()}function tT(a,b){var c=0,d=0,e=0,f=0;c=Xa-16|0;Xa=c;a:{if(!b){break a}if(!wb(a,b)){break a}while(1){g[c+11|0]=0;f=(c+12|0)+d|0;b:{if(d>>>0<b>>>0){Bf(a,c+11|0);e=j[c+11|0];break b}g[c+11|0]=0;e=0}g[f|0]=e;d=d+1|0;if((d|0)!=4){continue}break}i[c+4>>2]=i[c+12>>2];a=c+4|0;d=j[a|0]|j[a+1|0]<<8|(j[a+2|0]<<16|j[a+3|0]<<24)}Xa=c+16|0;return d}function rx(a,b,c,d){var e=0,f=0;e=Xa-16|0;Xa=e;a:{if(i[b+480180>>2]&64671904){b=j[c+4|0];g[e|0]=0;i[a>>2]=j[(b&15)+20816|0];g[a+4|0]=j[e|0];break a}g[e+15|0]=0;f=j[c+4|0];if(!(j[c+3|0]!=4|i[b+480180>>2]!=4)){g[e+15|0]=1;f=f<<1}kb(e,b+1074308|0,66);if(!(!d|!ib(e))){i[e>>2]=0;ci(a,e,e+15|0);break a}i[e>>2]=f<<4;ci(a,e,e+15|0)}Xa=e+16|0}function pv(a,b,c,d){var e=0,f=0,g=0,h=0,j=0;f=Xa-240|0;Xa=f;i[f>>2]=a;g=1;a:{if((c|0)<2){break a}e=a;while(1){e=e+ -4|0;j=c+ -2|0;h=e-i[(j<<2)+d>>2]|0;if(($a[b|0](a,h)|0)>=0){if(($a[b|0](a,e)|0)>-1){break a}}a=($a[b|0](h,e)|0)>-1;e=a?h:e;i[(g<<2)+f>>2]=e;g=g+1|0;c=a?c+ -1|0:j;if((c|0)<2){break a}a=i[f>>2];continue}}yE(f,g);Xa=f+240|0}function eJa(a,b){var c=0,d=0,e=0,f=0;d=Xa-32|0;Xa=d;e=fb(a);c=eR(d+8|0,fR(a,ii(a)+1|0),ii(a),e);f=i[c+8>>2];i[114610]=0;G(560,e|0,f|0,b|0);b=i[114610];i[114610]=0;a:{if((b|0)==1){break a}i[c+8>>2]=i[c+8>>2]+48;i[114610]=0;D(561,a|0,c|0);a=i[114610];i[114610]=0;if((a|0)==1){break a}Ys(c);Xa=d+32|0;return}a=B()|0;A()|0;Ys(c);E(a|0);x()}function OFa(a,b){var c=0,d=0,e=0,f=0;d=Xa-32|0;Xa=d;e=fb(a);c=dE(d+8|0,$l(a,cc(a)+1|0),cc(a),e);f=i[c+8>>2];i[114610]=0;G(730,e|0,f|0,b|0);b=i[114610];i[114610]=0;a:{if((b|0)==1){break a}i[c+8>>2]=i[c+8>>2]+12;i[114610]=0;D(205,a|0,c|0);a=i[114610];i[114610]=0;if((a|0)==1){break a}Bq(c);Xa=d+32|0;return}a=B()|0;A()|0;Bq(c);E(a|0);x()}function Nsa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=Xa-16|0;Xa=e;a:{b=Msa(e,a+8|0,b);if(i[b>>2]!=i[b+4>>2]){while(1){d=i[a+16>>2];f=i[b>>2];i[114610]=0;G(1178,d|0,f|0,c|0);d=i[114610];i[114610]=0;if((d|0)==1){break a}d=i[b>>2]+32|0;i[b>>2]=d;if((d|0)!=i[b+4>>2]){continue}break}}ac(b);Xa=e+16|0;return}a=B()|0;A()|0;ac(b);E(a|0);x()}function LHa(a,b){var c=0,d=0,e=0,f=0;d=Xa-32|0;Xa=d;e=fb(a);c=TQ(d+8|0,bq(a,Wc(a)+1|0),Wc(a),e);f=i[c+8>>2];i[114610]=0;G(611,e|0,f|0,b|0);b=i[114610];i[114610]=0;a:{if((b|0)==1){break a}i[c+8>>2]=i[c+8>>2]+16;i[114610]=0;D(612,a|0,c|0);a=i[114610];i[114610]=0;if((a|0)==1){break a}Vs(c);Xa=d+32|0;return}a=B()|0;A()|0;Vs(c);E(a|0);x()}function Cja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=Xa-16|0;Xa=e;a:{b=Aja(e,a+8|0,b);if(i[b>>2]!=i[b+4>>2]){while(1){d=i[a+16>>2];f=i[b>>2];i[114610]=0;G(1581,d|0,f|0,c|0);d=i[114610];i[114610]=0;if((d|0)==1){break a}d=i[b>>2]+52|0;i[b>>2]=d;if((d|0)!=i[b+4>>2]){continue}break}}ac(b);Xa=e+16|0;return}a=B()|0;A()|0;ac(b);E(a|0);x()}function xU(a,b){var c=0,d=0,e=0,f=0;d=Xa-32|0;Xa=d;e=fb(a);c=bB(d+8|0,Bl(a,be(a)+1|0),be(a),e);f=i[c+8>>2];i[114610]=0;G(347,e|0,f|0,b|0);b=i[114610];i[114610]=0;a:{if((b|0)==1){break a}i[c+8>>2]=i[c+8>>2]+32;i[114610]=0;D(267,a|0,c|0);a=i[114610];i[114610]=0;if((a|0)==1){break a}Tp(c);Xa=d+32|0;return}a=B()|0;A()|0;Tp(c);E(a|0);x()}function k4(a,b){var c=0,d=0,e=0,f=0;d=Xa-32|0;Xa=d;e=fb(a);c=dE(d+8|0,$l(a,cc(a)+1|0),cc(a),e);f=i[c+8>>2];i[114610]=0;G(204,e|0,f|0,b|0);b=i[114610];i[114610]=0;a:{if((b|0)==1){break a}i[c+8>>2]=i[c+8>>2]+12;i[114610]=0;D(205,a|0,c|0);a=i[114610];i[114610]=0;if((a|0)==1){break a}Bq(c);Xa=d+32|0;return}a=B()|0;A()|0;Bq(c);E(a|0);x()}function _Da(a,b){var c=0,d=0,e=0,f=0;d=Xa-32|0;Xa=d;e=fb(a);c=sn(d+8|0,ge(a,qb(a)+1|0),qb(a),e);f=i[c+8>>2];i[114610]=0;G(770,e|0,f|0,b|0);b=i[114610];i[114610]=0;a:{if((b|0)==1){break a}i[c+8>>2]=i[c+8>>2]+4;i[114610]=0;D(368,a|0,c|0);a=i[114610];i[114610]=0;if((a|0)==1){break a}uh(c);Xa=d+32|0;return}a=B()|0;A()|0;uh(c);E(a|0);x()}function WKa(a,b){var c=0,d=0,e=0,f=0;d=Xa-32|0;Xa=d;e=fb(a);c=tt(d+8|0,qi(a,Wb(a)+1|0),Wb(a),e);f=i[c+8>>2];i[114610]=0;G(381,e|0,f|0,b|0);b=i[114610];i[114610]=0;a:{if((b|0)==1){break a}i[c+8>>2]=i[c+8>>2]+2;i[114610]=0;D(380,a|0,c|0);a=i[114610];i[114610]=0;if((a|0)==1){break a}kk(c);Xa=d+32|0;return}a=B()|0;A()|0;kk(c);E(a|0);x()}function KT(a,b,c){var d=0,e=0;c=LT(a,b,c);if(!c){return 0}if(!((j[a+550|0]|j[a+551|0]<<8|(j[a+552|0]<<16|j[a+553|0]<<24))!=1297110104?(j[a+550|0]|j[a+551|0]<<8|(j[a+552|0]<<16|j[a+553|0]<<24))!=1481920589:0)){c=b+236|0;b=0;while(1){e=j[(a+b|0)+554|0];d=Mc(c,b);h[d>>1]=k[d>>1]|e<<8;b=b+1|0;if((b|0)!=120){continue}break}c=674}return c}function H9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=$K(a);a:{if(!i[b+4>>2]){break a}c=i[b+4>>2];i[114610]=0;D(2180,a|0,c|0);c=i[114610];i[114610]=0;if((c|0)!=1){c=i[b>>2];e=i[b>>2];f=o(i[b+4>>2],12);b=i[b+4>>2];i[114610]=0;J(2181,a|0,c|0,e+f|0,b|0);b=i[114610];i[114610]=0;if((b|0)!=1){break a}}a=B()|0;A()|0;IA(d);E(a|0);x()}return a|0}function zU(a,b){var c=0,d=0,e=0,f=0;d=Xa-32|0;Xa=d;e=fb(a);c=JA(d+8|0,ge(a,qb(a)+1|0),qb(a),e);f=i[c+8>>2];i[114610]=0;G(346,e|0,f|0,b|0);b=i[114610];i[114610]=0;a:{if((b|0)==1){break a}i[c+8>>2]=i[c+8>>2]+4;i[114610]=0;D(343,a|0,c|0);a=i[114610];i[114610]=0;if((a|0)==1){break a}Np(c);Xa=d+32|0;return}a=B()|0;A()|0;Np(c);E(a|0);x()}function rK(a,b,c){var d=0,e=0,f=0,h=0,k=0;e=i[a+1074392>>2];d=j[b+833|0];a:{if(e){break a}g[b+833|0]=0;d=0}a=i[a+1074416>>2];g[b+872|0]=j[b+872|0]|8;h=b;k=(c|0)>-1?0-d|0:d;f=(+(e>>>0)+1)*+(c|0)/+(a>>>0);b:{if(q(f)<2147483648){d=~~f;break b}d=-2147483648}i[h+876>>2]=k+(d+i[b+876>>2]|0);a=(a|0)==(e+1|0)?c:d;g[b+833|0]=(a|0)<0?0-a|0:a}function qra(a,b){var c=0,d=0,e=0,f=0;d=Xa-32|0;Xa=d;e=fb(a);c=Zr(d+8|0,ge(a,qb(a)+1|0),qb(a),e);f=i[c+8>>2];i[114610]=0;G(411,e|0,f|0,b|0);b=i[114610];i[114610]=0;a:{if((b|0)==1){break a}i[c+8>>2]=i[c+8>>2]+4;i[114610]=0;D(96,a|0,c|0);a=i[114610];i[114610]=0;if((a|0)==1){break a}Nj(c);Xa=d+32|0;return}a=B()|0;A()|0;Nj(c);E(a|0);x()}function gFa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=Xa-16|0;Xa=e;a:{b=eFa(e,a+8|0,b);if(i[b>>2]!=i[b+4>>2]){while(1){d=i[a+16>>2];f=i[b>>2];i[114610]=0;G(709,d|0,f|0,c|0);d=i[114610];i[114610]=0;if((d|0)==1){break a}d=i[b>>2]+6|0;i[b>>2]=d;if((d|0)!=i[b+4>>2]){continue}break}}ac(b);Xa=e+16|0;return}a=B()|0;A()|0;ac(b);E(a|0);x()}function _$(a,b){var c=0,d=0,e=0,f=0;d=Xa-32|0;Xa=d;e=fb(a);c=Iu(d+8|0,pl(a,rc(a)+1|0),rc(a),e);f=i[c+8>>2];i[114610]=0;G(210,e|0,f|0,b|0);b=i[114610];i[114610]=0;a:{if((b|0)==1){break a}i[c+8>>2]=i[c+8>>2]+1;i[114610]=0;D(209,a|0,c|0);a=i[114610];i[114610]=0;if((a|0)==1){break a}Ql(c);Xa=d+32|0;return}a=B()|0;A()|0;Ql(c);E(a|0);x()}function ZB(a,b,c,d,e){var f=0,g=0,h=0;f=Xa-16|0;Xa=f;if(1073741807-b>>>0>=c>>>0){g=xb(a);a:{if(536870887>b>>>0){i[f+8>>2]=b<<1;i[f+12>>2]=b+c;c=Nl(i[Jc(f+12|0,f+8|0)>>2]);break a}c=1073741806}h=c+1|0;c=Ak(h);if(e){Gh(c,g,e)}d=d-e|0;if(d){e=e<<2;Gh(e+c|0,e+g|0,d)}b=b+1|0;if((b|0)!=2){Ln(g,b)}gf(a,c);fg(a,h);Xa=f+16|0;return}gg();x()}function Hia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=Xa-16|0;Xa=e;a:{b=th(e,a+8|0,b);if(i[b>>2]!=i[b+4>>2]){while(1){d=i[a+16>>2];f=i[b>>2];i[114610]=0;G(1604,d|0,f|0,c|0);d=i[114610];i[114610]=0;if((d|0)==1){break a}d=i[b>>2]+4|0;i[b>>2]=d;if((d|0)!=i[b+4>>2]){continue}break}}ac(b);Xa=e+16|0;return}a=B()|0;A()|0;ac(b);E(a|0);x()}function yva(a,b){var c=0,d=0,e=0,f=0;d=Xa-32|0;Xa=d;e=fb(a);c=Zr(d+8|0,ge(a,qb(a)+1|0),qb(a),e);f=i[c+8>>2];i[114610]=0;G(95,e|0,f|0,b|0);b=i[114610];i[114610]=0;a:{if((b|0)==1){break a}i[c+8>>2]=i[c+8>>2]+4;i[114610]=0;D(96,a|0,c|0);a=i[114610];i[114610]=0;if((a|0)==1){break a}Nj(c);Xa=d+32|0;return}a=B()|0;A()|0;Nj(c);E(a|0);x()}function yMa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=Xa-16|0;Xa=e;a:{b=tl(e,a+8|0,b);if(i[b>>2]!=i[b+4>>2]){while(1){d=i[a+16>>2];f=i[b>>2];i[114610]=0;G(381,d|0,f|0,c|0);d=i[114610];i[114610]=0;if((d|0)==1){break a}d=i[b>>2]+2|0;i[b>>2]=d;if((d|0)!=i[b+4>>2]){continue}break}}ac(b);Xa=e+16|0;return}a=B()|0;A()|0;ac(b);E(a|0);x()}function hFa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=Xa-16|0;Xa=e;a:{b=Es(e,a+8|0,b);if(i[b>>2]!=i[b+4>>2]){while(1){d=i[a+16>>2];f=i[b>>2];i[114610]=0;G(571,d|0,f|0,c|0);d=i[114610];i[114610]=0;if((d|0)==1){break a}d=i[b>>2]+1|0;i[b>>2]=d;if((d|0)!=i[b+4>>2]){continue}break}}ac(b);Xa=e+16|0;return}a=B()|0;A()|0;ac(b);E(a|0);x()}function _Ha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=Xa-32|0;Xa=e;i[e+28>>2]=d;a:{if(j[a+8|0]){d=a+12|0;g=e,h=rc(d)-c|0,i[g+24>>2]=h;a=i[rb(e+24|0,e+28|0)>>2];g=e,h=Jb(d),i[g+24>>2]=h;f=Ze(e+24|0,c);g=e,h=Jb(d),i[g+8>>2]=h;g=e,h=Ze(e+8|0,c),i[g+16>>2]=h;$i(f,Ze(e+16|0,a),b);break a}a=EHa(a,b,c,d)}Xa=e+32|0;return a|0}function CN(a){var b=0;a:{if((j[a|0]|j[a+1|0]<<8|(j[a+2|0]<<16|j[a+3|0]<<24))!=-28486832|j[a+63|0]!=26){break a}b=a+65|0;if(j[a- -64|0]&3|(j[a+66|0]|(j[b|0]!=1?j[b|0]!=16:0))){break a}b=a+78|0;if((j[b|0]|j[b+1|0]<<8)>>>0>127){break a}a=a+80|0;if((j[a|0]|j[a+1|0]<<8)>>>0>127){break a}a=Zya(b,a);return(j[a|0]|j[a+1|0]<<8)!=0}return 0}function BFa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=Xa-16|0;Xa=e;a:{b=th(e,a+8|0,b);if(i[b>>2]!=i[b+4>>2]){while(1){d=i[a+16>>2];f=i[b>>2];i[114610]=0;G(411,d|0,f|0,c|0);d=i[114610];i[114610]=0;if((d|0)==1){break a}d=i[b>>2]+4|0;i[b>>2]=d;if((d|0)!=i[b+4>>2]){continue}break}}ac(b);Xa=e+16|0;return}a=B()|0;A()|0;ac(b);E(a|0);x()}function rqa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=Xa-16|0;Xa=d;i[d+12>>2]=c>>>2;i[d+8>>2]=i[a>>2];e=i[rb(d+12|0,d+8|0)>>2];b=jb(b);if(e){a=i[a+20>>2];c=e;while(1){f=a,g=jb(j[b|0])|jb(j[b+1|0])<<8,h[f>>1]=g;f=a,g=jb(j[b+2|0])|jb(j[b+3|0])<<8,h[f+2>>1]=g;a=a+4|0;b=b+4|0;c=c+ -1|0;if(c){continue}break}}Xa=d+16|0;return e<<2}function oqa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=Xa-16|0;Xa=d;i[d+12>>2]=c>>>2;i[d+8>>2]=i[a>>2];e=i[rb(d+12|0,d+8|0)>>2];b=jb(b);if(e){a=i[a+20>>2];c=e;while(1){f=a,g=jb(j[b+1|0])|jb(j[b|0])<<8,h[f>>1]=g;f=a,g=jb(j[b+3|0])|jb(j[b+2|0])<<8,h[f+2>>1]=g;a=a+4|0;b=b+4|0;c=c+ -1|0;if(c){continue}break}}Xa=d+16|0;return e<<2}function ut(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=Xa-16|0;Xa=e;a:{b=vh(e,a,b);if(i[b+4>>2]!=i[b+8>>2]){while(1){d=fb(a);f=i[b+4>>2];i[114610]=0;G(381,d|0,f|0,c|0);d=i[114610];i[114610]=0;if((d|0)==1){break a}d=i[b+4>>2]+2|0;i[b+4>>2]=d;if((d|0)!=i[b+8>>2]){continue}break}}sb(b);Xa=e+16|0;return}a=B()|0;A()|0;sb(b);E(a|0);x()}function at(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=Xa-16|0;Xa=e;a:{b=ql(e,a,b);if(i[b+4>>2]!=i[b+8>>2]){while(1){d=fb(a);f=i[b+4>>2];i[114610]=0;G(571,d|0,f|0,c|0);d=i[114610];i[114610]=0;if((d|0)==1){break a}d=i[b+4>>2]+1|0;i[b+4>>2]=d;if((d|0)!=i[b+8>>2]){continue}break}}sb(b);Xa=e+16|0;return}a=B()|0;A()|0;sb(b);E(a|0);x()}function Yy(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=Xa-16|0;Xa=e;a:{b=jp(e,a,b);if(i[b+4>>2]!=i[b+8>>2]){while(1){d=fb(a);f=i[b+4>>2];i[114610]=0;G(709,d|0,f|0,c|0);d=i[114610];i[114610]=0;if((d|0)==1){break a}d=i[b+4>>2]+6|0;i[b+4>>2]=d;if((d|0)!=i[b+8>>2]){continue}break}}sb(b);Xa=e+16|0;return}a=B()|0;A()|0;sb(b);E(a|0);x()}function TS(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=Xa-16|0;Xa=e;a:{b=Yd(e,a,b);if(i[b+4>>2]!=i[b+8>>2]){while(1){d=fb(a);f=i[b+4>>2];i[114610]=0;G(411,d|0,f|0,c|0);d=i[114610];i[114610]=0;if((d|0)==1){break a}d=i[b+4>>2]+4|0;i[b+4>>2]=d;if((d|0)!=i[b+8>>2]){continue}break}}sb(b);Xa=e+16|0;return}a=B()|0;A()|0;sb(b);E(a|0);x()}function ST(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=Xa-16|0;Xa=e;a:{b=ql(e,a,b);if(i[b+4>>2]!=i[b+8>>2]){while(1){d=fb(a);f=i[b+4>>2];i[114610]=0;G(366,d|0,f|0,c|0);d=i[114610];i[114610]=0;if((d|0)==1){break a}d=i[b+4>>2]+1|0;i[b+4>>2]=d;if((d|0)!=i[b+8>>2]){continue}break}}sb(b);Xa=e+16|0;return}a=B()|0;A()|0;sb(b);E(a|0);x()}function $ra(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=Xa-16|0;Xa=c;fb(b);f=sL(a,c+8|0);a:{d=bg(b);if(!d){break a}i[114610]=0;D(1221,a|0,d|0);e=i[114610];i[114610]=0;if((e|0)!=1){e=i[b+4>>2];b=i[b>>2];i[114610]=0;J(1222,a|0,b|0,e|0,d|0);b=i[114610];i[114610]=0;if((b|0)!=1){break a}}a=B()|0;A()|0;Cx(f);E(a|0);x()}Xa=c+16|0;return a|0}function nU(a){var b=0;a:{b:{c:{d:{if((a|0)<=-1){a=P(8)|0;i[114610]=0;F(352,a|0)|0;b=i[114610];i[114610]=0;if((b|0)!=1){break c}break d}if(56>a>>>0){break a}a=P(8)|0;i[114610]=0;F(352,a|0)|0;b=i[114610];i[114610]=0;if((b|0)!=1){break b}}b=B()|0;A()|0;Q(a|0);E(b|0);x()}W(a|0,77368,265);x()}W(a|0,77368,265);x()}return j[a+11680|0]}function lG(a,b){a=a|0;b=b|0;var c=0,d=0;c=Xa-48|0;Xa=c;d=i[b+12>>2];i[c+8>>2]=i[b+8>>2];i[c+12>>2]=d;d=i[b+4>>2];i[c>>2]=i[b>>2];i[c+4>>2]=d;d=RP(c);a:{if(d){kaa(c+24|0,b);St(c+32|0,c+24|0);break a}jaa(c+16|0,b);St(c+32|0,c+16|0)}b=a;a=Dl(c+40|0,c+32|0);SA(b,a);hb(a);hb(c+32|0);b:{if(!d){hb(c+16|0);break b}hb(c+24|0)}Xa=c+48|0}function _V(a){var b=0,c=0,d=0,e=0;d=Xa-32|0;Xa=d;c=fb(a);b=bB(d+8|0,Bl(a,be(a)+1|0),be(a),c);e=i[b+8>>2];i[114610]=0;D(266,c|0,e|0);c=i[114610];i[114610]=0;a:{if((c|0)==1){break a}i[b+8>>2]=i[b+8>>2]+32;i[114610]=0;D(267,a|0,b|0);a=i[114610];i[114610]=0;if((a|0)==1){break a}Tp(b);Xa=d+32|0;return}a=B()|0;A()|0;Tp(b);E(a|0);x()}function xN(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=Xa-16|0;Xa=c;fb(b);f=vN(a,c+8|0);a:{d=rc(b);if(!d){break a}i[114610]=0;D(564,a|0,d|0);e=i[114610];i[114610]=0;if((e|0)!=1){e=i[b+4>>2];b=i[b>>2];i[114610]=0;J(993,a|0,b|0,e|0,d|0);b=i[114610];i[114610]=0;if((b|0)!=1){break a}}a=B()|0;A()|0;Ip(f);E(a|0);x()}Xa=c+16|0;return a|0}function s7(a,b,c,d,e){var f=0,g=0,j=0,k=0,l=0,m=0;if(e){k=c+4|0;while(1){g=0;if(d){while(1){f=i[rf(b,g,j)>>2];Nb(c,g);f=(f+((Yq(k)^-2147483648)>>>21|0)|0)+ -2147482624>>>12|0;f=f>>>0>491520?f:491520;l=gm(a,g,j),m=(f|0)<557055?f:557055,h[l>>1]=m;g=g+1|0;if((g|0)!=(d|0)){continue}break}}j=j+1|0;if((j|0)!=(e|0)){continue}break}}}function nw(a){var b=0,c=0,d=0,e=0;b=zg(+m[a+4228>>2]*8)*.25+ -.25;n[a+4248>>3]=b;if(j[a+4240|0]){e=a;if(b<=45e-5){b=0}else{b=Vn(b)*1.4426950408889634;d=u(b);b=b-d;c=0;a:{if(b<.2075187496394219){break a}c=.4150374992788438;if(b<.5){break a}c=.5849625007211562;if(b<.792481250360578){break a}c=1}b=zg(c+d)*.5}n[e+4248>>3]=b}sr(a)}function le(a){var b=0,c=0,d=0;a:{b:{b=a;if(!(b&3)){break b}if(!j[a|0]){return 0}while(1){b=b+1|0;if(!(b&3)){break b}if(j[b|0]){continue}break}break a}while(1){c=b;b=b+4|0;d=i[c>>2];if(!((d^-1)&d+ -16843009&-2139062144)){continue}break}if(!(d&255)){return c-a|0}while(1){d=j[c+1|0];b=c+1|0;c=b;if(d){continue}break}}return b-a|0}function jH(a){a=a|0;var b=0,c=0;c=Xa-16|0;Xa=c;b=(we(i[a+16>>2])|0)/5|0;b=gc(b,b>>31);i[a+4272>>2]=b;i[114610]=0;i[c+12>>2]=0;G(1647,a+4256|0,b<<1,c+12|0);b=i[114610];i[114610]=0;a:{if((b|0)==1){b=H(71348)|0;if((A()|0)!=(U(71348)|0)){break a}M(b|0)|0;i[a+4272>>2]=0;O()}i[a+4276>>2]=0;i[a+4268>>2]=0;Xa=c+16|0;return}E(b|0);x()}function fH(a){var b=p(0),c=0,d=p(0),e=0;b=m[a+4224>>2];m[a+4260>>2]=w(p(p(1)-p(b*b)));g[a+4264|0]=m[a+4236>>2]>p(.5);c=a;d=p(i[a+4256>>2]<<1>>>0);b=p(m[a+4228>>2]*d);a:{if(b<p(4294967296)&b>=p(0)){e=~~b>>>0;break a}e=0}i[c+4248>>2]=e;c=a+4252|0;b=p(m[a+4232>>2]*d);b:{if(b<p(4294967296)&b>=p(0)){a=~~b>>>0;break b}a=0}i[c>>2]=a}function XS(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=Xa-16|0;Xa=c;fb(b);f=PS(a,c+8|0);a:{d=qb(b);if(!d){break a}i[114610]=0;D(404,a|0,d|0);e=i[114610];i[114610]=0;if((e|0)!=1){e=i[b+4>>2];b=i[b>>2];i[114610]=0;J(408,a|0,b|0,e|0,d|0);b=i[114610];i[114610]=0;if((b|0)!=1){break a}}a=B()|0;A()|0;js(f);E(a|0);x()}Xa=c+16|0;return a|0}function V7(a,b,c,d,e){var f=0,g=0,j=0,k=0,l=0,m=0;if(e){k=c+4|0;while(1){g=0;if(d){while(1){f=i[rf(b,g,j)>>2];Nb(c,g);f=(f+((Yq(k)^-2147483648)>>>21|0)|0)+ -2147482624>>>12|0;f=f>>>0>491520?f:491520;l=im(a,g,j),m=(f|0)<557055?f:557055,h[l>>1]=m;g=g+1|0;if((g|0)!=(d|0)){continue}break}}j=j+1|0;if((j|0)!=(e|0)){continue}break}}}function wy(a,b,c,d,e){var f=0;f=Xa-32|0;Xa=f;DO(a,b);HBa(b,c,e);on(f,3,b);oc(f+16|0,f);i[114610]=0;C(369,d|0,f+16|0)|0;a=i[114610];i[114610]=0;if((a|0)!=1){a=d+32|0;eb(f+16|0);while(1){if((j[d|0]+ -1&255)>>>0<=30){g[d|0]=32}d=d+1|0;if((a|0)!=(d|0)){continue}break}a=xy(b);Xa=f+32|0;return a}a=B()|0;A()|0;eb(f+16|0);E(a|0);x()}function m5(a){var b=0,c=0;a:{b:{c:{if(i[a+1380>>2]!=-1){break c}b=fe(a);if(i[a+96>>2]){break b}if((b|0)!=79){break a}if((fe(a)|0)!=103){break a}if((fe(a)|0)!=103){break a}if((fe(a)|0)!=83){break a}if(!TE(a)){break b}if(!(g[a+1375|0]&1)){break c}g[a+1376|0]=0;i[a+1384>>2]=0;Lb(a,32);return 0}c=xv(a)}return c}Lb(a,30);return 0}function KQ(a){a:{if((j[a|0]|j[a+1|0]<<8|(j[a+2|0]<<16|j[a+3|0]<<24))!=-28490681|j[a+68|0]!=13|(j[a+69|0]!=10|j[a+70|0]!=26)){break a}if(j[a+76|0]|((j[a+71|0]|j[a+72|0]<<8|(j[a+73|0]<<16|j[a+74|0]<<24))!=1397116231|j[a+75|0]!=1)){break a}a=a+116|0;if(10<=(j[a|0]|j[a+1|0]<<8)>>>0){break a}return(j[a|0]|j[a+1|0]<<8)!=0}return 0}function wha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=Xa-16|0;Xa=d;a:{b=rha(d,a+8|0,b);if(i[b>>2]!=i[b+4>>2]){while(1){c=i[a+16>>2];e=i[b>>2];i[114610]=0;D(1650,c|0,e|0);c=i[114610];i[114610]=0;if((c|0)==1){break a}c=i[b>>2]+2048|0;i[b>>2]=c;if((c|0)!=i[b+4>>2]){continue}break}}ac(b);Xa=d+16|0;return}a=B()|0;A()|0;ac(b);E(a|0);x()}function nW(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=Xa-32|0;Xa=d;b=Kf(d,b);i[114610]=0;G(253,d+16|0,b|0,c|0);e=i[114610];i[114610]=0;a:{b:{if((e|0)!=1){i[114610]=0;G(5,a|0,d+16|0,c|0);a=i[114610];i[114610]=0;if((a|0)==1){break b}eb(d+16|0);eb(b);Xa=d+32|0;return}a=B()|0;A()|0;break a}a=B()|0;A()|0;eb(d+16|0)}eb(b);E(a|0);x()}function jm(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=jr(a+60|0);i[a>>2]=76928;i[d>>2]=76948;i[114610]=0;e=a+8|0;I(175,a|0,76960,e|0)|0;f=i[114610];i[114610]=0;if((f|0)!=1){a:{i[a>>2]=76928;i[d>>2]=76948;i[114610]=0;I(176,e|0,b|0,c|8)|0;b=i[114610];i[114610]=0;if((b|0)==1){break a}return a|0}}a=B()|0;A()|0;kg(d);E(a|0);x()}function MR(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=Xa-32|0;Xa=d;f=d+8|0;g=b;if(GR(b,d+24|0)){e=RJa(d+24|0)}ad(f,g,e);a=FR(a,d+24|0,d+8|0);hb(d+8|0);a:{if(!c){break a}e=(e>>>0)%(c>>>0)|0;if(!e){break a}i[114610]=0;C(338,b|0,c-e|0)|0;b=i[114610];i[114610]=0;if((b|0)!=1){break a}b=B()|0;A()|0;re(a);E(b|0);x()}Xa=d+32|0}function yE(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;d=4;e=Xa-256|0;Xa=e;a:{if((b|0)<2){break a}h=(b<<2)+a|0;i[h>>2]=e;c=e;while(1){f=d>>>0<256?d:256;Tb(c,i[a>>2],f);c=0;while(1){g=(c<<2)+a|0;c=c+1|0;Tb(i[g>>2],i[(c<<2)+a>>2],f);i[g>>2]=i[g>>2]+f;if((b|0)!=(c|0)){continue}break}d=d-f|0;if(!d){break a}c=i[h>>2];continue}}Xa=e+256|0}function x5(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,h=0,j=0;f=Xa-1520|0;Xa=f;w5(f+8|0,e);g[f+56|0]=1;i[f+48>>2]=a+b;i[f+40>>2]=a;a:{b:{if(!v5(f+8|0)){i[d>>2]=i[f+104>>2]?1:i[f+108>>2];break b}b=yd(f+8|0,1512);if(b){h=c,j=i[Tb(b,f+8|0,1512)+32>>2]-a|0,i[h>>2]=j;i[d>>2]=0;break a}_E(f+8|0)}b=0}Xa=f+1520|0;return b|0}function tz(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=Xa-32|0;Xa=d;f=d+8|0;g=b;if(GR(b,d+24|0)){e=pz(d+24|0)}ad(f,g,e);a=FR(a,d+24|0,d+8|0);hb(d+8|0);a:{if(!c){break a}e=(e>>>0)%(c>>>0)|0;if(!e){break a}i[114610]=0;C(338,b|0,c-e|0)|0;b=i[114610];i[114610]=0;if((b|0)!=1){break a}b=B()|0;A()|0;re(a);E(b|0);x()}Xa=d+32|0}function nFa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=Xa-16|0;Xa=d;a:{b=lFa(d,a+8|0,b);if(i[b>>2]!=i[b+4>>2]){while(1){c=i[a+16>>2];e=i[b>>2];i[114610]=0;D(744,c|0,e|0);c=i[114610];i[114610]=0;if((c|0)==1){break a}c=i[b>>2]+48|0;i[b>>2]=c;if((c|0)!=i[b+4>>2]){continue}break}}ac(b);Xa=d+16|0;return}a=B()|0;A()|0;ac(b);E(a|0);x()}function lra(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=Xa-16|0;Xa=d;a:{b=WM(d,a+8|0,b);if(i[b>>2]!=i[b+4>>2]){while(1){c=i[a+16>>2];e=i[b>>2];i[114610]=0;D(1238,c|0,e|0);c=i[114610];i[114610]=0;if((c|0)==1){break a}c=i[b>>2]+12|0;i[b>>2]=c;if((c|0)!=i[b+4>>2]){continue}break}}ac(b);Xa=d+16|0;return}a=B()|0;A()|0;ac(b);E(a|0);x()}function lEa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=Xa-16|0;Xa=d;a:{b=fEa(d,a+8|0,b);if(i[b>>2]!=i[b+4>>2]){while(1){c=i[a+16>>2];e=i[b>>2];i[114610]=0;D(768,c|0,e|0);c=i[114610];i[114610]=0;if((c|0)==1){break a}c=i[b>>2]+33|0;i[b>>2]=c;if((c|0)!=i[b+4>>2]){continue}break}}ac(b);Xa=d+16|0;return}a=B()|0;A()|0;ac(b);E(a|0);x()}function WQ(a){var b=0;b=Xa-16|0;Xa=b;g[a|0]=0;g[a+1|0]=0;g[a+2|0]=0;g[a+3|0]=0;g[a+4|0]=0;g[a+5|0]=0;g[a+6|0]=0;g[a+7|0]=0;g[a+14|0]=0;g[a+15|0]=0;g[a+16|0]=0;g[a+17|0]=0;g[a+18|0]=0;g[a+19|0]=0;g[a+20|0]=0;g[a+21|0]=0;g[a+8|0]=0;g[a+9|0]=0;g[a+10|0]=0;g[a+11|0]=0;g[a+12|0]=0;g[a+13|0]=0;g[a+14|0]=0;g[a+15|0]=0;Xa=b+16|0}function KI(a){var b=0;b=Xa-16|0;Xa=b;g[a|0]=0;g[a+1|0]=0;g[a+2|0]=0;g[a+3|0]=0;g[a+4|0]=0;g[a+5|0]=0;g[a+6|0]=0;g[a+7|0]=0;g[a+16|0]=0;g[a+17|0]=0;g[a+18|0]=0;g[a+19|0]=0;g[a+20|0]=0;g[a+21|0]=0;g[a+22|0]=0;g[a+23|0]=0;g[a+8|0]=0;g[a+9|0]=0;g[a+10|0]=0;g[a+11|0]=0;g[a+12|0]=0;g[a+13|0]=0;g[a+14|0]=0;g[a+15|0]=0;Xa=b+16|0}function Cxa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=Xa-16|0;Xa=d;a:{b=WM(d,a+8|0,b);if(i[b>>2]!=i[b+4>>2]){while(1){c=i[a+16>>2];e=i[b>>2];i[114610]=0;D(1025,c|0,e|0);c=i[114610];i[114610]=0;if((c|0)==1){break a}c=i[b>>2]+12|0;i[b>>2]=c;if((c|0)!=i[b+4>>2]){continue}break}}ac(b);Xa=d+16|0;return}a=B()|0;A()|0;ac(b);E(a|0);x()}function qAa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=Xa-16|0;Xa=d;a:{b=oAa(d,a+8|0,b);if(i[b>>2]!=i[b+4>>2]){while(1){c=i[a+16>>2];e=i[b>>2];i[114610]=0;D(927,c|0,e|0);c=i[114610];i[114610]=0;if((c|0)==1){break a}c=i[b>>2]+8|0;i[b>>2]=c;if((c|0)!=i[b+4>>2]){continue}break}}ac(b);Xa=d+16|0;return}a=B()|0;A()|0;ac(b);E(a|0);x()}function mha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=Xa-16|0;Xa=d;a:{b=th(d,a+8|0,b);if(i[b>>2]!=i[b+4>>2]){while(1){c=i[a+16>>2];e=i[b>>2];i[114610]=0;D(1652,c|0,e|0);c=i[114610];i[114610]=0;if((c|0)==1){break a}c=i[b>>2]+4|0;i[b>>2]=c;if((c|0)!=i[b+4>>2]){continue}break}}ac(b);Xa=d+16|0;return}a=B()|0;A()|0;ac(b);E(a|0);x()}function aoa(a){a=a|0;var b=0,c=0,d=0,e=0;d=Xa-896|0;Xa=d;b=yb(a,0,66);i[b+72>>2]=0;i[b+76>>2]=0;i[b+68>>2]=256;h[b+66>>1]=65535;i[b+80>>2]=0;i[b+84>>2]=0;g[b+88|0]=1;e=b+229984|0;c=b+608|0;a=c;while(1){a=PJ(a)+896|0;if((e|0)!=(a|0)){continue}break}a=yb(d,0,896);Wma(c,((c+229376|0)-c|0)/896|0,PJ(a));Xa=a+896|0;return b|0}function aCa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=Xa-16|0;Xa=d;a:{b=RBa(d,a,b);if(i[b+4>>2]!=i[b+8>>2]){while(1){c=fb(a);e=i[b+4>>2];i[114610]=0;D(882,c|0,e|0);c=i[114610];i[114610]=0;if((c|0)==1){break a}c=i[b+4>>2]+20|0;i[b+4>>2]=c;if((c|0)!=i[b+8>>2]){continue}break}}sb(b);Xa=d+16|0;return}a=B()|0;A()|0;sb(b);E(a|0);x()}function NDa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=Xa-16|0;Xa=d;a:{b=EB(d,a+8|0,b);if(i[b>>2]!=i[b+4>>2]){while(1){c=i[a+16>>2];e=i[b>>2];i[114610]=0;D(418,c|0,e|0);c=i[114610];i[114610]=0;if((c|0)==1){break a}c=i[b>>2]+16|0;i[b>>2]=c;if((c|0)!=i[b+4>>2]){continue}break}}ac(b);Xa=d+16|0;return}a=B()|0;A()|0;ac(b);E(a|0);x()}function Ira(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=Xa-16|0;Xa=d;a:{b=Kl(d,a,b);if(i[b+4>>2]!=i[b+8>>2]){while(1){c=fb(a);e=i[b+4>>2];i[114610]=0;D(1231,c|0,e|0);c=i[114610];i[114610]=0;if((c|0)==1){break a}c=i[b+4>>2]+16|0;i[b+4>>2]=c;if((c|0)!=i[b+8>>2]){continue}break}}sb(b);Xa=d+16|0;return}a=B()|0;A()|0;sb(b);E(a|0);x()}function Dia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=Xa-16|0;Xa=d;a:{b=th(d,a+8|0,b);if(i[b>>2]!=i[b+4>>2]){while(1){c=i[a+16>>2];e=i[b>>2];i[114610]=0;D(1621,c|0,e|0);c=i[114610];i[114610]=0;if((c|0)==1){break a}c=i[b>>2]+4|0;i[b>>2]=c;if((c|0)!=i[b+4>>2]){continue}break}}ac(b);Xa=d+16|0;return}a=B()|0;A()|0;ac(b);E(a|0);x()}function qFa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=Xa-16|0;Xa=d;a:{b=th(d,a+8|0,b);if(i[b>>2]!=i[b+4>>2]){while(1){c=i[a+16>>2];e=i[b>>2];i[114610]=0;D(743,c|0,e|0);c=i[114610];i[114610]=0;if((c|0)==1){break a}c=i[b>>2]+4|0;i[b>>2]=c;if((c|0)!=i[b+4>>2]){continue}break}}ac(b);Xa=d+16|0;return}a=B()|0;A()|0;ac(b);E(a|0);x()}function bka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=Xa-16|0;Xa=d;a:{b=jp(d,a,b);if(i[b+4>>2]!=i[b+8>>2]){while(1){c=fb(a);e=i[b+4>>2];i[114610]=0;D(1579,c|0,e|0);c=i[114610];i[114610]=0;if((c|0)==1){break a}c=i[b+4>>2]+6|0;i[b+4>>2]=c;if((c|0)!=i[b+8>>2]){continue}break}}sb(b);Xa=d+16|0;return}a=B()|0;A()|0;sb(b);E(a|0);x()}function XCa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=Xa-16|0;Xa=d;a:{b=th(d,a+8|0,b);if(i[b>>2]!=i[b+4>>2]){while(1){c=i[a+16>>2];e=i[b>>2];i[114610]=0;D(825,c|0,e|0);c=i[114610];i[114610]=0;if((c|0)==1){break a}c=i[b>>2]+4|0;i[b>>2]=c;if((c|0)!=i[b+4>>2]){continue}break}}ac(b);Xa=d+16|0;return}a=B()|0;A()|0;ac(b);E(a|0);x()}function Uia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=p(0),f=0,g=0,h=p(0);c=Xa-32|0;Xa=c;jj(a,c+24|0);f=c,g=Vc(i[c+24>>2],i[c+28>>2]),i[f+16>>2]=g;i[c+12>>2]=256;Tk(b,i[rb(c+16|0,c+12|0)>>2]);if(qb(b)){while(1){i[c+16>>2]=0;fo(a,c+16|0);e=m[c+16>>2];f=vb(b,d),h=e,m[f>>2]=h;d=d+1|0;if(d>>>0<qb(b)>>>0){continue}break}}Xa=c+32|0}function Rwa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=Xa-16|0;Xa=d;a:{b=Yd(d,a,b);if(i[b+4>>2]!=i[b+8>>2]){while(1){c=fb(a);e=i[b+4>>2];i[114610]=0;D(1057,c|0,e|0);c=i[114610];i[114610]=0;if((c|0)==1){break a}c=i[b+4>>2]+4|0;i[b+4>>2]=c;if((c|0)!=i[b+8>>2]){continue}break}}sb(b);Xa=d+16|0;return}a=B()|0;A()|0;sb(b);E(a|0);x()}function RW(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=Xa-16|0;Xa=d;a:{b=EB(d,a+8|0,b);if(i[b>>2]!=i[b+4>>2]){while(1){c=i[a+16>>2];e=i[b>>2];i[114610]=0;D(216,c|0,e|0);c=i[114610];i[114610]=0;if((c|0)==1){break a}c=i[b>>2]+16|0;i[b>>2]=c;if((c|0)!=i[b+4>>2]){continue}break}}ac(b);Xa=d+16|0;return}a=B()|0;A()|0;ac(b);E(a|0);x()}function Pra(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=Xa-16|0;Xa=d;a:{b=Qp(d,a,b);if(i[b+4>>2]!=i[b+8>>2]){while(1){c=fb(a);e=i[b+4>>2];i[114610]=0;D(1228,c|0,e|0);c=i[114610];i[114610]=0;if((c|0)==1){break a}c=i[b+4>>2]+8|0;i[b+4>>2]=c;if((c|0)!=i[b+8>>2]){continue}break}}sb(b);Xa=d+16|0;return}a=B()|0;A()|0;sb(b);E(a|0);x()}function NLa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=Xa-16|0;Xa=d;a:{b=tl(d,a+8|0,b);if(i[b>>2]!=i[b+4>>2]){while(1){c=i[a+16>>2];e=i[b>>2];i[114610]=0;D(420,c|0,e|0);c=i[114610];i[114610]=0;if((c|0)==1){break a}c=i[b>>2]+2|0;i[b>>2]=c;if((c|0)!=i[b+4>>2]){continue}break}}ac(b);Xa=d+16|0;return}a=B()|0;A()|0;ac(b);E(a|0);x()}function NCa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=Xa-16|0;Xa=d;a:{b=tl(d,a+8|0,b);if(i[b>>2]!=i[b+4>>2]){while(1){c=i[a+16>>2];e=i[b>>2];i[114610]=0;D(832,c|0,e|0);c=i[114610];i[114610]=0;if((c|0)==1){break a}c=i[b>>2]+2|0;i[b>>2]=c;if((c|0)!=i[b+4>>2]){continue}break}}ac(b);Xa=d+16|0;return}a=B()|0;A()|0;ac(b);E(a|0);x()}function Iza(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=Xa-16|0;Xa=d;a:{b=th(d,a+8|0,b);if(i[b>>2]!=i[b+4>>2]){while(1){c=i[a+16>>2];e=i[b>>2];i[114610]=0;D(949,c|0,e|0);c=i[114610];i[114610]=0;if((c|0)==1){break a}c=i[b>>2]+4|0;i[b>>2]=c;if((c|0)!=i[b+4>>2]){continue}break}}ac(b);Xa=d+16|0;return}a=B()|0;A()|0;ac(b);E(a|0);x()}function Fda(a){a=a|0;var b=0;i[114610]=0;L(2015,a|0);b=i[114610];i[114610]=0;if((b|0)!=1){return i[a+16>>2]}b=H(0)|0;A()|0;M(b|0)|0;i[114610]=0;J(1989,34813,a|0,0,0);a=i[114610];i[114610]=0;if((a|0)!=1){O();return-1}a=B()|0;A()|0;i[114610]=0;K(20);b=i[114610];i[114610]=0;if((b|0)!=1){E(a|0);x()}a=H(0)|0;A()|0;gb(a);x()}function DLa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=Xa-16|0;Xa=d;a:{b=tl(d,a+8|0,b);if(i[b>>2]!=i[b+4>>2]){while(1){c=i[a+16>>2];e=i[b>>2];i[114610]=0;D(425,c|0,e|0);c=i[114610];i[114610]=0;if((c|0)==1){break a}c=i[b>>2]+2|0;i[b>>2]=c;if((c|0)!=i[b+4>>2]){continue}break}}ac(b);Xa=d+16|0;return}a=B()|0;A()|0;ac(b);E(a|0);x()}function xX(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;if(Nf(a,i[b+8>>2],e)){qu(b,c,d);return}a:{if(!Nf(a,i[b>>2],e)){break a}if(!(i[b+20>>2]!=(c|0)?i[b+16>>2]!=(c|0):0)){if((d|0)!=1){break a}i[b+32>>2]=1;return}i[b+20>>2]=c;i[b+32>>2]=d;i[b+40>>2]=i[b+40>>2]+1;if(!(i[b+36>>2]!=1|i[b+24>>2]!=2)){g[b+54|0]=1}i[b+44>>2]=4}}function rua(a,b,c,d){var e=0,f=0,g=0;a:{e=i[c>>2];f=i[d>>2];if(e|f){if(!b){break a}while(1){i[c>>2]=e-(((-2147483648-e>>>31|0)+ -1&255)+e>>8);i[d>>2]=i[d>>2]-(((-2147483648-f>>>31|0)+ -1&255)+f>>8);e=g<<3;i[e+a>>2]=i[c>>2];i[(e|4)+a>>2]=i[d>>2];g=g+1|0;if((g|0)==(b|0)){break a}f=i[d>>2];e=i[c>>2];continue}}BM(a,b<<1)}}function nea(a,b,c){var d=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0;e=i[a+4144>>2];f=i[a+4140>>2];if(c){j=h[a+4188>>1];while(1){d=g<<3;k=(d|4)+b|0;m=i[k>>2];d=b+d|0;l=i[d>>2]>>12;f=(o(l-f|0,j)>>15)+l|0;i[d>>2]=f;d=m>>12;e=(o(d-e|0,j)>>15)+d|0;i[k>>2]=e;g=g+1|0;if((g|0)!=(c|0)){continue}break}}i[a+4144>>2]=e;i[a+4140>>2]=f;return c}function jca(a){a=a|0;var b=0;i[114610]=0;L(2088,a|0);b=i[114610];i[114610]=0;a:{if((b|0)==1){b=H(0)|0;A()|0;M(b|0)|0;i[114610]=0;J(1989,37272,a|0,0,0);a=i[114610];i[114610]=0;if((a|0)==1){break a}O();a=0}return a|0}a=B()|0;A()|0;i[114610]=0;K(20);b=i[114610];i[114610]=0;if((b|0)!=1){E(a|0);x()}a=H(0)|0;A()|0;gb(a);x()}function dCa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=Xa-16|0;Xa=d;a:{b=Yd(d,a,b);if(i[b+4>>2]!=i[b+8>>2]){while(1){c=fb(a);e=i[b+4>>2];i[114610]=0;D(880,c|0,e|0);c=i[114610];i[114610]=0;if((c|0)==1){break a}c=i[b+4>>2]+4|0;i[b+4>>2]=c;if((c|0)!=i[b+8>>2]){continue}break}}sb(b);Xa=d+16|0;return}a=B()|0;A()|0;sb(b);E(a|0);x()}function WT(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=Xa-16|0;Xa=d;a:{b=Es(d,a+8|0,b);if(i[b>>2]!=i[b+4>>2]){while(1){c=i[a+16>>2];e=i[b>>2];i[114610]=0;D(365,c|0,e|0);c=i[114610];i[114610]=0;if((c|0)==1){break a}c=i[b>>2]+1|0;i[b>>2]=c;if((c|0)!=i[b+4>>2]){continue}break}}ac(b);Xa=d+16|0;return}a=B()|0;A()|0;ac(b);E(a|0);x()}function WCa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=Xa-16|0;Xa=d;a:{b=Es(d,a+8|0,b);if(i[b>>2]!=i[b+4>>2]){while(1){c=i[a+16>>2];e=i[b>>2];i[114610]=0;D(38,c|0,e|0);c=i[114610];i[114610]=0;if((c|0)==1){break a}c=i[b>>2]+1|0;i[b>>2]=c;if((c|0)!=i[b+4>>2]){continue}break}}ac(b);Xa=d+16|0;return}a=B()|0;A()|0;ac(b);E(a|0);x()}function UIa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=Xa-16|0;Xa=d;a:{b=jp(d,a,b);if(i[b+4>>2]!=i[b+8>>2]){while(1){c=fb(a);e=i[b+4>>2];i[114610]=0;D(569,c|0,e|0);c=i[114610];i[114610]=0;if((c|0)==1){break a}c=i[b+4>>2]+6|0;i[b+4>>2]=c;if((c|0)!=i[b+8>>2]){continue}break}}sb(b);Xa=d+16|0;return}a=B()|0;A()|0;sb(b);E(a|0);x()}function UFa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,h=0;d=Xa-16|0;Xa=d;Ce(b);i[d+12>>2]=0;h=!di(a,d+12|0);f=i[d+12>>2];a:{if(h|f>>>0>c>>>0){break a}if(!f){e=1;break a}c=0;while(1){b:{g[d+11|0]=0;if(!Bg(a,d+11|0)){break b}sl(b,g[d+11|0]);e=1;c=c+1|0;if((c|0)!=i[d+12>>2]){continue}break a}break}e=0}Xa=d+16|0;return e|0}function RS(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=Xa-16|0;Xa=d;a:{b=Kl(d,a,b);if(i[b+4>>2]!=i[b+8>>2]){while(1){c=fb(a);e=i[b+4>>2];i[114610]=0;D(418,c|0,e|0);c=i[114610];i[114610]=0;if((c|0)==1){break a}c=i[b+4>>2]+16|0;i[b+4>>2]=c;if((c|0)!=i[b+8>>2]){continue}break}}sb(b);Xa=d+16|0;return}a=B()|0;A()|0;sb(b);E(a|0);x()}function MW(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=Xa-16|0;Xa=d;a:{b=Es(d,a+8|0,b);if(i[b>>2]!=i[b+4>>2]){while(1){c=i[a+16>>2];e=i[b>>2];i[114610]=0;D(218,c|0,e|0);c=i[114610];i[114610]=0;if((c|0)==1){break a}c=i[b>>2]+1|0;i[b>>2]=c;if((c|0)!=i[b+4>>2]){continue}break}}ac(b);Xa=d+16|0;return}a=B()|0;A()|0;ac(b);E(a|0);x()}function DT(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=Xa-16|0;Xa=d;a:{b=th(d,a+8|0,b);if(i[b>>2]!=i[b+4>>2]){while(1){c=i[a+16>>2];e=i[b>>2];i[114610]=0;D(371,c|0,e|0);c=i[114610];i[114610]=0;if((c|0)==1){break a}c=i[b>>2]+4|0;i[b>>2]=c;if((c|0)!=i[b+4>>2]){continue}break}}ac(b);Xa=d+16|0;return}a=B()|0;A()|0;ac(b);E(a|0);x()}function vA(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=Xa-16|0;Xa=d;a:{b=ql(d,a,b);if(i[b+4>>2]!=i[b+8>>2]){while(1){c=fb(a);e=i[b+4>>2];i[114610]=0;D(365,c|0,e|0);c=i[114610];i[114610]=0;if((c|0)==1){break a}c=i[b+4>>2]+1|0;i[b+4>>2]=c;if((c|0)!=i[b+8>>2]){continue}break}}sb(b);Xa=d+16|0;return}a=B()|0;A()|0;sb(b);E(a|0);x()}function lL(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=Xa-16|0;Xa=e;a:{if(Wb(Fo(a))>>>0<=b>>>0){break a}b:{c:{if(cc(a)>>>0>b>>>0){if(l[Yc(a,b)+4>>2]>c>>>0){break c}}if(!d){break a}zx(a,b,c,1);break b}Ld(e+8|0,Yc(a,b),c);f=ib(e+8|0);if(f|!d){break a}Ld(e+8|0,Yc(a,b),c);Od(e+8|0,1);mL(a,b,c)}f=0}Xa=e+16|0;return f|0}function aga(a){a=a|0;var b=0,c=0;c=Xa-16|0;Xa=c;b=we(i[a+16>>2]);b=gc(YMa(XMa(b,b>>31,3840,0),_a,1e3,0),_a);i[a+4276>>2]=b;i[114610]=0;i[c+12>>2]=0;G(1647,a+4260|0,b|0,c+12|0);b=i[114610];i[114610]=0;a:{if((b|0)==1){b=H(71348)|0;if((A()|0)!=(U(71348)|0)){break a}M(b|0)|0;i[a+4276>>2]=0;O()}Xa=c+16|0;return}E(b|0);x()}function aC(a,b,c){var d=0,e=0,f=0,h=0,i=0;h=Xa-16|0;Xa=h;d=lb(a);if(d>>>0>=0){f=qc(a);a:{if(f-d>>>0>=c>>>0){if(!c){break a}e=xb(a);i=e;f=d;if(d){Cl(c+e|0,e,f);b=e>>>0<=b>>>0?d+e>>>0>b>>>0?b+c|0:b:b}Cl(i,b,c);b=c+d|0;yg(a,b);g[h+15|0]=0;Rd(b+e|0,h+15|0);break a}ku(a,f,(c+d|0)-f|0,d,0,0,c,b)}Xa=h+16|0;return a}Ml();x()}function WV(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=Xa-16|0;Xa=d;a:{b=Qp(d,a,b);if(i[b+4>>2]!=i[b+8>>2]){while(1){c=fb(a);e=i[b+4>>2];i[114610]=0;D(270,c|0,e|0);c=i[114610];i[114610]=0;if((c|0)==1){break a}c=i[b+4>>2]+8|0;i[b+4>>2]=c;if((c|0)!=i[b+8>>2]){continue}break}}sb(b);Xa=d+16|0;return}a=B()|0;A()|0;sb(b);E(a|0);x()}function WLa(a,b){var c=0,d=0,e=0;c=Xa-32|0;Xa=c;i[c+16>>2]=b;d=c,e=yLa(a,b),i[d+24>>2]=e;if(pb(c+24|0,c+16|0)){i[c>>2]=i[c+24>>2];Gd(c);if(pb(Gd(c),c+16|0)){while(1){if(!al(i[c+24>>2],i[c>>2])){a=i[i[c>>2]>>2];d=i[Gd(c+24|0)>>2],e=a,i[d>>2]=e}if(pb(Gd(c),c+16|0)){continue}break}}Gd(c+24|0)}Xa=c+32|0;return i[c+24>>2]}function W5(a,b){var c=0,d=0,e=0,f=p(0),g=p(0),h=p(0),i=p(0);if((b|0)>=1){while(1){d=0;while(1){c=d<<2;e=c+a|0;c=c+48672|0;f=m[c>>2];g=m[e+72>>2];h=m[c+32>>2];c=(17-d<<2)+a|0;i=m[c>>2];m[e+72>>2]=p(f*g)-p(h*i);m[c>>2]=p(h*g)+p(f*i);d=d+1|0;if((d|0)!=8){continue}break}a=a+72|0;d=(b|0)>1;b=b+ -1|0;if(d){continue}break}}}function SN(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=Xa-16|0;Xa=d;a:{b=Yd(d,a,b);if(i[b+4>>2]!=i[b+8>>2]){while(1){c=fb(a);e=i[b+4>>2];i[114610]=0;D(949,c|0,e|0);c=i[114610];i[114610]=0;if((c|0)==1){break a}c=i[b+4>>2]+4|0;i[b+4>>2]=c;if((c|0)!=i[b+8>>2]){continue}break}}sb(b);Xa=d+16|0;return}a=B()|0;A()|0;sb(b);E(a|0);x()}function SFa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,h=0;d=Xa-16|0;Xa=d;Ce(b);g[d+15|0]=0;h=!Bg(a,d+15|0);f=j[d+15|0];a:{if(h|f>>>0>c>>>0){break a}if(!f){e=1;break a}c=0;while(1){b:{g[d+14|0]=0;if(!Bg(a,d+14|0)){break b}sl(b,g[d+14|0]);e=1;c=c+1|0;if(j[d+15|0]!=(c&255)){continue}break a}break}e=0}Xa=d+16|0;return e|0}function NF(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=Xa-48|0;Xa=e;i[e+40>>2]=c;i[e+44>>2]=b;i[e+36>>2]=d;b=i[a+8>>2];i[e+28>>2]=e+36;i[e+24>>2]=e+40;c=i[e+28>>2];i[e+8>>2]=i[e+24>>2];i[e+12>>2]=c;i[e+16>>2]=a;i[e+20>>2]=e+44;c=i[e+20>>2];i[e>>2]=i[e+16>>2];i[e+4>>2]=c;$7(b,e);i[a+4>>2]=i[a+4>>2]+i[e+36>>2];Xa=e+48|0}function MF(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=Xa-48|0;Xa=e;i[e+40>>2]=c;i[e+44>>2]=b;i[e+36>>2]=d;b=i[a+8>>2];i[e+28>>2]=e+36;i[e+24>>2]=e+40;c=i[e+28>>2];i[e+8>>2]=i[e+24>>2];i[e+12>>2]=c;i[e+16>>2]=a;i[e+20>>2]=e+44;c=i[e+20>>2];i[e>>2]=i[e+16>>2];i[e+4>>2]=c;_7(b,e);i[a+4>>2]=i[a+4>>2]+i[e+36>>2];Xa=e+48|0}function LF(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=Xa-48|0;Xa=e;i[e+40>>2]=c;i[e+44>>2]=b;i[e+36>>2]=d;b=i[a+8>>2];i[e+28>>2]=e+36;i[e+24>>2]=e+40;c=i[e+28>>2];i[e+8>>2]=i[e+24>>2];i[e+12>>2]=c;i[e+16>>2]=a;i[e+20>>2]=e+44;c=i[e+20>>2];i[e>>2]=i[e+16>>2];i[e+4>>2]=c;L7(b,e);i[a+4>>2]=i[a+4>>2]+i[e+36>>2];Xa=e+48|0}function JF(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=Xa-48|0;Xa=e;i[e+40>>2]=c;i[e+44>>2]=b;i[e+36>>2]=d;b=i[a+8>>2];i[e+28>>2]=e+36;i[e+24>>2]=e+40;c=i[e+28>>2];i[e+8>>2]=i[e+24>>2];i[e+12>>2]=c;i[e+16>>2]=a;i[e+20>>2]=e+44;c=i[e+20>>2];i[e>>2]=i[e+16>>2];i[e+4>>2]=c;K7(b,e);i[a+4>>2]=i[a+4>>2]+i[e+36>>2];Xa=e+48|0}function J8(a,b){var c=0,d=0,e=0;d=Xa-16|0;Xa=d;i[d+12>>2]=i[a+4>>2];c=i[b+4>>2];i[114610]=0;i[d+8>>2]=c;c=C(33,d+12|0,d+8|0)|0;e=i[114610];i[114610]=0;if((e|0)!=1){c=xm(i[a>>2],i[b>>2],i[c>>2]);a:{if(c){break a}c=0;if(i[a+4>>2]==i[b+4>>2]){break a}c=l[a+4>>2]<l[b+4>>2]?-1:1}Xa=d+16|0;return c}a=H(0)|0;A()|0;gb(a);x()}function IF(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=Xa-48|0;Xa=e;i[e+40>>2]=c;i[e+44>>2]=b;i[e+36>>2]=d;b=i[a+8>>2];i[e+28>>2]=e+36;i[e+24>>2]=e+40;c=i[e+28>>2];i[e+8>>2]=i[e+24>>2];i[e+12>>2]=c;i[e+16>>2]=a;i[e+20>>2]=e+44;c=i[e+20>>2];i[e>>2]=i[e+16>>2];i[e+4>>2]=c;y7(b,e);i[a+4>>2]=i[a+4>>2]+i[e+36>>2];Xa=e+48|0}function HF(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=Xa-48|0;Xa=e;i[e+40>>2]=c;i[e+44>>2]=b;i[e+36>>2]=d;b=i[a+8>>2];i[e+28>>2]=e+36;i[e+24>>2]=e+40;c=i[e+28>>2];i[e+8>>2]=i[e+24>>2];i[e+12>>2]=c;i[e+16>>2]=a;i[e+20>>2]=e+44;c=i[e+20>>2];i[e>>2]=i[e+16>>2];i[e+4>>2]=c;x7(b,e);i[a+4>>2]=i[a+4>>2]+i[e+36>>2];Xa=e+48|0}function FS(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=Xa-16|0;Xa=d;a:{b=vh(d,a,b);if(i[b+4>>2]!=i[b+8>>2]){while(1){c=fb(a);e=i[b+4>>2];i[114610]=0;D(420,c|0,e|0);c=i[114610];i[114610]=0;if((c|0)==1){break a}c=i[b+4>>2]+2|0;i[b+4>>2]=c;if((c|0)!=i[b+8>>2]){continue}break}}sb(b);Xa=d+16|0;return}a=B()|0;A()|0;sb(b);E(a|0);x()}function FF(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=Xa-48|0;Xa=e;i[e+40>>2]=c;i[e+44>>2]=b;i[e+36>>2]=d;b=i[a+8>>2];i[e+28>>2]=e+36;i[e+24>>2]=e+40;c=i[e+28>>2];i[e+8>>2]=i[e+24>>2];i[e+12>>2]=c;i[e+16>>2]=a;i[e+20>>2]=e+44;c=i[e+20>>2];i[e>>2]=i[e+16>>2];i[e+4>>2]=c;i7(b,e);i[a+4>>2]=i[a+4>>2]+i[e+36>>2];Xa=e+48|0}function EF(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=Xa-48|0;Xa=e;i[e+40>>2]=c;i[e+44>>2]=b;i[e+36>>2]=d;b=i[a+8>>2];i[e+28>>2]=e+36;i[e+24>>2]=e+40;c=i[e+28>>2];i[e+8>>2]=i[e+24>>2];i[e+12>>2]=c;i[e+16>>2]=a;i[e+20>>2]=e+44;c=i[e+20>>2];i[e>>2]=i[e+16>>2];i[e+4>>2]=c;h7(b,e);i[a+4>>2]=i[a+4>>2]+i[e+36>>2];Xa=e+48|0}function xR(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=Xa-16|0;Xa=d;a:{b=ql(d,a,b);if(i[b+4>>2]!=i[b+8>>2]){while(1){c=fb(a);e=i[b+4>>2];i[114610]=0;D(38,c|0,e|0);c=i[114610];i[114610]=0;if((c|0)==1){break a}c=i[b+4>>2]+1|0;i[b+4>>2]=c;if((c|0)!=i[b+8>>2]){continue}break}}sb(b);Xa=d+16|0;return}a=B()|0;A()|0;sb(b);E(a|0);x()}function qT(a){var b=0,c=0,d=0;a:{if(j[a+110|0]>64|((j[a|0]|j[a+1|0]<<8)!=20042?(j[a|0]|j[a+1|0]<<8)!=26217:0)|(g[a+112|0]<0|j[a+111|0]>128)){break a}while(1){b=a+c|0;d=g[b+113|0];if(!(((d&255)>>>0<254?(d|0)<=-1:0)|(j[b+241|0]?0:(d|0)>=0)|j[b+369|0]>=64)){b=1;c=c+1|0;if((c|0)!=128){continue}break a}break}b=0}return b}function UG(a){var b=0;i[a+4116>>2]=0;i[a+4132>>2]=0;i[a+4136>>2]=0;h[a+4128>>1]=0;i[a+4104>>2]=0;i[a+4108>>2]=0;b=a+4140|0;i[b>>2]=0;i[b+4>>2]=0;b=a+4148|0;i[b>>2]=0;i[b+4>>2]=0;TG(a+4164|0);TG(a+4156|0);so(a+54060|0);so(a+62252|0);so(a+70444|0);so(a+78636|0);yb(a+4332|0,0,32768);Tx(a+37100|0);yb(a+37612|0,0,16384)}function TI(a){var b=0,c=0;a:{if((j[a|0]|j[a+1|0]<<8|(j[a+2|0]<<16|j[a+3|0]<<24))!=-1641380927){break a}b=a+12|0;if(!(j[b|0]|j[b+1|0]<<8|(j[b+2|0]<<16|j[b+3|0]<<24))){break a}b=a+20|0;if(!(j[b|0]|j[b+1|0]<<8|(j[b+2|0]<<16|j[b+3|0]<<24))){break a}a=a+28|0;c=(j[a|0]|j[a+1|0]<<8|(j[a+2|0]<<16|j[a+3|0]<<24))!=0}return c}function xw(a,b,c){var d=0,e=0,f=0;e=Xa-16|0;Xa=e;a:{b=Ija(e,a,b);if(i[b+4>>2]!=i[b+8>>2]){while(1){d=fb(a);f=i[b+4>>2];i[114610]=0;G(1581,d|0,f|0,c|0);d=i[114610];i[114610]=0;if((d|0)==1){break a}d=i[b+4>>2]+52|0;i[b+4>>2]=d;if((d|0)!=i[b+8>>2]){continue}break}}sb(b);Xa=e+16|0;return}a=B()|0;A()|0;sb(b);E(a|0);x()}function Xja(a,b,c){var d=0,e=0,f=0;e=Xa-16|0;Xa=e;i[e+8>>2]=a;if((b|0)>=1){while(1){d=i[e+8>>2];a=c;f=j[a|0]|j[a+1|0]<<8|(j[a+2|0]<<16|j[a+3|0]<<24);g[d|0]=f;g[d+1|0]=f>>>8;g[d+2|0]=f>>>16;g[d+3|0]=f>>>24;a=j[a+4|0]|j[a+5|0]<<8;g[d+4|0]=a;g[d+5|0]=a>>>8;a=(b|0)>1;jk(e+8|0);b=b+ -1|0;if(a){continue}break}}Xa=e+16|0}function Usa(a,b){var c=0,d=0,e=0,f=0;c=Xa-16|0;Xa=c;fb(b);f=XL(a,c+8|0);a:{d=Wb(b);if(!d){break a}i[114610]=0;D(921,a|0,d|0);e=i[114610];i[114610]=0;if((e|0)!=1){e=i[b+4>>2];b=i[b>>2];i[114610]=0;J(1196,a|0,b|0,e|0,d|0);b=i[114610];i[114610]=0;if((b|0)!=1){break a}}a=B()|0;A()|0;pt(f);E(a|0);x()}Xa=c+16|0;return a}function UEa(a,b){var c=0,d=0,e=0;d=ni(a+8|0);i[114610]=0;c=F(548,b|0)|0;e=i[114610];i[114610]=0;a:{b:{if((e|0)==1){break b}i[114610]=0;G(421,a|0,b|0,c|0);c=i[114610];i[114610]=0;if((c|0)==1){break b}a=i[a>>2];i[114610]=0;C(338,b|0,a|0)|0;a=i[114610];i[114610]=0;if((a|0)!=1){break a}}a=B()|0;A()|0;ug(d);E(a|0);x()}}function Fja(a,b){var c=0,d=0,e=0,f=0;c=Xa-16|0;Xa=c;fb(b);f=pI(a,c+8|0);a:{d=If(b);if(!d){break a}i[114610]=0;D(683,a|0,d|0);e=i[114610];i[114610]=0;if((e|0)!=1){e=i[b+4>>2];b=i[b>>2];i[114610]=0;J(1590,a|0,b|0,e|0,d|0);b=i[114610];i[114610]=0;if((b|0)!=1){break a}}a=B()|0;A()|0;Qs(f);E(a|0);x()}Xa=c+16|0;return a}function qua(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=i[a+96>>2];e=i[a+92>>2];if(d|e){if(c){while(1){f=g<<3;h=f+b|0;e=e-(((-2147483648-e>>>31|0)+ -1&255)+e>>8)|0;i[h>>2]=e+i[h>>2];f=(f|4)+b|0;d=d-(((-2147483648-d>>>31|0)+ -1&255)+d>>8)|0;i[f>>2]=d+i[f>>2];g=g+1|0;if((g|0)!=(c|0)){continue}break}}i[a+96>>2]=d;i[a+92>>2]=e}}function iea(){var a=0,b=0;i[114610]=0;a=R(1988)|0;b=i[114610];i[114610]=0;a:{if((b|0)==1){a=H(0)|0;A()|0;M(a|0)|0;i[114610]=0;J(1989,34080,0,0,0);a=i[114610];i[114610]=0;if((a|0)==1){break a}O();a=0}return a|0}b=B()|0;A()|0;i[114610]=0;K(20);a=i[114610];i[114610]=0;if((a|0)!=1){E(b|0);x()}a=H(0)|0;A()|0;gb(a);x()}function hqa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=Xa-16|0;Xa=e;i[e+12>>2]=c>>>2;i[e+8>>2]=i[a>>2];d=i[rb(e+12|0,e+8|0)>>2];b=jb(b);if(d){a=i[a+20>>2];c=d;while(1){jb(j[b|0]);jb(j[b+1|0]);f=a,g=jb(j[b+2|0])|jb(j[b+3|0])<<8,h[f>>1]=g;a=a+2|0;b=b+4|0;c=c+ -1|0;if(c){continue}break}}Xa=e+16|0;return d<<2}function gqa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=Xa-16|0;Xa=e;i[e+12>>2]=c>>>2;i[e+8>>2]=i[a>>2];d=i[rb(e+12|0,e+8|0)>>2];b=jb(b);if(d){a=i[a+20>>2];c=d;while(1){jb(j[b+3|0]);jb(j[b+2|0]);f=a,g=jb(j[b+1|0])|jb(j[b|0])<<8,h[f>>1]=g;a=a+2|0;b=b+4|0;c=c+ -1|0;if(c){continue}break}}Xa=e+16|0;return d<<2}function gea(){var a=0,b=0;i[114610]=0;a=R(1992)|0;b=i[114610];i[114610]=0;a:{if((b|0)==1){a=H(0)|0;A()|0;M(a|0)|0;i[114610]=0;J(1989,34108,0,0,0);a=i[114610];i[114610]=0;if((a|0)==1){break a}O();a=0}return a|0}b=B()|0;A()|0;i[114610]=0;K(20);a=i[114610];i[114610]=0;if((a|0)!=1){E(b|0);x()}a=H(0)|0;A()|0;gb(a);x()}function cK(a,b,c){var d=0,e=0,f=0;e=Xa-16|0;Xa=e;a:{b=fk(e,a,b);if(i[b+4>>2]!=i[b+8>>2]){while(1){d=fb(a);f=i[b+4>>2];i[114610]=0;G(1382,d|0,f|0,c|0);d=i[114610];i[114610]=0;if((d|0)==1){break a}d=i[b+4>>2]+24|0;i[b+4>>2]=d;if((d|0)!=i[b+8>>2]){continue}break}}sb(b);Xa=e+16|0;return}a=B()|0;A()|0;sb(b);E(a|0);x()}function Uda(){var a=0,b=0;i[114610]=0;a=R(2004)|0;b=i[114610];i[114610]=0;a:{if((b|0)==1){a=H(0)|0;A()|0;M(a|0)|0;i[114610]=0;J(1989,34520,0,0,0);a=i[114610];i[114610]=0;if((a|0)==1){break a}O();a=0}return a|0}b=B()|0;A()|0;i[114610]=0;K(20);a=i[114610];i[114610]=0;if((a|0)!=1){E(b|0);x()}a=H(0)|0;A()|0;gb(a);x()}function Jx(a,b,c){var d=0,e=0,f=0;e=Xa-16|0;Xa=e;a:{b=yn(e,a,b);if(i[b+4>>2]!=i[b+8>>2]){while(1){d=fb(a);f=i[b+4>>2];i[114610]=0;G(1178,d|0,f|0,c|0);d=i[114610];i[114610]=0;if((d|0)==1){break a}d=i[b+4>>2]+32|0;i[b+4>>2]=d;if((d|0)!=i[b+8>>2]){continue}break}}sb(b);Xa=e+16|0;return}a=B()|0;A()|0;sb(b);E(a|0);x()}function sw(a,b,c){var d=0,e=0,f=0;e=Xa-16|0;Xa=e;a:{b=Yd(e,a,b);if(i[b+4>>2]!=i[b+8>>2]){while(1){d=fb(a);f=i[b+4>>2];i[114610]=0;G(1604,d|0,f|0,c|0);d=i[114610];i[114610]=0;if((d|0)==1){break a}d=i[b+4>>2]+4|0;i[b+4>>2]=d;if((d|0)!=i[b+8>>2]){continue}break}}sb(b);Xa=e+16|0;return}a=B()|0;A()|0;sb(b);E(a|0);x()}function qM(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=Xa-16|0;Xa=c;e=bua(a);a=b+236|0;b=ms(a);a:{if((a|0)!=(b|0)){while(1){d=k[a>>1];h[c+14>>1]=d;if(d){i[114610]=0;G(1164,c|0,e|0,c+14|0);d=i[114610];i[114610]=0;if((d|0)==1){break a}}a=a+2|0;if((b|0)!=(a|0)){continue}break}}Xa=c+16|0;return}a=B()|0;A()|0;_o(e);E(a|0);x()}function a6(a,b,c){var d=0,e=0,f=0;d=j[a+769|0];e=o(d,72)+c|0;Tb(e+2304|0,e,o(j[a+768|0]-d|0,72));if(j[a+768|0]){e=0;while(1){d=0;while(1){f=(d<<2)+c|0;m[f>>2]=m[f>>2]*m[b>>2];f=f+2304|0;m[f>>2]=m[f>>2]*m[b+12>>2];d=d+1|0;if((d|0)!=12){continue}break}b=b+24|0;c=c+72|0;e=e+1|0;if(e>>>0<j[a+768|0]){continue}break}}}function yha(a,b){var c=0,d=0,e=0;d=Xa-16|0;Xa=d;a:{b=uha(d,a,b);if(i[b+4>>2]!=i[b+8>>2]){while(1){c=fb(a);e=i[b+4>>2];i[114610]=0;D(1650,c|0,e|0);c=i[114610];i[114610]=0;if((c|0)==1){break a}c=i[b+4>>2]+2048|0;i[b+4>>2]=c;if((c|0)!=i[b+8>>2]){continue}break}}sb(b);Xa=d+16|0;return}a=B()|0;A()|0;sb(b);E(a|0);x()}function HT(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;e=a;a=b+18|0;d=b+46|0;b=Ic(e,j[a|0]&2?16:8,1,0,(j[d|0]^-1)&1);if(!(!(j[a|0]&4)|c>>>0<532)){jA(b)}if(j[a|0]&8){cj(b,j[d|0]&4?5:4);return}if(!(j[a|0]&2|j[d|0]!=255)){cj(b,11);return}if(j[d|0]&2){g[b+2|0]=1}if(j[d|0]&4){cj(b,2)}if(!(!(j[d|0]&8)|!(j[a|0]&2))){cj(b,9)}}function zma(a,b,c){var d=0,e=0;d=Xa-16|0;Xa=d;a=a+1074308|0;kb(d+8|0,a,28);a:{if(ib(d+8|0)){i[c>>2]=i[c>>2]+h[b+788>>1];Kd(c,0,64);break a}kb(d+8|0,a,1);e=ib(d+8|0);a=h[b+788>>1];if(e){i[c>>2]=a+i[c>>2];Kd(c,0,256);break a}i[b+688>>2]=a+i[b+688>>2];Kd(b+688|0,0,256);i[c>>2]=i[b+688>>2];h[b+788>>1]=0}Xa=d+16|0}function yLa(a,b){var c=0;c=Xa-32|0;Xa=c;i[c+16>>2]=b;i[c+24>>2]=a;a:{b:{if(!pb(c+24|0,c+16|0)){break b}i[c+8>>2]=i[c+24>>2];if(!pb(Gd(c+8|0),c+16|0)){break b}while(1){if(al(i[c+24>>2],i[c+8>>2])){a=i[c+24>>2];break a}i[c+24>>2]=i[c+8>>2];if(pb(Gd(c+8|0),c+16|0)){continue}break}}a=i[c+16>>2]}Xa=c+32|0;return a}function xJa(a,b){a=a|0;b=b|0;var c=0;Bs(a,b);Xi(b);a=j[b+3|0];a:{if((a|0)!=9){if((a|0)!=19){break a}a=j[b+5|0];c=a&240;if((c|0)!=128){if((c|0)!=64){if((c|0)!=48|a>>>0>49){break a}g[b+5|0]=159;g[b+3|0]=20;return}if((a|0)!=64){break a}g[b+3|0]=0;g[b|0]=254;return}g[b+3|0]=20;g[b+5|0]=a&15|160;return}g[b+3|0]=0}}function sT(a,b){var c=0,d=0,e=0,f=0;c=Xa-16|0;Xa=c;a:{if(!b){break a}if(!wb(a,b)){break a}f=1;while(1){g[c+13|0]=0;e=(c+14|0)+d|0;b:{if(d>>>0<b>>>0){Bf(a,c+13|0);d=j[c+13|0];break b}g[c+13|0]=0;d=0}g[e|0]=d;d=1;e=f;f=0;if(e){continue}break}h[c+10>>1]=k[c+14>>1];a=c+10|0;d=j[a|0]|j[a+1|0]<<8}Xa=c+16|0;return d}function qY(a,b){var c=0,d=0,e=0;a:{b:{while(1){if(j[c+68592|0]!=(a|0)){d=87;c=c+1|0;if((c|0)!=87){continue}break b}break}d=c;if(c){break b}a=68688;break a}c=68688;while(1){e=j[c|0];a=c+1|0;c=a;if(e){continue}c=a;d=d+ -1|0;if(d){continue}break}}b=i[b+20>>2];if(b){b=M2(i[b>>2],i[b+4>>2],a)}else{b=0}return b?b:a}function hAa(a,b){a=a|0;b=b|0;var c=0;b=Xa-16|0;Xa=b;c=-1;a:{if(!ff(a,8)){break a}c=0;if(!Iz(a,16612,8)){break a}c=-1;if(!fj(a,b+8|0)){break a}a=b+8|4;c=0;if(!(j[a|0]|j[a+1|0]<<8|(j[a+2|0]<<16|j[a+3|0]<<24))){break a}c=!((j[b+8|0]|j[b+9|0]<<8|(j[b+10|0]<<16|j[b+11|0]<<24))&-2139062144)}a=c;Xa=b+16|0;return a|0}function aV(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=Xa-48|0;Xa=e;An(a);i[a>>2]=77272;f=Zg(e+40|0);XU(e+24|0,b,c,d);i[114610]=0;i[e+16>>2]=i[e+32>>2];b=i[e+28>>2];i[e+8>>2]=i[e+24>>2];i[e+12>>2]=b;I(287,a+12|0,f|0,e+8|0)|0;b=i[114610];i[114610]=0;if((b|0)!=1){Xa=e+48|0;return a|0}a=B()|0;A()|0;E(a|0);x()}function A4(a,b){var c=0,d=0,e=0,f=0,g=0;f=Xa-16|0;Xa=f;d=a+8|0;bm(a,a+4|0,d);c=a+12|0;while(1){if((b|0)!=(c|0)){if(pd(c,d)){i[f+12>>2]=i[c>>2];g=c;while(1){a:{e=d;i[g>>2]=i[e>>2];if((a|0)==(e|0)){e=a;break a}g=e;d=e+ -4|0;if(pd(f+12|0,d)){continue}}break}i[e>>2]=i[f+12>>2]}d=c;c=c+4|0;continue}break}Xa=f+16|0}function oEa(a,b){var c=0,d=0,e=0;d=Xa-16|0;Xa=d;a:{b=iEa(d,a,b);if(i[b+4>>2]!=i[b+8>>2]){while(1){c=fb(a);e=i[b+4>>2];i[114610]=0;D(768,c|0,e|0);c=i[114610];i[114610]=0;if((c|0)==1){break a}c=i[b+4>>2]+33|0;i[b+4>>2]=c;if((c|0)!=i[b+8>>2]){continue}break}}sb(b);Xa=d+16|0;return}a=B()|0;A()|0;sb(b);E(a|0);x()}function nra(a,b){var c=0,d=0,e=0;d=Xa-16|0;Xa=d;a:{b=Ik(d,a,b);if(i[b+4>>2]!=i[b+8>>2]){while(1){c=fb(a);e=i[b+4>>2];i[114610]=0;D(1238,c|0,e|0);c=i[114610];i[114610]=0;if((c|0)==1){break a}c=i[b+4>>2]+12|0;i[b+4>>2]=c;if((c|0)!=i[b+8>>2]){continue}break}}sb(b);Xa=d+16|0;return}a=B()|0;A()|0;sb(b);E(a|0);x()}function lqa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=Xa-16|0;Xa=e;i[e+12>>2]=(c>>>0)/3;i[e+8>>2]=i[a>>2];d=i[rb(e+12|0,e+8|0)>>2];b=jb(b);if(d){a=i[a+20>>2];c=d;while(1){jb(j[b|0]);f=a,g=jb(j[b+1|0])|jb(j[b+2|0])<<8,h[f>>1]=g;a=a+2|0;b=b+3|0;c=c+ -1|0;if(c){continue}break}}Xa=e+16|0;return o(d,3)|0}function kqa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=Xa-16|0;Xa=e;i[e+12>>2]=(c>>>0)/3;i[e+8>>2]=i[a>>2];d=i[rb(e+12|0,e+8|0)>>2];b=jb(b);if(d){a=i[a+20>>2];c=d;while(1){jb(j[b+2|0]);f=a,g=jb(j[b+1|0])|jb(j[b|0])<<8,h[f>>1]=g;a=a+2|0;b=b+3|0;c=c+ -1|0;if(c){continue}break}}Xa=e+16|0;return o(d,3)|0}function g6(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=Xa-16|0;Xa=d;a=dF(a,d+8|0);e=lb(b);f=lb(c);b=xb(b);i[114610]=0;J(195,a|0,b|0,e|0,e+f|0);b=i[114610];i[114610]=0;a:{if((b|0)!=1){b=xb(c);i[114610]=0;I(196,a|0,b|0,f|0)|0;b=i[114610];i[114610]=0;if((b|0)!=1){break a}}b=B()|0;A()|0;eb(a);E(b|0);x()}Xa=d+16|0}function Dxa(a,b){var c=0,d=0,e=0;d=Xa-16|0;Xa=d;a:{b=Ik(d,a,b);if(i[b+4>>2]!=i[b+8>>2]){while(1){c=fb(a);e=i[b+4>>2];i[114610]=0;D(1025,c|0,e|0);c=i[114610];i[114610]=0;if((c|0)==1){break a}c=i[b+4>>2]+12|0;i[b+4>>2]=c;if((c|0)!=i[b+8>>2]){continue}break}}sb(b);Xa=d+16|0;return}a=B()|0;A()|0;sb(b);E(a|0);x()}function oFa(a,b){var c=0,d=0,e=0;d=Xa-16|0;Xa=d;a:{b=gR(d,a,b);if(i[b+4>>2]!=i[b+8>>2]){while(1){c=fb(a);e=i[b+4>>2];i[114610]=0;D(744,c|0,e|0);c=i[114610];i[114610]=0;if((c|0)==1){break a}c=i[b+4>>2]+48|0;i[b+4>>2]=c;if((c|0)!=i[b+8>>2]){continue}break}}sb(b);Xa=d+16|0;return}a=B()|0;A()|0;sb(b);E(a|0);x()}function nha(a,b){var c=0,d=0,e=0;d=Xa-16|0;Xa=d;a:{b=Yd(d,a,b);if(i[b+4>>2]!=i[b+8>>2]){while(1){c=fb(a);e=i[b+4>>2];i[114610]=0;D(1652,c|0,e|0);c=i[114610];i[114610]=0;if((c|0)==1){break a}c=i[b+4>>2]+4|0;i[b+4>>2]=c;if((c|0)!=i[b+8>>2]){continue}break}}sb(b);Xa=d+16|0;return}a=B()|0;A()|0;sb(b);E(a|0);x()}function eba(a,b){var c=0,d=0,e=0,f=0;c=Xa-16|0;Xa=c;fb(b);f=dba(a,c+8|0);a:{d=Wc(b);if(!d){break a}i[114610]=0;D(2122,a|0,d|0);e=i[114610];i[114610]=0;if((e|0)!=1){e=i[b+4>>2];b=i[b>>2];i[114610]=0;J(2123,a|0,b|0,e|0,d|0);a=i[114610];i[114610]=0;if((a|0)!=1){break a}}a=B()|0;A()|0;DG(f);E(a|0);x()}Xa=c+16|0}function YZ(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=Xa-16|0;Xa=f;i[e>>2]=c;a=Fu(f+12|0,0,b,i[a+8>>2]);c=2;a:{if(a+1>>>0<2){break a}b=a+ -1|0;c=1;if(b>>>0>d-i[e>>2]>>>0){break a}c=f+12|0;while(1){if(b){a=j[c|0];d=i[e>>2];i[e>>2]=d+1;g[d|0]=a;b=b+ -1|0;c=c+1|0;continue}break}c=0}Xa=f+16|0;return c|0}function RH(a){a=a|0;var b=0,c=0;c=Xa-16|0;Xa=c;b=i[a+4232>>2];b=(b>>>1)+(b>>>6)|0;i[a+4220>>2]=b;i[114610]=0;i[c+12>>2]=0;G(1647,a+4208|0,b<<1,c+12|0);b=i[114610];i[114610]=0;a:{if((b|0)==1){b=H(71348)|0;if((A()|0)!=(U(71348)|0)){break a}M(b|0)|0;i[a+4220>>2]=0;O()}i[a+4224>>2]=0;Xa=c+16|0;return}E(b|0);x()}function Eia(a,b){var c=0,d=0,e=0;d=Xa-16|0;Xa=d;a:{b=Yd(d,a,b);if(i[b+4>>2]!=i[b+8>>2]){while(1){c=fb(a);e=i[b+4>>2];i[114610]=0;D(1621,c|0,e|0);c=i[114610];i[114610]=0;if((c|0)==1){break a}c=i[b+4>>2]+4|0;i[b+4>>2]=c;if((c|0)!=i[b+8>>2]){continue}break}}sb(b);Xa=d+16|0;return}a=B()|0;A()|0;sb(b);E(a|0);x()}function wN(a,b){a=a|0;b=b|0;var c=0;c=Xa-48|0;Xa=c;i[a>>2]=0;i[a+4>>2]=0;i[c+44>>2]=0;fb(b);Fc(a+8|0,c+44|0,c+40|0);if(i[b+4>>2]){Cp(a,i[b+4>>2]);Wi(c+32|0,b);Uj(c+24|0,b);b=i[c+36>>2];i[c+16>>2]=i[c+32>>2];i[c+20>>2]=b;b=i[c+28>>2];i[c+8>>2]=i[c+24>>2];i[c+12>>2]=b;Mya(a,c+16|0,c+8|0)}Xa=c+48|0;return a|0}function uya(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;b=Xa-16|0;Xa=b;e=te(1);i[114610]=0;c=C(85,b|0,1434)|0;d=i[114610];i[114610]=0;a:{b:{if((d|0)!=1){i[114610]=0;d=C(86,e|0,c|0)|0;f=i[114610];i[114610]=0;if((f|0)==1){break b}Rxa(a,d);eb(c);Xa=b+16|0;return}a=B()|0;A()|0;break a}a=B()|0;A()|0;eb(c)}Cb(e);E(a|0);x()}function tFa(a,b){var c=0,d=0,e=0;d=Xa-16|0;Xa=d;a:{b=Yd(d,a,b);if(i[b+4>>2]!=i[b+8>>2]){while(1){c=fb(a);e=i[b+4>>2];i[114610]=0;D(743,c|0,e|0);c=i[114610];i[114610]=0;if((c|0)==1){break a}c=i[b+4>>2]+4|0;i[b+4>>2]=c;if((c|0)!=i[b+8>>2]){continue}break}}sb(b);Xa=d+16|0;return}a=B()|0;A()|0;sb(b);E(a|0);x()}function tAa(a,b){var c=0,d=0,e=0;d=Xa-16|0;Xa=d;a:{b=Qp(d,a,b);if(i[b+4>>2]!=i[b+8>>2]){while(1){c=fb(a);e=i[b+4>>2];i[114610]=0;D(927,c|0,e|0);c=i[114610];i[114610]=0;if((c|0)==1){break a}c=i[b+4>>2]+8|0;i[b+4>>2]=c;if((c|0)!=i[b+8>>2]){continue}break}}sb(b);Xa=d+16|0;return}a=B()|0;A()|0;sb(b);E(a|0);x()}function mY(a,b,c,d){var e=0,f=0,h=0,j=0,k=0;h=Xa-16|0;Xa=h;f=lb(a);if(f>>>0>=b>>>0){if(c){e=qc(a);a:{if(e-f>>>0>=c>>>0){e=xb(a);j=f-b|0;if(!j){break a}k=b+e|0;Cl(k+c|0,k,j);break a}rl(a,e,(c+f|0)-e|0,f,b,0,c);e=i[a>>2]}ey(b+e|0,c,d);b=a;a=c+f|0;yg(b,a);g[h+15|0]=0;Rd(a+e|0,h+15|0)}Xa=h+16|0;return}Ml();x()}function ZCa(a,b){var c=0,d=0,e=0;d=Xa-16|0;Xa=d;a:{b=Yd(d,a,b);if(i[b+4>>2]!=i[b+8>>2]){while(1){c=fb(a);e=i[b+4>>2];i[114610]=0;D(825,c|0,e|0);c=i[114610];i[114610]=0;if((c|0)==1){break a}c=i[b+4>>2]+4|0;i[b+4>>2]=c;if((c|0)!=i[b+8>>2]){continue}break}}sb(b);Xa=d+16|0;return}a=B()|0;A()|0;sb(b);E(a|0);x()}function X1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=p(0),f=0;d=Xa-16|0;Xa=d;a:{if((a|0)!=(b|0)){f=i[114584];i[114584]=0;Ud();e=A2(a,d+12|0);a=i[114584];b:{if(a){if(i[d+12>>2]!=(b|0)){break b}if((a|0)!=68){break a}i[c>>2]=4;break a}i[114584]=f;if(i[d+12>>2]==(b|0)){break a}}}i[c>>2]=4;e=p(0)}Xa=d+16|0;return p(e)}function Uja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=Xa-16|0;Xa=d;i[d+12>>2]=b;a:{if(Mi(a)>>>0>=b>>>0){f=d,g=bf(a),i[f+8>>2]=g;Jja(i[a>>2],i[rb(d+12|0,d+8|0)>>2],c);b=i[d+12>>2];e=i[d+8>>2];if(b>>>0>e>>>0){xw(a,b-e|0,c);break a}wI(a,i[a>>2]+o(b,52)|0);break a}Sja(a);Rja(a,vI(a,b));xw(a,b,c)}Xa=d+16|0}function TW(a,b){var c=0,d=0,e=0;d=Xa-16|0;Xa=d;a:{b=Kl(d,a,b);if(i[b+4>>2]!=i[b+8>>2]){while(1){c=fb(a);e=i[b+4>>2];i[114610]=0;D(216,c|0,e|0);c=i[114610];i[114610]=0;if((c|0)==1){break a}c=i[b+4>>2]+16|0;i[b+4>>2]=c;if((c|0)!=i[b+8>>2]){continue}break}}sb(b);Xa=d+16|0;return}a=B()|0;A()|0;sb(b);E(a|0);x()}function PCa(a,b){var c=0,d=0,e=0;d=Xa-16|0;Xa=d;a:{b=vh(d,a,b);if(i[b+4>>2]!=i[b+8>>2]){while(1){c=fb(a);e=i[b+4>>2];i[114610]=0;D(832,c|0,e|0);c=i[114610];i[114610]=0;if((c|0)==1){break a}c=i[b+4>>2]+2|0;i[b+4>>2]=c;if((c|0)!=i[b+8>>2]){continue}break}}sb(b);Xa=d+16|0;return}a=B()|0;A()|0;sb(b);E(a|0);x()}function FLa(a,b){var c=0,d=0,e=0;d=Xa-16|0;Xa=d;a:{b=vh(d,a,b);if(i[b+4>>2]!=i[b+8>>2]){while(1){c=fb(a);e=i[b+4>>2];i[114610]=0;D(425,c|0,e|0);c=i[114610];i[114610]=0;if((c|0)==1){break a}c=i[b+4>>2]+2|0;i[b+4>>2]=c;if((c|0)!=i[b+8>>2]){continue}break}}sb(b);Xa=d+16|0;return}a=B()|0;A()|0;sb(b);E(a|0);x()}function Qf(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;d=Xa-16|0;Xa=d;g=a;h=a;a:{if(!b){b=0;break a}c=b>>31;e=c+b^c;c=r(e);kf(d,e,0,0,0,c+81|0);c=(i[d+12>>2]^65536)+(16414-c<<16)|0;e=0+i[d+8>>2]|0;if(e>>>0<f>>>0){c=c+1|0}f=b&-2147483648|c;c=i[d+4>>2];b=i[d>>2]}i[h>>2]=b;i[g+4>>2]=c;i[a+8>>2]=e;i[a+12>>2]=f;Xa=d+16|0}function NW(a,b){var c=0,d=0,e=0;d=Xa-16|0;Xa=d;a:{b=ql(d,a,b);if(i[b+4>>2]!=i[b+8>>2]){while(1){c=fb(a);e=i[b+4>>2];i[114610]=0;D(218,c|0,e|0);c=i[114610];i[114610]=0;if((c|0)==1){break a}c=i[b+4>>2]+1|0;i[b+4>>2]=c;if((c|0)!=i[b+8>>2]){continue}break}}sb(b);Xa=d+16|0;return}a=B()|0;A()|0;sb(b);E(a|0);x()}function JMa(a,b){var c=0;kd(b,0);i[b+24>>2]=8363;c=a+13|0;i[b>>2]=j[c|0]|j[c+1|0]<<8|(j[c+2|0]<<16|j[c+3|0]<<24);c=a+17|0;i[b+4>>2]=j[c|0]|j[c+1|0]<<8|(j[c+2|0]<<16|j[c+3|0]<<24);a=a+21|0;a=j[a|0]|j[a+1|0]<<8|(j[a+2|0]<<16|j[a+3|0]<<24);a=a>>>0>l[b>>2]?i[b+4>>2]?a:0:a;i[b+8>>2]=a;if(a){h[b+34>>1]=2;Nm(b)}}function ET(a,b){var c=0,d=0,e=0;d=Xa-16|0;Xa=d;a:{b=Yd(d,a,b);if(i[b+4>>2]!=i[b+8>>2]){while(1){c=fb(a);e=i[b+4>>2];i[114610]=0;D(371,c|0,e|0);c=i[114610];i[114610]=0;if((c|0)==1){break a}c=i[b+4>>2]+4|0;i[b+4>>2]=c;if((c|0)!=i[b+8>>2]){continue}break}}sb(b);Xa=d+16|0;return}a=B()|0;A()|0;sb(b);E(a|0);x()}function Cwa(a){var b=0,c=0;b=Xa-80|0;Xa=b;i[b+76>>2]=0;c=Bb(b- -64|0,18046);i[114610]=0;D(512,b+48|0,a|0);a=i[114610];i[114610]=0;a:{b:{c:{if((a|0)==1){break c}i[114610]=0;C(470,b+48|0,c|0)|0;a=i[114610];i[114610]=0;if((a|0)==1){break c}eb(c);break b}a=B()|0;A()|0;eb(c);break a}Xa=b+80|0;return}E(a|0);x()}function hI(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=Xa-16|0;Xa=d;i[d+12>>2]=b;a:{if(gd(a)>>>0>=b>>>0){f=d,g=qb(a),i[f+8>>2]=g;wia(i[a>>2],i[rb(d+12|0,d+8|0)>>2],c);b=i[d+12>>2];e=i[d+8>>2];if(b>>>0>e>>>0){sw(a,b-e|0,c);break a}vw(a,i[a>>2]+(b<<2)|0);break a}_ia(a);Zia(a,ge(a,b));sw(a,b,c)}Xa=d+16|0}function fpa(a,b,c){var d=0,e=0,f=0,g=0;d=Xa-16|0;Xa=d;i[d+12>>2]=b;a:{if(Be(a)>>>0>=b>>>0){f=d,g=nd(a),i[f+8>>2]=g;Boa(i[a>>2],i[rb(d+12|0,d+8|0)>>2],c);b=i[d+12>>2];e=i[d+8>>2];if(b>>>0>e>>>0){cK(a,b-e|0,c);break a}b=i[a>>2]+o(b,24)|0;nd(a);dK(a,b);To(a);break a}Doa(a);Coa(a,ek(a,b));cK(a,b,c)}Xa=d+16|0}function Lr(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=Xa-16|0;Xa=e;if(b){kb(e+8|0,a+1074308|0,73);k=ib(e+8|0)?c- -64|0:c;c=120;i=wo(a);l=i^-1;f=1;while(1){g=c>>>1|0;j=g+f|0;h=Vf(a,j,k,d);a:{if(!(h>>>0>b>>>0&l|!h|h>>>0<b>>>0&i)){c=g;break a}f=j+1|0;c=(g^-1)+c|0}if(c){continue}break}}Xa=e+16|0;return f}function Fqa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,h=0;d=Xa-16|0;Xa=d;i[d+12>>2]=c>>>1;i[d+8>>2]=i[a>>2];e=i[rb(d+12|0,d+8|0)>>2];b=jb(b);if(e){a=i[a+20>>2];c=e;while(1){f=a,h=jb(j[b|0])^128,g[f|0]=h;f=a,h=jb(j[b+1|0])^128,g[f+1|0]=h;a=a+2|0;b=b+2|0;c=c+ -1|0;if(c){continue}break}}Xa=d+16|0;return e<<1}function Eqa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,h=0;e=Xa-16|0;Xa=e;i[e+12>>2]=c>>>1;i[e+8>>2]=i[a>>2];f=i[rb(e+12|0,e+8|0)>>2];b=jb(b);if(f){a=i[a+20>>2];c=f;h=d;while(1){h=jb(j[b|0])+h|0;g[a|0]=h;d=jb(j[b+1|0])+d|0;g[a+1|0]=d;a=a+2|0;b=b+2|0;c=c+ -1|0;if(c){continue}break}}Xa=e+16|0;return f<<1}function B0(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=Xa-32|0;Xa=g;h=i[15591];i[g+24>>2]=i[15590];i[g+28>>2]=h;h=i[15589];i[g+16>>2]=i[15588];i[g+20>>2]=h;h=i[15587];i[g+8>>2]=i[15586];i[g+12>>2]=h;h=i[15585];i[g>>2]=i[15584];i[g+4>>2]=h;a=Bi(a,b,c,d,e,f,g,g+32|0);Xa=g+32|0;return a|0}function uJ(a,b,c){var d=0,e=0,f=0,g=0;d=Xa-16|0;Xa=d;e=pi(b,c);a:{if(e>>>0<=xf(a)>>>0){i[d+12>>2]=c;if(e>>>0>rc(a)>>>0){i[d+12>>2]=b;f=d,g=rc(a)+i[d+12>>2]|0,i[f+12>>2]=g;Oe(b,i[d+12>>2],i[a>>2]);cy(a,i[d+12>>2],c,e-rc(a)|0);break a}jR(a,Oe(b,c,i[a>>2]));break a}WK(a);BR(a,pl(a,e));cy(a,b,c,e)}Xa=d+16|0}function kka(a,b,c){var d=0,e=0,f=0;d=Xa-16|0;Xa=d;e=(c-b|0)/6|0;a:{if(e>>>0<=hi(a)>>>0){i[d+12>>2]=c;if(e>>>0>If(a)>>>0){i[d+12>>2]=b;f=If(a);i[d+12>>2]=i[d+12>>2]+o(f,6);Bw(b,i[d+12>>2],i[a>>2]);zw(a,i[d+12>>2],c,e-If(a)|0);break a}Xy(a,Bw(b,c,i[a>>2]));break a}zI(a);oQ(a,Ny(a,e));zw(a,b,c,e)}Xa=d+16|0}function Lja(a,b){a=a|0;b=b|0;var c=0,d=0;c=Xa-48|0;Xa=c;d=c+40|0;b=k[b>>1];g[d|0]=b;g[d+1|0]=b>>>8;ok(c+16|0,c+40|0);b=jb(i[c+16>>2]);ok(c+8|0,c+40|0);b=Uh(c+24|0,b,jb(i[c+8>>2]+2|0));i[114610]=0;C(1193,a|0,b|0)|0;a=i[114610];i[114610]=0;if((a|0)!=1){eb(b);Xa=c+48|0;return}a=B()|0;A()|0;eb(b);E(a|0);x()}function vd(a,b,c){var d=0,e=0,f=0,g=0;d=Xa-16|0;Xa=d;Fl(b);b=G_(d+8|0,b);a:{a=a+16|0;if(qb(a)>>>0<=c>>>0){i[114610]=0;D(2559,a|0,c+1|0);e=i[114610];i[114610]=0;if((e|0)==1){break a}}if(i[vb(a,c)>>2]){El(i[vb(a,c)>>2])}e=sd(b);f=vb(a,c),g=e,i[f>>2]=g;xC(b);Xa=d+16|0;return}a=B()|0;A()|0;xC(b);E(a|0);x()}function ffa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;b=Ph(a,b,c,d);i[a+4208>>2]=1017370378;i[a+4212>>2]=0;i[a>>2]=81364;i[114610]=0;I(1639,a+44|0,2,2)|0;c=i[114610];i[114610]=0;a:{if((c|0)==1){break a}i[114610]=0;L(1640,b|0);c=i[114610];i[114610]=0;if((c|0)==1){break a}return a|0}a=B()|0;A()|0;ve(b);E(a|0);x()}function XB(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=Xa-16|0;Xa=d;a=Zv(a,d+8|0);e=le(b);f=lb(c);i[114610]=0;J(2841,a|0,b|0,e|0,e+f|0);b=i[114610];i[114610]=0;a:{if((b|0)!=1){b=xb(c);i[114610]=0;I(2492,a|0,b|0,f|0)|0;b=i[114610];i[114610]=0;if((b|0)!=1){break a}}b=B()|0;A()|0;eb(a);E(b|0);x()}Xa=d+16|0}function Wu(a){var b=0,c=0,d=0,e=0;e=le(a);a:{if(!i[115396]|!j[a|0]){break a}b=K2(a);if(j[b|0]==61?b:0){break a}b=i[i[115396]>>2];if(!b){break a}b:{while(1){d=W4(a,b,e);b=i[115396];if(!d){d=i[b+(c<<2)>>2]+e|0;if(j[d|0]==61){break b}}c=c+1|0;b=i[b+(c<<2)>>2];if(b){continue}break}return 0}c=d+1|0}return c}function zsa(a,b,c,d){var e=0,f=0;e=Xa-16|0;Xa=e;a:{if(!j[a+530|0]){break a}f=XMa(d,0,6169,0);d=_a;d=Vc((d&65535)<<16|f>>>16,d>>>16|0);if(!c){break a}while(1){Hsa(i[a>>2],e+14|0,e+12|0);i[b>>2]=i[b>>2]+o(d,h[e+14>>1]);i[b+4>>2]=i[b+4>>2]+o(d,h[e+12>>1]);b=b+8|0;c=c+ -1|0;if(c){continue}break}}Xa=e+16|0}function tQ(a,b){var c=0,d=0,e=0,f=0,g=0;d=Xa-16|0;Xa=d;c=a+4|0;a:{if(rc(c)>>>0>=i[a+16>>2]+b>>>0){break a}if(!rc(c)){ck(c,$y(i[a+16>>2]+b|0,65536));break a}f=d,g=rc(c),i[f+12>>2]=g;e=pQ(d+12|0);a=i[a+16>>2]+b|0;if(e>>>0<a>>>0){ck(c,$y(a,65536));break a}f=d,g=rc(c),i[f+8>>2]=g;ck(c,pQ(d+8|0))}Xa=d+16|0}function dLa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=Xa-16|0;Xa=d;a:{b:{if(!ff(a,7)){break b}c=0;if(!vS(a,12222)){break a}if(!ff(a,1)){break b}c=-1;if(!Dc(a,nt(a))){break a}c=d+8|0;e=IKa(a,c);if(!e){dS(c)}c=-1;if(!e){break a}c=0;if(!qS(d+8|0)){break a}c=Le(a,b,pS(d+8|0),_a);break a}c=-1}Xa=d+16|0;return c|0}function MBa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=Xa+ -64|0;Xa=c;b=-1;a:{if(!ff(a,1084)){break a}Vj(a,1080);LO(a,c+60|0);d=KO(c+40|0);b=0;if(!JO(c+60|0,d)){break a}Vj(a,20);b=1;while(1){IO(a,c+8|0);e=xy(c+8|0)+e|0;f=b&65535;b=b+1|0;if(f>>>0<31){continue}break}b=e>>>0<=l[d+4>>2]}Xa=c- -64|0;return b|0}function tra(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=Xa-16|0;Xa=d;f=a+12|0;fM(d+8|0,f);iL(d,f);a:{if(!fs(d+8|0,d)|(c|0)==-1){break a}while(1){g=i[sra(d+8|0)>>2];zx(a,b,g,0);e=d+8|0;h=i[e+4>>2];i[d>>2]=i[e>>2];i[d+4>>2]=h;hL(e+4|0);iL(d,f);e=fs(d+8|0,d);if((c|0)==(g|0)){break a}if(e){continue}break}}Xa=d+16|0}function Qd(a){var b=p(0),c=p(0),d=0,e=0;d=(hNa(a),dNa(2));e=d>>>23&255;if(e>>>0<=149){if(e>>>0<=125){return p(a*p(0))}a=(d|0)>-1?a:p(-a);b=p(p(p(a+p(8388608))+p(-8388608))-a);a:{if(!(b>p(.5)^1)){c=p(p(a+b)+p(-1));break a}a=p(a+b);c=a;if(b<=p(-.5)^1){break a}c=p(a+p(1))}a=c;a=(d|0)>-1?a:p(-a)}return a}function wra(a,b,c,d){var e=0;e=Xa-32|0;Xa=e;a:{if(j[d|0]){d=i[b+4>>2];i[e+24>>2]=i[b>>2];i[e+28>>2]=d;b=$h(c,b);c=i[e+28>>2];i[e+8>>2]=i[e+24>>2];i[e+12>>2]=c;vra(a,e+8|0,b);break a}d=i[b+4>>2];i[e+16>>2]=i[b>>2];i[e+20>>2]=d;b=$h(c,b);c=i[e+20>>2];i[e>>2]=i[e+16>>2];i[e+4>>2]=c;ura(a,e,b)}Xa=e+32|0}function uua(a,b,c,d,e){var f=p(0),g=0,h=0,j=0;if(d){while(1){h=c;f=p(m[a>>2]*e);a:{if(p(q(f))<p(2147483648)){g=~~f;break a}g=-2147483648}i[h>>2]=g;h=c;f=p(m[b>>2]*e);b:{if(p(q(f))<p(2147483648)){g=~~f;break b}g=-2147483648}i[h+4>>2]=g;c=c+8|0;b=b+4|0;a=a+4|0;j=j+1|0;if((j|0)!=(d|0)){continue}break}}}function st(a,b,c,d,e){var f=0,g=0,l=0,m=0,n=0;f=Xa-16|0;Xa=f;i[f+12>>2]=c;kc(f+12|0,256);kc(f+12|0,65535);l=k[f+12>>1];Zf(a,l);if(l){c=0;while(1){g=j[b+c|0];a:{if((g|0)==(d|0)){g=65535;break a}if((e|0)!=(g|0)){break a}g=65534}m=lk(a,c),n=g,h[m>>1]=n;c=c+1|0;if((l|0)!=(c|0)){continue}break}}Xa=f+16|0}function fn(a,b,c,d,e){var f=0,g=0,l=0,m=0,n=0;f=Xa-16|0;Xa=f;i[f+12>>2]=c;kc(f+12|0,128);kc(f+12|0,65535);l=k[f+12>>1];Zf(a,l);if(l){c=0;while(1){g=j[b+c|0];a:{if((g|0)==(d|0)){g=65535;break a}if((e|0)!=(g|0)){break a}g=65534}m=lk(a,c),n=g,h[m>>1]=n;c=c+1|0;if((l|0)!=(c|0)){continue}break}}Xa=f+16|0}function bAa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=Xa-48|0;Xa=d;f=i[a+4>>2];e=_za(td(d+40|0,b),td(d+32|0,c))+i[a+4>>2]|0;i[a+4>>2]=e;if(!((e+ -1^f+ -1)>>>0<32?f:0)){g=i[a>>2];i[(e>>>0<33?g:(e+ -1>>>3&536870908)+g|0)>>2]=0}b=td(d+24|0,b);c=td(d+16|0,c);rn(d+8|0,a,f);Zza(d,b,c,d+8|0);Xa=d+48|0}function XZ(a){a=a|0;var b=0,c=0;b=i[a+8>>2];i[114610]=0;b=N(2575,0,0,4,b|0)|0;c=i[114610];i[114610]=0;a:{if((c|0)==1){break a}b:{if(b){a=-1}else{a=i[a+8>>2];if(a){break b}a=1}return a|0}i[114610]=0;a=F(2576,a|0)|0;b=i[114610];i[114610]=0;if((b|0)==1){break a}return(a|0)==1|0}a=H(0)|0;A()|0;gb(a);x()}function Qna(a,b){var c=0,d=0;a=Ke(a);c=lb(b);i[114610]=0;D(113,a|0,c|0);c=i[114610];i[114610]=0;if((c|0)!=1){a:{if(lb(b)){while(1){c=j[Sb(b,d)|0];i[114610]=0;D(112,a|0,c|0);c=i[114610];i[114610]=0;if((c|0)==1){break a}d=d+1|0;if(d>>>0<lb(b)>>>0){continue}break}}return}}b=B()|0;A()|0;nc(a);E(b|0);x()}function Pqa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=Xa-16|0;Xa=e;i[e+12>>2]=c>>>1;i[e+8>>2]=i[a>>2];f=i[rb(e+12|0,e+8|0)>>2];b=jb(b);if(f){a=i[a+20>>2];c=f;while(1){g=jb(j[b|0])+d|0;d=g+jb(j[b+1|0])|0;h[a>>1]=d<<8|g&255;a=a+2|0;b=b+2|0;c=c+ -1|0;if(c){continue}break}}Xa=e+16|0;return f<<1}function qna(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=Xa-16|0;Xa=d;i[d+12>>2]=b;a:{if(xf(a)>>>0>=b>>>0){f=d,g=rc(a),i[f+8>>2]=g;bj(i[a>>2],i[rb(d+12|0,d+8|0)>>2],c);b=i[d+12>>2];e=i[d+8>>2];if(b>>>0>e>>>0){at(a,b-e|0,c);break a}Jt(a,b+i[a>>2]|0);break a}pna(a);Ht(a,pl(a,b));at(a,b,c)}Xa=d+16|0}function pja(a,b){var c=0,d=0,e=0,f=0;c=Xa-16|0;Xa=c;i[114610]=0;F(1594,a+4|0)|0;d=i[114610];i[114610]=0;a:{b:{if((d|0)!=1){i[114610]=0;i[c+12>>2]=0;I(1595,a+8|0,c+12|0,b|0)|0;b=i[114610];i[114610]=0;if((b|0)!=1){break b}break a}break a}e=a,f=Pb(a),i[e>>2]=f;Xa=c+16|0;return}a=H(0)|0;A()|0;gb(a);x()}function p9(a){a=a|0;var b=0,c=0;b=Xa-32|0;Xa=b;a:{b:{if(Mh(a)){bo(b+24|0);break b}lm(b+8|0,a);i[114610]=0;D(2175,b+24|0,b+8|0);c=i[114610];i[114610]=0;if((c|0)==1){break a}We(b+8|0)}c=a+36|0;c:{if(Mh(a)){break c}c=i[b+24>>2]}a=nd(c);Ej(b+24|0);Xa=b+32|0;return a|0}a=B()|0;A()|0;We(b+8|0);E(a|0);x()}function bpa(a,b){var c=0,d=0,e=0,f=0;c=Xa-16|0;Xa=c;i[114610]=0;F(1373,a+4|0)|0;d=i[114610];i[114610]=0;a:{b:{if((d|0)!=1){i[114610]=0;i[c+12>>2]=0;I(1374,a+8|0,c+12|0,b|0)|0;b=i[114610];i[114610]=0;if((b|0)!=1){break b}break a}break a}e=a,f=Pb(a),i[e>>2]=f;Xa=c+16|0;return}a=H(0)|0;A()|0;gb(a);x()}function _ta(a,b){var c=0,d=0,e=0,f=0;c=Xa-16|0;Xa=c;i[114610]=0;F(1165,a+4|0)|0;d=i[114610];i[114610]=0;a:{b:{if((d|0)!=1){i[114610]=0;i[c+12>>2]=0;I(1166,a+8|0,c+12|0,b|0)|0;b=i[114610];i[114610]=0;if((b|0)!=1){break b}break a}break a}e=a,f=Pb(a),i[e>>2]=f;Xa=c+16|0;return}a=H(0)|0;A()|0;gb(a);x()}function Yla(a,b){var c=0,d=0,e=0,f=0;c=Xa-16|0;Xa=c;i[114610]=0;F(1521,a+4|0)|0;d=i[114610];i[114610]=0;a:{b:{if((d|0)!=1){i[114610]=0;i[c+12>>2]=0;I(1522,a+8|0,c+12|0,b|0)|0;b=i[114610];i[114610]=0;if((b|0)!=1){break b}break a}break a}e=a,f=Pb(a),i[e>>2]=f;Xa=c+16|0;return}a=H(0)|0;A()|0;gb(a);x()}function Xqa(a,b){var c=0,d=0,e=0,f=0;c=Xa-16|0;Xa=c;i[114610]=0;F(1253,a+4|0)|0;d=i[114610];i[114610]=0;a:{b:{if((d|0)!=1){i[114610]=0;i[c+12>>2]=0;I(1254,a+8|0,c+12|0,b|0)|0;b=i[114610];i[114610]=0;if((b|0)!=1){break b}break a}break a}e=a,f=Pb(a),i[e>>2]=f;Xa=c+16|0;return}a=H(0)|0;A()|0;gb(a);x()}function VI(a,b,c){var d=0,e=0,f=0,h=0;f=Xa-16|0;Xa=f;e=pi(b,c);if(e>>>0<=4294967279){a:{if(e>>>0<=10){Te(a,e);d=a;break a}h=Dk(e)+1|0;d=Ii(h);gf(a,d);fg(a,h);ce(a,e)}if((b|0)!=(c|0)){while(1){Rd(d,b);d=d+1|0;b=b+1|0;if((c|0)!=(b|0)){continue}break}}g[f+15|0]=0;Rd(d,f+15|0);Xa=f+16|0;return}gg();x()}function Hoa(a,b){var c=0,d=0,e=0,f=0;c=Xa-16|0;Xa=c;i[114610]=0;F(1376,a+4|0)|0;d=i[114610];i[114610]=0;a:{b:{if((d|0)!=1){i[114610]=0;i[c+12>>2]=0;I(1377,a+8|0,c+12|0,b|0)|0;b=i[114610];i[114610]=0;if((b|0)!=1){break b}break a}break a}e=a,f=Pb(a),i[e>>2]=f;Xa=c+16|0;return}a=H(0)|0;A()|0;gb(a);x()}function Boa(a,b,c){var d=0,e=0,f=0;if(b){while(1){d=c;e=i[d+4>>2];i[a>>2]=i[d>>2];i[a+4>>2]=e;e=k[d+18>>1]|k[d+20>>1]<<16;f=k[d+14>>1]|k[d+16>>1]<<16;h[a+14>>1]=f;h[a+16>>1]=f>>>16;h[a+18>>1]=e;h[a+20>>1]=e>>>16;e=i[d+12>>2];i[a+8>>2]=i[d+8>>2];i[a+12>>2]=e;a=a+24|0;b=b+ -1|0;if(b){continue}break}}}function U1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=Xa-16|0;Xa=d;a:{if((a|0)!=(b|0)){f=i[114584];i[114584]=0;Ud();e=z2(a,d+12|0);a=i[114584];b:{if(a){if(i[d+12>>2]!=(b|0)){break b}if((a|0)!=68){break a}i[c>>2]=4;break a}i[114584]=f;if(i[d+12>>2]==(b|0)){break a}}}i[c>>2]=4;e=0}Xa=d+16|0;return+e}function ym(a,b,c,d){var e=0;a:{if(b>>>0>255){break a}b:{c:{d:{e:{switch(c|0){case 1:break b;case 3:break c;case 0:break d;case 2:break e;default:break a}}e=BK(a,b,d);if(e+ -251>>>0<5){break d}if(e){break a}}return AK(a,b,d)}e=AK(a,b,d);if(e+ -251>>>0<5){break b}if(e){break a}}e=BK(a,b,d)}return e}function vwa(a){var b=0,c=0,d=0;d=a+32|0;while(1){b=j[a|0];a:{b:{if((b+ -97&255)>>>0<=5){c=b+ -32|0;break b}c=99;c:{if(b>>>0<=106){if(b+ -88>>>0<2){break c}if((b|0)==75){break b}break a}if(b+ -120>>>0<2){break c}if((b|0)==107){break b}break a}c=122}g[a|0]=c}a=a+1|0;if((d|0)!=(a|0)){continue}break}}function jDa(a,b){var c=0,d=0,e=0,f=0;c=Xa-16|0;Xa=c;i[114610]=0;F(819,a+4|0)|0;d=i[114610];i[114610]=0;a:{b:{if((d|0)!=1){i[114610]=0;i[c+12>>2]=0;I(820,a+8|0,c+12|0,b|0)|0;b=i[114610];i[114610]=0;if((b|0)!=1){break b}break a}break a}e=a,f=Pb(a),i[e>>2]=f;Xa=c+16|0;return}a=H(0)|0;A()|0;gb(a);x()}function a5(a,b,c,d,e){var f=0,g=0,h=0,k=p(0),l=p(0);g=QE(a,b);a:{if((g|0)<0){break a}f=1;a=i[b>>2];h=(a|0)<(d|0)?a:d;if((h|0)<1){break a}a=o(a,g);d=0;while(1){f=(o(d,e)<<2)+c|0;l=p(m[i[b+28>>2]+(a+d<<2)>>2]+k);m[f>>2]=m[f>>2]+l;k=j[b+22|0]?l:k;f=1;d=d+1|0;if((h|0)!=(d|0)){continue}break}}return f}function VFa(a,b){var c=0,d=0,e=0,f=0;c=Xa-16|0;Xa=c;i[114610]=0;F(728,a+4|0)|0;d=i[114610];i[114610]=0;a:{b:{if((d|0)!=1){i[114610]=0;i[c+12>>2]=0;I(729,a+8|0,c+12|0,b|0)|0;b=i[114610];i[114610]=0;if((b|0)!=1){break b}break a}break a}e=a,f=Pb(a),i[e>>2]=f;Xa=c+16|0;return}a=H(0)|0;A()|0;gb(a);x()}function Gqa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,h=0;d=Xa-16|0;Xa=d;i[d+12>>2]=c>>>1;i[d+8>>2]=i[a>>2];e=i[rb(d+12|0,d+8|0)>>2];b=jb(b);if(e){a=i[a+20>>2];c=e;while(1){f=a,h=Em(j[b|0]),g[f|0]=h;f=a,h=Em(j[b+1|0]),g[f+1|0]=h;a=a+2|0;b=b+2|0;c=c+ -1|0;if(c){continue}break}}Xa=d+16|0;return e<<1}function Ai(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;c=Xa-48|0;Xa=c;a:{if(!b){b=1;if(dd(a,5)){break a}b=wC(c+32|0);e=i[d>>2];f=i[a+8>>2];i[b+4>>2]=e-f;Ue(c,i[a+28>>2]);LC(c+16|0,c,i[d>>2],i[d+4>>2]);i[b+8>>2]=i[c+24>>2]}i[a>>2]=i[a>>2]|134217728;i[a+20>>2]=i[a+20>>2]+1;b=0}Xa=c+48|0;return b|0}function zd(a,b){var c=0,d=0,e=0,f=0;d=i[a+4>>2];c=d+b|0;i[a+4>>2]=c;if((c|0)<=i[a+8>>2]){c=d&7;e=c+b|0;b=e+ -8|0;a=i[a>>2]+(d>>3)|0;f=j[a|0]&255>>>c;a:{if((e|0)<9){c=0;d=b;break a}c=0;while(1){c=f<<b|c;e=(b|0)>8;f=j[a+1|0];d=b+ -8|0;b=d;a=a+1|0;if(e){continue}break}}a=f>>>0-d|c}else{a=0}return a}function gKa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Xa-32|0;Xa=d;ai(d+16|0,d+8|0,c);i[114610]=0;D(517,d|0,d+16|0);c=i[114610];i[114610]=0;a:{if((c|0)==1){break a}i[114610]=0;G(518,a|0,b|0,d|0);a=i[114610];i[114610]=0;if((a|0)==1){break a}ob(d+16|0);Xa=d+32|0;return}a=B()|0;A()|0;ob(d+16|0);E(a|0);x()}function dm(a,b,c){var d=0,e=0,f=0;a:{if((b|0)==1&a>>>0<0|b>>>0<1){d=a;break a}while(1){d=_Ma(a,b,10,0);e=_a;f=e;e=XMa(d,e,10,0);c=c+ -1|0;g[c|0]=a-e|48;e=b>>>0>9;a=d;b=f;if(e){continue}break}}if(d){while(1){c=c+ -1|0;a=(d>>>0)/10|0;g[c|0]=d-o(a,10)|48;b=d>>>0>9;d=a;if(b){continue}break}}return c}function IGa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Xa-32|0;Xa=d;az(d+16|0,d+8|0,c);i[114610]=0;D(517,d|0,d+16|0);c=i[114610];i[114610]=0;a:{if((c|0)==1){break a}i[114610]=0;G(518,a|0,b|0,d|0);a=i[114610];i[114610]=0;if((a|0)==1){break a}ob(d+16|0);Xa=d+32|0;return}a=B()|0;A()|0;ob(d+16|0);E(a|0);x()}function iH(a,b,c){var d=0,e=0,f=0,g=0;if(p(q(a))<p(2147483648)){d=~~a}else{d=-2147483648}f=d&-2147483648;e=f?0-d|0:d;a:{if(!((e|0)<0|(b|0)<1)){while(1){d=b+ -1|0;e=e<<1;if((e|0)<0){break a}g=(b|0)>1;b=d;if(g){continue}break a}}d=b}b=(e>>>31|0)+d<<31-c|(e&2147483647)>>>c;return p((f?b^-1|f:b)|0)}function Kg(a){var b=0,c=0,d=0;c=jr(a+56|0);i[a>>2]=76744;i[c>>2]=76764;i[114610]=0;b=a+4|0;I(126,a|0,76776,b|0)|0;d=i[114610];i[114610]=0;if((d|0)!=1){a:{i[a>>2]=76744;i[c>>2]=76764;i[114610]=0;C(127,b|0,16)|0;b=i[114610];i[114610]=0;if((b|0)==1){break a}return a}}a=B()|0;A()|0;kg(c);E(a|0);x()}function oMa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Xa-32|0;Xa=d;Vz(d+16|0,d+8|0,c);i[114610]=0;D(71,d|0,d+16|0);c=i[114610];i[114610]=0;a:{if((c|0)==1){break a}i[114610]=0;G(72,a|0,b|0,d|0);a=i[114610];i[114610]=0;if((a|0)==1){break a}ob(d+16|0);Xa=d+32|0;return}a=B()|0;A()|0;ob(d+16|0);E(a|0);x()}function JEa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;if(!i[a+300>>2]){return 0}if(($a[i[a+304>>2]](i[a+296>>2],c,0,0)|0)>=0){while(1){a:{g=f;c=h;if(!d){break a}e=$a[i[a+300>>2]](i[a+296>>2],b,d)|0;d=d-e|0;b=b+e|0;f=e+g|0;if(f>>>0<e>>>0){c=c+1|0}h=c;if(e){continue}}break}}return g|0}function Gta(a,b,c){var d=0,e=0,f=0;d=Xa-16|0;Xa=d;e=zz(b,c);a:{if(e>>>0<=zf(a)>>>0){i[d+8>>2]=c;if(e>>>0>Wb(a)>>>0){i[d+8>>2]=b;f=Wb(a);i[d+8>>2]=i[d+8>>2]+(f<<1);$i(b,i[d+8>>2],i[a>>2]);hM(a,i[d+8>>2],c,e-Wb(a)|0);break a}wp(a,$i(b,c,i[a>>2]));break a}gM(a);ly(a,qi(a,e));hM(a,b,c,e)}Xa=d+16|0}function GBa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Xa-32|0;Xa=d;ai(d+16|0,d+8|0,c);i[114610]=0;D(71,d|0,d+16|0);c=i[114610];i[114610]=0;a:{if((c|0)==1){break a}i[114610]=0;G(72,a|0,b|0,d|0);a=i[114610];i[114610]=0;if((a|0)==1){break a}ob(d+16|0);Xa=d+32|0;return}a=B()|0;A()|0;ob(d+16|0);E(a|0);x()}function Bna(a,b){var c=0,d=0;c=b+4|0;d=j[c|0]|j[c+1|0]<<8|(j[c+2|0]<<16|j[c+3|0]<<24);c=i[a>>2]+20|0;if((d|0)==(j[c|0]|j[c+1|0]<<8|(j[c+2|0]<<16|j[c+3|0]<<24))){a=i[a>>2]+16|0;a=(j[b|0]|j[b+1|0]<<8|(j[b+2|0]<<16|j[b+3|0]<<24))==(j[a|0]|j[a+1|0]<<8|(j[a+2|0]<<16|j[a+3|0]<<24))}else{a=0}return a}function toa(a,b,c){var d=0,e=0,f=0;d=qe(a);e=Pb(a);a:{if(d){b:{while(1){c:{fb(a);f=d+14|0;d:{if(ZJ(c,f)){if(!i[d>>2]){break a}e=d;break d}fb(a);if(!ZJ(f,c)){break b}e=d+4|0;if(!i[d+4>>2]){break c}d=e;e=d}d=i[d>>2];continue}break}i[b>>2]=d;return e}i[b>>2]=d;return e}d=Pb(a)}i[b>>2]=d;return d}function sba(a){var b=0,c=0;b=Xa-48|0;Xa=b;vk(b);i[114610]=0;D(246,b+32|0,b|0);c=i[114610];i[114610]=0;a:{b:{if((c|0)!=1){i[114610]=0;G(9,a|0,0,b+32|0);a=i[114610];i[114610]=0;if((a|0)==1){break b}eb(b+32|0);Ie(b);Xa=b+48|0;return}a=B()|0;A()|0;break a}a=B()|0;A()|0;eb(b+32|0)}Ie(b);E(a|0);x()}function pW(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Xa-32|0;Xa=d;Il(d+16|0,d+8|0,c);i[114610]=0;D(71,d|0,d+16|0);c=i[114610];i[114610]=0;a:{if((c|0)==1){break a}i[114610]=0;G(72,a|0,b|0,d|0);a=i[114610];i[114610]=0;if((a|0)==1){break a}ob(d+16|0);Xa=d+32|0;return}a=B()|0;A()|0;ob(d+16|0);E(a|0);x()}function loa(a,b,c){var d=0,e=0,f=0;d=qe(a);e=Pb(a);a:{if(d){b:{while(1){c:{fb(a);f=d+16|0;d:{if(XJ(c,f)){if(!i[d>>2]){break a}e=d;break d}fb(a);if(!XJ(f,c)){break b}e=d+4|0;if(!i[d+4>>2]){break c}d=e;e=d}d=i[d>>2];continue}break}i[b>>2]=d;return e}i[b>>2]=d;return e}d=Pb(a)}i[b>>2]=d;return d}function Y6(a,b,c){var d=0,e=0;d=Xa-32|0;Xa=d;i[d+24>>2]=c;a:{if((a|0)!=(b|0)){while(1){c=Bb(d+8|0,i[a>>2]);i[114610]=0;C(2208,d+24|0,c|0)|0;e=i[114610];i[114610]=0;if((e|0)==1){break a}eb(c);a=a+4|0;if((b|0)!=(a|0)){continue}break}c=i[d+24>>2]}Xa=d+32|0;return c}a=B()|0;A()|0;eb(c);E(a|0);x()}function Tta(a,b,c){var d=0,e=0,f=0;d=qe(a);e=Pb(a);a:{if(d){b:{while(1){c:{f=d+14|0;d:{if(vn(fb(a),c,f)){if(!i[d>>2]){break a}e=d;break d}if(!vn(fb(a),f,c)){break b}e=d+4|0;if(!i[d+4>>2]){break c}d=e;e=d}d=i[d>>2];continue}break}i[b>>2]=d;return e}i[b>>2]=d;return e}d=Pb(a)}i[b>>2]=d;return d}function Tqa(a,b,c){var d=0,e=0,f=0;d=qe(a);e=Pb(a);a:{if(d){b:{while(1){c:{f=d+16|0;d:{if(Xr(fb(a),c,f)){if(!i[d>>2]){break a}e=d;break d}if(!Xr(fb(a),f,c)){break b}e=d+4|0;if(!i[d+4>>2]){break c}d=e;e=d}d=i[d>>2];continue}break}i[b>>2]=d;return e}i[b>>2]=d;return e}d=Pb(a)}i[b>>2]=d;return d}function Sla(a,b,c){var d=0,e=0,f=0;d=qe(a);e=Pb(a);a:{if(d){b:{while(1){c:{f=d+16|0;d:{if(XI(fb(a),c,f)){if(!i[d>>2]){break a}e=d;break d}if(!XI(fb(a),f,c)){break b}e=d+4|0;if(!i[d+4>>2]){break c}d=e;e=d}d=i[d>>2];continue}break}i[b>>2]=d;return e}i[b>>2]=d;return e}d=Pb(a)}i[b>>2]=d;return d}function MFa(a,b,c){var d=0,e=0,f=0;d=qe(a);e=Pb(a);a:{if(d){b:{while(1){c:{f=d+16|0;d:{if(Zm(fb(a),c,f)){if(!i[d>>2]){break a}e=d;break d}if(!Zm(fb(a),f,c)){break b}e=d+4|0;if(!i[d+4>>2]){break c}d=e;e=d}d=i[d>>2];continue}break}i[b>>2]=d;return e}i[b>>2]=d;return e}d=Pb(a)}i[b>>2]=d;return d}function KCa(a,b,c){var d=0,e=0,f=0;d=qe(a);e=Pb(a);a:{if(d){b:{while(1){c:{f=d+14|0;d:{if(Zm(fb(a),c,f)){if(!i[d>>2]){break a}e=d;break d}if(!Zm(fb(a),f,c)){break b}e=d+4|0;if(!i[d+4>>2]){break c}d=e;e=d}d=i[d>>2];continue}break}i[b>>2]=d;return e}i[b>>2]=d;return e}d=Pb(a)}i[b>>2]=d;return d}function GK(a,b,c,d){var e=0,f=0;f=Xa-16|0;Xa=f;e=-2147483648;e=!c|!(g[c+15|0]&1)?e:i[c+8>>2];a:{b:{if(!(!d|!(j[d+34|0]&32))){e=k[d+28>>1];break b}if((e|0)==-2147483648){break a}}is(b,e,a);kb(f+8|0,a+1074308|0,10);if(!ib(f+8|0)|i[a+480208>>2]&16384){break a}i[b+88>>2]=i[b+88>>2]&-257}Xa=f+16|0}function Bia(a,b,c){var d=0,e=0,f=0;d=qe(a);e=Pb(a);a:{if(d){b:{while(1){c:{f=d+16|0;d:{if(wr(fb(a),c,f)){if(!i[d>>2]){break a}e=d;break d}if(!wr(fb(a),f,c)){break b}e=d+4|0;if(!i[d+4>>2]){break c}d=e;e=d}d=i[d>>2];continue}break}i[b>>2]=d;return e}i[b>>2]=d;return e}d=Pb(a)}i[b>>2]=d;return d}function zx(a,b,c,d){var e=0,f=0;e=Xa-16|0;Xa=e;f=Fo(a);a:{if(Wb(f)>>>0<=b>>>0){break a}if(Ax(a,k[$b(f,b)>>1])>>>0<=c>>>0){break a}b:{if(cc(a)>>>0>b>>>0){if(l[Yc(a,b)+4>>2]>c>>>0){break b}}Ri(a,0);if(cc(a)>>>0<=b>>>0){break a}}Ld(e+8|0,Yc(a,b),c);Od(e+8|0,d);if(!d){break a}mL(a,b,c)}Xa=e+16|0}function zqa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=Xa-16|0;Xa=d;i[d+12>>2]=c>>>1;i[d+8>>2]=i[a>>2];e=i[rb(d+12|0,d+8|0)>>2];b=jb(b);if(e){a=i[a+20>>2];c=e;while(1){f=a,g=(jb(j[b+1|0])|jb(j[b|0])<<8)^32768,h[f>>1]=g;a=a+2|0;b=b+2|0;c=c+ -1|0;if(c){continue}break}}Xa=d+16|0;return e<<1}function n3(a){var b=0,c=0;b=Xa-16|0;Xa=b;c=Hq(461220);i[115315]=461276;i[115313]=a;i[115305]=56856;g[461272]=0;i[115317]=-1;wq(b+8|0,c);a=i[i[115305]+8>>2];i[114610]=0;D(a|0,461220,b+8|0);a=i[114610];i[114610]=0;if((a|0)!=1){ub(b+8|0);Xa=b+16|0;return}a=B()|0;A()|0;ub(b+8|0);Kk(c);E(a|0);x()}function mT(a,b,c){var d=0,e=0,f=0,g=0,l=0;d=Xa-16|0;Xa=d;i[d+12>>2]=c;kc(d+12|0,128);kc(d+12|0,65535);f=k[d+12>>1];Zf(a,f);if(f){c=0;while(1){e=j[b+c|0];a:{if((e|0)==255){e=65535;break a}if((e|0)!=254){break a}e=65534}g=lk(a,c),l=e,h[g>>1]=l;c=c+1|0;if((f|0)!=(c|0)){continue}break}}Xa=d+16|0}function l3(a){var b=0,c=0;b=Xa-16|0;Xa=b;c=nE(461284);i[115331]=461340;i[115329]=a;i[115321]=56996;g[461336]=0;i[115333]=-1;wq(b+8|0,c);a=i[i[115321]+8>>2];i[114610]=0;D(a|0,461284,b+8|0);a=i[114610];i[114610]=0;if((a|0)!=1){ub(b+8|0);Xa=b+16|0;return}a=B()|0;A()|0;ub(b+8|0);Un(c);E(a|0);x()}function gla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,h=0,i=0;e=Xa-16|0;Xa=e;f=pi(b,c);d=qc(a);if(f>>>0>d>>>0){h=d;i=f-d|0;d=lb(a);rl(a,h,i,d,0,d,0)}d=xb(a);if((b|0)!=(c|0)){while(1){Rd(d,b);d=d+1|0;b=b+1|0;if((c|0)!=(b|0)){continue}break}}g[e+15|0]=0;Rd(d,e+15|0);yg(a,f);Xa=e+16|0;return a|0}function Cqa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=Xa-16|0;Xa=d;i[d+12>>2]=c>>>1;i[d+8>>2]=i[a>>2];e=i[rb(d+12|0,d+8|0)>>2];b=jb(b);if(e){a=i[a+20>>2];c=e;while(1){f=a,g=(jb(j[b|0])|jb(j[b+1|0])<<8)^32768,h[f>>1]=g;a=a+2|0;b=b+2|0;c=c+ -1|0;if(c){continue}break}}Xa=d+16|0;return e<<1}function eH(a){a=a|0;var b=0,c=0;c=Xa-16|0;Xa=c;b=i[a+4256>>2];i[a+4240>>2]=b<<1;i[114610]=0;i[c+12>>2]=0;G(1647,a+4208|0,b<<2,c+12|0);b=i[114610];i[114610]=0;a:{if((b|0)==1){b=H(71348)|0;if((A()|0)!=(U(71348)|0)){break a}M(b|0)|0;i[a+4240>>2]=0;O()}i[a+4244>>2]=0;Xa=c+16|0;return}E(b|0);x()}function IM(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=Xa-16|0;Xa=c;d=i[b+4>>2];i[c+8>>2]=i[b>>2];i[c+12>>2]=d;e=c,f=lb(a),i[e+4>>2]=f;i[c>>2]=i[c+12>>2];a=xm(xb(a),i[c+8>>2],i[rb(c+4|0,c)>>2]);a:{if(a){break a}a=-1;b=i[c+4>>2];d=i[c>>2];if(b>>>0<d>>>0){break a}a=b>>>0>d>>>0}Xa=c+16|0;return a|0}function FI(a,b){a=a|0;b=b|0;var c=0,d=0;a:{b:{c:{c=a+ -12|0;d:{if(c>>>0>28){break d}a=1;d=1<<c;if(d&270014517){break b}if(d&65792){break c}if((c|0)!=7){break d}b=b&240;if(!b|(b|0)==96|(b|0)==224){break b}}return 0}a=0;b=(b&240)+ -96|0;if(b>>>0<144){break a}}return a|0}return 297>>>(b>>>4)&1}function YAa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Xa-32|0;Xa=d;kO(d+16|0,c);i[114610]=0;D(517,d|0,d+16|0);c=i[114610];i[114610]=0;a:{if((c|0)==1){break a}i[114610]=0;G(518,a|0,b|0,d|0);a=i[114610];i[114610]=0;if((a|0)==1){break a}ob(d+16|0);Xa=d+32|0;return}a=B()|0;A()|0;ob(d+16|0);E(a|0);x()}function $ta(a){var b=0,c=0,d=0;b=i[a+2496>>2];c=(b+1>>>0)%624|0;d=i[(c<<2)+a>>2];b=o(d&1,-1727483681)^(i[((b+397>>>0)%624<<2)+a>>2]^(d&2147483647|i[(b<<2)+a>>2]&-2147483648)>>>1);i[(i[a+2496>>2]<<2)+a>>2]=b;i[a+2496>>2]=c;a=b^b>>>11;a=a<<7&-1658038656^a;a=a<<15&-272236544^a;return a>>>18^a}function rR(a,b,c){var d=0;d=Xa-32|0;Xa=d;i[d+16>>2]=b;i[d+24>>2]=a;i[d+8>>2]=c;a:{if(!pb(d+24|0,d+16|0)){break a}while(1){a=i[d+24>>2];if(i[i[d+8>>2]>>2]==(j[a|0]|j[a+1|0]<<8|(j[a+2|0]<<16|j[a+3|0]<<24))){break a}dk(d+24|0);if(pb(d+24|0,d+16|0)){continue}break}}Xa=d+32|0;return i[d+24>>2]}function lQ(a){var b=0,c=0,d=0,e=0,f=0,h=0,k=0;if(!j[a+20|0]){if(!($a[i[i[a>>2]+44>>2]](a)|0)){b=a+4|0;while(1){tQ(a,65536);c=a,d=(f=a,h=dc(b,i[a+16>>2]),k=65536,e=i[i[a>>2]+48>>2],$a[e](f|0,h|0,k|0)|0)+i[a+16>>2]|0,i[c+16>>2]=d;if(!($a[i[i[a>>2]+44>>2]](a)|0)){continue}break}}g[a+20|0]=1}}function cya(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Xa-32|0;Xa=d;Txa(d+16|0,c);i[114610]=0;D(71,d|0,d+16|0);c=i[114610];i[114610]=0;a:{if((c|0)==1){break a}i[114610]=0;G(72,a|0,b|0,d|0);a=i[114610];i[114610]=0;if((a|0)==1){break a}ob(d+16|0);Xa=d+32|0;return}a=B()|0;A()|0;ob(d+16|0);E(a|0);x()}function zQ(a){var b=0,c=0,d=0,e=0,f=0;b=a+32|0;d=j[b|0]|j[b+1|0]<<8;b=a+38|0;e=j[b|0]|j[b+1|0]<<8;b=0;c=a+34|0;f=j[c|0]|j[c+1|0]<<8;a=a+36|0;c=j[a|0]|j[a+1|0]<<8;a=f+c|0;if(a>>>0<c>>>0){b=1}c=e+a|0;if(c>>>0<a>>>0){b=b+1|0}a=b<<2|c>>>30;b=c<<2;c=d+b|0;if(c>>>0<b>>>0){a=a+1|0}_a=a;return c}function ve(a){a=a|0;var b=0,c=0;i[a>>2]=79824;b=i[a+12>>2];if(i[b>>2]==(a|0)){i[b>>2]=i[a+4>>2]}b=i[a+20>>2];if(b){i[b>>2]=0;i[a+20>>2]=0}b=i[a+4>>2];if(b){i[b+8>>2]=i[a+8>>2]}c=i[a+8>>2];if(c){i[c+4>>2]=b}i[a+4>>2]=0;i[a+8>>2]=0;b=a+44|0;rr(b+36|0);rr(b+24|0);qr(b+12|0);qr(b);return a|0}function pJa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Xa-32|0;Xa=d;mS(d+16|0,c);i[114610]=0;D(71,d|0,d+16|0);c=i[114610];i[114610]=0;a:{if((c|0)==1){break a}i[114610]=0;G(72,a|0,b|0,d|0);a=i[114610];i[114610]=0;if((a|0)==1){break a}ob(d+16|0);Xa=d+32|0;return}a=B()|0;A()|0;ob(d+16|0);E(a|0);x()}function TD(a,b,c){var d=0,e=0,f=0,h=0,j=0;d=Xa-16|0;Xa=d;e=Hq(a);i[a+32>>2]=b;i[a>>2]=57096;wq(d+8|0,e);i[114610]=0;b=F(2390,d+8|0)|0;f=i[114610];i[114610]=0;if((f|0)!=1){ub(d+8|0);i[a+40>>2]=c;i[a+36>>2]=b;h=a,j=Zl(b),g[h+44|0]=j;Xa=d+16|0;return}a=B()|0;A()|0;ub(d+8|0);Kk(e);E(a|0);x()}function SD(a,b,c){var d=0,e=0,f=0,h=0,j=0;d=Xa-16|0;Xa=d;e=nE(a);i[a+32>>2]=b;i[a>>2]=57200;wq(d+8|0,e);i[114610]=0;b=F(2391,d+8|0)|0;f=i[114610];i[114610]=0;if((f|0)!=1){ub(d+8|0);i[a+40>>2]=c;i[a+36>>2]=b;h=a,j=Zl(b),g[h+44|0]=j;Xa=d+16|0;return}a=B()|0;A()|0;ub(d+8|0);Un(e);E(a|0);x()}function Joa(a){var b=0,c=0,d=0,e=0;c=a+1074412|0;a:{b:{b=a+484344|0;if(sp(b,k[a+1074436>>1])){if(NK(Fb(b,k[a+1074436>>1]))){break b}}i[a+1074408>>2]=i[a+480216>>2];a=i[a+480220>>2];break a}d=a+1074408|0,e=i[Fb(b,k[a+1074436>>1])+16>>2],i[d>>2]=e;a=i[Fb(b,k[a+1074436>>1])+20>>2]}i[c>>2]=a}function Fma(a,b,c){var d=0,e=0,f=0,g=0;e=Xa-16|0;Xa=e;g=c<<2;while(1){i[e>>2]=0;f=((d<<11)+a|0)+16396|0;RK(f,g+f|0,e);d=d+1|0;if((d|0)!=4){continue}break}d=0;while(1){i[(d<<2)+e>>2]=((d<<11)+a|0)+16396;d=d+1|0;if((d|0)!=4){continue}break}$a[i[i[b>>2]+8>>2]](b,e,i[a+24632>>2],c);Xa=e+16|0}function yqa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=Xa-16|0;Xa=e;i[e+12>>2]=c>>>1;i[e+8>>2]=i[a>>2];f=i[rb(e+12|0,e+8|0)>>2];b=jb(b);if(f){a=i[a+20>>2];c=f;while(1){d=(jb(j[b+1|0])|jb(j[b|0])<<8)+d|0;h[a>>1]=d;a=a+2|0;b=b+2|0;c=c+ -1|0;if(c){continue}break}}Xa=e+16|0;return f<<1}function y4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=Xa-32|0;Xa=c;a=x4(c+8|0,a);d=i[a>>2];e=i[a+4>>2];a=i[b+4>>2];i[c>>2]=i[b>>2];i[c+4>>2]=a;b=i[c+4>>2]+e|0;e=i[c>>2];d=d+e|0;if(d>>>0<e>>>0){b=b+1|0}i[c+16>>2]=d;i[c+20>>2]=b;a=Qj(c+24|0,c+16|0);b=i[a+4>>2];a=i[a>>2];Xa=c+32|0;_a=b;return a|0}function v4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=Xa-32|0;Xa=c;a=u4(c+8|0,a);d=i[a>>2];e=i[a+4>>2];a=i[b+4>>2];i[c>>2]=i[b>>2];i[c+4>>2]=a;b=i[c+4>>2]+e|0;e=i[c>>2];d=d+e|0;if(d>>>0<e>>>0){b=b+1|0}i[c+16>>2]=d;i[c+20>>2]=b;a=Qj(c+24|0,c+16|0);b=i[a+4>>2];a=i[a>>2];Xa=c+32|0;_a=b;return a|0}function QU(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,m=0;e=Xa-16|0;Xa=e;i[e+12>>2]=d;d=0;if(l[a+16>>2]>c>>>0){d=i[a+4>>2];f=i[a+12>>2];i[e+8>>2]=i[a+16>>2]-c;d=(h=d,j=b,k=c+f|0,m=i[rb(e+12|0,e+8|0)>>2],g=i[i[d>>2]+28>>2],$a[g](h|0,j|0,k|0,m|0)|0)}Xa=e+16|0;return d|0}function Bqa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=Xa-16|0;Xa=e;i[e+12>>2]=c>>>1;i[e+8>>2]=i[a>>2];f=i[rb(e+12|0,e+8|0)>>2];b=jb(b);if(f){a=i[a+20>>2];c=f;while(1){d=(jb(j[b|0])|jb(j[b+1|0])<<8)+d|0;h[a>>1]=d;a=a+2|0;b=b+2|0;c=c+ -1|0;if(c){continue}break}}Xa=e+16|0;return f<<1}function wta(a,b,c){var d=0,e=0,f=0,g=0;d=Xa-16|0;Xa=d;i[d+12>>2]=b;a:{if(zf(a)>>>0>=b>>>0){f=d,g=Wb(a),i[f+8>>2]=g;Ey(i[a>>2],i[rb(d+12|0,d+8|0)>>2],c);b=i[d+12>>2];e=i[d+8>>2];if(b>>>0>e>>>0){ut(a,b-e|0,c);break a}wp(a,i[a>>2]+(b<<1)|0);break a}gM(a);ly(a,qi(a,b));ut(a,b,c)}Xa=d+16|0}function X5(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;e=b;f=j[c|0];if(f){d=a;while(1){i=f<<1;g=0;while(1){m[e>>2]=m[d>>2];m[e+4>>2]=m[(f<<2)+d>>2];h=i<<2;m[e+8>>2]=m[h+d>>2];d=d+4|0;e=e+12|0;g=g+1|0;if((g|0)!=(f|0)){continue}break}d=d+h|0;f=j[c+3|0];c=c+3|0;if(f){continue}break}}Tb(a,b,e-b|0)}function L2(){var a=0,b=0,c=0;a=Xa-16|0;Xa=a;a:{if(Ha(a+12|0,a+8|0)|0){break a}b=Zc((i[a+12>>2]<<2)+4|0);i[115396]=b;if(!b){break a}b:{b=Zc(i[a+8>>2]);if(b){c=i[115396];if(c){break b}}i[115396]=0;break a}i[(i[a+12>>2]<<2)+c>>2]=0;if(!(Ga(i[115396],b|0)|0)){break a}i[115396]=0}Xa=a+16|0}function Jsa(a){i[a>>2]=0;i[a+4>>2]=0;i[a+68>>2]=0;i[a+72>>2]=0;i[a+24>>2]=0;i[a+28>>2]=0;h[a+20>>1]=511;i[a+16>>2]=-1;h[a+14>>1]=1;h[a+6>>1]=0;h[a+8>>1]=0;h[a+10>>1]=0;h[a+12>>1]=0;g[a+73|0]=0;g[a+74|0]=0;g[a+75|0]=0;g[a+76|0]=0;g[a+77|0]=0;g[a+78|0]=0;g[a+79|0]=0;g[a+80|0]=0;return a}function BW(a,b){var c=0,d=0,e=0;c=Xa-16|0;Xa=c;a=dF(a,c+8|0);d=lb(b);e=le(7063);b=xb(b);i[114610]=0;J(195,a|0,b|0,d|0,d+e|0);b=i[114610];i[114610]=0;a:{if((b|0)!=1){i[114610]=0;I(196,a|0,7063,e|0)|0;b=i[114610];i[114610]=0;if((b|0)!=1){break a}}b=B()|0;A()|0;eb(a);E(b|0);x()}Xa=c+16|0}function aba(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Xa-48|0;Xa=d;i[d+44>>2]=b;Li(d+8|0,0,c);b=d+24|0;i[b>>2]=i[d+44>>2];Lc(b+4|0,d+8|0);i[114610]=0;D(2126,a+4|0,d+24|0);a=i[114610];i[114610]=0;if((a|0)!=1){Os(d+24|0);eb(d+8|0);Xa=d+48|0;return}a=B()|0;A()|0;Os(d+24|0);eb(d+8|0);E(a|0);x()}function Dqa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=Xa-16|0;Xa=d;i[d+12>>2]=c>>>1;i[d+8>>2]=i[a>>2];e=i[rb(d+12|0,d+8|0)>>2];b=jb(b);if(e){a=i[a+20>>2];c=e;while(1){f=a,g=jb(j[b|0])|jb(j[b+1|0])<<8,h[f>>1]=g;a=a+2|0;b=b+2|0;c=c+ -1|0;if(c){continue}break}}Xa=d+16|0;return e<<1}function Aqa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=Xa-16|0;Xa=d;i[d+12>>2]=c>>>1;i[d+8>>2]=i[a>>2];e=i[rb(d+12|0,d+8|0)>>2];b=jb(b);if(e){a=i[a+20>>2];c=e;while(1){f=a,g=jb(j[b+1|0])|jb(j[b|0])<<8,h[f>>1]=g;a=a+2|0;b=b+2|0;c=c+ -1|0;if(c){continue}break}}Xa=d+16|0;return e<<1}function $V(a,b,c){var d=0,e=0,f=0,h=0;d=Xa-16|0;Xa=d;i[d+12>>2]=c;f=lb(a);if(f>>>0>=b>>>0){if(c){h=xb(a);e=f-b|0;i[d+8>>2]=e;c=i[rb(d+12|0,d+8|0)>>2];i[d+12>>2]=c;e=e-c|0;if(e){b=b+h|0;Cl(b,b+c|0,e);c=i[d+12>>2]}b=a;a=f-c|0;yg(b,a);g[d+7|0]=0;Rd(a+h|0,d+7|0)}Xa=d+16|0;return}Ml();x()}function yma(a,b){var c=0;c=Xa-16|0;Xa=c;a=a+1074308|0;kb(c+8|0,a,28);a:{b:{if(!ib(c+8|0)){kb(c,a,1);if(!ib(c)){break b}}i[b+684>>2]=i[b+692>>2]+h[b+790>>1];Kd(b+684|0,0,256);break a}i[b+692>>2]=i[b+692>>2]+h[b+790>>1];Kd(b+692|0,0,256);h[b+790>>1]=0;i[b+684>>2]=i[b+692>>2]}Xa=c+16|0}function s1(a,b){var c=0,d=0;c=Xa-16|0;Xa=c;fc(c+8|0,a);i[114610]=0;a=F(2449,c+8|0)|0;d=i[114610];i[114610]=0;a:{if((d|0)==1){break a}i[114610]=0;N(2463,a|0,62112,62138,b|0)|0;a=i[114610];i[114610]=0;if((a|0)==1){break a}ub(c+8|0);Xa=c+16|0;return b}a=B()|0;A()|0;ub(c+8|0);E(a|0);x()}function TX(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=Xa-16|0;Xa=d;a:{if(i[b>>2]){if(!Cc(c)){lu(c,70664)}e=i[b+4>>2];$a[i[i[e>>2]+24>>2]](d,e,i[b>>2]);i[114610]=0;C(1251,c|0,d|0)|0;b=i[114610];i[114610]=0;if((b|0)==1){break a}eb(d)}Lc(a,c);Xa=d+16|0;return}a=B()|0;A()|0;eb(d);E(a|0);x()}function t7(a,b,c,d,e){var f=0,g=0,j=0,k=0,l=0;if(e){while(1){g=0;if(d){while(1){f=i[rf(b,g,j)>>2];Nb(c,g);f=f+ -2147481600>>>12|0;f=f>>>0>491520?f:491520;k=gm(a,g,j),l=(f|0)<557055?f:557055,h[k>>1]=l;g=g+1|0;if((g|0)!=(d|0)){continue}break}}j=j+1|0;if((j|0)!=(e|0)){continue}break}}}function W7(a,b,c,d,e){var f=0,g=0,j=0,k=0,l=0;if(e){while(1){g=0;if(d){while(1){f=i[rf(b,g,j)>>2];Nb(c,g);f=f+ -2147481600>>>12|0;f=f>>>0>491520?f:491520;k=im(a,g,j),l=(f|0)<557055?f:557055,h[k>>1]=l;g=g+1|0;if((g|0)!=(d|0)){continue}break}}j=j+1|0;if((j|0)!=(e|0)){continue}break}}}function JC(a,b){a=a|0;b=b|0;var c=0,d=0;d=Xa-16|0;Xa=d;b=Yd(d,a,b);c=i[b+4>>2];a:{while(1){if(i[b+8>>2]==(c|0)){break a}Ck(a);c=i[b+4>>2];i[114610]=0;ls(c);c=i[114610];i[114610]=0;if((c|0)!=1){c=i[b+4>>2]+4|0;i[b+4>>2]=c;continue}break}a=B()|0;A()|0;sb(b);E(a|0);x()}sb(b);Xa=d+16|0}function BJ(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=Xa-16|0;Xa=e;a:{b:{if(!Jd(c)|(!d|i[b+480180>>2]!=16777216)|k[b+480192>>1]<d>>>0){break b}d=i[((d<<2)+b|0)+900380>>2];if(!d){break b}d=i[d+44>>2];if(!d){break b}h[e+14>>1]=c+ -61;hja(a,d,e+14|0);break a}ina(a,c,i[b>>2])}Xa=e+16|0}function xd(a){var b=0,c=0,d=0,e=0;gNa(+a);b=dNa(1)|0;dNa(0)|0;e=b;b=b>>>20&2047;if(b>>>0<=1074){if(b>>>0<=1021){return a*0}a=(e|0)>-1?a:-a;c=a+4503599627370496+ -4503599627370496-a;a:{if(!(c>.5^1)){d=a+c+ -1;break a}a=a+c;d=a;if(c<=-.5^1){break a}d=a+1}a=d;a=(e|0)>-1?a:-a}return a}function oD(a,b,c){var d=0,e=0,f=0,g=0;f=Xa-16|0;Xa=f;e=Fs(b,c);if(e>>>0<=1073741807){a:{if(e>>>0<=1){Te(a,e);d=a;break a}g=Nl(e)+1|0;d=Ak(g);gf(a,d);fg(a,g);ce(a,e)}while(1){if((b|0)!=(c|0)){ye(d,b);d=d+4|0;b=b+4|0;continue}break}i[f+12>>2]=0;ye(d,f+12|0);Xa=f+16|0;return}gg();x()}function _1(a,b,c){var d=0;d=Xa-16|0;Xa=d;i[d+12>>2]=c;i[d+8>>2]=0;i[d+4>>2]=4;c=xk(a,d+8|0,i[rb(d+12|0,d+4|0)>>2])>>>0>=0;a=_a;if((a|0)>0?1:(a|0)>=0?c:0){i[d+4>>2]=4;i[rb(d+12|0,d+4|0)>>2]}i[d+4>>2]=i[d+8>>2];a=d+4|0;i[b>>2]=j[a|0]|j[a+1|0]<<8|(j[a+2|0]<<16|j[a+3|0]<<24);Xa=d+16|0}function UZ(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0;while(1){a:{if((c|0)==(d|0)|g>>>0>=e>>>0){break a}f=1;b:{c:{h=TZ(c,d-c|0,b,i[a+8>>2]);switch(h+2|0){case 0:case 1:break a;case 2:break b;default:break c}}f=h}g=g+1|0;j=f+j|0;c=c+f|0;continue}break}return j|0}function wW(a){var b=0,c=0;c=Xa-32|0;Xa=c;a=Oc(a);i[114610]=0;L(236,c|0);b=i[114610];i[114610]=0;a:{b:{if((b|0)!=1){b=xg(c);i[114610]=0;C(237,a|0,b|0)|0;b=i[114610];i[114610]=0;if((b|0)==1){break b}Ie(c);Xa=c+32|0;return}b=B()|0;A()|0;break a}b=B()|0;A()|0;Ie(c)}eb(a);E(b|0);x()}function si(a,b){var c=0,d=0,e=0,f=0;if(b){c=i[a>>2];while(1){a:{if(c){d=i[a+4>>2];break a}i[a>>2]=8;c=i[a+12>>2];if((c|0)!=i[a+8>>2]){c=c+ -1|0;i[a+12>>2]=c}d=j[c|0];i[a+4>>2]=d;c=8}c=c+ -1|0;i[a>>2]=c;i[a+4>>2]=d>>>1;e=d&1|e<<1;f=f+1|0;if((f|0)!=(b|0)){continue}break}}return e}function oga(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;i[a+4>>2]=b;i[a>>2]=0;b=ds(a+8|0,e);i[114610]=0;C(1760,a+20|0,d|0)|0;d=i[114610];i[114610]=0;if((d|0)!=1){i[a+32>>2]=0;i[a+36>>2]=0;g[a+42|0]=0;g[a+40|0]=0;g[a+41|0]=j[a+41|0]&240|c|8;return a|0}a=B()|0;A()|0;ob(b);E(a|0);x()}function Noa(a,b,c){a=a|0;b=b|0;c=c|0;a:{switch(b|0){case 0:xoa(a,c);return;case 1:poa(a,c);return;case 2:hoa(a,c);return;case 3:to(a,c,1520);return;case 4:to(a,c,2544);return;case 5:to(a,c,3568);return;case 6:to(a,c,4592);return;case 7:to(a,c,5616);return;default:break a}}Ab(a)}function lDa(a,b,c){var d=0,e=0;d=Xa-16|0;Xa=d;e=Fs(b,c);a:{if(e>>>0<=gd(a)>>>0){i[d+12>>2]=c;if(e>>>0>qb(a)>>>0){i[d+12>>2]=b;cP(d+12|0,qb(a));Oe(b,i[d+12>>2],i[a>>2]);tp(a,i[d+12>>2],c,e-qb(a)|0);break a}Ft(a,Oe(b,c,i[a>>2]));break a}bP(a);TCa(a,ge(a,e));tp(a,b,c,e)}Xa=d+16|0}function e4(a,b,c,d){var e=0,f=0,h=0;e=Xa-16|0;Xa=e;d=d-c|0;a:{if(!d){b=a;break a}f=b-a|0;if((f|0)<(d|0)){break a}g[e+15|0]=j[c|0];h=1-d|0;while(1){a=Bn(a,f+h|0,e+15|0);if(!a){break a}if(!xm(a,c,d)){b=a;break a}a=a+1|0;f=b-a|0;if((f|0)>=(d|0)){continue}break}}Xa=e+16|0;return b}function aka(a,b,c){var d=0,e=0;d=Xa-16|0;Xa=d;e=Fs(b,c);a:{if(e>>>0<=gd(a)>>>0){i[d+12>>2]=c;if(e>>>0>qb(a)>>>0){i[d+12>>2]=b;cP(d+12|0,qb(a));Oe(b,i[d+12>>2],i[a>>2]);tp(a,i[d+12>>2],c,e-qb(a)|0);break a}bQ(a,Oe(b,c,i[a>>2]));break a}$ja(a);US(a,ge(a,e));tp(a,b,c,e)}Xa=d+16|0}function Yqa(a){if(!(0x8000000000000000>a)){_a=2147483647;return-1}if(!(-0x8000000000000000<a)){_a=-2147483648;return 0}if(q(a)<0x8000000000000000){_a=q(a)>=1?a>0?~~s(u(a/4294967296),4294967295)>>>0:~~v((a- +(~~a>>>0>>>0))/4294967296)>>>0:0;return~~a>>>0}_a=-2147483648;return 0}function Rg(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=Xa-32|0;Xa=e;g=ij(a,c);Ue(e+8|0,i[a+28>>2]);f=i[e+20>>2];i[e+24>>2]=i[e+16>>2];i[e+28>>2]=f;a:{b:{if(!g){f=-1;if(!dd(a,5)){break b}break a}f=i[g+8>>2]}$a[d|0](i[a+28>>2],b,f)}a=Ai(a,g,c,e+24|0);Xa=e+32|0;return a|0}function Kqa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,h=0;d=Xa-16|0;Xa=d;i[d+12>>2]=c;i[d+8>>2]=i[a>>2];e=i[rb(d+12|0,d+8|0)>>2];b=jb(b);if(e){a=i[a+20>>2];c=e;while(1){f=a,h=Eb(Em(j[b|0]),-64,63)<<1,g[f|0]=h;a=a+1|0;b=b+1|0;c=c+ -1|0;if(c){continue}break}}Xa=d+16|0;return e|0}function Kj(a,b,c,d){var e=0,f=0;a:{f=i[(o(b,896)+a|0)+1075640>>2];if(!f){break a}if(!Xh(f)){break a}e=j[f+34|0];if(e+ -251>>>0<5|!e){break a}e=i[(o(e,160)+a|0)+906140>>2];if(!e){break a}$a[i[i[e>>2]+88>>2]](e,f,c,d,b);if(c>>>0>250){break a}h[(o(b,896)+a|0)+1075846>>1]=65535}}function AA(a,b,c,d){var e=0,f=0;b=i[a+1072>>2]+((b&c?0-(c<<1)|0:0)+b|0)|0;i[a+1072>>2]=b;c=b+i[a+1076>>2]|0;i[a+1076>>2]=c;h[(i[a+1064>>2]<<1)+d>>1]=j[a+1080|0]?c:b;i[a+1060>>2]=i[a+1060>>2]+1;e=a,f=$d(i[a+1056>>2])+i[a+1064>>2]|0,i[e+1064>>2]=f;i[a+1068>>2]=i[a+1068>>2]+ -1}function n5(a,b,c,d){var e=0,f=0,g=0,h=0,j=0,l=0;if((b|0)>=1){h=(b<<1)+a|0;j=-1;l=65536;while(1){g=(f<<1)+a|0;e=k[g>>1];if(!((j|0)>=(e|0)|e>>>0>=k[h>>1])){i[c>>2]=f;e=k[g>>1];j=e}if(!((l|0)<=(e|0)|e>>>0<=k[h>>1])){i[d>>2]=f;l=k[g>>1]}f=f+1|0;if((f|0)!=(b|0)){continue}break}}}function iV(a){var b=0;b=Xa-16|0;Xa=b;g[a|0]=0;g[a+1|0]=0;g[a+2|0]=0;g[a+3|0]=0;g[a+4|0]=0;g[a+5|0]=0;g[a+6|0]=0;g[a+7|0]=0;g[a+16|0]=0;g[a+17|0]=0;g[a+18|0]=0;g[a+19|0]=0;g[a+8|0]=0;g[a+9|0]=0;g[a+10|0]=0;g[a+11|0]=0;g[a+12|0]=0;g[a+13|0]=0;g[a+14|0]=0;g[a+15|0]=0;Xa=b+16|0}function R6(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=Xa-16|0;Xa=f;d=co(f+8|0,d);i[114610]=0;S(2014,a+8|0,b|0,c|0,d|0,e|0)|0;b=i[114610];i[114610]=0;if((b|0)!=1){Ec(d);DF(a);b=CF(a+88|0);i[a>>2]=84280;i[b>>2]=84368;Xa=f+16|0;return a|0}a=B()|0;A()|0;Ec(d);E(a|0);x()}function JLa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;i[a>>2]=0;i[a+4>>2]=0;if(!wb(b,c)){c=cf(b)}i[a>>2]=c;d=i[b>>2];if($a[i[i[d>>2]+16>>2]](d)|0){c=a;a=i[b>>2];e=c,f=($a[i[i[a>>2]+20>>2]](a)|0)+i[b+8>>2]|0,i[e+4>>2]=f;return}d=a+8|0;ck(d,i[a>>2]);if(!Uc(d)){qg(b,dc(d,0),c)}}function $sa(a,b){a=a|0;b=b|0;var c=0;c=Xa-48|0;Xa=c;g[c+40|0]=j[b|0];Pp(c+16|0,c+40|0);b=jb(i[c+16>>2]);Pp(c+8|0,c+40|0);b=Uh(c+24|0,b,jb(i[c+8>>2]+1|0));i[114610]=0;C(1193,a|0,b|0)|0;a=i[114610];i[114610]=0;if((a|0)!=1){eb(b);Xa=c+48|0;return}a=B()|0;A()|0;eb(b);E(a|0);x()}function pfa(a,b,c){a=a|0;b=b|0;c=p(c);var d=0;d=Xa-16|0;Xa=d;m[d+12>>2]=c;if((b|0)<=6){Id(d+12|0,p(0));c=m[d+12>>2];a:{if(!((b|0)!=1|c>=p(1))){i[d+12>>2]=0;c=p(0);break a}if((b|0)!=4){break a}c=p(Qd(p(c*p(4)))*p(.25));m[d+12>>2]=c}m[((b<<2)+a|0)+4208>>2]=c;hw(a)}Xa=d+16|0}function cga(a,b,c){a=a|0;b=b|0;c=p(c);var d=0;d=Xa-16|0;Xa=d;m[d+12>>2]=c;if((b|0)<=6){Id(d+12|0,p(0));c=m[d+12>>2];a:{if(!((b|0)!=3|c>=p(1))){i[d+12>>2]=0;c=p(0);break a}if((b|0)!=4){break a}c=p(Qd(p(c*p(4)))*p(.25));m[d+12>>2]=c}m[((b<<2)+a|0)+4208>>2]=c;hw(a)}Xa=d+16|0}function _6(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=p(0);if(e){while(1){f=0;if(d){while(1){h=n[Ig(b,f,g)>>3];Nb(c,f);i=Ui(xd(h*134217728));j=rf(a,f,g),k=p(+(i|0)*7.450580596923828e-9),m[j>>2]=k;f=f+1|0;if((f|0)!=(d|0)){continue}break}}g=g+1|0;if((g|0)!=(e|0)){continue}break}}}function Z6(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=p(0);if(e){while(1){f=0;if(d){while(1){h=n[Ig(b,f,g)>>3];Ae(c,f);i=Ui(xd(h*134217728));j=rf(a,f,g),k=p(+(i|0)*7.450580596923828e-9),m[j>>2]=k;f=f+1|0;if((f|0)!=(d|0)){continue}break}}g=g+1|0;if((g|0)!=(e|0)){continue}break}}}function Jxa(a,b){var c=0;c=Xa-16|0;Xa=c;a=qxa(c,a,b);b=i[a+4>>2];if((b|0)!=i[a+8>>2]){while(1){g[b|0]=0;g[b+1|0]=0;g[b+2|0]=0;g[b+3|0]=0;g[b+4|0]=0;g[b+5|0]=0;g[b+6|0]=0;g[b+7|0]=0;g[b+8|0]=0;b=i[a+4>>2]+9|0;i[a+4>>2]=b;if(i[a+8>>2]!=(b|0)){continue}break}}sb(a);Xa=c+16|0}function C7(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=p(0);if(e){while(1){f=0;if(d){while(1){h=n[Ig(b,f,g)>>3];Nb(c,f);i=Ui(xd(h*134217728));j=Qm(a,f,g),k=p(+(i|0)*7.450580596923828e-9),m[j>>2]=k;f=f+1|0;if((f|0)!=(d|0)){continue}break}}g=g+1|0;if((g|0)!=(e|0)){continue}break}}}function B7(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=p(0);if(e){while(1){f=0;if(d){while(1){h=n[Ig(b,f,g)>>3];Ae(c,f);i=Ui(xd(h*134217728));j=Qm(a,f,g),k=p(+(i|0)*7.450580596923828e-9),m[j>>2]=k;f=f+1|0;if((f|0)!=(d|0)){continue}break}}g=g+1|0;if((g|0)!=(e|0)){continue}break}}}function Ni(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(!(b?0:!(i[a+480180>>2]&1))){e=i[a+24616>>2]&524288;b=0;while(1){c=(b<<5)+a|0;h[c+480286>>1]=64;d=c+480280|0;i[d>>2]=i[d>>2]&-257;d=c+480284|0;c=(b&3)+ -1>>>0<2;h[d>>1]=e?c<<8:c?192:64;b=b+1|0;if((b|0)!=127){continue}break}}}function zA(a,b,c,d){var e=0,f=0;b=i[a+1072>>2]+((b&c?0-(c<<1)|0:0)+b|0)|0;i[a+1072>>2]=b;c=b+i[a+1076>>2]|0;i[a+1076>>2]=c;g[i[a+1064>>2]+d|0]=j[a+1080|0]?c:b;i[a+1060>>2]=i[a+1060>>2]+1;e=a,f=$d(i[a+1056>>2])+i[a+1064>>2]|0,i[e+1064>>2]=f;i[a+1068>>2]=i[a+1068>>2]+ -1}function xH(a,b){var c=0,d=0;c=Xa-16|0;Xa=c;fc(c+8|0,a);i[114610]=0;a=F(21,c+8|0)|0;d=i[114610];i[114610]=0;a:{if((d|0)==1){break a}i[114610]=0;a=C(22,a|0,b|0)|0;b=i[114610];i[114610]=0;if((b|0)==1){break a}ub(c+8|0);Xa=c+16|0;return a}a=B()|0;A()|0;ub(c+8|0);E(a|0);x()}function rv(a){var b=0,c=0;a:{if(l[a+20>>2]<=l[a+28>>2]){break a}$a[i[a+36>>2]](a,0,0)|0;if(i[a+20>>2]){break a}return-1}b=i[a+4>>2];c=i[a+8>>2];if(b>>>0<c>>>0){b=b-c|0;$a[i[a+40>>2]](a,b,b>>31,1)|0}i[a+28>>2]=0;i[a+16>>2]=0;i[a+20>>2]=0;i[a+4>>2]=0;i[a+8>>2]=0;return 0}function Xl(a,b){var c=0,d=0,e=0,f=0;i[a>>2]=0;i[a+4>>2]=0;e=a;f=a;if(b){a=b;c=r(a);d=(c|32)+113&63;b=d&31;if(32<=(d&63)>>>0){d=a<<b;b=0}else{d=(1<<b)-1&a>>>32-b;b=a<<b}a=16414-c<<16;c=0;b=b+c|0;a=a+(d^65536)|0;a=b>>>0<c>>>0?a+1|0:a}else{a=0;b=0}i[f+8>>2]=b;i[e+12>>2]=a}function Xe(a,b){var c=0,d=0,e=0,f=0;c=lb(a);a:{if((c|0)!=(lb(b)|0)){break a}d=xb(a);b=xb(b);b:{if(!oe(a)){if(c){break b}return 1}return!xm(d,b,c)}while(1){a=j[b|0];e=j[d|0];f=(a|0)==(e|0);if((a|0)!=(e|0)){break a}b=b+1|0;d=d+1|0;c=c+ -1|0;if(c){continue}break}}return f}function ZLa(a,b){var c=0;c=Xa-32|0;Xa=c;i[c+16>>2]=b;i[c+24>>2]=a;a:{if(!pb(c+24|0,c+16|0)){break a}i[c>>2]=i[c+24>>2];if(!pb(he(c),c+16|0)){break a}while(1){if(NS(i[c+24>>2],i[c>>2])){i[c+24>>2]=i[c>>2]}if(pb(he(c),c+16|0)){continue}break}}Xa=c+32|0;return i[c+24>>2]}function Xn(a,b,c){var d=0,e=0,f=0;d=a*a;f=d*(d*d)*(d*1.58969099521155e-10+ -2.5050760253406863e-8)+(d*(d*27557313707070068e-22+ -.0001984126982985795)+.00833333333332249);e=d*a;if(!c){return e*(d*f+ -.16666666666666632)+a}return a-(d*(b*.5-e*f)-b+e*.16666666666666632)}function Nga(a){var b=p(0),c=0,d=0;b=p(1);c=i[a+20>>2];if(c){b=p(p(j[c+26|0])*p(.10000000149011612))}b=b<p(.10000000149011612)?p(1):b;c=a;if($a[i[i[a>>2]+132>>2]](a)|0){d=AH(i[a+16>>2]);a=i[a+16>>2];b=p(p(b*p(l[a+480232>>2]))/p(m[d+8>>2]*m[AH(a)+20>>2]))}m[c+4196>>2]=b}function IY(a,b){a=a|0;b=b|0;var c=0;c=Xa-16|0;Xa=c;b=th(c,a+8|0,b);a=i[b>>2];a:{while(1){if(i[b+4>>2]==(a|0)){break a}a=i[b>>2];i[114610]=0;ls(a);a=i[114610];i[114610]=0;if((a|0)!=1){a=i[b>>2]+4|0;i[b>>2]=a;continue}break}a=B()|0;A()|0;ac(b);E(a|0);x()}ac(b);Xa=c+16|0}function FE(a,b){var c=0,d=0,e=0;gNa(+a);c=dNa(1)|0;d=dNa(0)|0;e=c;c=c>>>20&2047;if((c|0)!=2047){if(!c){c=b;if(a==0){b=0}else{a=FE(a*0x10000000000000000,b);b=i[b>>2]+ -64|0}i[c>>2]=b;return a}i[b>>2]=c+ -1022;eNa(0,d|0);eNa(1,e&-2146435073|1071644672);a=+fNa()}return a}function $Ia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=Xa-16|0;Xa=d;g[d+15|0]=1;g[d+14|0]=a>>>2;a=j[Ug(d+15|0,d+14|0)|0];e=b>>>0<2|a>>>0<15;if(!e){g[d+13|0]=1;g[d+12|0]=((a+b|0)+ -2|0)/(b+ -1|0);a=j[Ug(d+13|0,d+12|0)|0]}Xa=d+16|0;return(c?a<<4|(e?15:0):a&15|(e?-16:0))&255}function zq(a,b){var c=0,d=0,e=0;c=-1;a:{if((a|0)==-1){break a}e=i[b+76>>2]>=0?1:e;b:{d=i[b+4>>2];c:{if(!d){UD(b);d=i[b+4>>2];if(!d){break c}}if(d>>>0>i[b+44>>2]+ -8>>>0){break b}}if(!e){break a}return-1}c=d+ -1|0;i[b+4>>2]=c;g[c|0]=a;i[b>>2]=i[b>>2]&-17;c=a}return c}function ry(a,b){var c=0,d=0,e=0,f=0;c=a;d=a+1024|0;a:{if((d|0)==(a|0)){b=0;break a}f=b?224:240;b=0;while(1){a=c;e=a+16|0;if((a|0)!=(e|0)){while(1){b=((j[Nb(a,0)|0]&f)!=0)+b|0;a=a+4|0;if((e|0)!=(a|0)){continue}break}}c=c+16|0;if((d|0)!=(c|0)){continue}break}}return b}function fta(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=Xa-32|0;Xa=e;i[e+24>>2]=d;d=ij(a,c);Ue(e,i[a+28>>2]);f=i[e+12>>2];i[e+16>>2]=i[e+8>>2];i[e+20>>2]=f;a:{if(!d){b:{if(!dd(a,5)){break b}break a}}dta(e+24|0,i[a+28>>2],b)}a=Ai(a,d,c,e+16|0);Xa=e+32|0;return a|0}function Pka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=Xa-32|0;Xa=c;e=-1;d=a;a=c+8|0;d=Aka(d,a);if(!d){KI(a)}a:{if(!d){break a}e=0;if(!OI(c+8|0)){break a}if(b){a=c+16|0;if(i[b>>2]!=(j[a|0]|j[a+1|0]<<8|(j[a+2|0]<<16|j[a+3|0]<<24))|i[b+4>>2]){break a}}e=1}Xa=c+32|0;return e|0}function Mqa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,h=0;d=Xa-16|0;Xa=d;i[d+12>>2]=c;i[d+8>>2]=i[a>>2];e=i[rb(d+12|0,d+8|0)>>2];b=jb(b);if(e){a=i[a+20>>2];c=e;while(1){f=a,h=jb(j[b|0])^128,g[f|0]=h;a=a+1|0;b=b+1|0;c=c+ -1|0;if(c){continue}break}}Xa=d+16|0;return e|0}function lza(a,b){var c=0,d=0,e=0;e=Xa-16|0;Xa=e;c=e;i[c>>2]=a;d=i[a+4>>2];i[c+4>>2]=d;i[c+8>>2]=d+56;d=fb(a);a=i[c+4>>2];i[114610]=0;G(979,d|0,a|0,b|0);a=i[114610];i[114610]=0;if((a|0)!=1){i[c+4>>2]=i[c+4>>2]+56;sb(c);Xa=e+16|0;return}a=B()|0;A()|0;sb(c);E(a|0);x()}function ix(a,b){var c=0,d=0;a:{if(b){ix(a,i[b>>2]);ix(a,i[b+4>>2]);a=Pb(a);i[114610]=0;c=F(1385,b+16|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break a}i[114610]=0;D(1386,a|0,c|0);c=i[114610];i[114610]=0;if((c|0)==1){break a}zs(a,b,1)}return}a=H(0)|0;A()|0;gb(a);x()}function _2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,h=0;a:{if(!j[a+44|0]){c=(c|0)>0?c:0;while(1){if((c|0)==(d|0)){break a}if(((f=a,h=cg(g[b|0]),e=i[i[a>>2]+52>>2],$a[e](f|0,h|0)|0)|0)==-1){return d|0}else{b=b+1|0;d=d+1|0;continue}}}c=xi(b,1,c,i[a+32>>2])}return c|0}function Jr(a,b){var c=0,d=0;a:{if(b){Jr(a,i[b>>2]);Jr(a,i[b+4>>2]);a=Pb(a);i[114610]=0;c=F(1380,b+14|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break a}i[114610]=0;D(1381,a|0,c|0);c=i[114610];i[114610]=0;if((c|0)==1){break a}Xo(a,b,1)}return}a=H(0)|0;A()|0;gb(a);x()}function ota(a){a=a|0;var b=0,c=0,d=0;c=Xa-32|0;Xa=c;b=255;a:{if(ph(a)>>>0<=49){b=Lx(c,i[a+12>>2]);i[114610]=0;D(1179,a|0,b|0);d=i[114610];i[114610]=0;if((d|0)==1){break a}dl(b);Ko(a,ph(a)+ -1&255);b=ph(a)+ -1|0}Xa=c+32|0;return b&255}a=B()|0;A()|0;dl(b);E(a|0);x()}function Nz(a,b,c){var d=0,e=0;a=a+3|0;a=(j[a|0]|j[a+1|0]<<8)>>>o(c,3)|0;e=a>>>2&1|j[b+12|0]&-4;d=e|a<<1&2;g[b+12|0]=d;if(a&2){g[b+12|0]=d|4;return}g[b+12|0]=d&251;if(!(!(a>>>9-(c<<1)&1)|(a&3)!=1)){a=j[b+13|0]|j[b+14|0]<<8;g[b+15|0]=a;g[b+16|0]=a>>>8;g[b+12|0]=e|4}}function u9(a,b){a=a|0;b=b|0;var c=p(0),d=p(0);a:{if((b|0)<0){break a}a=a+24|0;if(k[i[a>>2]+480188>>1]<=(b|0)){break a}b=o(b,896);c=p(p(j[(b+i[a>>2]|0)+1075847|0])*p(.0078125));d=p(c*c);c=p(p(j[(b+i[a>>2]|0)+1075846|0])*p(.0078125));c=p(w(p(d+p(c*c))))}return p(c)}function Sy(a,b){var c=0,d=0;a:{if(b){Sy(a,i[b>>2]);Sy(a,i[b+4>>2]);a=Pb(a);i[114610]=0;c=F(735,b+16|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break a}i[114610]=0;D(736,a|0,c|0);c=i[114610];i[114610]=0;if((c|0)==1){break a}Xg(a,b,1)}return}a=H(0)|0;A()|0;gb(a);x()}function Qy(a,b){var c=0,d=0;a:{if(b){Qy(a,i[b>>2]);Qy(a,i[b+4>>2]);a=Pb(a);i[114610]=0;c=F(731,b+16|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break a}i[114610]=0;D(734,a|0,c|0);c=i[114610];i[114610]=0;if((c|0)==1){break a}Xg(a,b,1)}return}a=H(0)|0;A()|0;gb(a);x()}function By(a,b){var c=0,d=0;a:{if(b){By(a,i[b>>2]);By(a,i[b+4>>2]);a=Pb(a);i[114610]=0;c=F(827,b+14|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break a}i[114610]=0;D(828,a|0,c|0);c=i[114610];i[114610]=0;if((c|0)==1){break a}Xo(a,b,1)}return}a=H(0)|0;A()|0;gb(a);x()}function xEa(a,b,c){var d=0;d=Xa-32|0;Xa=d;i[d+16>>2]=b;i[d+24>>2]=a;i[d+8>>2]=c;a:{if(!pb(d+24|0,d+16|0)){break a}while(1){a=i[d+24>>2];if(i[i[d+8>>2]>>2]==(j[a|0]|j[a+1|0]<<8)){break a}dk(d+24|0);if(pb(d+24|0,d+16|0)){continue}break}}Xa=d+32|0;return i[d+24>>2]}function moa(a,b){var c=0,d=0,e=0;a:{if(j[a+4|0]){c=i[a>>2];i[114610]=0;d=F(1380,b+14|0)|0;e=i[114610];i[114610]=0;if((e|0)==1){break a}i[114610]=0;D(1381,c|0,d|0);c=i[114610];i[114610]=0;if((c|0)==1){break a}}if(b){Xo(i[a>>2],b,1)}return}a=H(0)|0;A()|0;gb(a);x()}function foa(a,b){var c=0,d=0,e=0;a:{if(j[a+4|0]){c=i[a>>2];i[114610]=0;d=F(1385,b+16|0)|0;e=i[114610];i[114610]=0;if((e|0)==1){break a}i[114610]=0;D(1386,c|0,d|0);c=i[114610];i[114610]=0;if((c|0)==1){break a}}if(b){zs(i[a>>2],b,1)}return}a=H(0)|0;A()|0;gb(a);x()}function Nqa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,h=0;d=Xa-16|0;Xa=d;i[d+12>>2]=c;i[d+8>>2]=i[a>>2];e=i[rb(d+12|0,d+8|0)>>2];b=jb(b);if(e){a=i[a+20>>2];c=e;while(1){f=a,h=Em(j[b|0]),g[f|0]=h;a=a+1|0;b=b+1|0;c=c+ -1|0;if(c){continue}break}}Xa=d+16|0;return e|0}function MC(a){a=a|0;var b=0,c=0,d=0;i[a>>2]=62488;b=i[a+8>>2];i[114610]=0;c=R(2445)|0;d=i[114610];i[114610]=0;a:{if((d|0)!=1){if((b|0)==(c|0)){break a}b=i[a+8>>2];i[114610]=0;Tu(b);b=i[114610];i[114610]=0;if((b|0)!=1){break a}}a=H(0)|0;A()|0;gb(a);x()}return a|0}function Lqa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=Xa-16|0;Xa=e;i[e+12>>2]=c;i[e+8>>2]=i[a>>2];f=i[rb(e+12|0,e+8|0)>>2];b=jb(b);if(f){a=i[a+20>>2];c=f;while(1){d=jb(j[b|0])+d|0;g[a|0]=d;a=a+1|0;b=b+1|0;c=c+ -1|0;if(c){continue}break}}Xa=e+16|0;return f|0}function AQ(a){var b=0;a:{if((j[a|0]|j[a+1|0]<<8|(j[a+2|0]<<16|j[a+3|0]<<24))!=778924148?(j[a|0]|j[a+1|0]<<8|(j[a+2|0]<<16|j[a+3|0]<<24))!=1297108297:0){break a}b=a+34|0;if((j[b|0]|j[b+1|0]<<8)>>>0>255){break a}a=a+36|0;return(j[a|0]|j[a+1|0]<<8)>>>0<4e3}return 0}function wx(a,b){var c=0,d=0;a:{if(b){wx(a,i[b>>2]);wx(a,i[b+4>>2]);a=Pb(a);i[114610]=0;c=F(1257,b+16|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break a}i[114610]=0;D(1258,a|0,c|0);a=i[114610];i[114610]=0;if((a|0)==1){break a}vx(b)}return}a=H(0)|0;A()|0;gb(a);x()}function Z4(a,b){var c=p(0),d=0,e=0,f=0,g=p(0);if((a|0)>=2){a=a>>1;d=(a|0)>1?a:1;e=1/+(a|0);a=0;while(1){c=p(Hh((+(a|0)*1.5707963705062866+.7853981852531433)*e));f=(a<<2)+b|0,g=p(Hh(+p(c*c)*1.5707963705062866)),m[f>>2]=g;a=a+1|0;if((d|0)!=(a|0)){continue}break}}}function Toa(a,b){var c=0,d=0,e=0,f=0;c=Xa-96|0;Xa=c;UK(b,c,c+96|0);b=0;while(1){d=b<<3;e=d+a|0;f=i[c+d>>2];d=i[(d|4)+c>>2];i[e>>2]=f;i[e+4>>2]=d&65535;b=b+1|0;if((b|0)!=12){continue}break}i[a+104>>2]=0;i[a+96>>2]=!(i[a+88>>2]|i[a+92>>2]);i[a+100>>2]=0;Xa=c+96|0}function REa(a,b){var c=0,d=0;c=Xa-16|0;Xa=c;d=i[b+12>>2];i[c+8>>2]=i[b+8>>2];i[c+12>>2]=d;d=i[b+4>>2];i[c>>2]=i[b>>2];i[c+4>>2]=d;WJa(a,NP(c));i[a>>2]=76516;d=i[b+4>>2];i[a+296>>2]=i[b>>2];i[a+300>>2]=d;d=i[b+12>>2];i[a+304>>2]=i[b+8>>2];i[a+308>>2]=d;Xa=c+16|0}function NH(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=Xa-16|0;Xa=e;i[e+12>>2]=0;xc(a+12|0,d);if(b){d=b;if(2097151<b>>>0){ic(32635);x()}f=Yb(d<<11,4)}i[a>>2]=f;c=(c<<11)+f|0;i[a+8>>2]=c;i[a+4>>2]=c;g=Mb(a),h=(b<<11)+f|0,i[g>>2]=h;Xa=e+16|0;return a|0}function LH(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=Xa-16|0;Xa=e;i[e+12>>2]=0;xc(a+12|0,d);if(b){d=b;if(1073741823<b>>>0){ic(32635);x()}f=Yb(d<<2,4)}i[a>>2]=f;c=(c<<2)+f|0;i[a+8>>2]=c;i[a+4>>2]=c;g=Mb(a),h=(b<<2)+f|0,i[g>>2]=h;Xa=e+16|0;return a|0}function yia(a,b){var c=0,d=0,e=0;a:{if(j[a+4|0]){c=i[a>>2];i[114610]=0;d=F(735,b+16|0)|0;e=i[114610];i[114610]=0;if((e|0)==1){break a}i[114610]=0;D(736,c|0,d|0);c=i[114610];i[114610]=0;if((c|0)==1){break a}}if(b){Xg(i[a>>2],b,1)}return}a=H(0)|0;A()|0;gb(a);x()}function pC(a,b){var c=0,d=0,e=0,f=0,h=0;c=Xa-16|0;Xa=c;i[b>>2]=0;g[c+15|0]=0;f=Bg(a,c+15|0);d=j[c+15|0];i[b>>2]=d>>>2;d=d&3;if(d){while(1){g[c+15|0]=0;h=Bg(a,c+15|0);e=e+1|0;i[b>>2]=i[b>>2]|j[c+15|0]<<(e<<3)+ -2;f=f&h;if((d|0)!=(e|0)){continue}break}}Xa=c+16|0}function oJa(a){var b=0,c=0,d=0,e=0;if(!j[a+8|0]){if(j[a+24|0]){g[a+24|0]=0;c=a+40|0;while(1){d=ji(c,b),e=0,g[d+8|0]=e;b=b+1|0;if((b|0)!=16){continue}break}b=a+28|0;ck(b,0);qR(b)}b=a+12|0;ck(b,i[a+4>>2]);$a[i[i[a>>2]+44>>2]](a,i[b>>2],0,i[a+4>>2])|0;g[a+8|0]=1}}function Jo(a,b,c,d){var e=0,f=0,h=0,k=0;a:{e=Sj(a,b);if((e|0)==255){break a}if(Si(a)){break a}b=ji(a+314|0,e);e=GL(e);if(!(f=0,h=!(g[Nb(b,10)|0]&1),k=d,k?f:h)){Ng(i[a>>2],e- -64&65535,FL(c,j[Nb(b,2)|0]))}if(d){break a}Ng(i[a>>2],e+67&65535,FL(c,j[Nb(b,3)|0]))}}function GFa(a,b){var c=0,d=0,e=0;a:{if(j[a+4|0]){c=i[a>>2];i[114610]=0;d=F(731,b+16|0)|0;e=i[114610];i[114610]=0;if((e|0)==1){break a}i[114610]=0;D(734,c|0,d|0);c=i[114610];i[114610]=0;if((c|0)==1){break a}}if(b){Xg(i[a>>2],b,1)}return}a=H(0)|0;A()|0;gb(a);x()}function FCa(a,b){var c=0,d=0,e=0;a:{if(j[a+4|0]){c=i[a>>2];i[114610]=0;d=F(827,b+14|0)|0;e=i[114610];i[114610]=0;if((e|0)==1){break a}i[114610]=0;D(828,c|0,d|0);c=i[114610];i[114610]=0;if((c|0)==1){break a}}if(b){Xo(i[a>>2],b,1)}return}a=H(0)|0;A()|0;gb(a);x()}function ww(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{if(!bf(a)){break a}while(1){if(!rh(se(a,e))){break a}d=d+1|0;e=d&65535;if(bf(a)>>>0>e>>>0){continue}break}}if(!((d&65535)>>>0>=k[i[i[a+12>>2]+8>>2]+10>>1]?c:0)){return(Sf(a,d&65535,b)?d:-1)&65535}return 65535}function O5(a){var b=0,c=0,d=p(0);if((a|0)<=128){return m[(a<<2)+48080>>2]}c=(a|0)<1024;a=c?a<<3:a;b=a<<1&64;d=p(p((a&63)-b|0)/p((a&-64)+b|0));return p(p(p(p(p(p(d*p(.2222222238779068))+p(1.3333333730697632))*d)+p(1))*(c?p(16):p(256)))*m[(a+b>>6<<2)+48080>>2])}function Bj(a){var b=0,c=0;a:{b=i[a+1396>>2];if((b|0)>24){break a}if(!b){i[a+1392>>2]=0}while(1){if(j[a+1376|0]?0:i[a+1384>>2]){break a}c=Sq(a);if((c|0)==-1){break a}b=i[a+1396>>2];i[a+1396>>2]=b+8;i[a+1392>>2]=i[a+1392>>2]+(c<<b);if((b|0)<17){continue}break}}}function qK(a,b,c){a:{switch(b|0){case 0:RJ(a,c);return;case 1:Vna(a,c);return;case 2:Qna(a,c);return;case 3:qo(a,c,1520);return;case 4:qo(a,c,2544);return;case 5:qo(a,c,3568);return;case 6:qo(a,c,4592);return;case 7:qo(a,c,5616);return;default:break a}}Ke(a)}function TB(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=Xa-16|0;Xa=c;d=P(16)|0;VB();a=Ac(c+8|0,a,85304);i[114610]=0;e=i[a+4>>2];i[c>>2]=i[a>>2];i[c+4>>2]=e;I(2844,d|0,c|0,b|0)|0;a=i[114610];i[114610]=0;if((a|0)!=1){W(d|0,70712,2845);x()}a=B()|0;A()|0;Q(d|0);E(a|0);x()}function nMa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=Qx(a);a:{if(!b){break a}i[114610]=0;D(404,a|0,b|0);e=i[114610];i[114610]=0;if((e|0)!=1){i[114610]=0;G(405,a|0,b|0,c|0);b=i[114610];i[114610]=0;if((b|0)!=1){break a}}a=B()|0;A()|0;js(d);E(a|0);x()}return a|0}function hGa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=Xa-32|0;Xa=e;i[e+24>>2]=d;d=ij(a,c);Ue(e,i[a+28>>2]);f=i[e+12>>2];i[e+16>>2]=i[e+8>>2];i[e+20>>2]=f;a:{if(!d){b:{if(!dd(a,5)){break b}break a}}cta(i[a+28>>2],b,i[e+24>>2])}Ai(a,d,c,e+16|0);Xa=e+32|0}function dV(a,b,c,d){var e=0,f=0,g=0;f=Xa-48|0;Xa=f;e=f+40|0;e=bV(f+24|0,YA(e,1),Ac(f+16|0,e,1));g=i[e>>2];i[114610]=0;N(285,g|0,b|0,c|0,d|0)|0;b=i[114610];i[114610]=0;if((b|0)!=1){Cn(a,Mb(i[e>>2]),sd(e));RA(e);Xa=f+48|0;return}a=B()|0;A()|0;RA(e);E(a|0);x()}function cJ(a,b){var c=0,d=0,e=0,f=0;c=Xa-32|0;Xa=c;if(i[a+4>>2]==i[b+4>>2]){d=i[a+4>>2];e=i[a>>2];i[c+24>>2]=e;i[c+28>>2]=d;f=i[b+4>>2];a=c;b=i[b>>2];i[a+16>>2]=b;i[a+20>>2]=f;i[a+8>>2]=e;i[a+12>>2]=d;i[a>>2]=b;i[a+4>>2]=f;d=!hma(a+8|0,a)}Xa=c+32|0;return d}function _sa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=Xa-32|0;Xa=e;i[e+24>>2]=d;d=ij(a,c);Ue(e,i[a+28>>2]);f=i[e+12>>2];i[e+16>>2]=i[e+8>>2];i[e+20>>2]=f;a:{if(!d){b:{if(!dd(a,5)){break b}break a}}ita(i[a+28>>2],b,i[e+24>>2])}Ai(a,d,c,e+16|0);Xa=e+32|0}function XAa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=Uz(a);a:{if(!b){break a}i[114610]=0;D(921,a|0,b|0);e=i[114610];i[114610]=0;if((e|0)!=1){i[114610]=0;G(922,a|0,b|0,c|0);b=i[114610];i[114610]=0;if((b|0)!=1){break a}}a=B()|0;A()|0;pt(d);E(a|0);x()}return a|0}function Via(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=Xa-32|0;Xa=e;i[e+24>>2]=d;d=ij(a,c);Ue(e,i[a+28>>2]);f=i[e+12>>2];i[e+16>>2]=i[e+8>>2];i[e+20>>2]=f;a:{if(!d){b:{if(!dd(a,5)){break b}break a}}Kia(i[a+28>>2],b,i[e+24>>2])}Ai(a,d,c,e+16|0);Xa=e+32|0}function Osa(a,b,c){var d=0;d=Xa-16|0;Xa=d;i[d+12>>2]=c;h[d+10>>1]=0;i[d+4>>2]=2;c=xk(a,d+10|0,i[rb(d+12|0,d+4|0)>>2])>>>0>=0;a=_a;if((a|0)>0?1:(a|0)>=0?c:0){i[d+4>>2]=2;i[rb(d+12|0,d+4|0)>>2]}h[d+4>>1]=k[d+10>>1];a=d+4|0;h[b>>1]=j[a|0]|j[a+1|0]<<8;Xa=d+16|0}function AX(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;if(Nf(a,i[b+8>>2],0)){su(b,c,d);return}e=i[a+12>>2];f=a+16|0;MB(f,b,c,d);a:{if((e|0)<2){break a}e=(e<<3)+f|0;a=a+24|0;while(1){MB(a,b,c,d);if(j[b+54|0]){break a}a=a+8|0;if(a>>>0<e>>>0){continue}break}}}function y0(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=Xa-16|0;Xa=g;i[g+8>>2]=b;fc(g,d);i[114610]=0;b=F(2449,g|0)|0;d=i[114610];i[114610]=0;if((d|0)!=1){ub(g);dD(a,f+24|0,g+8|0,c,e,b);Xa=g+16|0;return i[g+8>>2]}a=B()|0;A()|0;ub(g);E(a|0);x()}function x0(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=Xa-16|0;Xa=g;i[g+8>>2]=b;fc(g,d);i[114610]=0;b=F(2449,g|0)|0;d=i[114610];i[114610]=0;if((d|0)!=1){ub(g);cD(a,f+16|0,g+8|0,c,e,b);Xa=g+16|0;return i[g+8>>2]}a=B()|0;A()|0;ub(g);E(a|0);x()}function wQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=Zy(a);a:{if(!b){break a}i[114610]=0;D(683,a|0,b|0);e=i[114610];i[114610]=0;if((e|0)!=1){i[114610]=0;G(684,a|0,b|0,c|0);b=i[114610];i[114610]=0;if((b|0)!=1){break a}}a=B()|0;A()|0;Qs(d);E(a|0);x()}return a|0}function jS(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=eU(a);a:{if(!b){break a}i[114610]=0;D(467,a|0,b|0);e=i[114610];i[114610]=0;if((e|0)!=1){i[114610]=0;G(468,a|0,b|0,c|0);b=i[114610];i[114610]=0;if((b|0)!=1){break a}}a=B()|0;A()|0;CA(d);E(a|0);x()}return a|0}function et(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=Lt(a);a:{if(!b){break a}i[114610]=0;D(564,a|0,b|0);e=i[114610];i[114610]=0;if((e|0)!=1){i[114610]=0;G(565,a|0,b|0,c|0);b=i[114610];i[114610]=0;if((b|0)!=1){break a}}a=B()|0;A()|0;Ip(d);E(a|0);x()}return a|0}function eY(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;f=Xa-16|0;Xa=f;d=iq(a);e=lb(a);a:{if(d-e>>>0>=c>>>0){if(!c){break a}d=xb(a);Gh(d+(e<<2)|0,b,c);b=c+e|0;yg(a,b);i[f+12>>2]=0;ye(d+(b<<2)|0,f+12|0);break a}_B(a,d,(c+e|0)-d|0,e,e,0,c,b)}Xa=f+16|0;return a|0}function Wia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=Xa-32|0;Xa=e;i[e+24>>2]=d;d=ij(a,c);Ue(e,i[a+28>>2]);f=i[e+12>>2];i[e+16>>2]=i[e+8>>2];i[e+20>>2]=f;a:{if(!d){b:{if(!dd(a,5)){break b}break a}}dI(i[a+28>>2],b,i[e+24>>2])}Ai(a,d,c,e+16|0);Xa=e+32|0}function rka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=Xa-32|0;Xa=d;i[d+16>>2]=c;i[d+24>>2]=b;b=i[a>>2];e=d,f=Jb(a),i[e+8>>2]=f;b=b+o(yr(d+24|0,d+8|0),6)|0;if(pb(d+24|0,d+16|0)){Xy(a,Bw(b+o(yr(d+16|0,d+24|0),6)|0,i[a+4>>2],b))}a=Pe(b);Xa=d+32|0;return a|0}function qfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;qH(a,b,c,d);i[a+4232>>2]=1056964608;b=a+4224|0;i[b>>2]=1056964608;i[b+4>>2]=1048406533;b=a+4216|0;i[b>>2]=1020054733;i[b+4>>2]=1065353216;i[a+4208>>2]=1056964608;i[a+4212>>2]=1065353216;i[a>>2]=81132;return a|0}function pS(a){var b=0,c=0,d=0,e=0;b=a+5|0;c=j[b|0]|j[b+1|0]<<8;b=c+j[a+2|0]|0;if(b>>>0<c>>>0){d=1}c=d<<1|b>>>31;d=b<<1;b=c;e=d;a=a+3|0;a=j[a|0]|j[a+1|0]<<8;c=a>>>30|0;d=a<<2;e=e+d|0;a=b+c|0;a=e>>>0<d>>>0?a+1|0:a;b=e+47|0;if(b>>>0<47){a=a+1|0}_a=a;return b}function d8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=Xa-16|0;Xa=d;e=Hq(a);i[a>>2]=76848;f=Zv(a+32|0,d+8|0);i[a+48>>2]=c;i[a+44>>2]=0;i[114610]=0;D(182,a|0,b|0);b=i[114610];i[114610]=0;if((b|0)!=1){Xa=d+16|0;return a|0}a=B()|0;A()|0;eb(f);Kk(e);E(a|0);x()}function aaa(a,b){var c=0,d=0,e=0;c=Xa-80|0;Xa=c;i[c+40>>2]=i[b+32>>2];i[c>>2]=i[b+36>>2];e=i[wf(c+40|0,c)>>2];a:{if(i[b+32>>2]==i[Qo(c+40|0)+32>>2]){d=-1;if(i[b+36>>2]==i[Qo(c)+36>>2]){break a}}d=0;if((e|0)<1){break a}d=(e+500|0)/1e3|0}i[a>>2]=d;Xa=c+80|0}function Dta(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=Xa-32|0;Xa=d;i[d+16>>2]=c;i[d+24>>2]=b;b=i[a>>2];e=d,f=Jb(a),i[e+8>>2]=f;b=b+(qp(d+24|0,d+8|0)<<1)|0;if(pb(d+24|0,d+16|0)){wp(a,Oe(b+(qp(d+16|0,d+24|0)<<1)|0,i[a+4>>2],b))}a=Pe(b);Xa=d+32|0;return a|0}function AK(a,b,c){var d=0,e=0;d=(c|0)==1;c=i[(o(b,896)+a|0)+1075072>>2];a:{if(d&(c&134218752)!=0|c&67108864){break a}if(k[a+480188>>1]<=b>>>0){c=k[(o(b,896)+a|0)+1075792>>1];b=c?c+ -1|0:b}b=b&65535;if(b>>>0>126){break a}e=j[((b<<5)+a|0)+480288|0]}return e}function xr(a,b,c){var d=0,e=0,f=0;d=Xa-32|0;Xa=d;a:{if(!(!b|!c)){e=Bb(d,b);i[114610]=0;G(1567,d+16|0,e|0,c|0);f=i[114610];i[114610]=0;if((f|0)==1){break a}mb(a+36|0,d+16|0);eb(d+16|0);eb(e)}Xa=d+32|0;return(b|0)!=0&(c|0)!=0}a=B()|0;A()|0;eb(e);E(a|0);x()}function s2(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;a:{while(1){if((d|0)!=(e|0)){a=-1;if((b|0)==(c|0)){break a}f=i[b>>2];g=i[d>>2];if((f|0)<(g|0)){break a}if((g|0)<(f|0)){return 1}else{d=d+4|0;b=b+4|0;continue}}break}a=(b|0)!=(c|0)}return a|0}function hna(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=Xa-16|0;Xa=d;e=Xa-16|0;Xa=e;sJ(d,b,c<<24>>24);Xa=e+16|0;b=d;c=xb(d);e=lb(d);i[114610]=0;I(196,a|0,c|0,e|0)|0;c=i[114610];i[114610]=0;if((c|0)!=1){eb(b);Xa=d+16|0;return a|0}a=B()|0;A()|0;eb(b);E(a|0);x()}function Xq(a){var b=0,c=0,d=0,e=0;b=Xa-16|0;Xa=b;i[b+12>>2]=12;i[b+8>>2]=32;if(i[rb(b+12|0,b+8|0)>>2]){while(1){e=xo(a);i[b+8>>2]=32;c=c<<15^e;d=d+15|0;if(d>>>0<l[rb(b+12|0,b+8|0)>>2]){continue}break}}Xa=b+16|0;a=i[b+12>>2];return(a>>>0>31?-1:-1<<a^-1)&c}function S0(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=Xa-16|0;Xa=g;i[g+8>>2]=b;fc(g,d);i[114610]=0;b=F(21,g|0)|0;d=i[114610];i[114610]=0;if((d|0)!=1){ub(g);hD(a,f+24|0,g+8|0,c,e,b);Xa=g+16|0;return i[g+8>>2]}a=B()|0;A()|0;ub(g);E(a|0);x()}function R0(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=Xa-16|0;Xa=g;i[g+8>>2]=b;fc(g,d);i[114610]=0;b=F(21,g|0)|0;d=i[114610];i[114610]=0;if((d|0)!=1){ub(g);gD(a,f+16|0,g+8|0,c,e,b);Xa=g+16|0;return i[g+8>>2]}a=B()|0;A()|0;ub(g);E(a|0);x()}function Jla(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;b=Xa-16|0;Xa=b;d=Wc(a);e=b,f=Jb(a),i[e+8>>2]=f;e=b,f=Kb(a),i[e>>2]=f;if(pb(b+8|0,b)){c=+(d>>>0);while(1){a=i[b+8>>2];n[a>>3]=n[a>>3]/c;n[a+8>>3]=n[a+8>>3]/c;vf(b+8|0);if(pb(b+8|0,b)){continue}break}}Xa=b+16|0}function v2(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,h=0;a:{while(1){if((d|0)!=(e|0)){a=-1;if((b|0)==(c|0)){break a}f=g[b|0];h=g[d|0];if((f|0)<(h|0)){break a}if((h|0)<(f|0)){return 1}else{d=d+1|0;b=b+1|0;continue}}break}a=(b|0)!=(c|0)}return a|0}function TMa(a,b,c,d){var e=0,f=0,g=0,h=0;e=b;f=e>>31;e=e>>31;a=a^e;g=a-e|0;h=(b^f)-((a>>>0<e>>>0)+f|0)|0;e=d;f=e>>31;e=e>>31;a=c^e;e=_Ma(g,h,a-e|0,(d^f)-((a>>>0<e>>>0)+f|0)|0);b=b^d;c=b>>31;a=b>>31;b=e^a;d=b-a|0;_a=(c^_a)-((b>>>0<a>>>0)+c|0)|0;return d}function mka(a,b){a=a|0;b=b|0;var c=0,d=0;d=Xa-32|0;Xa=d;c=Hj(a);if(b){c=o(b,c);a:{b:{if(i[a+12>>2]!=(b|0)){break b}if((If(a)|0)!=(c|0)){break b}oka(a);break a}Tg(d+8|0);c=wQ(d+16|0,c,d+8|0);lka(a,c);kl(c);i[a+12>>2]=b}a=1}else{a=0}Xa=d+32|0;return a|0}function br(a){var b=0,c=0;c=a+24|0;b=i[c>>2];i[114610]=0;F(1402,b|0)|0;b=i[114610];i[114610]=0;if((b|0)!=1){Sc(a+68|0);We(a+36|0);$e(a+32|0);ih(c);Ec(a+4|0);Ec(a);return a}b=H(0)|0;A()|0;Sc(a+68|0);We(a+36|0);$e(a+32|0);ih(c);Ec(a+4|0);Ec(a);gb(b);x()}function UD(a){var b=0,c=0;b=j[a+74|0];g[a+74|0]=b+ -1|b;if(l[a+20>>2]>l[a+28>>2]){$a[i[a+36>>2]](a,0,0)|0}i[a+28>>2]=0;i[a+16>>2]=0;i[a+20>>2]=0;b=i[a>>2];if(b&4){i[a>>2]=b|32;return-1}c=i[a+44>>2]+i[a+48>>2]|0;i[a+8>>2]=c;i[a+4>>2]=c;return b<<27>>31}function Ti(a){a=a|0;var b=0,c=0;b=Xa-48|0;Xa=b;if(!Uc(a)){fM(b+32|0,a);eM(b+24|0,a);c=i[b+36>>2];i[b+16>>2]=i[b+32>>2];i[b+20>>2]=c;c=i[b+28>>2];i[b+8>>2]=i[b+24>>2];i[b+12>>2]=c;Ata(b+40|0,b+16|0,b+8|0);c=zz(Jb(a),i[b+44>>2])}Xa=b+48|0;return c&65535}function LDa(a){var b=0;b=Xa-16|0;Xa=b;g[a|0]=0;g[a+1|0]=0;g[a+2|0]=0;g[a+3|0]=0;g[a+4|0]=0;g[a+5|0]=0;g[a+6|0]=0;g[a+7|0]=0;g[a+16|0]=0;g[a+17|0]=0;g[a+8|0]=0;g[a+9|0]=0;g[a+10|0]=0;g[a+11|0]=0;g[a+12|0]=0;g[a+13|0]=0;g[a+14|0]=0;g[a+15|0]=0;Xa=b+16|0}function y$(a,b){a=a|0;b=b|0;var c=0,d=0;c=N_(a);a:{if(!b){break a}i[114610]=0;D(2554,a|0,b|0);d=i[114610];i[114610]=0;if((d|0)!=1){i[114610]=0;D(2555,a|0,b|0);b=i[114610];i[114610]=0;if((b|0)!=1){break a}}a=B()|0;A()|0;IC(c);E(a|0);x()}return a|0}



function xna(a){var b=0,c=0;c=a+946300|0;b=a+906300|0;while(1){a=i[b>>2];a:{if(!a){break a}if(!($a[i[i[a>>2]+112>>2]](a)|0)){break a}$a[i[i[a>>2]+104>>2]](a,0);$a[i[i[a>>2]+92>>2]](a);$a[i[i[a>>2]+120>>2]](a)}b=b+160|0;if((c|0)!=(b|0)){continue}break}}function IEa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=Xa-48|0;Xa=c;a:{if(!wb(a,1)){break a}vEa(b);d=id(a);if(!d){break a}while(1){d=d+ -1|0;b:{if(!pEa(a,c+8|0)){break b}e=j[c+8|0];if(e>>>0>63){break b}Tb(JP(b,e),c+8|0,33)}if(d&255){continue}break}}Xa=c+48|0}function e7(a,b,c,d,e){var f=0,g=0,h=0,j=0,k=p(0);if(e){while(1){f=0;if(d){while(1){h=i[rf(b,f,g)>>2];Nb(c,f);j=rf(a,f,g),k=p(p(h|0)*p(7.450580596923828e-9)),m[j>>2]=k;f=f+1|0;if((f|0)!=(d|0)){continue}break}}g=g+1|0;if((g|0)!=(e|0)){continue}break}}}function d7(a,b,c,d,e){var f=0,g=0,h=0,j=0,k=p(0);if(e){while(1){f=0;if(d){while(1){h=i[rf(b,f,g)>>2];Ae(c,f);j=rf(a,f,g),k=p(p(h|0)*p(7.450580596923828e-9)),m[j>>2]=k;f=f+1|0;if((f|0)!=(d|0)){continue}break}}g=g+1|0;if((g|0)!=(e|0)){continue}break}}}function I7(a,b,c,d,e){var f=0,g=0,h=0,j=0,k=p(0);if(e){while(1){f=0;if(d){while(1){h=i[rf(b,f,g)>>2];Nb(c,f);j=Qm(a,f,g),k=p(p(h|0)*p(7.450580596923828e-9)),m[j>>2]=k;f=f+1|0;if((f|0)!=(d|0)){continue}break}}g=g+1|0;if((g|0)!=(e|0)){continue}break}}}function H7(a,b,c,d,e){var f=0,g=0,h=0,j=0,k=p(0);if(e){while(1){f=0;if(d){while(1){h=i[rf(b,f,g)>>2];Ae(c,f);j=Qm(a,f,g),k=p(p(h|0)*p(7.450580596923828e-9)),m[j>>2]=k;f=f+1|0;if((f|0)!=(d|0)){continue}break}}g=g+1|0;if((g|0)!=(e|0)){continue}break}}}function Sw(a,b,c){var d=0,e=0,f=0;e=Xa-16|0;Xa=e;f=i[b+656>>2];d=0;a:{if(!f){break a}f=bA(f,c);d=a+1074308|0;kb(e+8|0,d,31);a=0;if(!ib(e+8|0)){kb(e,d,93);a=ib(e)^1}if(!(g[hJ(b,c)|0]&1)){d=0;if(!(g[f+12|0]&1)|a){break a}}d=Uc(f)^1}Xa=e+16|0;return d}function Rqa(a,b){var c=0,d=0;a:{if(j[a+4|0]){a=i[a>>2];i[114610]=0;c=F(1257,b+16|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break a}i[114610]=0;D(1258,a|0,c|0);a=i[114610];i[114610]=0;if((a|0)==1){break a}}if(b){vx(b)}return}a=H(0)|0;A()|0;gb(a);x()}function f6(a,b,c,d){var e=0,f=0,g=0,h=0,j=0;g=i[b+4>>2];h=i[b+8>>2];e=i[a+6144>>2];f=e-d|0;e=(e|0)>(d|0)?d:e;f=Tb(c+12|0,(((f|0)>0?f:0)+a|0)+6156|0,e);j=i[b>>2]+(i[b+4>>2]/8|0)|0;b=(h-g|0)/8|0;Tb(e+f|0,j,b);hF(c,f,b+e|0);return i[a+6144>>2]>=(d|0)}function eKa(a,b,c){var d=0;d=Xa-32|0;Xa=d;i[d+16>>2]=b;i[d+24>>2]=a;i[d+8>>2]=c;a:{if(!pb(d+24|0,d+16|0)){break a}while(1){if((mk(i[d+24>>2])|0)==i[i[d+8>>2]>>2]){break a}dk(d+24|0);if(pb(d+24|0,d+16|0)){continue}break}}Xa=d+32|0;return i[d+24>>2]}function w0(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;a=Xa-16|0;Xa=a;i[a+8>>2]=b;fc(a,d);i[114610]=0;b=F(2449,a|0)|0;d=i[114610];i[114610]=0;if((d|0)!=1){ub(a);bD(f+20|0,a+8|0,c,e,b);Xa=a+16|0;return i[a+8>>2]}b=B()|0;A()|0;ub(a);E(b|0);x()}function vCa(a,b){a=a|0;b=b|0;var c=0,d=0;c=fCa(a);a:{if(!b){break a}i[114610]=0;D(875,a|0,b|0);d=i[114610];i[114610]=0;if((d|0)!=1){i[114610]=0;D(876,a|0,b|0);b=i[114610];i[114610]=0;if((b|0)!=1){break a}}a=B()|0;A()|0;RO(c);E(a|0);x()}return a|0}function sCa(a,b){a=a|0;b=b|0;var c=0,d=0;c=cCa(a);a:{if(!b){break a}i[114610]=0;D(877,a|0,b|0);d=i[114610];i[114610]=0;if((d|0)!=1){i[114610]=0;D(878,a|0,b|0);b=i[114610];i[114610]=0;if((b|0)!=1){break a}}a=B()|0;A()|0;PO(c);E(a|0);x()}return a|0}function iGa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=Xa-32|0;Xa=e;i[e+24>>2]=d;d=ij(a,c);Ue(e,i[a+28>>2]);f=i[e+12>>2];i[e+16>>2]=i[e+8>>2];i[e+20>>2]=f;a:{if(!d){if(dd(a,5)){break a}}nQ(i[a+28>>2],b,i[e+24>>2],0)}Ai(a,d,c,e+16|0);Xa=e+32|0}function _wa(a,b){a=a|0;b=b|0;var c=0,d=0;c=Qx(a);a:{if(!b){break a}i[114610]=0;D(404,a|0,b|0);d=i[114610];i[114610]=0;if((d|0)!=1){i[114610]=0;D(1055,a|0,b|0);b=i[114610];i[114610]=0;if((b|0)!=1){break a}}a=B()|0;A()|0;js(c);E(a|0);x()}return a|0}function tj(a,b,c,d){var e=0;if(d&2048){g[a|0]=43;a=a+1|0}if(d&512){g[a|0]=35;a=a+1|0}while(1){e=j[b|0];if(e){g[a|0]=e;a=a+1|0;b=b+1|0;continue}break}e=d&74;b=111;a:{if((e|0)==64){break a}b=d&16384?88:120;if((e|0)==8){break a}b=c?100:117}g[a|0]=b}function kaa(a,b){var c=0,d=0,e=0;c=Xa-48|0;Xa=c;d=E8(c+24|0,Yb(324,4),Ac(c+16|0,c+40|0,1));e=i[d>>2];i[114610]=0;C(2163,e|0,b|0)|0;b=i[114610];i[114610]=0;if((b|0)!=1){Cn(a,Mb(i[d>>2]),sd(d));YF(d);Xa=c+48|0;return}a=B()|0;A()|0;YF(d);E(a|0);x()}function kGa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=Xa-32|0;Xa=e;i[e+24>>2]=d;d=ij(a,c);Ue(e,i[a+28>>2]);f=i[e+12>>2];i[e+16>>2]=i[e+8>>2];i[e+20>>2]=f;a:{if(!d){if(dd(a,5)){break a}}aFa(i[a+28>>2],b,i[e+24>>2])}Ai(a,d,c,e+16|0);Xa=e+32|0}function hMa(a,b){a=a|0;b=b|0;var c=0,d=0;c=SS(a);a:{if(!b){break a}i[114610]=0;D(406,a|0,b|0);d=i[114610];i[114610]=0;if((d|0)!=1){i[114610]=0;D(407,a|0,b|0);b=i[114610];i[114610]=0;if((b|0)!=1){break a}}a=B()|0;A()|0;QS(c);E(a|0);x()}return a|0}function Gn(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;f=Xa-16|0;Xa=f;d=qc(a);e=lb(a);a:{if(d-e>>>0>=c>>>0){if(!c){break a}d=xb(a);jh(d+e|0,b,c);b=c+e|0;yg(a,b);g[f+15|0]=0;Rd(b+d|0,f+15|0);break a}ku(a,d,(c+e|0)-d|0,e,e,0,c,b)}Xa=f+16|0;return a|0}function tna(a,b,c,d){var e=0;e=Xa-16|0;Xa=e;a:{b:{if((b|0)==(c|0)){b=a;a=xb(d);Uh(b,a,lb(d)+a|0);break b}qK(e,c,d);i[114610]=0;G(115,a|0,b|0,e|0);a=i[114610];i[114610]=0;if((a|0)==1){break a}nc(e)}Xa=e+16|0;return}a=B()|0;A()|0;nc(e);E(a|0);x()}function jaa(a,b){var c=0,d=0,e=0;c=Xa-48|0;Xa=c;d=C8(c+24|0,Yb(56,4),Ac(c+16|0,c+40|0,1));e=i[d>>2];i[114610]=0;C(2164,e|0,b|0)|0;b=i[114610];i[114610]=0;if((b|0)!=1){Cn(a,Mb(i[d>>2]),sd(d));VF(d);Xa=c+48|0;return}a=B()|0;A()|0;VF(d);E(a|0);x()}function dq(a,b){var c=0,d=0;if(!a){return Zc(b)}if(b>>>0>=4294967232){i[114584]=48;return 0}c=rX(a+ -8|0,b>>>0<11?16:b+11&-8);if(c){return c+8|0}c=Zc(b);if(!c){return 0}d=i[a+ -4>>2];d=(d&3?-4:-8)+(d&-8)|0;Tb(c,a,d>>>0<b>>>0?d:b);Cb(a);return c}function cz(a,b){a=a|0;b=b|0;var c=0,d=0;c=Lt(a);a:{if(!b){break a}i[114610]=0;D(564,a|0,b|0);d=i[114610];i[114610]=0;if((d|0)!=1){i[114610]=0;D(673,a|0,b|0);b=i[114610];i[114610]=0;if((b|0)!=1){break a}}a=B()|0;A()|0;Ip(c);E(a|0);x()}return a|0}function _ja(a,b,c){var d=0,e=0;if(b){while(1){d=c;e=j[d|0]|j[d+1|0]<<8|(j[d+2|0]<<16|j[d+3|0]<<24);g[a|0]=e;g[a+1|0]=e>>>8;g[a+2|0]=e>>>16;g[a+3|0]=e>>>24;d=j[d+4|0]|j[d+5|0]<<8;g[a+4|0]=d;g[a+5|0]=d>>>8;a=a+6|0;b=b+ -1|0;if(b){continue}break}}}function Sta(a,b,c){var d=0,e=0,f=0,h=0;d=Xa-16|0;Xa=d;b=Pb(b);a=Qta(a,Yb(16,4),Zj(d+8|0,b));e=i[a>>2];i[114610]=0;G(1168,b|0,e+14|0,c|0);b=i[114610];i[114610]=0;if((b|0)!=1){f=Pb(a),h=1,g[f+4|0]=h;Xa=d+16|0;return}b=B()|0;A()|0;oM(a);E(b|0);x()}function Rla(a,b,c){var d=0,e=0,f=0,h=0;d=Xa-16|0;Xa=d;b=Pb(b);a=Qla(a,Yb(28,4),Zj(d+8|0,b));e=i[a>>2];i[114610]=0;G(1526,b|0,e+16|0,c|0);b=i[114610];i[114610]=0;if((b|0)!=1){f=Pb(a),h=1,g[f+4|0]=h;Xa=d+16|0;return}b=B()|0;A()|0;WI(a);E(b|0);x()}function P0(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;a=Xa-16|0;Xa=a;i[a+8>>2]=b;fc(a,d);i[114610]=0;b=F(21,a|0)|0;d=i[114610];i[114610]=0;if((d|0)!=1){ub(a);fD(f+20|0,a+8|0,c,e,b);Xa=a+16|0;return i[a+8>>2]}b=B()|0;A()|0;ub(a);E(b|0);x()}function j1(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=Xa-16|0;Xa=e;i[e+12>>2]=b;i[e+8>>2]=d;b=ah(e,e+12|0);i[114610]=0;a=I(2470,a|0,c|0,i[e+8>>2])|0;c=i[114610];i[114610]=0;if((c|0)!=1){ne(b);Xa=e+16|0;return a|0}a=B()|0;A()|0;ne(b);E(a|0);x()}function Wn(a,b){var c=0,d=0,e=0,f=0;c=a*a;d=c*.5;e=1-d;f=1-e-d;d=c*c;return e+(f+(c*(c*(c*(c*2480158728947673e-20+ -.001388888888887411)+.0416666666666666)+d*d*(c*(c*-1.1359647557788195e-11+2.087572321298175e-9)+ -2.7557314351390663e-7))-a*b))}function NJa(a,b){a=a|0;b=b|0;var c=0,d=0;c=eA(a);a:{if(!b){break a}i[114610]=0;D(36,a|0,b|0);d=i[114610];i[114610]=0;if((d|0)!=1){i[114610]=0;D(37,a|0,b|0);b=i[114610];i[114610]=0;if((b|0)!=1){break a}}a=B()|0;A()|0;iT(c);E(a|0);x()}return a|0}function wIa(a,b){a=a|0;b=b|0;var c=0;b=Xa-32|0;Xa=b;c=-1;a:{if(!oz(a,b+16|0)){break a}c=0;if(!$Q(b+16|0)){break a}if(i[b+16>>2]==1179472708){c=-1;if(!Dc(a,4)){break a}}c=-1;if(!fj(a,b+8|0)){break a}c=i[b+8>>2]==1196314451}Xa=b+32|0;return c|0}function qD(a,b,c,d,e){var f=0;f=Xa-144|0;Xa=f;i[f+44>>2]=a;i[f+4>>2]=a;i[f>>2]=0;i[f+76>>2]=-1;i[f+8>>2]=(a|0)<0?-1:a+2147483647|0;Gg(f,0,0);c=ED(f,c,1,d,e);d=_a;if(b){i[b>>2]=((i[f+4>>2]+i[f+120>>2]|0)-i[f+8>>2]|0)+a}Xa=f+144|0;_a=d;return c}function Ud(){var a=0,b=0;a:{b:{if(g[461768]&1){break b}if(!cd(461768)){break b}i[114610]=0;a=I(2447,2147483647,62405,0)|0;b=i[114610];i[114610]=0;if((b|0)==1){break a}i[115441]=a;bd(461768)}return i[115441]}a=B()|0;A()|0;Xd(461768);E(a|0);x()}function SEa(a){a:{if((j[a|0]|j[a+1|0]<<8|(j[a+2|0]<<16|j[a+3|0]<<24))!=(mk(14647)|0)){break a}a=a+4|0;if((j[a|0]|j[a+1|0]<<8|(j[a+2|0]<<16|j[a+3|0]<<24))>>>0>259){break a}return(j[a|0]|j[a+1|0]<<8|(j[a+2|0]<<16|j[a+3|0]<<24))>>>0>255}return 0}function PV(a,b){var c=0,d=0,e=0;c=Xa-48|0;Xa=c;d=OV(c+24|0,Yb(24,4),Ac(c+16|0,c+40|0,1));e=i[d>>2];i[114610]=0;C(273,e|0,b|0)|0;b=i[114610];i[114610]=0;if((b|0)!=1){Cn(a,Mb(i[d>>2]),sd(d));kB(d);Xa=c+48|0;return}a=B()|0;A()|0;kB(d);E(a|0);x()}function HL(a){a=a|0;var b=0,c=0,d=0;b=Xa-16|0;Xa=b;if(j[a+530|0]){while(1){d=c&65535;Zh(a,d,1);c=c+1|0;if(d>>>0<255){continue}break}g[a+530|0]=0}g[b+15|0]=0;bj(a+4|0,18,b+15|0);Ey(a+22|0,18,20090);g[b+14|0]=255;bj(a+58|0,256,b+14|0);Xa=b+16|0}function wpa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;i[a>>2]=b;c=a+4|0;Ioa(c,LK(te(229984),b+1074376|0));b=ipa(a+8|0);d=a+20|0;Goa(d);i[114610]=0;L(1341,a|0);e=i[114610];i[114610]=0;if((e|0)!=1){return a|0}a=B()|0;A()|0;JK(d);fK(b);$e(c);E(a|0);x()}function mra(a,b,c,d){var e=0,f=0,g=0,h=0;e=Xa-16|0;Xa=e;i[e+12>>2]=0;xc(a+12|0,d);if(b){d=b;if(357913941<b>>>0){ic(20165);x()}f=Yb(o(d,12),4)}i[a>>2]=f;c=o(c,12)+f|0;i[a+8>>2]=c;i[a+4>>2]=c;g=Mb(a),h=o(b,12)+f|0,i[g>>2]=h;Xa=e+16|0;return a}function mEa(a,b,c,d){var e=0,f=0,g=0,h=0;e=Xa-16|0;Xa=e;i[e+12>>2]=0;xc(a+12|0,d);if(b){d=b;if(130150524<b>>>0){ic(14703);x()}f=Yb(o(d,33),1)}i[a>>2]=f;c=o(c,33)+f|0;i[a+8>>2]=c;i[a+4>>2]=c;g=Mb(a),h=o(b,33)+f|0,i[g>>2]=h;Xa=e+16|0;return a}function bC(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{if(a-b>>2>>>0<c>>>0){while(1){c=c+ -1|0;d=c<<2;i[d+a>>2]=i[b+d>>2];if(c){continue}break a}}if(!c){break a}d=a;while(1){i[d>>2]=i[b>>2];d=d+4|0;b=b+4|0;c=c+ -1|0;if(c){continue}break}}return a|0}function Wya(a,b,c,d){var e=0,f=0,g=0,h=0;e=Xa-16|0;Xa=e;i[e+12>>2]=0;xc(a+12|0,d);if(b){d=b;if(178956970<b>>>0){ic(16908);x()}f=Yb(o(d,24),4)}i[a>>2]=f;c=o(c,24)+f|0;i[a+8>>2]=c;i[a+4>>2]=c;g=Mb(a),h=o(b,24)+f|0,i[g>>2]=h;Xa=e+16|0;return a}function VN(a){var b=0,c=0,d=0,e=0,f=0;_a=0;d=j[a+4|0];e=j[a+92|0];b=a+94|0;f=j[b|0]|j[b+1|0]<<8;b=j[a+93|0];a=f+b|0;if(a>>>0<b>>>0){c=1}b=e+a|0;if(b>>>0<a>>>0){c=c+1|0}a=c<<2|b>>>30;c=b<<2;b=d+c|0;if(b>>>0<c>>>0){a=a+1|0}c=b+ -96|0;return c}function UDa(a,b,c,d){var e=0,f=0,g=0,h=0;e=Xa-16|0;Xa=e;i[e+12>>2]=0;xc(a+12|0,d);if(b){d=b;if(178956970<b>>>0){ic(14703);x()}f=Yb(o(d,24),4)}i[a>>2]=f;c=o(c,24)+f|0;i[a+8>>2]=c;i[a+4>>2]=c;g=Mb(a),h=o(b,24)+f|0,i[g>>2]=h;Xa=e+16|0;return a}function THa(a,b,c,d){var e=0,f=0,g=0,h=0;e=Xa-16|0;Xa=e;i[e+12>>2]=0;xc(a+12|0,d);if(b){d=b;if(178956970<b>>>0){ic(12852);x()}f=Yb(o(d,24),4)}i[a>>2]=f;c=o(c,24)+f|0;i[a+8>>2]=c;i[a+4>>2]=c;g=Mb(a),h=o(b,24)+f|0,i[g>>2]=h;Xa=e+16|0;return a}function PJa(a,b,c,d){var e=0,f=0,g=0,h=0;e=Xa-16|0;Xa=e;i[e+12>>2]=0;xc(a+12|0,d);if(b){d=b;if(178956970<b>>>0){ic(12489);x()}f=Yb(o(d,24),4)}i[a>>2]=f;c=o(c,24)+f|0;i[a+8>>2]=c;i[a+4>>2]=c;g=Mb(a),h=o(b,24)+f|0,i[g>>2]=h;Xa=e+16|0;return a}function Gka(a,b,c,d){var e=0,f=0,g=0,h=0;e=Xa-16|0;Xa=e;i[e+12>>2]=0;xc(a+12|0,d);if(b){d=b;if(178956970<b>>>0){ic(31737);x()}f=Yb(o(d,24),4)}i[a>>2]=f;c=o(c,24)+f|0;i[a+8>>2]=c;i[a+4>>2]=c;g=Mb(a),h=o(b,24)+f|0,i[g>>2]=h;Xa=e+16|0;return a}function CIa(a,b,c,d){var e=0,f=0,g=0,h=0;e=Xa-16|0;Xa=e;i[e+12>>2]=0;xc(a+12|0,d);if(b){d=b;if(178956970<b>>>0){ic(12706);x()}f=Yb(o(d,24),4)}i[a>>2]=f;c=o(c,24)+f|0;i[a+8>>2]=c;i[a+4>>2]=c;g=Mb(a),h=o(b,24)+f|0,i[g>>2]=h;Xa=e+16|0;return a}function i8(a,b,c,d){var e=0,f=0,g=0,h=0;e=Xa-16|0;Xa=e;i[e+12>>2]=0;xc(a+12|0,d);if(b){d=b;if(178956970<b>>>0){ic(39453);x()}f=Yb(o(d,24),8)}i[a>>2]=f;c=o(c,24)+f|0;i[a+8>>2]=c;i[a+4>>2]=c;g=Mb(a),h=o(b,24)+f|0,i[g>>2]=h;Xa=e+16|0;return a}function ed(a,b){var c=0,d=0,e=0,f=0,g=0;a:{c=k[a+20>>1];if(c){d=k[a+22>>1];g=c+d|0;c=d;while(1){e=((c&127)<<2)+a|0;f=k[e+28>>1]+b|0;h[e+28>>1]=f;if((f&65535)>>>0>=2048){break a}c=c+1|0;if((g|0)!=(c|0)){continue}break}}return}h[a+20>>1]=c-d}function bFa(a,b,c){var d=0;d=Xa-32|0;Xa=d;i[d+28>>2]=c;g[d+27|0]=0;i[d+20>>2]=1;c=xk(a,d+27|0,i[rb(d+28|0,d+20|0)>>2])>>>0>=0;a=_a;if((a|0)>0?1:(a|0)>=0?c:0){i[d+16>>2]=1;i[rb(d+28|0,d+16|0)>>2]}g[d+8|0]=j[d+27|0];g[b|0]=j[d+8|0];Xa=d+32|0}function _x(a,b,c,d){var e=0,f=0,g=0,h=0;e=Xa-16|0;Xa=e;i[e+12>>2]=0;xc(a+12|0,d);if(b){d=b;if(357913941<b>>>0){ic(17372);x()}f=Yb(o(d,12),4)}i[a>>2]=f;c=o(c,12)+f|0;i[a+8>>2]=c;i[a+4>>2]=c;g=Mb(a),h=o(b,12)+f|0,i[g>>2]=h;Xa=e+16|0;return a}function TK(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=Xa-16|0;Xa=d;a:{if(!c){break a}i[b+40>>2]=c;if(i[a+480180>>2]!=256){break a}i[d+12>>2]=c>>>4;i[d+8>>2]=1;e=b,f=i[Jc(d+12|0,d+8|0)>>2],i[e+40>>2]=f;e=b,f=HK(c&255),i[e+44>>2]=f}Xa=d+16|0}function Qya(a,b,c,d){var e=0,f=0,g=0,h=0;e=Xa-16|0;Xa=e;i[e+12>>2]=0;xc(a+12|0,d);if(b){d=b;if(76695844<b>>>0){ic(16908);x()}f=Yb(o(d,56),4)}i[a>>2]=f;c=o(c,56)+f|0;i[a+8>>2]=c;i[a+4>>2]=c;g=Mb(a),h=o(b,56)+f|0,i[g>>2]=h;Xa=e+16|0;return a}function MKa(a){var b=0;b=Xa-16|0;Xa=b;g[a|0]=0;g[a+1|0]=0;g[a+2|0]=0;g[a+3|0]=0;g[a+4|0]=0;g[a+5|0]=0;g[a+6|0]=0;g[a+7|0]=0;g[a+16|0]=0;g[a+8|0]=0;g[a+9|0]=0;g[a+10|0]=0;g[a+11|0]=0;g[a+12|0]=0;g[a+13|0]=0;g[a+14|0]=0;g[a+15|0]=0;Xa=b+16|0}function Gna(a,b,c){var d=0;d=Xa-32|0;Xa=d;i[d+16>>2]=b;i[d+24>>2]=a;i[d+8>>2]=c;a:{if(!pb(d+24|0,d+16|0)){break a}while(1){if(Bna(d+8|0,i[i[d+24>>2]>>2])){break a}Gd(d+24|0);if(pb(d+24|0,d+16|0)){continue}break}}Xa=d+32|0;return i[d+24>>2]}function eR(a,b,c,d){var e=0,f=0,g=0,h=0;e=Xa-16|0;Xa=e;i[e+12>>2]=0;xc(a+12|0,d);if(b){d=b;if(89478485<b>>>0){ic(12706);x()}f=Yb(o(d,48),4)}i[a>>2]=f;c=o(c,48)+f|0;i[a+8>>2]=c;i[a+4>>2]=c;g=Mb(a),h=o(b,48)+f|0,i[g>>2]=h;Xa=e+16|0;return a}function dE(a,b,c,d){var e=0,f=0,g=0,h=0;e=Xa-16|0;Xa=e;i[e+12>>2]=0;xc(a+12|0,d);if(b){d=b;if(357913941<b>>>0){ic(6863);x()}f=Yb(o(d,12),4)}i[a>>2]=f;c=o(c,12)+f|0;i[a+8>>2]=c;i[a+4>>2]=c;g=Mb(a),h=o(b,12)+f|0,i[g>>2]=h;Xa=e+16|0;return a}function aF(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=Xa-16|0;Xa=e;if(4294967279>=d>>>0){a:{if(d>>>0<=10){Te(a,c);d=a;break a}f=Dk(d)+1|0;d=Ii(f);gf(a,d);fg(a,f);ce(a,c)}jh(d,b,c);g[e+15|0]=0;Rd(c+d|0,e+15|0);Xa=e+16|0;return}gg();x()}function Ho(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;f=1/(n[i[a+4>>2]+ -8>>3]-n[i[a>>2]>>3]);while(1){d=-xd(n[uk(a,c)>>3]*131072*f);a:{if(q(d)<2147483648){e=~~d;break a}e=-2147483648}g=Ae(b,c),h=e,i[g>>2]=h;c=c+1|0;if((c|0)!=2048){continue}break}}function uV(a){var b=0,c=0,d=0;b=Xa-48|0;Xa=b;c=tV(b+24|0,Yb(16,4),Ac(b+16|0,b+40|0,1));d=i[c>>2];i[114610]=0;F(279,d|0)|0;d=i[114610];i[114610]=0;if((d|0)!=1){Cn(a,Mb(i[c>>2]),sd(c));$A(c);Xa=b+48|0;return}a=B()|0;A()|0;$A(c);E(a|0);x()}function sFa(a,b,c,d){var e=0,f=0,g=0,h=0;e=Xa-16|0;Xa=e;i[e+12>>2]=0;xc(a+12|0,d);if(b){d=b;if(1073741823<b>>>0){ic(14480);x()}f=Yb(d<<2,1)}i[a>>2]=f;c=(c<<2)+f|0;i[a+8>>2]=c;i[a+4>>2]=c;g=Mb(a),h=(b<<2)+f|0,i[g>>2]=h;Xa=e+16|0;return a}function cia(a,b,c,d){var e=0,f=0,g=0,h=0;e=Xa-16|0;Xa=e;i[e+12>>2]=0;xc(a+12|0,d);if(b){d=b;if(1073741823<b>>>0){ic(32539);x()}f=Yb(d<<2,4)}i[a>>2]=f;c=(c<<2)+f|0;i[a+8>>2]=c;i[a+4>>2]=c;g=Mb(a),h=(b<<2)+f|0,i[g>>2]=h;Xa=e+16|0;return a}function YCa(a,b,c,d){var e=0,f=0,g=0,h=0;e=Xa-16|0;Xa=e;i[e+12>>2]=0;xc(a+12|0,d);if(b){d=b;if(1073741823<b>>>0){ic(15083);x()}f=Yb(d<<2,1)}i[a>>2]=f;c=(c<<2)+f|0;i[a+8>>2]=c;i[a+4>>2]=c;g=Mb(a),h=(b<<2)+f|0,i[g>>2]=h;Xa=e+16|0;return a}function Vla(a,b,c,d){var e=0,f=0,g=0,h=0;e=Xa-16|0;Xa=e;i[e+12>>2]=0;xc(a+12|0,d);if(b){d=b;if(1073741823<b>>>0){ic(30778);x()}f=Yb(d<<2,4)}i[a>>2]=f;c=(c<<2)+f|0;i[a+8>>2]=c;i[a+4>>2]=c;g=Mb(a),h=(b<<2)+f|0,i[g>>2]=h;Xa=e+16|0;return a}function OCa(a,b,c,d){var e=0,f=0,g=0,h=0;e=Xa-16|0;Xa=e;i[e+12>>2]=0;xc(a+12|0,d);if(b){d=b;if(2147483647<b>>>0){ic(15083);x()}f=Yb(d<<1,1)}i[a>>2]=f;c=(c<<1)+f|0;i[a+8>>2]=c;i[a+4>>2]=c;g=Mb(a),h=(b<<1)+f|0,i[g>>2]=h;Xa=e+16|0;return a}function Jma(a,b,c,d){var e=0,f=0,g=0,h=0;e=Xa-16|0;Xa=e;i[e+12>>2]=0;xc(a+12|0,d);if(b){d=b;if(1073741823<b>>>0){ic(20572);x()}f=Yb(d<<2,4)}i[a>>2]=f;c=(c<<2)+f|0;i[a+8>>2]=c;i[a+4>>2]=c;g=Mb(a),h=(b<<2)+f|0,i[g>>2]=h;Xa=e+16|0;return a}function Gwa(a,b,c,d){var e=0,f=0,g=0,h=0;e=Xa-16|0;Xa=e;i[e+12>>2]=0;xc(a+12|0,d);if(b){d=b;if(1073741823<b>>>0){ic(17977);x()}f=Yb(d<<2,1)}i[a>>2]=f;c=(c<<2)+f|0;i[a+8>>2]=c;i[a+4>>2]=c;g=Mb(a),h=(b<<2)+f|0,i[g>>2]=h;Xa=e+16|0;return a}function ELa(a,b,c,d){var e=0,f=0,g=0,h=0;e=Xa-16|0;Xa=e;i[e+12>>2]=0;xc(a+12|0,d);if(b){d=b;if(2147483647<b>>>0){ic(12065);x()}f=Yb(d<<1,1)}i[a>>2]=f;c=(c<<1)+f|0;i[a+8>>2]=c;i[a+4>>2]=c;g=Mb(a),h=(b<<1)+f|0,i[g>>2]=h;Xa=e+16|0;return a}function sH(a,b,c,d){var e=0,f=0,g=0,h=0;e=Xa-16|0;Xa=e;i[e+12>>2]=0;xc(a+12|0,d);if(b){d=b;if(1073741823<b>>>0){ic(33205);x()}f=Yb(d<<2,4)}i[a>>2]=f;c=(c<<2)+f|0;i[a+8>>2]=c;i[a+4>>2]=c;g=Mb(a),h=(b<<2)+f|0,i[g>>2]=h;Xa=e+16|0;return a}function rAa(a,b,c,d){var e=0,f=0,g=0,h=0;e=Xa-16|0;Xa=e;i[e+12>>2]=0;xc(a+12|0,d);if(b){d=b;if(536870911<b>>>0){ic(16504);x()}f=Yb(d<<3,1)}i[a>>2]=f;c=(c<<3)+f|0;i[a+8>>2]=c;i[a+4>>2]=c;g=Mb(a),h=(b<<3)+f|0,i[g>>2]=h;Xa=e+16|0;return a}function qga(a,b){a=a|0;b=b|0;var c=0,d=0;c=Xa-32|0;Xa=c;a:{if(gd(a)>>>0<b>>>0){d=fb(a);b=sH(c+8|0,b,qb(a),d);i[114610]=0;D(1759,a|0,b|0);a=i[114610];i[114610]=0;if((a|0)==1){break a}nr(b)}Xa=c+32|0;return}a=B()|0;A()|0;nr(b);E(a|0);x()}function qba(a){var b=0,c=0;b=Xa-48|0;Xa=b;vk(b+16|0);a:{if(i[b+28>>2]){c=i[b+28>>2];i[114610]=0;i[b+12>>2]=c;D(2118,a|0,b+12|0);a=i[114610];i[114610]=0;if((a|0)!=1){break a}a=B()|0;A()|0;Ie(b+16|0);E(a|0);x()}Ab(a)}Ie(b+16|0);Xa=b+48|0}function iU(a,b){var c=0,d=0,e=0;i[a>>2]=0;i[a+4>>2]=0;i[a+8>>2]=0;i[a+12>>2]=0;if(i[b+16>>2]){FA(a,b);e=i[b+8>>2];b=i[b+12>>2];c=b;d=b>>31;b=b>>31;c=c+d|0;c=b+e>>>0<b>>>0?c+1|0:c;b=c^d;i[a+12>>2]=b>>>0>8191?2:16384/(b+1>>>0)|0}return a}function _xa(a,b){a=a|0;b=b|0;var c=0,d=0;c=Xa-32|0;Xa=c;a:{if(Rf(a)>>>0<b>>>0){d=fb(a);b=_x(c+8|0,b,cc(a),d);i[114610]=0;D(1017,a|0,b|0);a=i[114610];i[114610]=0;if((a|0)==1){break a}ns(b)}Xa=c+32|0;return}a=B()|0;A()|0;ns(b);E(a|0);x()}function UT(a,b,c,d){var e=0,f=0,g=0,h=0;e=Xa-16|0;Xa=e;i[e+12>>2]=0;xc(a+12|0,d);if(b){d=b;if(2147483647<b>>>0){ic(11736);x()}f=Yb(d<<1,2)}i[a>>2]=f;c=(c<<1)+f|0;i[a+8>>2]=c;i[a+4>>2]=c;g=Mb(a),h=(b<<1)+f|0,i[g>>2]=h;Xa=e+16|0;return a}function JA(a,b,c,d){var e=0,f=0,g=0,h=0;e=Xa-16|0;Xa=e;i[e+12>>2]=0;xc(a+12|0,d);if(b){d=b;if(1073741823<b>>>0){ic(11561);x()}f=Yb(d<<2,4)}i[a>>2]=f;c=(c<<2)+f|0;i[a+8>>2]=c;i[a+4>>2]=c;g=Mb(a),h=(b<<2)+f|0,i[g>>2]=h;Xa=e+16|0;return a}function IR(a,b,c,d){var e=0,f=0,g=0,h=0;e=Xa-16|0;Xa=e;i[e+12>>2]=0;xc(a+12|0,d);if(b){d=b;if(2147483647<b>>>0){ic(12489);x()}f=Yb(d<<1,1)}i[a>>2]=f;c=(c<<1)+f|0;i[a+8>>2]=c;i[a+4>>2]=c;g=Mb(a),h=(b<<1)+f|0,i[g>>2]=h;Xa=e+16|0;return a}function Bla(a,b){a=a|0;b=b|0;var c=0,d=0;c=Xa-32|0;Xa=c;a:{if(Rf(a)>>>0<b>>>0){d=fb(a);b=_K(c+8|0,b,cc(a),d);i[114610]=0;D(1256,a|0,b|0);a=i[114610];i[114610]=0;if((a|0)==1){break a}Wr(b)}Xa=c+32|0;return}a=B()|0;A()|0;Wr(b);E(a|0);x()}function uDa(a,b){a=a|0;b=b|0;var c=0,d=0;c=Xa-32|0;Xa=c;a:{if(zf(a)>>>0<b>>>0){d=fb(a);b=tt(c+8|0,b,Wb(a),d);i[114610]=0;D(380,a|0,b|0);a=i[114610];i[114610]=0;if((a|0)==1){break a}kk(b)}Xa=c+32|0;return}a=B()|0;A()|0;kk(b);E(a|0);x()}function OY(a){var b=0,c=0,d=0;b=i[a>>2];i[114610]=0;c=R(2445)|0;d=i[114610];i[114610]=0;a:{if((d|0)==1){break a}if((b|0)!=(c|0)){a=i[a>>2];i[114610]=0;Tu(a);a=i[114610];i[114610]=0;if((a|0)==1){break a}}return}a=H(0)|0;A()|0;gb(a);x()}function wL(a,b){var c=0,d=0;c=Kra(a);a:{if(!b){break a}i[114610]=0;D(1224,a|0,b|0);d=i[114610];i[114610]=0;if((d|0)!=1){i[114610]=0;D(1225,a|0,b|0);b=i[114610];i[114610]=0;if((b|0)!=1){break a}}a=B()|0;A()|0;qL(c);E(a|0);x()}return a}function pua(a,b,c,d){var e=0,f=0,g=0,h=0;a:{if((d|0)==65536){break a}c=o(b,c);if(!c){break a}b=d;f=d>>31;d=0;while(1){e=i[a>>2];g=a,h=gc(YMa(XMa(e,e>>31,b,f),_a,65536,0),_a),i[g>>2]=h;a=a+4|0;d=d+1|0;if((c|0)!=(d|0)){continue}break}}}function cFa(a,b){var c=0,d=0,e=0;c=ni(a+8|0);i[114610]=0;d=F(548,b|0)|0;e=i[114610];i[114610]=0;a:{if((e|0)==1){break a}i[114610]=0;G(421,a|0,b|0,d|0);a=i[114610];i[114610]=0;if((a|0)==1){break a}return}a=B()|0;A()|0;ug(c);E(a|0);x()}function bga(a){a=a|0;var b=0;$a[i[i[a>>2]+124>>2]](a);hw(a);i[a+4236>>2]=0;g[a+4202|0]=1;b=$a[i[i[a>>2]+188>>2]](a)|0;i[a+4272>>2]=0;m[a+4240>>2]=b?p(.5):p(1);b=i[a+4256>>2];i[a+4292>>2]=b;i[a+4288>>2]=b;i[a+4284>>2]=b;i[a+4280>>2]=b}function W4(a,b,c){var d=0,e=0,f=0;if(!c){return 0}d=j[a|0];a:{if(!d){break a}while(1){b:{e=j[b|0];if((e|0)!=(d|0)){break b}c=c+ -1|0;if(!c|!e){break b}b=b+1|0;d=j[a+1|0];a=a+1|0;if(d){continue}break a}break}f=d}return(f&255)-j[b|0]|0}function SW(a,b,c,d){var e=0,f=0,g=0,h=0;e=Xa-16|0;Xa=e;i[e+12>>2]=0;xc(a+12|0,d);if(b){d=b;if(268435455<b>>>0){ic(6967);x()}f=Yb(d<<4,4)}i[a>>2]=f;c=(c<<4)+f|0;i[a+8>>2]=c;i[a+4>>2]=c;g=Mb(a),h=(b<<4)+f|0,i[g>>2]=h;Xa=e+16|0;return a}function Qea(a,b,c){a=a|0;b=b|0;c=p(c);var d=0;d=Xa-16|0;Xa=d;m[d+12>>2]=c;if((b|0)<=12){Id(d+12|0,p(0));c=m[d+12>>2];if((b|0)==12){c=p(Qd(p(c*p(3)))*p(.3333333432674408));m[d+12>>2]=c}m[((b<<2)+a|0)+4208>>2]=c;g[a+5046|0]=1}Xa=d+16|0}function Of(a,b,c){c=i[c+4>>2]&176;if((c|0)==32){return b}a:{if((c|0)!=16){break a}b:{c:{c=j[a|0];switch(c+ -43|0){case 0:case 2:break c;default:break b}}return a+1|0}if((c|0)!=48|(b-a|0)<2|(j[a+1|0]|32)!=120){break a}a=a+2|0}return a}function FU(a,b){a=a|0;b=b|0;var c=0,d=0;c=Xa-32|0;Xa=c;a:{if(gd(a)>>>0<b>>>0){d=fb(a);b=JA(c+8|0,b,qb(a),d);i[114610]=0;D(343,a|0,b|0);a=i[114610];i[114610]=0;if((a|0)==1){break a}Np(b)}Xa=c+32|0;return}a=B()|0;A()|0;Np(b);E(a|0);x()}function Cca(a){a=a|0;if(l[a+44>>2]<l[a+24>>2]){i[a+44>>2]=i[a+24>>2]}a:{if(!(j[a+48|0]&8)){break a}if(l[a+16>>2]<l[a+44>>2]){pm(a,i[a+8>>2],i[a+12>>2],i[a+44>>2])}if(l[a+12>>2]>=l[a+16>>2]){break a}return cg(g[i[a+12>>2]])|0}return-1}function hka(a,b){var c=0,d=0;c=Zy(a);a:{if(!b){break a}i[114610]=0;D(683,a|0,b|0);d=i[114610];i[114610]=0;if((d|0)!=1){i[114610]=0;D(1568,a|0,b|0);b=i[114610];i[114610]=0;if((b|0)!=1){break a}}a=B()|0;A()|0;Qs(c);E(a|0);x()}return a}function g0(a,b,c,d,e,f){var g=0;g=Xa-144|0;Xa=g;i[g+28>>2]=g+132;aD(a,g+32|0,g+28|0,d,e,f);i[g+16>>2]=0;i[g+20>>2]=0;i[g+12>>2]=g+32;a=f0(b,g+12|0,aP(b,i[c>>2]),g+16|0,i[a>>2]);if((a|0)==-1){Pl(62932);x()}i[c>>2]=(a<<2)+b;Xa=g+144|0}function fJ(a,b,c){var d=0,e=0,f=0,g=0,h=0;if(b){g=c;h=c>>31;c=0;while(1){d=i[a>>2];e=i[a+4>>2];f=(d+e|0)/2|0;d=d-e|0;d=gc(YMa(XMa(d,d>>31,g,h),_a,256,0),_a);i[a+4>>2]=f-d;i[a>>2]=d+f;a=a+8|0;c=c+1|0;if((c|0)!=(b|0)){continue}break}}}function Uza(a,b){var c=0,d=0;c=Qza(a);a:{if(!b){break a}i[114610]=0;D(946,a|0,b|0);d=i[114610];i[114610]=0;if((d|0)!=1){i[114610]=0;D(947,a|0,b|0);b=i[114610];i[114610]=0;if((b|0)!=1){break a}}a=B()|0;A()|0;RN(c);E(a|0);x()}return a}function Nta(a){var b=0,c=0,d=0,e=0;b=Xa-16|0;Xa=b;e=b+8|0;d=i[a+24>>2];c=0;a:{if(!d){break a}c=Mm(Vn(+(d>>>0)*.00011957431543704412)*2215.9795828054475)}xE(e,Eb(c,-16384,16383),128);g[a+36|0]=i[b+8>>2];g[a+37|0]=i[b+12>>2];Xa=b+16|0}function Cta(a,b){var c=0,d=0;c=Uz(a);a:{if(!b){break a}i[114610]=0;D(921,a|0,b|0);d=i[114610];i[114610]=0;if((d|0)!=1){i[114610]=0;D(1174,a|0,b|0);b=i[114610];i[114610]=0;if((b|0)!=1){break a}}a=B()|0;A()|0;pt(c);E(a|0);x()}return a}function tea(a){var b=0;i[a>>2]=8;i[a+4>>2]=0;h[a+4128>>1]=0;b=a+4120|0;i[b>>2]=0;i[b+4>>2]=0;b=a+4112|0;i[b>>2]=0;i[b+4>>2]=0;i[a+4104>>2]=0;i[a+4108>>2]=0;yb(a+4132|0,0,40);BM(a+8|0,1024);yb(a+4172|0,0,49824);yb(a+53996|0,0,32832)}function oJ(a,b){var c=0,d=0;a:{if(!(j[a+89|0]&16)){break a}c=i[a+656>>2];if(!c){break a}c=i[c>>2];if(c){d=a;a=i[a+696>>2]-(c<<1)|0;a=(a|0)>0?a:0;i[d+696>>2]=a;i[b>>2]=(o(a,i[b>>2])|0)/65536;return}if(i[a+696>>2]){break a}i[b>>2]=0}}function YGa(a,b){a=a|0;b=b|0;var c=0;c=Xa-32|0;Xa=c;a:{if(b){Bb(c,b);break a}Ab(c)}i[114610]=0;D(669,c+16|0,c|0);b=i[114610];i[114610]=0;if((b|0)!=1){Lc(a,c+16|0);eb(c+16|0);eb(c);Xa=c+32|0;return a|0}a=B()|0;A()|0;eb(c);E(a|0);x()}function cW(a,b){var c=0,d=0;c=YV(a);a:{if(!b){break a}i[114610]=0;D(262,a|0,b|0);d=i[114610];i[114610]=0;if((d|0)!=1){i[114610]=0;D(263,a|0,b|0);b=i[114610];i[114610]=0;if((b|0)!=1){break a}}a=B()|0;A()|0;nB(c);E(a|0);x()}return a}function X2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{if(!j[a+44|0]){c=(c|0)>0?c:0;while(1){if((c|0)==(d|0)){break a}if(($a[i[i[a>>2]+52>>2]](a,i[b>>2])|0)==-1){return d|0}else{b=b+4|0;d=d+1|0;continue}}}c=xi(b,4,c,i[a+32>>2])}return c|0}function N7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=p(0);e=Xa-16|0;Xa=e;f=i[a+4>>2];LF(a,b,c,d);g=m[a+28>>2];b=i[a+24>>2];i[e+8>>2]=i[a+20>>2];i[e+12>>2]=b;b=i[a+16>>2];i[e>>2]=i[a+12>>2];i[e+4>>2]=b;yba(e,f,c,d,g);Xa=e+16|0}function MK(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=Xa-16|0;Xa=a;d=i[b+104>>2];if(d){i[b+88>>2]=i[b+88>>2]&-131|128;d=i[d>>2];i[b+76>>2]=d;i[a+12>>2]=c<<8;i[a+8>>2]=d+ -1;c=d+(i[rb(a+12|0,a+8|0)>>2]^-1)|0;i[b>>2]=0;i[b+4>>2]=c}Xa=a+16|0}function Hma(a,b,c){var d=0;d=Xa-16|0;Xa=d;a:{b:{if(!b){b=a;a=xb(c);Uh(b,a,lb(c)+a|0);break b}RJ(d,c);i[114610]=0;G(115,a|0,b|0,d|0);a=i[114610];i[114610]=0;if((a|0)==1){break a}nc(d)}Xa=d+16|0;return}a=B()|0;A()|0;nc(d);E(a|0);x()}function kV(a,b,c,d){var e=0;a:{if((a|0)==(b|0)){break a}while(1){e=c;if((e|0)!=(d|0)){while(1){if($a[26](g[a|0],g[e|0])|0){break a}e=e+1|0;if((e|0)!=(d|0)){continue}break}}a=a+1|0;if((b|0)!=(a|0)){continue}break}return b}return a}function Io(a){var b=0,c=0,d=0,e=0;b=Xa-16|0;Xa=b;c=Sra(Jb(a),Kb(a));d=b,e=Jb(a),i[d+8>>2]=e;d=b,e=Kb(a),i[d>>2]=e;if(pb(b+8|0,b)){c=-c;while(1){a=i[b+8>>2];c=n[a>>3]+c;n[a>>3]=c;Dx(b+8|0);if(pb(b+8|0,b)){continue}break}}Xa=b+16|0}function xLa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=Xa-16|0;Xa=d;c=-1;a:{if(!ff(a,7)){break a}c=0;if(!vS(a,12168)){break a}c=d;e=PKa(a,d);if(!e){hS(c)}c=-1;if(!e){break a}c=0;if(!uS(d)){break a}c=Le(a,b,tS(d),_a)}Xa=d+16|0;return c|0}function xB(){var a=0,b=0,c=0;b=Xa-16|0;Xa=b;a=Bb(b,10940);a:{if(!lb(a)){break a}c=1;if((Ef(a,10946)|0)!=-1){break a}if((Ef(a,10948)|0)!=-1){break a}if((Ef(a,10952)|0)!=-1){break a}c=(Ef(a,10954)|0)!=-1}eb(a);Xa=b+16|0;return c|0}function nf(a,b){var c=0,d=0,e=0,f=0;c=k[a+24>>1]<<17;e=k[a+20>>1];if(e){d=k[a+22>>1];e=e+d|0;while(1){f=c;c=((d&127)<<2)+a|0;c=f-o(i[Ae(b,k[c+28>>1])>>2],h[c+26>>1])|0;d=d+1|0;if((e|0)!=(d|0)){continue}break}}return(c|0)/32768|0}function n0(a,b,c,d,e,f){a=$a[i[i[a+8>>2]+8>>2]](a+8|0)|0;if((lb(a)|0)==(0-lb(a+12|0)|0)){i[e>>2]=i[e>>2]|4;return}a=rq(c,d,a,a+24|0,f,e,0)-a|0;c=i[b>>2];if(!(a|(c|0)!=12)){i[b>>2]=0;return}if(!((a|0)!=12|(c|0)>11)){i[b>>2]=c+12}}function _ma(a,b,c){var d=0;d=Xa-16|0;Xa=d;a:{b:{if(!b){b=a;a=xb(c);Uh(b,a,lb(c)+a|0);break b}qK(d,b,c);i[114610]=0;D(116,a|0,d|0);a=i[114610];i[114610]=0;if((a|0)==1){break a}nc(d)}Xa=d+16|0;return}a=B()|0;A()|0;nc(d);E(a|0);x()}function G0(a,b,c,d,e,f){a=$a[i[i[a+8>>2]+8>>2]](a+8|0)|0;if((lb(a)|0)==(0-lb(a+12|0)|0)){i[e>>2]=i[e>>2]|4;return}a=tq(c,d,a,a+24|0,f,e,0)-a|0;c=i[b>>2];if(!(a|(c|0)!=12)){i[b>>2]=0;return}if(!((a|0)!=12|(c|0)>11)){i[b>>2]=c+12}}function xIa(a){var b=0;b=Xa-16|0;Xa=b;g[a|0]=0;g[a+1|0]=0;g[a+2|0]=0;g[a+3|0]=0;g[a+4|0]=0;g[a+5|0]=0;g[a+6|0]=0;g[a+7|0]=0;g[a+8|0]=0;g[a+9|0]=0;g[a+10|0]=0;g[a+11|0]=0;g[a+12|0]=0;g[a+13|0]=0;g[a+14|0]=0;g[a+15|0]=0;Xa=b+16|0}function vsa(a,b,c){var d=0,e=0;b=Sj(a,b);a:{if((b|0)==255){break a}if(Si(a)){break a}d=j[Nb(ji(a+314|0,b),10)|0];e=i[a>>2];a=d&-49;a=(c|0)<171?a|16:a;a=((c|0)>84?a|32:a)&255;Ng(e,bs(b)|192,a);d=(a>>>5&1)+(a<<27>>31)|0}return d}function uN(a,b){var c=0,d=0,e=0,f=0;c=Xa-32|0;Xa=c;d=i[a+4>>2];e=i[a>>2];i[c+24>>2]=e;i[c+28>>2]=d;f=i[b+4>>2];a=i[b>>2];i[c+16>>2]=a;i[c+20>>2]=f;i[c+8>>2]=e;i[c+12>>2]=d;i[c>>2]=a;i[c+4>>2]=f;a=YN(c+8|0,c);Xa=c+32|0;return a}function OHa(a){var b=0;b=Xa-16|0;Xa=b;g[a|0]=0;g[a+1|0]=0;g[a+2|0]=0;g[a+3|0]=0;g[a+4|0]=0;g[a+5|0]=0;g[a+6|0]=0;g[a+7|0]=0;g[a+7|0]=0;g[a+8|0]=0;g[a+9|0]=0;g[a+10|0]=0;g[a+11|0]=0;g[a+12|0]=0;g[a+13|0]=0;g[a+14|0]=0;Xa=b+16|0}function KLa(a,b,c){var d=0;d=ni(a+8|0);i[114610]=0;G(421,a|0,b|0,c|0);c=i[114610];i[114610]=0;a:{if((c|0)!=1){a=i[a>>2];i[114610]=0;C(338,b|0,a|0)|0;a=i[114610];i[114610]=0;if((a|0)!=1){break a}}a=B()|0;A()|0;ug(d);E(a|0);x()}}function E4(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;e=a;b=i[a+112>>2];if((b|0)>=11){f=a;d=378;while(1){wE(f);b=c+ -1|0;c=d+ -1|0;if((c|0)!=-1){b=b+1|0}d=c;c=b;if(d|b){continue}break}i[a+112>>2]=0;b=0}i[e+112>>2]=b+1;a=wE(a);return a|0}function ypa(a,b){var c=0;c=Xa-2496|0;Xa=c;UK(b,c,c+2496|0);b=Tb(a,c,2496);i[b+2496>>2]=0;a:{if(i[b>>2]<=-1){break a}a=1;while(1){if(i[b+(a<<2)>>2]){break a}a=a+1|0;if((a|0)!=624){continue}break}i[b>>2]=-2147483648}Xa=c+2496|0}function mta(a,b){var c=0,d=0,e=0;d=Xa-16|0;Xa=d;c=yn(d,a,1);a=fb(a);e=i[c+4>>2];i[114610]=0;G(1180,a|0,e|0,b|0);a=i[114610];i[114610]=0;if((a|0)!=1){i[c+4>>2]=i[c+4>>2]+32;sb(c);Xa=d+16|0;return}a=B()|0;A()|0;sb(c);E(a|0);x()}function hpa(a,b){var c=0,d=0,e=0;d=Xa-16|0;Xa=d;c=yn(d,a,1);a=fb(a);e=i[c+4>>2];i[114610]=0;G(1371,a|0,e|0,b|0);a=i[114610];i[114610]=0;if((a|0)!=1){i[c+4>>2]=i[c+4>>2]+32;sb(c);Xa=d+16|0;return}a=B()|0;A()|0;sb(c);E(a|0);x()}function _aa(a,b){var c=0,d=0,e=0;d=Xa-16|0;Xa=d;c=Kl(d,a,1);a=fb(a);e=i[c+4>>2];i[114610]=0;G(2127,a|0,e|0,b|0);a=i[114610];i[114610]=0;if((a|0)!=1){i[c+4>>2]=i[c+4>>2]+16;sb(c);Xa=d+16|0;return}a=B()|0;A()|0;sb(c);E(a|0);x()}function Wqa(a,b){var c=0,d=0,e=0;d=Xa-16|0;Xa=d;c=Ik(d,a,1);a=fb(a);e=i[c+4>>2];i[114610]=0;G(1255,a|0,e|0,b|0);a=i[114610];i[114610]=0;if((a|0)!=1){i[c+4>>2]=i[c+4>>2]+12;sb(c);Xa=d+16|0;return}a=B()|0;A()|0;sb(c);E(a|0);x()}function Paa(a,b){var c=0,d=0,e=0;d=Xa-16|0;Xa=d;c=fk(d,a,1);a=fb(a);e=i[c+4>>2];i[114610]=0;G(2132,a|0,e|0,b|0);a=i[114610];i[114610]=0;if((a|0)!=1){i[c+4>>2]=i[c+4>>2]+24;sb(c);Xa=d+16|0;return}a=B()|0;A()|0;sb(c);E(a|0);x()}function Nxa(a,b){var c=0,d=0,e=0;d=Xa-16|0;Xa=d;c=Ik(d,a,1);a=fb(a);e=i[c+4>>2];i[114610]=0;G(1022,a|0,e|0,b|0);a=i[114610];i[114610]=0;if((a|0)!=1){i[c+4>>2]=i[c+4>>2]+12;sb(c);Xa=d+16|0;return}a=B()|0;A()|0;sb(c);E(a|0);x()}function Jka(a,b){var c=0,d=0,e=0;d=Xa-16|0;Xa=d;c=fk(d,a,1);a=fb(a);e=i[c+4>>2];i[114610]=0;G(1561,a|0,e|0,b|0);a=i[114610];i[114610]=0;if((a|0)!=1){i[c+4>>2]=i[c+4>>2]+24;sb(c);Xa=d+16|0;return}a=B()|0;A()|0;sb(c);E(a|0);x()}function r9(a,b){a=a|0;b=b|0;var c=p(0);a:{if((b|0)<0){break a}a=a+24|0;if(k[i[a>>2]+480188>>1]<=(b|0)){break a}b=o(b,896);if(!(g[(b+i[a>>2]|0)+1075073|0]&1)){break a}c=p(p(j[(b+i[a>>2]|0)+1075846|0])*p(.0078125))}return p(c)}function qs(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,h=0;f=Xa-16|0;Xa=f;if(b){e=qc(a);d=lb(a);h=d+b|0;if(e-d>>>0<b>>>0){rl(a,e,h-e|0,d,d,0,0)}e=d;d=xb(a);ey(e+d|0,b,c);yg(a,h);g[f+15|0]=0;Rd(d+h|0,f+15|0)}Xa=f+16|0;return a|0}function q9(a,b){a=a|0;b=b|0;var c=p(0);a:{if((b|0)<0){break a}a=a+24|0;if(k[i[a>>2]+480188>>1]<=(b|0)){break a}b=o(b,896);if(!(g[(b+i[a>>2]|0)+1075073|0]&1)){break a}c=p(p(j[(b+i[a>>2]|0)+1075847|0])*p(.0078125))}return p(c)}function lga(a,b){var c=0,d=0,e=0;d=Xa-16|0;Xa=d;c=Yd(d,a,1);a=fb(a);e=i[c+4>>2];i[114610]=0;G(1762,a|0,e|0,b|0);a=i[114610];i[114610]=0;if((a|0)!=1){i[c+4>>2]=i[c+4>>2]+4;sb(c);Xa=d+16|0;return}a=B()|0;A()|0;sb(c);E(a|0);x()}function iJ(a){var b=0,c=0,d=0;b=Xa-16|0;Xa=b;i[b+12>>2]=7;i[b+8>>2]=32;if(i[rb(b+12|0,b+8|0)>>2]){while(1){d=xo(a);i[b+12>>2]=7;i[b+8>>2]=32;c=c+15|0;if(c>>>0<l[rb(b+12|0,b+8|0)>>2]){continue}break}c=d&127}Xa=b+16|0;return c}function fJa(a,b){var c=0,d=0,e=0;d=Xa-16|0;Xa=d;c=gR(d,a,1);a=fb(a);e=i[c+4>>2];i[114610]=0;G(560,a|0,e|0,b|0);a=i[114610];i[114610]=0;if((a|0)!=1){i[c+4>>2]=i[c+4>>2]+48;sb(c);Xa=d+16|0;return}a=B()|0;A()|0;sb(c);E(a|0);x()}function eia(a,b){var c=0,d=0,e=0;d=Xa-16|0;Xa=d;c=Yd(d,a,1);a=fb(a);e=i[c+4>>2];i[114610]=0;G(1635,a|0,e|0,b|0);a=i[114610];i[114610]=0;if((a|0)!=1){i[c+4>>2]=i[c+4>>2]+4;sb(c);Xa=d+16|0;return}a=B()|0;A()|0;sb(c);E(a|0);x()}function dma(a,b){var c=0,d=0,e=0;d=Xa-16|0;Xa=d;c=Yd(d,a,1);a=fb(a);e=i[c+4>>2];i[114610]=0;G(1518,a|0,e|0,b|0);a=i[114610];i[114610]=0;if((a|0)!=1){i[c+4>>2]=i[c+4>>2]+4;sb(c);Xa=d+16|0;return}a=B()|0;A()|0;sb(c);E(a|0);x()}function dB(a){var b=0;b=Xa-16|0;Xa=b;g[a|0]=0;g[a+1|0]=0;g[a+2|0]=0;g[a+3|0]=0;g[a+4|0]=0;g[a+5|0]=0;g[a+6|0]=0;g[a+7|0]=0;g[a+6|0]=0;g[a+7|0]=0;g[a+8|0]=0;g[a+9|0]=0;g[a+10|0]=0;g[a+11|0]=0;g[a+12|0]=0;g[a+13|0]=0;Xa=b+16|0}function cJa(a,b){var c=0,d=0;c=WIa(a);a:{if(!b){break a}i[114610]=0;D(562,a|0,b|0);d=i[114610];i[114610]=0;if((d|0)!=1){i[114610]=0;D(563,a|0,b|0);a=i[114610];i[114610]=0;if((a|0)!=1){break a}}a=B()|0;A()|0;kR(c);E(a|0);x()}}function Yya(a,b){var c=0,d=0,e=0;d=Xa-16|0;Xa=d;c=fk(d,a,1);a=fb(a);e=i[c+4>>2];i[114610]=0;G(988,a|0,e|0,b|0);a=i[114610];i[114610]=0;if((a|0)!=1){i[c+4>>2]=i[c+4>>2]+24;sb(c);Xa=d+16|0;return}a=B()|0;A()|0;sb(c);E(a|0);x()}function XDa(a,b){var c=0,d=0,e=0;d=Xa-16|0;Xa=d;c=fk(d,a,1);a=fb(a);e=i[c+4>>2];i[114610]=0;G(772,a|0,e|0,b|0);a=i[114610];i[114610]=0;if((a|0)!=1){i[c+4>>2]=i[c+4>>2]+24;sb(c);Xa=d+16|0;return}a=B()|0;A()|0;sb(c);E(a|0);x()}function WHa(a,b){var c=0,d=0,e=0;d=Xa-16|0;Xa=d;c=fk(d,a,1);a=fb(a);e=i[c+4>>2];i[114610]=0;G(608,a|0,e|0,b|0);a=i[114610];i[114610]=0;if((a|0)!=1){i[c+4>>2]=i[c+4>>2]+24;sb(c);Xa=d+16|0;return}a=B()|0;A()|0;sb(c);E(a|0);x()}function TJa(a,b){var c=0,d=0,e=0;d=Xa-16|0;Xa=d;c=fk(d,a,1);a=fb(a);e=i[c+4>>2];i[114610]=0;G(529,a|0,e|0,b|0);a=i[114610];i[114610]=0;if((a|0)!=1){i[c+4>>2]=i[c+4>>2]+24;sb(c);Xa=d+16|0;return}a=B()|0;A()|0;sb(c);E(a|0);x()}function Qwa(a,b){var c=0,d=0,e=0;d=Xa-16|0;Xa=d;c=Yd(d,a,1);a=fb(a);e=i[c+4>>2];i[114610]=0;G(1058,a|0,e|0,b|0);a=i[114610];i[114610]=0;if((a|0)!=1){i[c+4>>2]=i[c+4>>2]+4;sb(c);Xa=d+16|0;return}a=B()|0;A()|0;sb(c);E(a|0);x()}function QFa(a,b){var c=0,d=0,e=0;d=Xa-16|0;Xa=d;c=Ik(d,a,1);a=fb(a);e=i[c+4>>2];i[114610]=0;G(730,a|0,e|0,b|0);a=i[114610];i[114610]=0;if((a|0)!=1){i[c+4>>2]=i[c+4>>2]+12;sb(c);Xa=d+16|0;return}a=B()|0;A()|0;sb(c);E(a|0);x()}function Mia(a,b){var c=0,d=0,e=0;d=Xa-16|0;Xa=d;c=Yd(d,a,1);a=fb(a);e=i[c+4>>2];i[114610]=0;G(1604,a|0,e|0,b|0);a=i[114610];i[114610]=0;if((a|0)!=1){i[c+4>>2]=i[c+4>>2]+4;sb(c);Xa=d+16|0;return}a=B()|0;A()|0;sb(c);E(a|0);x()}function MHa(a,b){var c=0,d=0,e=0;d=Xa-16|0;Xa=d;c=Kl(d,a,1);a=fb(a);e=i[c+4>>2];i[114610]=0;G(611,a|0,e|0,b|0);a=i[114610];i[114610]=0;if((a|0)!=1){i[c+4>>2]=i[c+4>>2]+16;sb(c);Xa=d+16|0;return}a=B()|0;A()|0;sb(c);E(a|0);x()}function Fr(a,b){var c=0;c=79388;a:{b:{c:{switch(b+ -2|0){default:if((b|0)==16777216){break a}if((b|0)!=32){break b}c=79404;break a;case 2:c=79400;break a;case 1:break b;case 0:break c}}c=79396;break a}c=79392}i[a>>2]=i[c>>2]}function FIa(a,b){var c=0,d=0,e=0;d=Xa-16|0;Xa=d;c=fk(d,a,1);a=fb(a);e=i[c+4>>2];i[114610]=0;G(574,a|0,e|0,b|0);a=i[114610];i[114610]=0;if((a|0)!=1){i[c+4>>2]=i[c+4>>2]+24;sb(c);Xa=d+16|0;return}a=B()|0;A()|0;sb(c);E(a|0);x()}function Ana(a,b){var c=0,d=0,e=0;d=Xa-16|0;Xa=d;c=Yd(d,a,1);a=fb(a);e=i[c+4>>2];i[114610]=0;G(1421,a|0,e|0,b|0);a=i[114610];i[114610]=0;if((a|0)!=1){i[c+4>>2]=i[c+4>>2]+4;sb(c);Xa=d+16|0;return}a=B()|0;A()|0;sb(c);E(a|0);x()}function $Q(a){if(!((j[a+8|0]|j[a+9|0]<<8|(j[a+10|0]<<16|j[a+11|0]<<24))==1179472708?(j[a|0]|j[a+1|0]<<8|(j[a+2|0]<<16|j[a+3|0]<<24))==1179011410:0)){return(j[a|0]|j[a+1|0]<<8|(j[a+2|0]<<16|j[a+3|0]<<24))==1179472708}return 1}function yU(a,b){var c=0,d=0,e=0;d=Xa-16|0;Xa=d;c=yn(d,a,1);a=fb(a);e=i[c+4>>2];i[114610]=0;G(347,a|0,e|0,b|0);a=i[114610];i[114610]=0;if((a|0)!=1){i[c+4>>2]=i[c+4>>2]+32;sb(c);Xa=d+16|0;return}a=B()|0;A()|0;sb(c);E(a|0);x()}function wna(a){var b=0,c=0;c=a+946300|0;b=a+906300|0;while(1){a=i[b>>2];a:{if(!a){break a}if($a[i[i[a>>2]+112>>2]](a)|0){break a}$a[i[i[a>>2]+104>>2]](a,1);$a[i[i[a>>2]+116>>2]](a)}b=b+160|0;if((c|0)!=(b|0)){continue}break}}function rra(a,b){var c=0,d=0,e=0;d=Xa-16|0;Xa=d;c=Yd(d,a,1);a=fb(a);e=i[c+4>>2];i[114610]=0;G(411,a|0,e|0,b|0);a=i[114610];i[114610]=0;if((a|0)!=1){i[c+4>>2]=i[c+4>>2]+4;sb(c);Xa=d+16|0;return}a=B()|0;A()|0;sb(c);E(a|0);x()}function p4(a,b){var c=0,d=0,e=0;d=Xa-16|0;Xa=d;c=Ik(d,a,1);a=fb(a);e=i[c+4>>2];i[114610]=0;G(204,a|0,e|0,b|0);a=i[114610];i[114610]=0;if((a|0)!=1){i[c+4>>2]=i[c+4>>2]+12;sb(c);Xa=d+16|0;return}a=B()|0;A()|0;sb(c);E(a|0);x()}function aKa(a,b){var c=0,d=0,e=0;d=Xa-16|0;Xa=d;c=vh(d,a,1);a=fb(a);e=i[c+4>>2];i[114610]=0;G(521,a|0,e|0,b|0);a=i[114610];i[114610]=0;if((a|0)!=1){i[c+4>>2]=i[c+4>>2]+2;sb(c);Xa=d+16|0;return}a=B()|0;A()|0;sb(c);E(a|0);x()}function XKa(a,b){var c=0,d=0,e=0;d=Xa-16|0;Xa=d;c=vh(d,a,1);a=fb(a);e=i[c+4>>2];i[114610]=0;G(381,a|0,e|0,b|0);a=i[114610];i[114610]=0;if((a|0)!=1){i[c+4>>2]=i[c+4>>2]+2;sb(c);Xa=d+16|0;return}a=B()|0;A()|0;sb(c);E(a|0);x()}function SMa(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0;e=c>>>16|0;f=a>>>16|0;j=o(e,f);g=c&65535;h=a&65535;i=o(g,h);f=(i>>>16|0)+o(f,g)|0;e=(f&65535)+o(e,h)|0;a=(o(b,c)+j|0)+o(a,d)+(f>>>16)+(e>>>16)|0;b=i&65535|e<<16;_a=a;return b}function L8(a,b){var c=0,d=0,e=0;c=Xa-32|0;Xa=c;b=Zb(c+24|0,i[b>>2]);d=i[a>>2];a=i[d+4>>2];d=i[d>>2];i[c+16>>2]=d;i[c+20>>2]=a;e=i[b+4>>2];i[c+8>>2]=i[b>>2];i[c+12>>2]=e;i[c>>2]=d;i[c+4>>2]=a;a=mc(c+8|0,c);Xa=c+32|0;return a}function zP(a,b){var c=0,d=0,e=0;d=Xa-16|0;Xa=d;c=Yd(d,a,1);a=fb(a);e=i[c+4>>2];i[114610]=0;G(770,a|0,e|0,b|0);a=i[114610];i[114610]=0;if((a|0)!=1){i[c+4>>2]=i[c+4>>2]+4;sb(c);Xa=d+16|0;return}a=B()|0;A()|0;sb(c);E(a|0);x()}function yC(){var a=0;a:{b:{if(g[461780]&1){break b}if(!cd(461780)){break b}i[114610]=0;R(2561)|0;a=i[114610];i[114610]=0;if((a|0)==1){break a}i[115444]=461772;bd(461780)}return i[115444]}a=B()|0;A()|0;Xd(461780);E(a|0);x()}function tua(a,b,c){var d=0,e=0,f=0;c=c+ -1|0;if((c|0)>-1){while(1){d=c<<4;e=c<<3;f=e|4;i[(d|12)+a>>2]=i[f+b>>2];i[(d|8)+a>>2]=i[b+e>>2];i[(d|4)+a>>2]=i[a+f>>2];i[a+d>>2]=i[a+e>>2];d=(c|0)>0;c=c+ -1|0;if(d){continue}break}}}function ixa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=Xa-32|0;Xa=d;e=ke(b);c=SM(d+8|0,c);i[114610]=0;T(1031,a|0,b|0,0,e+ -1&65535,c|0);a=i[114610];i[114610]=0;if((a|0)!=1){Td(c);Xa=d+32|0;return}a=B()|0;A()|0;Td(c);E(a|0);x()}function e0(a,b){var c=0,d=0,e=0;d=Xa-16|0;Xa=d;c=ql(d,a,1);a=fb(a);e=i[c+4>>2];i[114610]=0;G(210,a|0,e|0,b|0);a=i[114610];i[114610]=0;if((a|0)!=1){i[c+4>>2]=i[c+4>>2]+1;sb(c);Xa=d+16|0;return}a=B()|0;A()|0;sb(c);E(a|0);x()}function Jva(a,b){var c=0,d=0,e=0;d=Xa-16|0;Xa=d;c=Yd(d,a,1);a=fb(a);e=i[c+4>>2];i[114610]=0;G(95,a|0,e|0,b|0);a=i[114610];i[114610]=0;if((a|0)!=1){i[c+4>>2]=i[c+4>>2]+4;sb(c);Xa=d+16|0;return}a=B()|0;A()|0;sb(c);E(a|0);x()}function H2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=Xa-16|0;Xa=d;i[d+12>>2]=c;i[d+8>>2]=c;e=-1;c=uq(0,0,b,c);a:{if((c|0)<0){break a}f=a;c=c+1|0;a=Zc(c);i[f>>2]=a;if(!a){break a}e=uq(a,c,b,i[d+12>>2])}Xa=d+16|0;return e|0}function Baa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=Xa-16|0;Xa=d;e=d+8|0;i[e>>2]=83824;i[e>>2]=83780;i[114610]=0;a=N(2155,a|0,b|0,c|0,e|0)|0;b=i[114610];i[114610]=0;if((b|0)!=1){Xa=d+16|0;return a|0}a=B()|0;A()|0;E(a|0);x()}function B_(){var a=0;a:{b:{if(g[461792]&1){break b}if(!cd(461792)){break b}i[114610]=0;R(2565)|0;a=i[114610];i[114610]=0;if((a|0)==1){break a}i[115447]=461784;bd(461792)}return i[115447]}a=B()|0;A()|0;Xd(461792);E(a|0);x()}function AU(a,b){var c=0,d=0,e=0;d=Xa-16|0;Xa=d;c=Yd(d,a,1);a=fb(a);e=i[c+4>>2];i[114610]=0;G(346,a|0,e|0,b|0);a=i[114610];i[114610]=0;if((a|0)!=1){i[c+4>>2]=i[c+4>>2]+4;sb(c);Xa=d+16|0;return}a=B()|0;A()|0;sb(c);E(a|0);x()}function xMa(a,b){var c=0,d=0;a:{while(1){if(i[a+8>>2]==(b|0)){break a}c=i[a+16>>2];d=i[a+8>>2]+ -2|0;i[a+8>>2]=d;i[114610]=0;D(382,c|0,d|0);c=i[114610];i[114610]=0;if((c|0)!=1){continue}break}a=H(0)|0;A()|0;gb(a);x()}}



function tia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=Xa-16|0;Xa=c;a:{if(qb(a)){while(1){Kf(c,i[vb(a,d)>>2]+40|0);e=ep(c,b);eb(c);if(e){a=i[vb(a,d)>>2];break a}d=d+1|0;if(d>>>0<qb(a)>>>0){continue}break}}a=0}Xa=c+16|0;return a|0}function t9(a,b){a=a|0;b=b|0;var c=p(0);a:{if((b|0)<0){break a}a=a+24|0;if(k[i[a>>2]+480188>>1]<=(b|0)){break a}b=o(b,896);if(g[(b+i[a>>2]|0)+1075073|0]&1){break a}c=p(p(j[(b+i[a>>2]|0)+1075846|0])*p(.0078125))}return p(c)}function sg(a){a=a|0;var b=0,c=0;b=Xa-16|0;Xa=b;g[a+8|0]=0;i[a>>2]=0;i[a+4>>2]=4194432;c=Bb(b,11931);i[114610]=0;C(378,a+9|0,c|0)|0;a=i[114610];i[114610]=0;if((a|0)!=1){eb(c);Xa=b+16|0;return}a=B()|0;A()|0;eb(c);E(a|0);x()}function s9(a,b){a=a|0;b=b|0;var c=p(0);a:{if((b|0)<0){break a}a=a+24|0;if(k[i[a>>2]+480188>>1]<=(b|0)){break a}b=o(b,896);if(g[(b+i[a>>2]|0)+1075073|0]&1){break a}c=p(p(j[(b+i[a>>2]|0)+1075847|0])*p(.0078125))}return p(c)}function pha(a,b){var c=0,d=0;a:{while(1){if(i[a+8>>2]==(b|0)){break a}c=i[a+16>>2];d=i[a+8>>2]+ -2048|0;i[a+8>>2]=d;i[114610]=0;D(1651,c|0,d|0);c=i[114610];i[114610]=0;if((c|0)!=1){continue}break}a=H(0)|0;A()|0;gb(a);x()}}function mma(a,b,c){var d=0;d=Xa-32|0;Xa=d;i[d+16>>2]=b;i[d+24>>2]=a;i[d+8>>2]=c;if(pb(d+24|0,d+16|0)){while(1){a=$a[117](g[i[d+24>>2]])|0;g[i[d+8>>2]]=a;Tf(d+24|0);Tf(d+8|0);if(pb(d+24|0,d+16|0)){continue}break}}Xa=d+32|0}function jY(a,b,c){var d=0,e=0,f=0;d=Xa-16|0;Xa=d;if(1073741807>=c>>>0){a:{if(c>>>0<=1){Te(a,c);e=a;break a}f=Nl(c)+1|0;e=Ak(f);gf(a,e);fg(a,f);ce(a,c)}Gh(e,b,c);i[d+12>>2]=0;ye((c<<2)+e|0,d+12|0);Xa=d+16|0;return}gg();x()}function gna(a,b){a=a|0;b=b|0;var c=0,d=0;c=Xa-16|0;Xa=c;i[a+480180>>2]=b;LJ(c,ro(a));d=i[c+12>>2];b=a+1074316|0;i[b>>2]=i[c+8>>2];i[b+4>>2]=d;b=i[c+4>>2];i[a+1074308>>2]=i[c>>2];i[a+1074312>>2]=b;Fr(a+8|0,ro(a));Xa=c+16|0}function eD(a,b){var c=0,d=0;c=Xa-32|0;Xa=c;a:{if(xf(a)>>>0<b>>>0){d=fb(a);b=Iu(c+8|0,b,rc(a),d);i[114610]=0;D(209,a|0,b|0);a=i[114610];i[114610]=0;if((a|0)==1){break a}Ql(b)}Xa=c+32|0;return}a=B()|0;A()|0;Ql(b);E(a|0);x()}function dY(a,b,c){var d=0,e=0,f=0;d=Xa-16|0;Xa=d;if(1073741807>=b>>>0){a:{if(b>>>0<=1){Te(a,b);e=a;break a}f=Nl(b)+1|0;e=Ak(f);gf(a,e);fg(a,f);ce(a,b)}gY(e,b,c);i[d+12>>2]=0;ye((b<<2)+e|0,d+12|0);Xa=d+16|0;return}gg();x()}function bna(a,b){a=a|0;b=b|0;var c=0;c=65535;a:{if(k[i[a+8>>2]+58>>1]<b>>>0){break a}while(1){if(!i[(((b&65535)<<2)+a|0)+900380>>2]){c=b;break a}b=b+1|0;if((b&65535)>>>0<=k[i[a+8>>2]+58>>1]){continue}break}}return c&65535}function Era(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;Dra(a);d=a;e=Sm(a+12|0);g[a+30|0]=c;h[a+28>>1]=0;i[a+24>>2]=b;i[114610]=0;D(1233,a|0,1);b=i[114610];i[114610]=0;if((b|0)!=1){return a|0}a=B()|0;A()|0;Sd(e);pL(d);E(a|0);x()}function oL(a,b){var c=0,d=0;c=Xa-32|0;Xa=c;a:{if(gd(a)>>>0<b>>>0){d=fb(a);b=Zr(c+8|0,b,qb(a),d);i[114610]=0;D(96,a|0,b|0);a=i[114610];i[114610]=0;if((a|0)==1){break a}Nj(b)}Xa=c+32|0;return}a=B()|0;A()|0;Nj(b);E(a|0);x()}function jGa(a,b){var c=0,d=0,e=0;c=Xa-16|0;Xa=c;d=2;e=i[a>>2];if((e|0)!=1){i[c+12>>2]=e>>>1;i[c+8>>2]=-1-i[a>>2];d=rb(c+12|0,c+8|0);i[c+12>>2]=i[a>>2]+i[d>>2];i[c+8>>2]=i[b>>2];d=i[rb(c+12|0,c+8|0)>>2]}Xa=c+16|0;return d}function fja(a,b){var c=0,d=0,e=0;c=Xa-16|0;Xa=c;d=c,e=Cia(a,b,qe(a),Pb(a)),i[d+8>>2]=e;d=c,e=Zi(a),i[d>>2]=e;a:{b:{if(!pb(c+8|0,c)){break b}if(wr(fb(a),b,Qg(c+8|0))){break b}a=i[c+8>>2];break a}a=Zi(a)}Xa=c+16|0;return a}function bJa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=Xa-16|0;Xa=d;e=0;a:{if(!a){break a}e=a|-16;if(!(a>>>0<16&c?0:b>>>0>=2)){break a}g[d+15|0]=1;g[d+14|0]=(a|0)/(b+ -1|0);e=j[Ug(d+15|0,d+14|0)|0]}a=e;Xa=d+16|0;return a&255}function Sq(a){var b=0;a:{b=j[a+1376|0];b:{if(!b){b=-1;if(i[a+1384>>2]){break b}if(!wv(a)){break b}b=j[a+1376|0];if(!b){break a}}g[a+1376|0]=b+ -1;i[a+1400>>2]=i[a+1400>>2]+1;b=fe(a)}return b}V(50530,50448,1563,50550);x()}function RFa(a,b){var c=0,d=0,e=0;c=Xa-16|0;Xa=c;d=c,e=FFa(a,b,qe(a),Pb(a)),i[d+8>>2]=e;d=c,e=Zi(a),i[d>>2]=e;a:{b:{if(!pb(c+8|0,c)){break b}if(Zm(fb(a),b,Qg(c+8|0))){break b}a=i[c+8>>2];break a}a=Zi(a)}Xa=c+16|0;return a}function N$(a,b,c){var d=0;d=Xa-32|0;Xa=d;i[d+16>>2]=b;i[d+24>>2]=a;i[d+8>>2]=c;while(1){a:{a=pb(d+24|0,d+16|0);if(!a){break a}if(!al(i[d+24>>2],i[d+8>>2])){break a}Gd(d+24|0);Gd(d+8|0);continue}break}Xa=d+32|0;return a^1}function Iba(a,b){var c=0,d=0,e=0;c=Xa-16|0;Xa=c;d=c,e=Gba(a,b,qe(a),Pb(a)),i[d+8>>2]=e;d=c,e=Zi(a),i[d>>2]=e;a:{b:{if(!pb(c+8|0,c)){break b}if(Xr(fb(a),b,Qg(c+8|0))){break b}a=i[c+8>>2];break a}a=Zi(a)}Xa=c+16|0;return a}function D7(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=p(0);if(e){while(1){f=0;if(d){while(1){h=n[Ig(b,f,g)>>3];Nb(c,f);i=Qm(a,f,g),j=p(h),m[i>>2]=j;f=f+1|0;if((f|0)!=(d|0)){continue}break}}g=g+1|0;if((g|0)!=(e|0)){continue}break}}}function $6(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=p(0);if(e){while(1){f=0;if(d){while(1){h=n[Ig(b,f,g)>>3];Nb(c,f);i=rf(a,f,g),j=p(h),m[i>>2]=j;f=f+1|0;if((f|0)!=(d|0)){continue}break}}g=g+1|0;if((g|0)!=(e|0)){continue}break}}}function wZ(a){a=a|0;a:{b:{if(g[461868]&1){break b}if(!cd(461868)){break b}i[114610]=0;K(2580);a=i[114610];i[114610]=0;if((a|0)==1){break a}i[115466]=462048;bd(461868)}return i[115466]}a=B()|0;A()|0;Xd(461868);E(a|0);x()}function vxa(a,b){var c=0,d=0;a:{while(1){if(i[a+8>>2]==(b|0)){break a}c=i[a+16>>2];d=i[a+8>>2]+ -12|0;i[a+8>>2]=d;i[114610]=0;D(1023,c|0,d|0);c=i[114610];i[114610]=0;if((c|0)!=1){continue}break}a=H(0)|0;A()|0;gb(a);x()}}function vY(a,b){a=a|0;b=b|0;var c=0;c=Xa-16|0;Xa=c;a:{if(Us(b,68513)){XB(c,68526,b);a=xb(c);i[114610]=0;D(2310,44,a|0);a=i[114610];i[114610]=0;if((a|0)!=1){break a}a=B()|0;A()|0;eb(c);E(a|0);x()}Xa=c+16|0;return a|0}x()}function uja(a,b){var c=0,d=0;a:{while(1){if(i[a+8>>2]==(b|0)){break a}c=i[a+16>>2];d=i[a+8>>2]+ -52|0;i[a+8>>2]=d;i[114610]=0;D(1438,c|0,d|0);c=i[114610];i[114610]=0;if((c|0)!=1){continue}break}a=H(0)|0;A()|0;gb(a);x()}}function txa(a,b){var c=0,d=0;a:{while(1){if(i[a+8>>2]==(b|0)){break a}c=i[a+16>>2];d=i[a+8>>2]+ -12|0;i[a+8>>2]=d;i[114610]=0;D(1024,c|0,d|0);c=i[114610];i[114610]=0;if((c|0)!=1){continue}break}a=H(0)|0;A()|0;gb(a);x()}}function tZ(a){a=a|0;a:{b:{if(g[461876]&1){break b}if(!cd(461876)){break b}i[114610]=0;K(2582);a=i[114610];i[114610]=0;if((a|0)==1){break a}i[115468]=462224;bd(461876)}return i[115468]}a=B()|0;A()|0;Xd(461876);E(a|0);x()}function qZ(a){a=a|0;a:{b:{if(g[461884]&1){break b}if(!cd(461884)){break b}i[114610]=0;K(2584);a=i[114610];i[114610]=0;if((a|0)==1){break a}i[115470]=462400;bd(461884)}return i[115470]}a=B()|0;A()|0;Xd(461884);E(a|0);x()}function nZ(a){a=a|0;a:{b:{if(g[461892]&1){break b}if(!cd(461892)){break b}i[114610]=0;K(2586);a=i[114610];i[114610]=0;if((a|0)==1){break a}i[115472]=462704;bd(461892)}return i[115472]}a=B()|0;A()|0;Xd(461892);E(a|0);x()}function kZ(a){a=a|0;a:{b:{if(g[461900]&1){break b}if(!cd(461900)){break b}i[114610]=0;K(2588);a=i[114610];i[114610]=0;if((a|0)==1){break a}i[115474]=463008;bd(461900)}return i[115474]}a=B()|0;A()|0;Xd(461900);E(a|0);x()}function hra(a,b){var c=0,d=0;a:{while(1){if(i[a+8>>2]==(b|0)){break a}c=i[a+16>>2];d=i[a+8>>2]+ -12|0;i[a+8>>2]=d;i[114610]=0;D(1237,c|0,d|0);c=i[114610];i[114610]=0;if((c|0)!=1){continue}break}a=H(0)|0;A()|0;gb(a);x()}}function gZ(a){a=a|0;a:{b:{if(g[461908]&1){break b}if(!cd(461908)){break b}i[114610]=0;K(2590);a=i[114610];i[114610]=0;if((a|0)==1){break a}i[115476]=463040;bd(461908)}return i[115476]}a=B()|0;A()|0;Xd(461908);E(a|0);x()}function Zra(a){var b=0,c=0;c=Qra(a);i[114610]=0;D(1221,a|0,2048);b=i[114610];i[114610]=0;a:{if((b|0)!=1){i[114610]=0;D(1223,a|0,2048);b=i[114610];i[114610]=0;if((b|0)!=1){break a}}a=B()|0;A()|0;Cx(c);E(a|0);x()}return a}function Psa(a,b){var c=0,d=0;a:{while(1){if(i[a+8>>2]==(b|0)){break a}c=i[a+16>>2];d=i[a+8>>2]+ -32|0;i[a+8>>2]=d;i[114610]=0;D(1195,c|0,d|0);c=i[114610];i[114610]=0;if((c|0)!=1){continue}break}a=H(0)|0;A()|0;gb(a);x()}}function Moa(a,b){var c=0,d=0;a:{if(256<=b>>>0){break a}c=i[(o(b,896)+a|0)+1075640>>2];if(!c){break a}if(j[c+31|0]==17){a=k[(o(b,896)+a|0)+1075792>>1];return(a?a+ -1|0:b)&15}if(!Xh(c)){break a}d=j[c+31|0]+ -1&15}return d}function Fka(a,b){var c=0,d=0;a:{while(1){if(i[a+8>>2]==(b|0)){break a}c=i[a+16>>2];d=i[a+8>>2]+ -24|0;i[a+8>>2]=d;i[114610]=0;D(1560,c|0,d|0);c=i[114610];i[114610]=0;if((c|0)!=1){continue}break}a=H(0)|0;A()|0;gb(a);x()}}function uoa(a,b){var c=0,d=0;a:{while(1){if(i[a+8>>2]==(b|0)){break a}c=i[a+16>>2];d=i[a+8>>2]+ -32|0;i[a+8>>2]=d;i[114610]=0;D(896,c|0,d|0);c=i[114610];i[114610]=0;if((c|0)!=1){continue}break}a=H(0)|0;A()|0;gb(a);x()}}function lx(a,b){var c=0,d=0;c=o(b,896)+a|0;a:{if(i[c+1075072>>2]&134218752){break a}if(!Pi(c+1074984|0)){break a}b=j[i[(o(b,896)+a|0)+1075640>>2]+34|0];if((b+5&255)>>>0<6){break a}d=i[(o(b,160)+a|0)+906140>>2]}return d}function lha(a,b){var c=0,d=0;a:{while(1){if(i[a+8>>2]==(b|0)){break a}c=i[a+16>>2];d=i[a+8>>2]+ -4|0;i[a+8>>2]=d;i[114610]=0;D(1653,c|0,d|0);c=i[114610];i[114610]=0;if((c|0)!=1){continue}break}a=H(0)|0;A()|0;gb(a);x()}}function k8(a,b){var c=0,d=0;a:{while(1){if(i[a+8>>2]==(b|0)){break a}c=i[a+16>>2];d=i[a+8>>2]+ -16|0;i[a+8>>2]=d;i[114610]=0;D(2206,c|0,d|0);c=i[114610];i[114610]=0;if((c|0)!=1){continue}break}a=H(0)|0;A()|0;gb(a);x()}}function iga(a,b){var c=0,d=0;a:{while(1){if(i[a+8>>2]==(b|0)){break a}c=i[a+16>>2];d=i[a+8>>2]+ -4|0;i[a+8>>2]=d;i[114610]=0;D(1763,c|0,d|0);c=i[114610];i[114610]=0;if((c|0)!=1){continue}break}a=H(0)|0;A()|0;gb(a);x()}}function iN(a,b,c){var d=0;d=Xa-16|0;Xa=d;g[d+15|0]=a;a=0;if(!(c>>>0>108|b>>>0>108|(c>>>0<25|b>>>0<25)|b>>>0>=c>>>0)){g[d+14|0]=(k[(b<<1)+20782>>1]-k[(c<<1)+20782>>1]|0)/5;a=j[Xb(d+15|0,d+14|0)|0]}Xa=d+16|0;return a&255}function f8(a,b){var c=0,d=0;a:{while(1){if(i[a+8>>2]==(b|0)){break a}c=i[a+16>>2];d=i[a+8>>2]+ -24|0;i[a+8>>2]=d;i[114610]=0;D(2207,c|0,d|0);c=i[114610];i[114610]=0;if((c|0)!=1){continue}break}a=H(0)|0;A()|0;gb(a);x()}}function cEa(a,b){var c=0,d=0;a:{while(1){if(i[a+8>>2]==(b|0)){break a}c=i[a+16>>2];d=i[a+8>>2]+ -33|0;i[a+8>>2]=d;i[114610]=0;D(769,c|0,d|0);c=i[114610];i[114610]=0;if((c|0)!=1){continue}break}a=H(0)|0;A()|0;gb(a);x()}}function aEa(a){var b=0,c=0;c=Xa-32|0;Xa=c;a:{if(gd(a)>>>0<15){b=fb(a);b=sn(c+8|0,15,qb(a),b);i[114610]=0;D(368,a|0,b|0);a=i[114610];i[114610]=0;if((a|0)==1){break a}uh(b)}Xa=c+32|0;return}a=B()|0;A()|0;uh(b);E(a|0);x()}function _ha(a,b){var c=0,d=0;a:{while(1){if(i[a+8>>2]==(b|0)){break a}c=i[a+16>>2];d=i[a+8>>2]+ -4|0;i[a+8>>2]=d;i[114610]=0;D(1439,c|0,d|0);c=i[114610];i[114610]=0;if((c|0)!=1){continue}break}a=H(0)|0;A()|0;gb(a);x()}}function Vya(a,b){var c=0,d=0;a:{while(1){if(i[a+8>>2]==(b|0)){break a}c=i[a+16>>2];d=i[a+8>>2]+ -24|0;i[a+8>>2]=d;i[114610]=0;D(986,c|0,d|0);c=i[114610];i[114610]=0;if((c|0)!=1){continue}break}a=H(0)|0;A()|0;gb(a);x()}}function Ula(a,b){var c=0,d=0;a:{while(1){if(i[a+8>>2]==(b|0)){break a}c=i[a+16>>2];d=i[a+8>>2]+ -4|0;i[a+8>>2]=d;i[114610]=0;D(1524,c|0,d|0);c=i[114610];i[114610]=0;if((c|0)!=1){continue}break}a=H(0)|0;A()|0;gb(a);x()}}function SHa(a,b){var c=0,d=0;a:{while(1){if(i[a+8>>2]==(b|0)){break a}c=i[a+16>>2];d=i[a+8>>2]+ -24|0;i[a+8>>2]=d;i[114610]=0;D(607,c|0,d|0);c=i[114610];i[114610]=0;if((c|0)!=1){continue}break}a=H(0)|0;A()|0;gb(a);x()}}function Rka(a,b){var c=0,d=0,e=0,f=0;c=a+1|0;d=a+2|0;e=a+3|0;f=a+4|0;MI(j[a|0]&15,j[c|0]&15,j[d|0]&15,j[e|0]&15,j[f|0]&15,a+5|0,b+48|0);MI(j[a|0]>>>4|0,j[c|0]>>>4|0,j[d|0]>>>4|0,j[e|0]>>>4|0,j[f|0]>>>4|0,a+35|0,b+68|0)}function Qqa(a,b){var c=0,d=0;a:{while(1){if(i[a+8>>2]==(b|0)){break a}c=i[a+16>>2];d=i[a+8>>2]+ -12|0;i[a+8>>2]=d;i[114610]=0;D(348,c|0,d|0);c=i[114610];i[114610]=0;if((c|0)!=1){continue}break}a=H(0)|0;A()|0;gb(a);x()}}function PM(a){var b=0,c=0,d=0;c=a- -64|0;d=j[c|0]|j[c+1|0]<<8;c=0;b=a+70|0;a=a+72|0;a=j[a|0]|j[a+1|0]<<8;b=(j[b|0]|j[b+1|0]<<8)+a|0;if(b>>>0<a>>>0){c=1}a=c<<2|b>>>30;b=b<<2;c=d+b|0;if(c>>>0<b>>>0){a=a+1|0}_a=a;return c}function PDa(a,b){var c=0,d=0;a:{while(1){if(i[a+8>>2]==(b|0)){break a}c=i[a+16>>2];d=i[a+8>>2]+ -24|0;i[a+8>>2]=d;i[114610]=0;D(771,c|0,d|0);c=i[114610];i[114610]=0;if((c|0)!=1){continue}break}a=H(0)|0;A()|0;gb(a);x()}}function MJa(a,b){var c=0,d=0;a:{while(1){if(i[a+8>>2]==(b|0)){break a}c=i[a+16>>2];d=i[a+8>>2]+ -24|0;i[a+8>>2]=d;i[114610]=0;D(528,c|0,d|0);c=i[114610];i[114610]=0;if((c|0)!=1){continue}break}a=H(0)|0;A()|0;gb(a);x()}}function Iya(a,b){var c=0,d=0;a:{while(1){if(i[a+8>>2]==(b|0)){break a}c=i[a+16>>2];d=i[a+8>>2]+ -56|0;i[a+8>>2]=d;i[114610]=0;D(990,c|0,d|0);c=i[114610];i[114610]=0;if((c|0)!=1){continue}break}a=H(0)|0;A()|0;gb(a);x()}}function Ima(a,b){var c=0,d=0;a:{while(1){if(i[a+8>>2]==(b|0)){break a}c=i[a+16>>2];d=i[a+8>>2]+ -4|0;i[a+8>>2]=d;i[114610]=0;D(1440,c|0,d|0);c=i[114610];i[114610]=0;if((c|0)!=1){continue}break}a=H(0)|0;A()|0;gb(a);x()}}function HHa(a,b){var c=0,d=0;a:{while(1){if(i[a+8>>2]==(b|0)){break a}c=i[a+16>>2];d=i[a+8>>2]+ -16|0;i[a+8>>2]=d;i[114610]=0;D(426,c|0,d|0);c=i[114610];i[114610]=0;if((c|0)!=1){continue}break}a=H(0)|0;A()|0;gb(a);x()}}function GIa(a,b){var c=0,d=0;a:{while(1){if(i[a+8>>2]==(b|0)){break a}c=i[a+16>>2];d=i[a+8>>2]+ -48|0;i[a+8>>2]=d;i[114610]=0;D(573,c|0,d|0);c=i[114610];i[114610]=0;if((c|0)!=1){continue}break}a=H(0)|0;A()|0;gb(a);x()}}function Ewa(a,b){var c=0,d=0;a:{while(1){if(i[a+8>>2]==(b|0)){break a}c=i[a+16>>2];d=i[a+8>>2]+ -4|0;i[a+8>>2]=d;i[114610]=0;D(1060,c|0,d|0);c=i[114610];i[114610]=0;if((c|0)!=1){continue}break}a=H(0)|0;A()|0;gb(a);x()}}function Bpa(a,b){a=a|0;b=+b;var c=0,d=0,e=0;c=Xa-16|0;Xa=c;d=c,e=(i[a+480208>>2]&32768?28.85390081777927:34.624680981335125)*(Vn(b)+ -4.8737671609324025),n[d+8>>3]=e;mf(c+8|0,0,127);a=Gs(n[c+8>>3]);Xa=c+16|0;return a|0}function BIa(a,b){var c=0,d=0;a:{while(1){if(i[a+8>>2]==(b|0)){break a}c=i[a+16>>2];d=i[a+8>>2]+ -24|0;i[a+8>>2]=d;i[114610]=0;D(572,c|0,d|0);c=i[114610];i[114610]=0;if((c|0)!=1){continue}break}a=H(0)|0;A()|0;gb(a);x()}}function qd(a){var b=0,c=0,d=0;b=Xa-32|0;Xa=b;i[b+12>>2]=0;i[b+8>>2]=2558;c=i[b+12>>2];i[b>>2]=i[b+8>>2];i[b+4>>2]=c;d=i[b+4>>2];c=b+16|0;i[c+4>>2]=i[b>>2];i[c+8>>2]=d;i[c>>2]=a;z_(a,c);Xa=b+32|0;return i[a+4>>2]+ -1|0}function pFa(a,b){var c=0,d=0;a:{while(1){if(i[a+8>>2]==(b|0)){break a}c=i[a+16>>2];d=i[a+8>>2]+ -4|0;i[a+8>>2]=d;i[114610]=0;D(740,c|0,d|0);c=i[114610];i[114610]=0;if((c|0)!=1){continue}break}a=H(0)|0;A()|0;gb(a);x()}}function nAa(a,b){var c=0,d=0;a:{while(1){if(i[a+8>>2]==(b|0)){break a}c=i[a+16>>2];d=i[a+8>>2]+ -8|0;i[a+8>>2]=d;i[114610]=0;D(924,c|0,d|0);c=i[114610];i[114610]=0;if((c|0)!=1){continue}break}a=H(0)|0;A()|0;gb(a);x()}}function lV(a,b){var c=0,d=0;a:{while(1){if(i[a+8>>2]==(b|0)){break a}c=i[a+16>>2];d=i[a+8>>2]+ -32|0;i[a+8>>2]=d;i[114610]=0;D(276,c|0,d|0);c=i[114610];i[114610]=0;if((c|0)!=1){continue}break}a=H(0)|0;A()|0;gb(a);x()}}function dja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=Xa-16|0;Xa=d;a:{if(!Cc(c)){vi(iI(a+52|0,b),c);break a}a=a+52|0;e=d,f=tw(a,b),i[e+8>>2]=f;e=d,f=fi(a),i[e>>2]=f;if(!ei(d+8|0,d)){break a}cja(a,i[d+8>>2])}Xa=d+16|0}function dFa(a,b){var c=0,d=0;a:{while(1){if(i[a+8>>2]==(b|0)){break a}c=i[a+16>>2];d=i[a+8>>2]+ -6|0;i[a+8>>2]=d;i[114610]=0;D(739,c|0,d|0);c=i[114610];i[114610]=0;if((c|0)!=1){continue}break}a=H(0)|0;A()|0;gb(a);x()}}function cqa(a,b){var c=0,d=0;a:{while(1){if(i[a+8>>2]==(b|0)){break a}c=i[a+16>>2];d=i[a+8>>2]+ -4|0;i[a+8>>2]=d;i[114610]=0;D(107,c|0,d|0);c=i[114610];i[114610]=0;if((c|0)!=1){continue}break}a=H(0)|0;A()|0;gb(a);x()}}function aW(a){var b=0,c=0,d=0;c=Xa-16|0;Xa=c;b=yn(c,a,1);a=fb(a);d=i[b+4>>2];i[114610]=0;D(266,a|0,d|0);a=i[114610];i[114610]=0;if((a|0)!=1){i[b+4>>2]=i[b+4>>2]+32;sb(b);Xa=c+16|0;return}a=B()|0;A()|0;sb(b);E(a|0);x()}function WZ(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=Xa-16|0;Xa=e;i[e+12>>2]=d;d=ah(e+8|0,e+12|0);i[114610]=0;a=tD(a,b,c);b=i[114610];i[114610]=0;if((b|0)!=1){ne(d);Xa=e+16|0;return a|0}a=B()|0;A()|0;ne(d);E(a|0);x()}function VCa(a,b){var c=0,d=0;a:{while(1){if(i[a+8>>2]==(b|0)){break a}c=i[a+16>>2];d=i[a+8>>2]+ -4|0;i[a+8>>2]=d;i[114610]=0;D(822,c|0,d|0);c=i[114610];i[114610]=0;if((c|0)!=1){continue}break}a=H(0)|0;A()|0;gb(a);x()}}function Q2(a,b){var c=0,d=0;a:{while(1){if(i[a+8>>2]==(b|0)){break a}c=i[a+16>>2];d=i[a+8>>2]+ -12|0;i[a+8>>2]=d;i[114610]=0;D(206,c|0,d|0);c=i[114610];i[114610]=0;if((c|0)!=1){continue}break}a=H(0)|0;A()|0;gb(a);x()}}function Oea(a,b){var c=0,d=0;c=Xa-32|0;Xa=c;d=i[b+48>>2];a:{if(d&16){if(l[b+44>>2]<l[b+24>>2]){i[b+44>>2]=i[b+24>>2]}Uh(a,i[b+20>>2],i[b+44>>2]);break a}if(d&8){Uh(a,i[b+8>>2],i[b+16>>2]);break a}Zv(a,c+8|0)}Xa=c+32|0}function OW(a,b){var c=0,d=0;a:{while(1){if(i[a+8>>2]==(b|0)){break a}c=i[a+16>>2];d=i[a+8>>2]+ -16|0;i[a+8>>2]=d;i[114610]=0;D(217,c|0,d|0);c=i[114610];i[114610]=0;if((c|0)!=1){continue}break}a=H(0)|0;A()|0;gb(a);x()}}function MCa(a,b){var c=0,d=0;a:{while(1){if(i[a+8>>2]==(b|0)){break a}c=i[a+16>>2];d=i[a+8>>2]+ -2|0;i[a+8>>2]=d;i[114610]=0;D(829,c|0,d|0);c=i[114610];i[114610]=0;if((c|0)!=1){continue}break}a=H(0)|0;A()|0;gb(a);x()}}function Hza(a,b){var c=0,d=0;a:{while(1){if(i[a+8>>2]==(b|0)){break a}c=i[a+16>>2];d=i[a+8>>2]+ -4|0;i[a+8>>2]=d;i[114610]=0;D(950,c|0,d|0);c=i[114610];i[114610]=0;if((c|0)!=1){continue}break}a=H(0)|0;A()|0;gb(a);x()}}function Fia(a,b){var c=0,d=0;a:{while(1){if(i[a+8>>2]==(b|0)){break a}c=i[a+16>>2];d=i[a+8>>2]+ -4|0;i[a+8>>2]=d;i[114610]=0;D(737,c|0,d|0);c=i[114610];i[114610]=0;if((c|0)!=1){continue}break}a=H(0)|0;A()|0;gb(a);x()}}function EJa(a,b){var c=0,d=0;a:{while(1){if(i[a+8>>2]==(b|0)){break a}c=i[a+16>>2];d=i[a+8>>2]+ -2|0;i[a+8>>2]=d;i[114610]=0;D(532,c|0,d|0);c=i[114610];i[114610]=0;if((c|0)!=1){continue}break}a=H(0)|0;A()|0;gb(a);x()}}function CLa(a,b){var c=0,d=0;a:{while(1){if(i[a+8>>2]==(b|0)){break a}c=i[a+16>>2];d=i[a+8>>2]+ -2|0;i[a+8>>2]=d;i[114610]=0;D(422,c|0,d|0);c=i[114610];i[114610]=0;if((c|0)!=1){continue}break}a=H(0)|0;A()|0;gb(a);x()}}function sU(a,b){var c=0,d=0;a:{while(1){if(i[a+8>>2]==(b|0)){break a}c=i[a+16>>2];d=i[a+8>>2]+ -4|0;i[a+8>>2]=d;i[114610]=0;D(349,c|0,d|0);c=i[114610];i[114610]=0;if((c|0)!=1){continue}break}a=H(0)|0;A()|0;gb(a);x()}}function sJ(a,b,c){var d=0,e=0,f=0;d=Xa-16|0;Xa=d;if(4294967279>=b>>>0){a:{if(b>>>0<=10){Te(a,b);e=a;break a}f=Dk(b)+1|0;e=Ii(f);gf(a,e);fg(a,f);ce(a,b)}ey(e,b,c);g[d+15|0]=0;Rd(b+e|0,d+15|0);Xa=d+16|0;return}gg();x()}function nva(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Xa-32|0;Xa=d;i[d+24>>2]=c;i[d+16>>2]=b;if(pb(d+16|0,d+24|0)){while(1){i[d+12>>2]=i[i[d+16>>2]>>2];Wx(a,d+12|0);Gd(d+16|0);if(pb(d+16|0,d+24|0)){continue}break}}Xa=d+32|0}function lN(a){var b=0,c=0,d=0;c=a+32|0;d=j[c|0]|j[c+1|0]<<8;c=0;b=a+34|0;a=a+36|0;a=j[a|0]|j[a+1|0]<<8;b=(j[b|0]|j[b+1|0]<<8)+a|0;if(b>>>0<a>>>0){c=1}a=c<<1|b>>>31;b=b<<1;c=d+b|0;if(c>>>0<b>>>0){a=a+1|0}_a=a;return c}function eLa(a,b){var c=0,d=0;a:{while(1){if(i[a+8>>2]==(b|0)){break a}c=i[a+16>>2];d=i[a+8>>2]+ -1|0;i[a+8>>2]=d;i[114610]=0;D(32,c|0,d|0);c=i[114610];i[114610]=0;if((c|0)!=1){continue}break}a=H(0)|0;A()|0;gb(a);x()}}function bba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=Xa-16|0;Xa=e;d=Kl(e,a,d);a=fb(a);i[114610]=0;J(2125,a|0,b|0,c|0,d+4|0);a=i[114610];i[114610]=0;if((a|0)!=1){sb(d);Xa=e+16|0;return}a=B()|0;A()|0;sb(d);E(a|0);x()}function VT(a,b){var c=0,d=0;a:{while(1){if(i[a+8>>2]==(b|0)){break a}c=i[a+16>>2];d=i[a+8>>2]+ -1|0;i[a+8>>2]=d;i[114610]=0;D(361,c|0,d|0);c=i[114610];i[114610]=0;if((c|0)!=1){continue}break}a=H(0)|0;A()|0;gb(a);x()}}function UW(a,b){var c=0,d=0;a:{while(1){if(i[a+8>>2]==(b|0)){break a}c=i[a+16>>2];d=i[a+8>>2]+ -1|0;i[a+8>>2]=d;i[114610]=0;D(215,c|0,d|0);c=i[114610];i[114610]=0;if((c|0)!=1){continue}break}a=H(0)|0;A()|0;gb(a);x()}}function TT(a,b){var c=0,d=0;a:{while(1){if(i[a+8>>2]==(b|0)){break a}c=i[a+16>>2];d=i[a+8>>2]+ -2|0;i[a+8>>2]=d;i[114610]=0;D(362,c|0,d|0);c=i[114610];i[114610]=0;if((c|0)!=1){continue}break}a=H(0)|0;A()|0;gb(a);x()}}function So(a,b,c){var d=0,e=0,f=0;d=Xa-16|0;Xa=d;if(4294967279>=c>>>0){a:{if(c>>>0<=10){Te(a,c);e=a;break a}f=Dk(c)+1|0;e=Ii(f);gf(a,e);fg(a,f);ce(a,c)}jh(e,b,c);g[d+15|0]=0;Rd(c+e|0,d+15|0);Xa=d+16|0;return}gg();x()}function JL(a,b){a:{if(j[a+76|0]==(b|0)){break a}g[a+76|0]=b;if(b){b=0;if(k[a+24>>1]==15){h[a+20>>1]=0;b=1}i[a+8>>2]=0;i[a+16>>2]=b;return}b:{switch(i[a+16>>2]+1|0){case 0:case 4:break a;default:break b}}i[a+16>>2]=3}}function AT(a,b){var c=0,d=0;a:{while(1){if(i[a+8>>2]==(b|0)){break a}c=i[a+16>>2];d=i[a+8>>2]+ -4|0;i[a+8>>2]=d;i[114610]=0;D(372,c|0,d|0);c=i[114610];i[114610]=0;if((c|0)!=1){continue}break}a=H(0)|0;A()|0;gb(a);x()}}function xY(a){var b=0;i[114610]=0;a=F(2836,a|0)|0;b=i[114610];i[114610]=0;a:{if((b|0)==1){a=H(0)|0;A()|0;M(a|0)|0;i[114610]=0;K(20);b=i[114610];i[114610]=0;a=0;if((b|0)==1){break a}}return a}a=H(0)|0;A()|0;gb(a);x()}function sB(a){var b=0;a:{b=a+2|0;if(!(j[b|0]|j[b+1|0]<<8)){break a}a=a+4|0;if(!(j[a|0]|j[a+1|0]<<8|(j[a+2|0]<<16|j[a+3|0]<<24))){break a}return(j[a|0]|j[a+1|0]<<8|(j[a+2|0]<<16|j[a+3|0]<<24))>>>0<2147483649}return 0}function hg(a){var b=0;i[114610]=0;a=F(1398,a|0)|0;b=i[114610];i[114610]=0;a:{if((b|0)==1){a=H(0)|0;A()|0;M(a|0)|0;i[114610]=0;K(20);b=i[114610];i[114610]=0;a=0;if((b|0)==1){break a}}return a}a=H(0)|0;A()|0;gb(a);x()}function Zka(a,b,c){var d=0;d=Xa-32|0;Xa=d;i[d+16>>2]=b;i[d+24>>2]=a;i[d+8>>2]=c;if(pb(d+24|0,d+16|0)){while(1){a=g[i[d+24>>2]];g[i[d+8>>2]]=a?a:32;Tf(d+24|0);Tf(d+8|0);if(pb(d+24|0,d+16|0)){continue}break}}Xa=d+32|0}function Nm(a){a=a|0;kc(a+16|0,i[a>>2]);kc(a+8|0,i[a>>2]);if(l[a+12>>2]>=l[a+16>>2]){i[a+12>>2]=0;i[a+16>>2]=0;h[a+34>>1]=k[a+34>>1]&65511}if(l[a+4>>2]>=l[a+8>>2]){i[a+4>>2]=0;i[a+8>>2]=0;h[a+34>>1]=k[a+34>>1]&65529}}function F9(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=Xa-16|0;Xa=e;d=Ik(e,a,d);a=fb(a);i[114610]=0;J(2182,a|0,b|0,c|0,d+4|0);a=i[114610];i[114610]=0;if((a|0)!=1){sb(d);Xa=e+16|0;return}a=B()|0;A()|0;sb(d);E(a|0);x()}function xv(a){var b=0;a:{b:{while(1){if(i[a+1380>>2]!=-1){break b}b=0;if(!Rq(a)){break a}if(!(g[a+1375|0]&1)){continue}break}Lb(a,32);return 0}i[a+1396>>2]=0;i[a+1400>>2]=0;i[a+1384>>2]=0;g[a+1376|0]=0;b=1}return b}function bZ(a){a=a|0;a:{b:{if(g[461940]&1){break b}if(!cd(461940)){break b}i[114610]=0;C(2593,461928,62680)|0;a=i[114610];i[114610]=0;if((a|0)==1){break a}bd(461940)}return 461928}a=B()|0;A()|0;Xd(461940);E(a|0);x()}function ZY(a){a=a|0;a:{b:{if(g[461972]&1){break b}if(!cd(461972)){break b}i[114610]=0;C(2593,461960,62728)|0;a=i[114610];i[114610]=0;if((a|0)==1){break a}bd(461972)}return 461960}a=B()|0;A()|0;Xd(461972);E(a|0);x()}function VY(a){a=a|0;a:{b:{if(g[462004]&1){break b}if(!cd(462004)){break b}i[114610]=0;C(2593,461992,62788)|0;a=i[114610];i[114610]=0;if((a|0)==1){break a}bd(462004)}return 461992}a=B()|0;A()|0;Xd(462004);E(a|0);x()}function RY(a){a=a|0;a:{b:{if(g[462036]&1){break b}if(!cd(462036)){break b}i[114610]=0;C(2593,462024,62884)|0;a=i[114610];i[114610]=0;if((a|0)==1){break a}bd(462036)}return 462024}a=B()|0;A()|0;Xd(462036);E(a|0);x()}function KH(a,b){var c=0,d=0;c=i[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=fb(a);i[114610]=0;c=c+ -2048|0;D(1651,d|0,c|0);d=i[114610];i[114610]=0;if((d|0)!=1){continue}break}a=H(0)|0;A()|0;gb(a);x()}i[a+4>>2]=b}function D8(a,b){a=a|0;b=b|0;var c=0,d=0;c=Xa-16|0;Xa=c;An(a);i[a>>2]=83848;d=Zg(c+8|0);b=Zg(b);i[114610]=0;I(2203,a+12|0,d|0,b|0)|0;b=i[114610];i[114610]=0;if((b|0)!=1){Xa=c+16|0;return a|0}a=B()|0;A()|0;E(a|0);x()}function B8(a,b){a=a|0;b=b|0;var c=0,d=0;c=Xa-16|0;Xa=c;An(a);i[a>>2]=83888;d=Zg(c+8|0);b=Zg(b);i[114610]=0;I(2205,a+12|0,d|0,b|0)|0;b=i[114610];i[114610]=0;if((b|0)!=1){Xa=c+16|0;return a|0}a=B()|0;A()|0;E(a|0);x()}function tL(a,b){var c=0,d=0,e=0,f=0;e=n[a+48>>3];c=n[a+40>>3];n[a+48>>3]=c;f=n[a+64>>3];d=n[a+56>>3];n[a+64>>3]=d;n[a+40>>3]=b;b=c*n[a+8>>3]+n[a>>3]*b+e*n[a+16>>3]-(f*n[a+32>>3]+d*n[a+24>>3]);n[a+56>>3]=b;return b}function pka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;$s(a);e=i[b+4>>2];d=b+4|0;PP(fb(a),i[a>>2],c,d);f=c;c=b+8|0;yI(fb(a),f,i[a+4>>2],c);Gb(a,d);Gb(a+4|0,c);Gb(fb(a),Mb(b));i[b>>2]=i[b+4>>2];ct(a,If(a));return e|0}function is(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Xa-16|0;Xa=d;kb(d+8|0,c+1074308|0,102);a:{if(!ib(d+8|0)){break a}c=k[a+692>>1]+1|0;h[a+796>>1]=c;if(!(g[a+89|0]&1)){break a}h[a+796>>1]=c|32768}i[a+692>>2]=b;Xa=d+16|0}function gW(a,b){a=a|0;b=b|0;var c=0,d=0;b=Xa-32|0;Xa=b;c=b+16|0;d=FV(a,c);if(!d){fB(c)}c=-1;a:{if(!d){break a}c=0;if(!tB(b+16|0)){break a}c=b;a=EV(a,b);if(!a){dB(c)}c=-1;if(!a){break a}c=sB(b)}Xa=b+32|0;return c|0}function fua(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;_e(a);e=i[b+4>>2];d=b+4|0;ki(fb(a),i[a>>2],c,d);f=c;c=b+8|0;kn(fb(a),f,i[a+4>>2],c);Gb(a,d);Gb(a+4|0,c);Gb(fb(a),Mb(b));i[b>>2]=i[b+4>>2];Mj(a,qb(a));return e|0}function NV(a,b){a=a|0;b=b|0;var c=0,d=0;c=Xa-16|0;Xa=c;An(a);i[a>>2]=77064;d=Zg(c+8|0);b=Zg(b);i[114610]=0;I(275,a+12|0,d|0,b|0)|0;b=i[114610];i[114610]=0;if((b|0)!=1){Xa=c+16|0;return a|0}a=B()|0;A()|0;E(a|0);x()}function Kka(a,b){var c=0,d=0;c=i[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=fb(a);i[114610]=0;c=c+ -24|0;D(1560,d|0,c|0);d=i[114610];i[114610]=0;if((d|0)!=1){continue}break}a=H(0)|0;A()|0;gb(a);x()}i[a+4>>2]=b}function Gra(a,b){var c=0,d=0;c=i[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=fb(a);i[114610]=0;c=c+ -16|0;D(1232,d|0,c|0);d=i[114610];i[114610]=0;if((d|0)!=1){continue}break}a=H(0)|0;A()|0;gb(a);x()}i[a+4>>2]=b}function Exa(a,b){var c=0,d=0;c=i[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=fb(a);i[114610]=0;c=c+ -12|0;D(1024,d|0,c|0);d=i[114610];i[114610]=0;if((d|0)!=1){continue}break}a=H(0)|0;A()|0;gb(a);x()}i[a+4>>2]=b}function wY(a,b){var c=0,d=0;c=Xa-16|0;Xa=c;b=b>>>0>4?b:4;a=a?a:1;a:{while(1){if(!pX(c+12|0,b,a)){break a}d=i[115919];if(d){$a[d|0]();continue}break}a=P(4)|0;zk(a);W(a|0,71348,2008);x()}Xa=c+16|0;return i[c+12>>2]}function wJ(a,b){var c=0,d=0;c=i[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=fb(a);i[114610]=0;c=c+ -52|0;D(1438,d|0,c|0);d=i[114610];i[114610]=0;if((d|0)!=1){continue}break}a=H(0)|0;A()|0;gb(a);x()}i[a+4>>2]=b}function p8(a,b){var c=0,d=0;c=i[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=fb(a);i[114610]=0;c=c+ -16|0;D(2206,d|0,c|0);d=i[114610];i[114610]=0;if((d|0)!=1){continue}break}a=H(0)|0;A()|0;gb(a);x()}i[a+4>>2]=b}function j8(a,b){var c=0,d=0;c=i[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=fb(a);i[114610]=0;c=c+ -24|0;D(2207,d|0,c|0);d=i[114610];i[114610]=0;if((d|0)!=1){continue}break}a=H(0)|0;A()|0;gb(a);x()}i[a+4>>2]=b}function iBa(a,b){var c=0,d=0;c=i[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=fb(a);i[114610]=0;c=c+ -32|0;D(896,d|0,c|0);d=i[114610];i[114610]=0;if((d|0)!=1){continue}break}a=H(0)|0;A()|0;gb(a);x()}i[a+4>>2]=b}function hga(a,b){var c=0,d=0;c=i[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=fb(a);i[114610]=0;c=c+ -4|0;D(1763,d|0,c|0);d=i[114610];i[114610]=0;if((d|0)!=1){continue}break}a=H(0)|0;A()|0;gb(a);x()}i[a+4>>2]=b}function fL(a,b){var c=0,d=0;c=i[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=fb(a);i[114610]=0;c=c+ -12|0;D(1237,d|0,c|0);d=i[114610];i[114610]=0;if((d|0)!=1){continue}break}a=H(0)|0;A()|0;gb(a);x()}i[a+4>>2]=b}function em(a,b){var c=0,d=0,e=0;c=a*a;d=c*a;e=d*(c*.13339200271297674+.3333313950307914)+a;a=c*c;a=e+d*a*(c*.024528318116654728+.05338123784456704+a*(c*.009465647849436732+.002974357433599673));return p(b?-1/a:a)}function dZ(a){a=a|0;a:{b:{if(g[461924]&1){break b}if(!cd(461924)){break b}i[114610]=0;C(85,461912,62668)|0;a=i[114610];i[114610]=0;if((a|0)==1){break a}bd(461924)}return 461912}a=B()|0;A()|0;Xd(461924);E(a|0);x()}function dK(a,b){var c=0,d=0;c=i[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=fb(a);i[114610]=0;c=c+ -24|0;D(1379,d|0,c|0);d=i[114610];i[114610]=0;if((d|0)!=1){continue}break}a=H(0)|0;A()|0;gb(a);x()}i[a+4>>2]=b}function bza(a,b){var c=0,d=0;c=i[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=fb(a);i[114610]=0;c=c+ -24|0;D(986,d|0,c|0);d=i[114610];i[114610]=0;if((d|0)!=1){continue}break}a=H(0)|0;A()|0;gb(a);x()}i[a+4>>2]=b}function ZHa(a,b){var c=0,d=0;c=i[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=fb(a);i[114610]=0;c=c+ -24|0;D(607,d|0,c|0);d=i[114610];i[114610]=0;if((d|0)!=1){continue}break}a=H(0)|0;A()|0;gb(a);x()}i[a+4>>2]=b}function ZDa(a,b){var c=0,d=0;c=i[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=fb(a);i[114610]=0;c=c+ -24|0;D(771,d|0,c|0);d=i[114610];i[114610]=0;if((d|0)!=1){continue}break}a=H(0)|0;A()|0;gb(a);x()}i[a+4>>2]=b}function YM(a,b){var c=0,d=0;c=i[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=fb(a);i[114610]=0;c=c+ -12|0;D(1023,d|0,c|0);d=i[114610];i[114610]=0;if((d|0)!=1){continue}break}a=H(0)|0;A()|0;gb(a);x()}i[a+4>>2]=b}function YL(a,b){var c=0,d=0;c=i[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=fb(a);i[114610]=0;c=c+ -32|0;D(1195,d|0,c|0);d=i[114610];i[114610]=0;if((d|0)!=1){continue}break}a=H(0)|0;A()|0;gb(a);x()}i[a+4>>2]=b}function XY(a){a=a|0;a:{b:{if(g[461988]&1){break b}if(!cd(461988)){break b}i[114610]=0;C(85,461976,62764)|0;a=i[114610];i[114610]=0;if((a|0)==1){break a}bd(461988)}return 461976}a=B()|0;A()|0;Xd(461988);E(a|0);x()}function Wla(a,b){var c=0,d=0;c=i[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=fb(a);i[114610]=0;c=c+ -4|0;D(1524,d|0,c|0);d=i[114610];i[114610]=0;if((d|0)!=1){continue}break}a=H(0)|0;A()|0;gb(a);x()}i[a+4>>2]=b}function Uya(a,b){var c=0,d=0;c=i[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=fb(a);i[114610]=0;c=c+ -56|0;D(990,d|0,c|0);d=i[114610];i[114610]=0;if((d|0)!=1){continue}break}a=H(0)|0;A()|0;gb(a);x()}i[a+4>>2]=b}function UJa(a,b){var c=0,d=0;c=i[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=fb(a);i[114610]=0;c=c+ -24|0;D(528,d|0,c|0);d=i[114610];i[114610]=0;if((d|0)!=1){continue}break}a=H(0)|0;A()|0;gb(a);x()}i[a+4>>2]=b}function TY(a){a=a|0;a:{b:{if(g[462020]&1){break b}if(!cd(462020)){break b}i[114610]=0;C(85,462008,62872)|0;a=i[114610];i[114610]=0;if((a|0)==1){break a}bd(462020)}return 462008}a=B()|0;A()|0;Xd(462020);E(a|0);x()}function Rma(a,b){var c=0,d=0;c=i[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=fb(a);i[114610]=0;c=c+ -4|0;D(1439,d|0,c|0);d=i[114610];i[114610]=0;if((d|0)!=1){continue}break}a=H(0)|0;A()|0;gb(a);x()}i[a+4>>2]=b}function OIa(a,b){var c=0,d=0;c=i[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=fb(a);i[114610]=0;c=c+ -24|0;D(572,d|0,c|0);d=i[114610];i[114610]=0;if((d|0)!=1){continue}break}a=H(0)|0;A()|0;gb(a);x()}i[a+4>>2]=b}function OBa(a,b){var c=0,d=0;c=i[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=fb(a);i[114610]=0;c=c+ -20|0;D(885,d|0,c|0);d=i[114610];i[114610]=0;if((d|0)!=1){continue}break}a=H(0)|0;A()|0;gb(a);x()}i[a+4>>2]=b}function Nra(a,b){var c=0,d=0;c=i[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=fb(a);i[114610]=0;c=c+ -8|0;D(1229,d|0,c|0);d=i[114610];i[114610]=0;if((d|0)!=1){continue}break}a=H(0)|0;A()|0;gb(a);x()}i[a+4>>2]=b}function Kma(a,b){var c=0,d=0;c=i[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=fb(a);i[114610]=0;c=c+ -4|0;D(1440,d|0,c|0);d=i[114610];i[114610]=0;if((d|0)!=1){continue}break}a=H(0)|0;A()|0;gb(a);x()}i[a+4>>2]=b}function Jwa(a,b){var c=0,d=0;c=i[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=fb(a);i[114610]=0;c=c+ -4|0;D(1060,d|0,c|0);d=i[114610];i[114610]=0;if((d|0)!=1){continue}break}a=H(0)|0;A()|0;gb(a);x()}i[a+4>>2]=b}function HR(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;pk(a);e=i[b+4>>2];d=b+4|0;ki(fb(a),i[a>>2],c,d);f=c;c=b+8|0;kn(fb(a),f,i[a+4>>2],c);Gb(a,d);Gb(a+4|0,c);Gb(fb(a),Mb(b));i[b>>2]=i[b+4>>2];It(a,Wb(a));return e|0}function $Y(a){a=a|0;a:{b:{if(g[461956]&1){break b}if(!cd(461956)){break b}i[114610]=0;C(85,461944,62716)|0;a=i[114610];i[114610]=0;if((a|0)==1){break a}bd(461956)}return 461944}a=B()|0;A()|0;Xd(461956);E(a|0);x()}function xS(a,b){var c=0,d=0;c=i[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=fb(a);i[114610]=0;c=c+ -16|0;D(426,d|0,c|0);d=i[114610];i[114610]=0;if((d|0)!=1){continue}break}a=H(0)|0;A()|0;gb(a);x()}i[a+4>>2]=b}function vza(a,b){a=a|0;b=b|0;var c=0;c=Xa-16|0;Xa=c;FN(a,c+11|0);if((j[c+11|0]|j[c+12|0]<<8|(j[c+13|0]<<16|j[c+14|0]<<24))==1414807888){FN(a,c+11|0);g[b|0]=1;a=0}else{a=1}a=mza(a+(c+11|0)|0);Xa=c+16|0;return a|0}function uU(a,b){var c=0,d=0;c=i[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=fb(a);i[114610]=0;c=c+ -12|0;D(348,d|0,c|0);d=i[114610];i[114610]=0;if((d|0)!=1){continue}break}a=H(0)|0;A()|0;gb(a);x()}i[a+4>>2]=b}function sA(a){var b=0,c=0;b=Xa-16|0;Xa=b;fb(a);i[b+12>>2]=2147483647;i[114610]=0;i[b+8>>2]=2147483647;a=C(33,b+12|0,b+8|0)|0;c=i[114610];i[114610]=0;if((c|0)!=1){Xa=b+16|0;return i[a>>2]}a=H(0)|0;A()|0;gb(a);x()}function mA(a,b,c){var d=0,e=0,f=0,g=0;d=Xa-16|0;Xa=d;e=i[a+4>>2];f=e+b|0;i[a+4>>2]=f;if(!((f+ -1^e+ -1)>>>0<32?e:0)){g=i[a>>2];i[(f>>>0<33?g:(f+ -1>>>3&536870908)+g|0)>>2]=0}rn(d+8|0,a,e);Bp(d+8|0,b,c);Xa=d+16|0}function iv(a){a=a|0;var b=0;i[a>>2]=56152;i[114610]=0;D(2313,a|0,0);b=i[114610];i[114610]=0;if((b|0)!=1){ub(a+28|0);Cb(i[a+32>>2]);Cb(i[a+36>>2]);Cb(i[a+48>>2]);Cb(i[a+60>>2]);return a|0}a=H(0)|0;A()|0;gb(a);x()}function hR(a,b){var c=0,d=0;c=i[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=fb(a);i[114610]=0;c=c+ -48|0;D(573,d|0,c|0);d=i[114610];i[114610]=0;if((d|0)!=1){continue}break}a=H(0)|0;A()|0;gb(a);x()}i[a+4>>2]=b}function gEa(a){var b=0,c=0;b=Xa-16|0;Xa=b;fb(a);i[b+12>>2]=130150524;i[114610]=0;i[b+8>>2]=2147483647;a=C(33,b+12|0,b+8|0)|0;c=i[114610];i[114610]=0;if((c|0)!=1){Xa=b+16|0;return i[a>>2]}a=H(0)|0;A()|0;gb(a);x()}function gDa(a,b,c,d,e){var f=0,h=0;f=Xa-32|0;Xa=f;h=KCa(b,f+28|0,c);c=i[h>>2];g[f+27|0]=0;if(!c){JCa(f+8|0,b,d,e);_j(b,i[f+28>>2],h,i[f+8>>2]);c=sd(f+8|0);g[f+27|0]=1;ZO(f+8|0)}ci(a,yc(f+8|0,c),f+27|0);Xa=f+32|0}function dpa(a,b,c,d,e){var f=0,h=0;f=Xa-32|0;Xa=f;h=toa(b,f+28|0,c);c=i[h>>2];g[f+27|0]=0;if(!c){soa(f+8|0,b,d,e);_j(b,i[f+28>>2],h,i[f+8>>2]);c=sd(f+8|0);g[f+27|0]=1;_J(f+8|0)}ci(a,yc(f+8|0,c),f+27|0);Xa=f+32|0}function bja(a,b,c,d,e){var f=0,h=0;f=Xa-32|0;Xa=f;h=Bia(b,f+28|0,c);c=i[h>>2];g[f+27|0]=0;if(!c){Aia(f+8|0,b,d,e);_j(b,i[f+28>>2],h,i[f+8>>2]);c=sd(f+8|0);g[f+27|0]=1;$H(f+8|0)}ci(a,yc(f+8|0,c),f+27|0);Xa=f+32|0}function apa(a,b,c,d,e){var f=0,h=0;f=Xa-32|0;Xa=f;h=loa(b,f+28|0,c);c=i[h>>2];g[f+27|0]=0;if(!c){koa(f+8|0,b,d,e);_j(b,i[f+28>>2],h,i[f+8>>2]);c=sd(f+8|0);g[f+27|0]=1;YJ(f+8|0)}ci(a,yc(f+8|0,c),f+27|0);Xa=f+32|0}function UBa(a,b){var c=0,d=0;c=i[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=fb(a);i[114610]=0;c=c+ -4|0;D(884,d|0,c|0);d=i[114610];i[114610]=0;if((d|0)!=1){continue}break}a=H(0)|0;A()|0;gb(a);x()}i[a+4>>2]=b}function SIa(a,b){var c=0,d=0;c=i[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=fb(a);i[114610]=0;c=c+ -6|0;D(570,d|0,c|0);d=i[114610];i[114610]=0;if((d|0)!=1){continue}break}a=H(0)|0;A()|0;gb(a);x()}i[a+4>>2]=b}function SBa(a){var b=0,c=0;b=Xa-16|0;Xa=b;fb(a);i[b+12>>2]=214748364;i[114610]=0;i[b+8>>2]=2147483647;a=C(33,b+12|0,b+8|0)|0;c=i[114610];i[114610]=0;if((c|0)!=1){Xa=b+16|0;return i[a>>2]}a=H(0)|0;A()|0;gb(a);x()}function Rna(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Xa-32|0;Xa=d;a=i[a+1304560>>2];a:{if(a){$a[i[i[a>>2]+8>>2]](a,b,c);break a}if(i[19092]<(b|0)){break a}MJ(d+8|0,20479,20500,132);wB(d+24|0,d+8|0,b,20470,c)}Xa=d+32|0}function QK(a,b,c){var d=0,e=0;d=Xa-16|0;Xa=d;e=c&15;if(e){g[b+844|0]=e}c=c&240;if(c){g[b+843|0]=c>>>4}i[b+88>>2]=i[b+88>>2]|131072;kb(d+8|0,a+1074308|0,80);if(!(!e|!ib(d+8|0))){g[b+844|0]=j[b+844|0]<<2}Xa=d+16|0}function Nda(a,b,c,d,e){var f=0,h=0;f=Xa-32|0;Xa=f;h=Tqa(b,f+28|0,c);c=i[h>>2];g[f+27|0]=0;if(!c){Lba(f+8|0,b,d,e);_j(b,i[f+28>>2],h,i[f+8>>2]);c=sd(f+8|0);g[f+27|0]=1;aL(f+8|0)}ci(a,yc(f+8|0,c),f+27|0);Xa=f+32|0}function NFa(a,b,c,d,e){var f=0,h=0;f=Xa-32|0;Xa=f;h=MFa(b,f+28|0,c);c=i[h>>2];g[f+27|0]=0;if(!c){LFa(f+8|0,b,d,e);_j(b,i[f+28>>2],h,i[f+8>>2]);c=sd(f+8|0);g[f+27|0]=1;fQ(f+8|0)}ci(a,yc(f+8|0,c),f+27|0);Xa=f+32|0}function JJa(a,b){var c=0,d=0;c=i[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=fb(a);i[114610]=0;c=c+ -2|0;D(532,d|0,c|0);d=i[114610];i[114610]=0;if((d|0)!=1){continue}break}a=H(0)|0;A()|0;gb(a);x()}i[a+4>>2]=b}function Hm(a){var b=0,c=0;b=Xa-16|0;Xa=b;fb(a);i[b+12>>2]=1073741823;i[114610]=0;i[b+8>>2]=2147483647;a=C(33,b+12|0,b+8|0)|0;c=i[114610];i[114610]=0;if((c|0)!=1){Xa=b+16|0;return i[a>>2]}a=H(0)|0;A()|0;gb(a);x()}function HH(a,b){var c=0,d=0;c=i[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=fb(a);i[114610]=0;c=c+ -4|0;D(1653,d|0,c|0);d=i[114610];i[114610]=0;if((d|0)!=1){continue}break}a=H(0)|0;A()|0;gb(a);x()}i[a+4>>2]=b}function GB(a,b){var c=0,d=0;c=i[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=fb(a);i[114610]=0;c=c+ -16|0;D(217,d|0,c|0);d=i[114610];i[114610]=0;if((d|0)!=1){continue}break}a=H(0)|0;A()|0;gb(a);x()}i[a+4>>2]=b}function G4(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=Xa-16|0;Xa=e;a:{if(!Jq(ra(i[a+60>>2],b|0,c|0,d&255,e+8|0)|0)){b=i[e+12>>2];a=i[e+8>>2];break a}i[e+8>>2]=-1;i[e+12>>2]=-1;b=-1;a=-1}Xa=e+16|0;_a=b;return a|0}function FP(a,b){var c=0,d=0;c=i[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=fb(a);i[114610]=0;c=c+ -33|0;D(769,d|0,c|0);d=i[114610];i[114610]=0;if((d|0)!=1){continue}break}a=H(0)|0;A()|0;gb(a);x()}i[a+4>>2]=b}function DV(a,b){var c=0,d=0;c=i[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=fb(a);i[114610]=0;c=c+ -32|0;D(276,d|0,c|0);d=i[114610];i[114610]=0;if((d|0)!=1){continue}break}a=H(0)|0;A()|0;gb(a);x()}i[a+4>>2]=b}function B2(a,b){var c=0,d=0;c=i[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=fb(a);i[114610]=0;c=c+ -12|0;D(206,d|0,c|0);d=i[114610];i[114610]=0;if((d|0)!=1){continue}break}a=H(0)|0;A()|0;gb(a);x()}i[a+4>>2]=b}function xA(a,b){var c=0,d=0;c=i[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=fb(a);i[114610]=0;c=c+ -1|0;D(361,d|0,c|0);d=i[114610];i[114610]=0;if((d|0)!=1){continue}break}a=H(0)|0;A()|0;gb(a);x()}i[a+4>>2]=b}function tU(a,b){var c=0,d=0;c=i[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=fb(a);i[114610]=0;c=c+ -4|0;D(349,d|0,c|0);d=i[114610];i[114610]=0;if((d|0)!=1){continue}break}a=H(0)|0;A()|0;gb(a);x()}i[a+4>>2]=b}function rz(a){var b=0,c=0;b=Xa-16|0;Xa=b;fb(a);i[b+12>>2]=715827882;i[114610]=0;i[b+8>>2]=2147483647;a=C(33,b+12|0,b+8|0)|0;c=i[114610];i[114610]=0;if((c|0)!=1){Xa=b+16|0;return i[a>>2]}a=H(0)|0;A()|0;gb(a);x()}function iA(a,b){var c=0,d=0;c=i[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=fb(a);i[114610]=0;c=c+ -4|0;D(372,d|0,c|0);d=i[114610];i[114610]=0;if((d|0)!=1){continue}break}a=H(0)|0;A()|0;gb(a);x()}i[a+4>>2]=b}function hV(a,b){var c=0,d=0;c=i[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=fb(a);i[114610]=0;c=c+ -8|0;D(283,d|0,c|0);d=i[114610];i[114610]=0;if((d|0)!=1){continue}break}a=H(0)|0;A()|0;gb(a);x()}i[a+4>>2]=b}function hT(a,b){var c=0,d=0;c=i[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=fb(a);i[114610]=0;c=c+ -2|0;D(382,d|0,c|0);d=i[114610];i[114610]=0;if((d|0)!=1){continue}break}a=H(0)|0;A()|0;gb(a);x()}i[a+4>>2]=b}function fO(a,b){var c=0,d=0;c=i[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=fb(a);i[114610]=0;c=c+ -8|0;D(924,d|0,c|0);d=i[114610];i[114610]=0;if((d|0)!=1){continue}break}a=H(0)|0;A()|0;gb(a);x()}i[a+4>>2]=b}function eP(a,b){var c=0,d=0;c=i[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=fb(a);i[114610]=0;c=c+ -4|0;D(822,d|0,c|0);d=i[114610];i[114610]=0;if((d|0)!=1){continue}break}a=H(0)|0;A()|0;gb(a);x()}i[a+4>>2]=b}function cQ(a,b){var c=0,d=0;c=i[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=fb(a);i[114610]=0;c=c+ -4|0;D(737,d|0,c|0);d=i[114610];i[114610]=0;if((d|0)!=1){continue}break}a=H(0)|0;A()|0;gb(a);x()}i[a+4>>2]=b}function aq(a){var b=0,c=0;b=Xa-16|0;Xa=b;fb(a);i[b+12>>2]=268435455;i[114610]=0;i[b+8>>2]=2147483647;a=C(33,b+12|0,b+8|0)|0;c=i[114610];i[114610]=0;if((c|0)!=1){Xa=b+16|0;return i[a>>2]}a=H(0)|0;A()|0;gb(a);x()}function _T(a,b){var c=0,d=0;c=i[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=fb(a);i[114610]=0;c=c+ -1|0;D(360,d|0,c|0);d=i[114610];i[114610]=0;if((d|0)!=1){continue}break}a=H(0)|0;A()|0;gb(a);x()}i[a+4>>2]=b}function ZT(a,b){var c=0,d=0;c=i[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=fb(a);i[114610]=0;c=c+ -2|0;D(362,d|0,c|0);d=i[114610];i[114610]=0;if((d|0)!=1){continue}break}a=H(0)|0;A()|0;gb(a);x()}i[a+4>>2]=b}function ZA(a){var b=0,c=0;b=Xa-16|0;Xa=b;fb(a);i[b+12>>2]=134217727;i[114610]=0;i[b+8>>2]=2147483647;a=C(33,b+12|0,b+8|0)|0;c=i[114610];i[114610]=0;if((c|0)!=1){Xa=b+16|0;return i[a>>2]}a=H(0)|0;A()|0;gb(a);x()}function YP(a,b){var c=0,d=0;c=i[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=fb(a);i[114610]=0;c=c+ -4|0;D(740,d|0,c|0);d=i[114610];i[114610]=0;if((d|0)!=1){continue}break}a=H(0)|0;A()|0;gb(a);x()}i[a+4>>2]=b}function Xt(a){var b=0,c=0;b=Xa-16|0;Xa=b;fb(a);i[b+12>>2]=536870911;i[114610]=0;i[b+8>>2]=2147483647;a=C(33,b+12|0,b+8|0)|0;c=i[114610];i[114610]=0;if((c|0)!=1){Xa=b+16|0;return i[a>>2]}a=H(0)|0;A()|0;gb(a);x()}function Ww(a,b){var c=0;c=i[b+24>>2];c=c?c:1;i[a+24628>>2]=c>>>0<512?c:512;a:{if(!(i[b+16>>2]!=i[a+24620>>2]|i[b+20>>2]!=i[a+24624>>2])){c=0;if(i[b+12>>2]==i[a+24616>>2]){break a}}c=1}Tb(a+24604|0,b,40);rJ(a,c)}function WD(a){var b=0,c=0;b=Xa-16|0;Xa=b;fb(a);i[b+12>>2]=357913941;i[114610]=0;i[b+8>>2]=2147483647;a=C(33,b+12|0,b+8|0)|0;c=i[114610];i[114610]=0;if((c|0)!=1){Xa=b+16|0;return i[a>>2]}a=H(0)|0;A()|0;gb(a);x()}function PL(a,b){var c=0,d=0;c=i[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=fb(a);i[114610]=0;c=c+ -4|0;D(107,d|0,c|0);d=i[114610];i[114610]=0;if((d|0)!=1){continue}break}a=H(0)|0;A()|0;gb(a);x()}i[a+4>>2]=b}function MN(a,b){var c=0,d=0;c=i[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=fb(a);i[114610]=0;c=c+ -4|0;D(950,d|0,c|0);d=i[114610];i[114610]=0;if((d|0)!=1){continue}break}a=H(0)|0;A()|0;gb(a);x()}i[a+4>>2]=b}function Lya(a){var b=0,c=0;b=Xa-16|0;Xa=b;fb(a);i[b+12>>2]=76695844;i[114610]=0;i[b+8>>2]=2147483647;a=C(33,b+12|0,b+8|0)|0;c=i[114610];i[114610]=0;if((c|0)!=1){Xa=b+16|0;return i[a>>2]}a=H(0)|0;A()|0;gb(a);x()}function Lsa(a,b){a=a|0;b=b|0;var c=0,d=0;d=a+808|0;c=a+16|0;while(1){c=Ksa(c)+44|0;if((d|0)!=(c|0)){continue}break}d=a+3832|0;c=a+808|0;while(1){c=Jsa(c)+84|0;if((d|0)!=(c|0)){continue}break}Isa(a,b);return a|0}function JIa(a){var b=0,c=0;b=Xa-16|0;Xa=b;fb(a);i[b+12>>2]=89478485;i[114610]=0;i[b+8>>2]=2147483647;a=C(33,b+12|0,b+8|0)|0;c=i[114610];i[114610]=0;if((c|0)!=1){Xa=b+16|0;return i[a>>2]}a=H(0)|0;A()|0;gb(a);x()}function DR(a){var b=0,c=0;b=Xa-16|0;Xa=b;fb(a);i[b+12>>2]=178956970;i[114610]=0;i[b+8>>2]=2147483647;a=C(33,b+12|0,b+8|0)|0;c=i[114610];i[114610]=0;if((c|0)!=1){Xa=b+16|0;return i[a>>2]}a=H(0)|0;A()|0;gb(a);x()}function CS(a,b){var c=0,d=0;c=i[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=fb(a);i[114610]=0;c=c+ -2|0;D(422,d|0,c|0);d=i[114610];i[114610]=0;if((d|0)!=1){continue}break}a=H(0)|0;A()|0;gb(a);x()}i[a+4>>2]=b}function CB(a,b){var c=0,d=0;c=i[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=fb(a);i[114610]=0;c=c+ -1|0;D(215,d|0,c|0);d=i[114610];i[114610]=0;if((d|0)!=1){continue}break}a=H(0)|0;A()|0;gb(a);x()}i[a+4>>2]=b}function $P(a,b){var c=0,d=0;c=i[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=fb(a);i[114610]=0;c=c+ -6|0;D(739,d|0,c|0);d=i[114610];i[114610]=0;if((d|0)!=1){continue}break}a=H(0)|0;A()|0;gb(a);x()}i[a+4>>2]=b}function $O(a,b){var c=0,d=0;c=i[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=fb(a);i[114610]=0;c=c+ -2|0;D(829,d|0,c|0);d=i[114610];i[114610]=0;if((d|0)!=1){continue}break}a=H(0)|0;A()|0;gb(a);x()}i[a+4>>2]=b}function sha(a){var b=0,c=0;b=Xa-16|0;Xa=b;fb(a);i[b+12>>2]=2097151;i[114610]=0;i[b+8>>2]=2147483647;a=C(33,b+12|0,b+8|0)|0;c=i[114610];i[114610]=0;if((c|0)!=1){Xa=b+16|0;return i[a>>2]}a=H(0)|0;A()|0;gb(a);x()}function rI(a){var b=0,c=0;b=Xa-16|0;Xa=b;fb(a);i[b+12>>2]=82595524;i[114610]=0;i[b+8>>2]=2147483647;a=C(33,b+12|0,b+8|0)|0;c=i[114610];i[114610]=0;if((c|0)!=1){Xa=b+16|0;return i[a>>2]}a=H(0)|0;A()|0;gb(a);x()}function nua(a,b,c,d,e){var f=0,g=0,h=0,i=0;if(!(!d|e==p(1))){while(1){if(c){i=b+g|0;f=0;while(1){h=rf(a,f,i);m[h>>2]=m[h>>2]*e;f=f+1|0;if((f|0)!=(c|0)){continue}break}}g=g+1|0;if((g|0)!=(d|0)){continue}break}}}function mua(a,b,c,d,e){var f=0,g=0,h=0,i=0;if(!(!d|e==p(1))){while(1){if(c){i=b+g|0;f=0;while(1){h=Qm(a,f,i);m[h>>2]=m[h>>2]*e;f=f+1|0;if((f|0)!=(c|0)){continue}break}}g=g+1|0;if((g|0)!=(d|0)){continue}break}}}function OS(a,b){var c=0,d=0;c=i[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=fb(a);i[114610]=0;c=c+ -1|0;D(32,d|0,c|0);d=i[114610];i[114610]=0;if((d|0)!=1){continue}break}a=H(0)|0;A()|0;gb(a);x()}i[a+4>>2]=b}function IV(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=Xa-16|0;Xa=e;i[e+12>>2]=d;d=0;f=i[a+8>>2];if(f>>>0>c>>>0){i[e+8>>2]=f-c;d=rb(e+8|0,e+12|0);a=i[a+4>>2]+c|0;d=i[d>>2];Oe(a,a+d|0,b)}Xa=e+16|0;return d|0}function Ek(a,b){a=a|0;b=b|0;F1(a);i[a+28>>2]=b;jD(a+32|0);d1(a+44|0);i[a+72>>2]=0;i[a+76>>2]=0;i[a+64>>2]=0;i[a+56>>2]=0;i[a+60>>2]=0;i[a+80>>2]=0;i[a+84>>2]=0;i[a+88>>2]=0;i[a+92>>2]=0;i[a+96>>2]=0;return a|0}function rxa(){var a=0,b=0,c=0;a=Xa-16|0;Xa=a;i[a+12>>2]=477218588;i[114610]=0;i[a+8>>2]=2147483647;b=C(33,a+12|0,a+8|0)|0;c=i[114610];i[114610]=0;if((c|0)!=1){Xa=a+16|0;return i[b>>2]}a=H(0)|0;A()|0;gb(a);x()}function mza(a){var b=0,c=0,d=0;b=Xa-16|0;Xa=b;a:{b:{if(!a){a=0;break b}c=Bb(b,a);i[114610]=0;a=F(978,c|0)|0;d=i[114610];i[114610]=0;if((d|0)==1){break a}eb(c)}Xa=b+16|0;return a}a=B()|0;A()|0;eb(c);E(a|0);x()}function Ysa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=Xa-16|0;Xa=e;i[e>>2]=c;i[e+8>>2]=b;if(pb(e+8|0,e)){while(1){up(a,i[d>>2],i[e+8>>2]);he(e+8|0);i[d>>2]=i[d>>2]+2;if(pb(e+8|0,e)){continue}break}}Xa=e+16|0}function Vw(a,b){var c=0,d=0;c=i[b+4>>2];i[a+24648>>2]=i[b>>2];i[a+24652>>2]=c;d=i[b+20>>2];c=a+24664|0;i[c>>2]=i[b+16>>2];i[c+4>>2]=d;d=i[b+12>>2];c=a+24656|0;i[c>>2]=i[b+8>>2];i[c+4>>2]=d;qJ(a+24648|0);DJ(a)}function su(a,b,c){var d=0;d=i[a+16>>2];if(!d){i[a+36>>2]=1;i[a+24>>2]=c;i[a+16>>2]=b;return}a:{if((b|0)==(d|0)){if(i[a+24>>2]!=2){break a}i[a+24>>2]=c;return}g[a+54|0]=1;i[a+24>>2]=2;i[a+36>>2]=i[a+36>>2]+1}}function oT(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=Xa-16|0;Xa=e;i[e+12>>2]=0;xc(a+12|0,d);if(b){f=rS(b)}i[a>>2]=f;c=c+f|0;i[a+8>>2]=c;i[a+4>>2]=c;g=Mb(a),h=b+f|0,i[g>>2]=h;Xa=e+16|0;return a|0}function lKa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=Xa-16|0;Xa=e;g=i[i[b>>2]+20>>2];f=i[c+12>>2];i[e+8>>2]=i[c+8>>2];i[e+12>>2]=f;f=i[c+4>>2];i[e>>2]=i[c>>2];i[e+4>>2]=f;$a[g|0](a,b,e,d);Xa=e+16|0}function kC(a){var b=0,c=0;b=Xa-16|0;Xa=b;Ck(a);i[b+12>>2]=1073741823;i[114610]=0;i[b+8>>2]=2147483647;a=rb(b+12|0,b+8|0);c=i[114610];i[114610]=0;if((c|0)!=1){Xa=b+16|0;return i[a>>2]}a=H(0)|0;A()|0;gb(a);x()}function bm(a,b,c){var d=0,e=0;d=pd(b,a);e=pd(c,b);a:{b:{if(!d){d=0;if(!e){break a}Gb(b,c);d=1;if(!pd(b,a)){break a}Gb(a,b);break b}if(e){Gb(a,c);return 1}Gb(a,b);d=1;if(!pd(c,b)){break a}Gb(b,c)}d=2}return d}function Woa(a){var b=0,c=0;b=Xa-16|0;Xa=b;h[b+12>>1]=0;i[b+8>>2]=0;aj(b+8|0);c=k[b+12>>1];g[a+814|0]=c;g[a+815|0]=c>>>8;c=i[b+8>>2];g[a+810|0]=c;g[a+811|0]=c>>>8;g[a+812|0]=c>>>16;g[a+813|0]=c>>>24;Xa=b+16|0}function Uta(a,b,c,d){var e=0,f=0;e=Xa-32|0;Xa=e;f=Tta(b,e+28|0,c);c=i[f>>2];g[e+27|0]=0;if(!c){Sta(e+8|0,b,d);_j(b,i[e+28>>2],f,i[e+8>>2]);c=sd(e+8|0);g[e+27|0]=1;oM(e+8|0)}ci(a,yc(e+8|0,c),e+27|0);Xa=e+32|0}function Tla(a,b,c,d){var e=0,f=0;e=Xa-32|0;Xa=e;f=Sla(b,e+28|0,c);c=i[f>>2];g[e+27|0]=0;if(!c){Rla(e+8|0,b,d);_j(b,i[e+28>>2],f,i[e+8>>2]);c=sd(e+8|0);g[e+27|0]=1;WI(e+8|0)}ci(a,yc(e+8|0,c),e+27|0);Xa=e+32|0}function Nq(a){var b=0;if(a){if(i[a+76>>2]<=-1){return rv(a)}return rv(a)}if(i[21324]){b=Nq(i[21324])}a=i[114605];if(a){while(1){if(l[a+20>>2]>l[a+28>>2]){b=rv(a)|b}a=i[a+56>>2];if(a){continue}break}}return b}function NEa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=Xa-16|0;Xa=d;i[d+12>>2]=c;e=d,f=xEa(Jb(b),Kb(b),d+12|0),i[e+8>>2]=f;e=d,f=Kb(b),i[e>>2]=f;a:{if(pb(d+8|0,d)){He(a,fb(i[d+8>>2]));break a}wh(a)}Xa=d+16|0}function zla(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=b,h=kh(a),i[g>>2]=h;kh(a);if(f>>>0>=60){Ib(a,4)}g=e,h=kh(a),i[g>>2]=h;Ib(a,4);b=kh(a);i[d>>2]=b;if((b|0)>=1){g=c,h=kh(a),i[g>>2]=h}}function voa(a,b){var c=0;c=i[b+4>>2];i[a>>2]=i[b>>2];i[a+4>>2]=c;c=i[b+28>>2];i[a+24>>2]=i[b+24>>2];i[a+28>>2]=c;c=i[b+20>>2];i[a+16>>2]=i[b+16>>2];i[a+20>>2]=c;c=i[b+12>>2];i[a+8>>2]=i[b+8>>2];i[a+12>>2]=c}function fV(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=Xa-16|0;Xa=e;b=tk(e+8|0,b);i[114610]=0;J(284,a|0,b|0,c|0,d|0);a=i[114610];i[114610]=0;if((a|0)!=1){hb(b);Xa=e+16|0;return}a=B()|0;A()|0;hb(b);E(a|0);x()}function Zea(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=Xa-16|0;Xa=f;b=gc(YMa(XMa(d,d>>31,b,b>>31),_a,1e3,0),_a);i[a+16>>2]=0;i[a+12>>2]=b+c;cH(a,e);b=i[a+12>>2];i[f+12>>2]=0;hI(a,b,f+12|0);Xa=f+16|0}function XR(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=Xa-16|0;Xa=d;i[d+12>>2]=c;e=d,f=eKa(Jb(b),Kb(b),d+12|0),i[e+8>>2]=f;e=d,f=Kb(b),i[e>>2]=f;a:{if(pb(d+8|0,d)){He(a,fb(i[d+8>>2]));break a}wh(a)}Xa=d+16|0}function vz(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=Xa-16|0;Xa=d;i[d+12>>2]=c;e=d,f=rR(Jb(b),Kb(b),d+12|0),i[e+8>>2]=f;e=d,f=Kb(b),i[e>>2]=f;a:{if(pb(d+8|0,d)){He(a,fb(i[d+8>>2]));break a}wh(a)}Xa=d+16|0}function sy(a,b,c){var d=0;d=Xa-16|0;Xa=d;i[d>>2]=b;i[d+8>>2]=a;a:{if(!pb(d+8|0,d)){break a}while(1){if(k[i[d+8>>2]>>1]==k[c>>1]){break a}he(d+8|0);if(pb(d+8|0,d)){continue}break}}Xa=d+16|0;return i[d+8>>2]}function aJa(a,b){a=a|0;b=b|0;var c=0;c=Xa-16|0;Xa=c;i[c+12>>2]=1;i[c+8>>2]=a>>>4;b=Eb(128/(o(i[wf(c+12|0,c+8|0)>>2],b)|0)|0,1,15);g[c+7|0]=1;g[c+6|0]=a&15;a=j[Ug(c+7|0,c+6|0)|0];Xa=c+16|0;return a|b<<4&240}function DJ(a){var b=0,c=0;b=Xa-544|0;Xa=b;if(!(!(j[a+480210|0]&128)|!i[a+24668>>2])){rL(b,we(a));c=a+1304360|0;a=a+1074984|0;while(1){Tb(a+112|0,b,538);a=a+896|0;if((c|0)!=(a|0)){continue}break}}Xa=b+544|0}function wM(a,b){var c=0;c=j[a+822|0];a:{if(c){break a}c=_i(j[a+819|0]-i[a+772>>2]|0);if(!b|!i[a+656>>2]){break a}if(!c){c=0;break a}if(129<=c>>>0){break a}c=j[Nb(i[a+656>>2]+108|0,c+ -1|0)|0]}return c&255}function rJ(a,b){var c=0;if(b){no(a);c=a+24596|0;i[c>>2]=0;i[c+4>>2]=0;i[a+24588>>2]=0;i[a+24592>>2]=0;DJ(a)}qJ(a+24648|0);sea(a+393352|0,b,i[a+24620>>2]);b=a+1304392|0;if($c(b)){IL(i[b>>2],i[a+24620>>2])}}function lf(a,b,c,d,e){var f=0;f=Xa-256|0;Xa=f;if(!(e&73728|(c|0)<=(d|0))){c=c-d|0;d=c>>>0<256;yb(f,b&255,d?c:256);if(!d){while(1){ue(a,f,256);c=c+ -256|0;if(c>>>0>255){continue}break}}ue(a,f,c)}Xa=f+256|0}function k7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=p(0);e=Xa-16|0;Xa=e;f=i[a+4>>2];FF(a,b,c,d);g=m[a+24>>2];i[e+8>>2]=i[a+20>>2];b=i[a+16>>2];i[e>>2]=i[a+12>>2];i[e+4>>2]=b;zba(e,f,c,d,g);Xa=e+16|0}function aD(a,b,c,d,e,f){var h=0,j=0,k=0;h=Xa-16|0;Xa=h;g[h+15|0]=0;g[h+14|0]=f;g[h+13|0]=e;g[h+12|0]=37;if(f){Sg(h+13|0,h+14|0)}j=c,k=(Fa(b|0,fT(b,i[c>>2])|0,h+12|0,d|0,i[a>>2])|0)+b|0,i[j>>2]=k;Xa=h+16|0}function Xaa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Xa-16|0;Xa=d;a=i[a+24>>2];Dr(d,0,c);i[114610]=0;G(650,a|0,b|0,d|0);a=i[114610];i[114610]=0;if((a|0)!=1){eb(d);Xa=d+16|0;return}a=B()|0;A()|0;eb(d);E(a|0);x()}function Pga(a){var b=0,c=0,d=0,e=0;b=CH(a);c=CH(a+12|0);d=BH(a+24|0);e=BH(a+36|0);i[114610]=0;I(1639,a|0,2,0)|0;a=i[114610];i[114610]=0;if((a|0)!=1){return}a=B()|0;A()|0;rr(e);rr(d);qr(c);qr(b);E(a|0);x()}function Owa(a,b,c){var d=0;d=Xa-16|0;Xa=d;i[d+12>>2]=c;i[d>>2]=4896;c=i[rb(d+12|0,d)>>2];if(!wb(a,c)){c=cf(a)}Oy(d,b);qg(a,i[d>>2],c);Oy(d,b);yb(i[d>>2]+c|0,0,4896-c|0);Ib(a,i[d+12>>2]);Xa=d+16|0;return c}function _I(){var a=0;a:{b:{if(g[457304]&1){break b}if(!cd(457304)){break b}i[114610]=0;C(1523,88600,1)|0;a=i[114610];i[114610]=0;if((a|0)==1){break a}bd(457304)}return}a=B()|0;A()|0;Xd(457304);E(a|0);x()}function Sv(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=Xa-32|0;Xa=e;i[e+24>>2]=b;f=e,g=ld(a),i[f+16>>2]=g;b=En(e+24|0,e+16|0);mY(a,b,c,d);f=e,g=ld(a),i[f+8>>2]=g;a=Ze(e+8|0,b);Xa=e+32|0;return a|0}function Rta(){var a=0;a:{b:{if(g[85356]&1){break b}if(!cd(85356)){break b}i[114610]=0;F(100,85328)|0;a=i[114610];i[114610]=0;if((a|0)==1){break a}bd(85356)}return 85328}a=B()|0;A()|0;Xd(85356);E(a|0);x()}function Mr(a,b){a=Tb(a,b,88);i[a+88>>2]=i[b+88>>2];Tb(a+92|0,b+92|0,576);i[a+668>>2]=i[b+668>>2];Tb(a+672|0,b+672|0,52);px(a+724|0,b+724|0);px(a+736|0,b+736|0);px(a+748|0,b+748|0);Tb(a+760|0,b+760|0,135)}function Jz(a){var b=0,c=0;b=Xa-16|0;Xa=b;fb(a);i[b+12>>2]=-1;i[114610]=0;i[b+8>>2]=2147483647;a=C(33,b+12|0,b+8|0)|0;c=i[114610];i[114610]=0;if((c|0)!=1){Xa=b+16|0;return i[a>>2]}a=H(0)|0;A()|0;gb(a);x()}function Ix(a){var b=0,c=0,d=0;b=k[a+20>>1];h[a+28>>1]=k[a+22>>1]<<1|(j[i[a+16>>2]+3842|0]?b>>>9|0:b>>>8&1);b=0;while(1){c=(b<<2)+a|0;d=i[c>>2];if(d){Lm(d);KL(i[c>>2])}b=b+1|0;if((b|0)!=4){continue}break}}function q3(){var a=0;a:{b:{if(g[461576]&1){break b}if(!cd(461576)){break b}i[114610]=0;F(2386,461572)|0;a=i[114610];i[114610]=0;if((a|0)==1){break a}bd(461576)}return}a=B()|0;A()|0;Xd(461576);E(a|0);x()}function gc(a,b){a=a|0;b=b|0;var c=0;c=Xa-32|0;Xa=c;i[c+24>>2]=a;i[c+28>>2]=b;i[c+16>>2]=-2147483648;i[c+20>>2]=-1;i[c+8>>2]=2147483647;i[c+12>>2]=0;a=yQ(c+16|0,dz(c+24|0,c+8|0));Xa=c+32|0;return i[a>>2]}function bB(a,b,c,d){var e=0,f=0,g=0,h=0;e=Xa-16|0;Xa=e;i[e+12>>2]=0;xc(a+12|0,d);if(b){f=YA(i[a+16>>2],b)}i[a>>2]=f;c=(c<<5)+f|0;i[a+8>>2]=c;i[a+4>>2]=c;g=Mb(a),h=(b<<5)+f|0,i[g>>2]=h;Xa=e+16|0;return a}function ZN(a,b,c){var d=0,e=0,f=0,h=0;e=Xa-16|0;Xa=e;d=qc(a);a:{if(d>>>0>=c>>>0){d=xb(a);Cl(d,b,c);g[e+15|0]=0;Rd(c+d|0,e+15|0);yg(a,c);break a}f=d;h=c-d|0;d=lb(a);ku(a,f,h,d,0,d,c,b)}Xa=e+16|0;return a}function W$(a,b,c){var d=0;d=Xa-32|0;Xa=d;i[d+16>>2]=b;i[d+24>>2]=a;i[d+8>>2]=c;while(1){a=pb(d+24|0,d+16|0);if(!(!a|j[i[d+24>>2]]!=j[i[d+8>>2]])){Tf(d+24|0);Tf(d+8|0);continue}break}Xa=d+32|0;return a^1}function Twa(a,b,c){var d=0;d=Xa-16|0;Xa=d;i[d+12>>2]=c;i[d>>2]=263;c=i[rb(d+12|0,d)>>2];if(!wb(a,c)){c=cf(a)}LM(d,b);qg(a,i[d>>2],c);LM(d,b);yb(i[d>>2]+c|0,0,263-c|0);Ib(a,i[d+12>>2]);Xa=d+16|0;return c}function JY(a,b,c,d){var e=0,f=0,g=0,h=0;e=Xa-16|0;Xa=e;i[e+12>>2]=0;xc(a+12|0,d);if(b){f=jC(i[a+16>>2],b)}i[a>>2]=f;c=(c<<2)+f|0;i[a+8>>2]=c;i[a+4>>2]=c;g=Mb(a),h=(b<<2)+f|0,i[g>>2]=h;Xa=e+16|0;return a}function Gg(a,b,c){var d=0,e=0,f=0,g=0;i[a+112>>2]=b;i[a+116>>2]=c;d=i[a+8>>2];g=i[a+4>>2];e=d-g|0;f=e>>31;i[a+120>>2]=e;i[a+124>>2]=f;i[a+104>>2]=b|c?((f|0)>(c|0)?1:(f|0)>=(c|0)?e>>>0>b>>>0:0)?b+g|0:d:d}function yd(a,b){var c=0,d=0,e=0;b=b+7&-8;i[a+8>>2]=b+i[a+8>>2];d=i[a+80>>2];a:{if(d){c=b;b=i[a+88>>2];e=c+b|0;c=0;if((e|0)>i[a+92>>2]){break a}i[a+88>>2]=e;return b+d|0}if(!b){return 0}c=Zc(b)}return c}function xI(a){var b=0,c=0,d=0;if(bf(a)){while(1){b=a;d=c&65535;if(bf(b)>>>0>d>>>0){b=se(b,d);i[b+20>>2]=0;i[b+12>>2]=0;i[b+16>>2]=0;CI(b);Ce(b+36|0)}c=c+1|0;if(bf(a)>>>0>(c&65535)>>>0){continue}break}}}function wza(a,b){a=a|0;b=b|0;var c=0;c=Xa-16|0;Xa=c;a:{if(b){Bb(c,b);break a}Ab(c)}i[114610]=0;G(13,a|0,4,c|0);a=i[114610];i[114610]=0;if((a|0)!=1){eb(c);Xa=c+16|0;return}a=B()|0;A()|0;eb(c);E(a|0);x()}function tB(a){var b=0;b=a;if((j[b|0]|j[b+1|0]<<8|(j[b+2|0]<<16|j[b+3|0]<<24))==1129474426&(j[b+4|0]|j[b+5|0]<<8|(j[b+6|0]<<16|j[b+7|0]<<24))==1634291279){a=a+8|0;return(j[a|0]|j[a+1|0]<<8)==14}return 0}function sya(a,b){var c=0;c=Xa-16|0;Xa=c;i[c>>2]=b;i[c+8>>2]=a;if(pb(c+8|0,c)){while(1){a=i[c+8>>2];if(j[a+3|0]==31){g[a+3|0]=20;g[a+5|0]=j[a+5|0]|128}jk(c+8|0);if(pb(c+8|0,c)){continue}break}}Xa=c+16|0}function mN(a){var b=0;a:{if((j[a+44|0]|j[a+45|0]<<8|(j[a+46|0]<<16|j[a+47|0]<<24))!=1297236819|j[a+29|0]!=16){break a}a=a+42|0;if((j[a|0]|j[a+1|0]<<8)!=2?(j[a|0]|j[a+1|0]<<8)!=1:0){break a}b=1}return b}function FQ(a){var b=0,c=0;b=a+36|0;c=XMa(j[b|0]|j[b+1|0]<<8,0,384,0);a=a+34|0;b=j[a|0]|j[a+1|0]<<8;a=b>>>30|0;b=b<<2;c=c+b|0;a=a+_a|0;a=c>>>0<b>>>0?a+1|0:a;b=c+256|0;if(b>>>0<256){a=a+1|0}_a=a;return b}function yFa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=Xa-16|0;Xa=e;i[e+12>>2]=d;Uy(a,c,d);d=0;f=i[a+16>>2];if(f>>>0>c>>>0){i[e+8>>2]=f-c;d=i[rb(e+8|0,e+12|0)>>2];PFa(a,b,c,d)}Xa=e+16|0;return d|0}function mDa(a,b,c){var d=0;d=Xa-16|0;Xa=d;i[d+12>>2]=c;i[d>>2]=18;c=i[rb(d+12|0,d)>>2];if(!wb(a,c)){c=cf(a)}Jy(d,b);qg(a,i[d>>2],c);Jy(d,b);yb(i[d>>2]+c|0,0,18-c|0);Ib(a,i[d+12>>2]);Xa=d+16|0;return c}function kDa(a,b,c){var d=0;d=Xa-16|0;Xa=d;i[d+12>>2]=c;i[d>>2]=40;c=i[rb(d+12|0,d)>>2];if(!wb(a,c)){c=cf(a)}Dy(d,b);qg(a,i[d>>2],c);Dy(d,b);yb(i[d>>2]+c|0,0,40-c|0);Ib(a,i[d+12>>2]);Xa=d+16|0;return c}function bCa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(SBa(a)>>>0<b>>>0){Kc();x()}fb(a);c=b;if(214748364<c>>>0){ic(15535);x()}c=Yb(o(c,20),4);i[a>>2]=c;i[a+4>>2]=c;d=fb(a),e=c+o(b,20)|0,i[d>>2]=e;Wo(a);Wo(a)}function b8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=Xa-16|0;Xa=e;OF(b,c,d,m[a+28>>2]);NF(a,b,c,d);b=i[a+24>>2];i[e+8>>2]=i[a+20>>2];i[e+12>>2]=b;b=i[a+16>>2];i[e>>2]=i[a+12>>2];i[e+4>>2]=b;Xa=e+16|0}function Vja(a){var b=0,c=0,d=0;b=Xa+ -64|0;Xa=b;xI(a);d=bf(a);c=yw(b+8|0,a);i[114610]=0;G(1580,a|0,d|0,c|0);a=i[114610];i[114610]=0;if((a|0)!=1){Yk(c);Xa=b- -64|0;return}a=B()|0;A()|0;Yk(c);E(a|0);x()}function VR(a,b){a=a|0;b=b|0;var c=0;c=Xa-16|0;Xa=c;a:{if(b){Bb(c,b);break a}Ab(c)}i[114610]=0;G(13,a|0,2,c|0);a=i[114610];i[114610]=0;if((a|0)!=1){eb(c);Xa=c+16|0;return}a=B()|0;A()|0;eb(c);E(a|0);x()}function Tga(a,b,c){var d=0;d=Xa-16|0;Xa=d;i[d+12>>2]=c;i[d>>2]=33;c=i[rb(d+12|0,d)>>2];if(!wb(a,c)){c=cf(a)}Ky(d,b);qg(a,i[d>>2],c);Ky(d,b);yb(i[d>>2]+c|0,0,33-c|0);Ib(a,i[d+12>>2]);Xa=d+16|0;return c}function TR(a,b){a=a|0;b=b|0;var c=0;c=Xa-16|0;Xa=c;a:{if(b){Bb(c,b);break a}Ab(c)}i[114610]=0;G(13,a|0,1,c|0);a=i[114610];i[114610]=0;if((a|0)!=1){eb(c);Xa=c+16|0;return}a=B()|0;A()|0;eb(c);E(a|0);x()}function RZ(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;a=Xa-16|0;Xa=a;i[a+12>>2]=c;i[a+8>>2]=f;b=QZ(c,d,a+12|0,f,g,a+8|0);i[e>>2]=i[a+12>>2];i[h>>2]=i[a+8>>2];Xa=a+16|0;return b|0}function PZ(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;a=Xa-16|0;Xa=a;i[a+12>>2]=c;i[a+8>>2]=f;b=OZ(c,d,a+12|0,f,g,a+8|0);i[e>>2]=i[a+12>>2];i[h>>2]=i[a+8>>2];Xa=a+16|0;return b|0}function Lp(a,b,c){a:{if(l[a+12>>2]<=b>>>0){a=P(8)|0;i[114610]=0;F(352,a|0)|0;b=i[114610];i[114610]=0;if((b|0)!=1){break a}b=B()|0;A()|0;Q(a|0);E(b|0);x()}g[i[a+8>>2]+b|0]=c;return}W(a|0,77368,265);x()}function LZ(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;a=Xa-16|0;Xa=a;i[a+12>>2]=c;i[a+8>>2]=f;b=KZ(c,d,a+12|0,f,g,a+8|0);i[e>>2]=i[a+12>>2];i[h>>2]=i[a+8>>2];Xa=a+16|0;return b|0}function JZ(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;a=Xa-16|0;Xa=a;i[a+12>>2]=c;i[a+8>>2]=f;b=IZ(c,d,a+12|0,f,g,a+8|0);i[e>>2]=i[a+12>>2];i[h>>2]=i[a+8>>2];Xa=a+16|0;return b|0}function JJ(a,b){a=a|0;b=b|0;var c=0;c=Xa-16|0;Xa=c;a:{if(b){Bb(c,b);break a}Ab(c)}i[114610]=0;G(13,a|0,0,c|0);a=i[114610];i[114610]=0;if((a|0)!=1){eb(c);Xa=c+16|0;return}a=B()|0;A()|0;eb(c);E(a|0);x()}function sla(a,b,c,d){var e=0;e=Xa-16|0;Xa=e;i[e>>2]=c;i[e+8>>2]=b;if(pb(e+8|0,e)){while(1){rla(d,i[e+8>>2]);jk(e+8|0);if(pb(e+8|0,e)){continue}break}}b=i[d+4>>2];i[a>>2]=i[d>>2];i[a+4>>2]=b;Xa=e+16|0}function rta(a,b){var c=0;c=Xa+ -64|0;Xa=c;b=cpa(c+16|0,b);b=Zoa(c,b,b+48|0);i[114610]=0;I(106,a|0,b|0,0)|0;a=i[114610];i[114610]=0;if((a|0)!=1){Sd(b);Xa=c- -64|0;return}a=B()|0;A()|0;Sd(b);E(a|0);x()}function m3(){var a=0,b=0;b=jr(460544);i[115134]=55860;i[b>>2]=55880;i[115135]=0;i[114610]=0;D(2388,i[13962]+460536|0,461220);a=i[114610];i[114610]=0;if((a|0)!=1){return}a=B()|0;A()|0;kg(b);E(a|0);x()}function k3(){var a=0,b=0;b=QD(460632);i[115156]=55908;i[b>>2]=55928;i[115157]=0;i[114610]=0;D(2389,i[13974]+460624|0,461284);a=i[114610];i[114610]=0;if((a|0)!=1){return}a=B()|0;A()|0;kg(b);E(a|0);x()}function ZZ(a,b,c,d,e,f){var g=0;g=Xa-16|0;Xa=g;i[g+12>>2]=f;f=ah(g+8|0,g+12|0);i[114610]=0;a=uD(a,b,c,d,e);b=i[114610];i[114610]=0;if((b|0)!=1){ne(f);Xa=g+16|0;return a}a=B()|0;A()|0;ne(f);E(a|0);x()}function HEa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=b&63;if(Yj(c)>>>0>d>>>0){uEa(JP(c,d),a)}a:{b:{if(b<<24>>24>=0){b=a+12|0;break b}b=a+12|0;if(Uc(a)){break b}a=j[a+12|0]|1;break a}a=j[a+12|0]&-2}g[b|0]=a}function $Z(a,b,c,d,e,f){var g=0;g=Xa-16|0;Xa=g;i[g+12>>2]=f;f=ah(g+8|0,g+12|0);i[114610]=0;a=vD(a,b,c,d,e);b=i[114610];i[114610]=0;if((b|0)!=1){ne(f);Xa=g+16|0;return a}a=B()|0;A()|0;ne(f);E(a|0);x()}function msa(){var a=0;a:{b:{if(g[87556]&1){break b}if(!cd(87556)){break b}i[114610]=0;F(1210,87552)|0;a=i[114610];i[114610]=0;if((a|0)==1){break a}bd(87556)}return}a=B()|0;A()|0;Xd(87556);E(a|0);x()}function dAa(a,b){a=a|0;b=b|0;var c=0,d=0;c=Xa-16|0;Xa=c;d=fA(a);if(d>>>0>=b>>>0){a=us(a);if(a>>>0<d>>>1>>>0){i[c+12>>2]=a<<1;i[c+8>>2]=b+31&-32;d=i[Jc(c+12|0,c+8|0)>>2]}Xa=c+16|0;return d|0}Kc();x()}function cM(a){a=a|0;var b=0,c=0;b=Xa-32|0;Xa=b;g[a+16|0]=0;c=Lx(b,i[a+12>>2]);i[114610]=0;G(1176,a|0,1,c|0);a=i[114610];i[114610]=0;if((a|0)!=1){dl(c);Xa=b+32|0;return}a=B()|0;A()|0;dl(c);E(a|0);x()}function Qra(a){var b=0,c=0;b=Xa-16|0;Xa=b;i[a>>2]=0;i[a+4>>2]=0;i[114610]=0;i[b+12>>2]=0;I(1227,a+8|0,b+12|0,b+8|0)|0;c=i[114610];i[114610]=0;if((c|0)!=1){Xa=b+16|0;return a}a=H(0)|0;A()|0;gb(a);x()}function Kra(a){var b=0,c=0;b=Xa-16|0;Xa=b;i[a>>2]=0;i[a+4>>2]=0;i[114610]=0;i[b+12>>2]=0;I(1230,a+8|0,b+12|0,b+8|0)|0;c=i[114610];i[114610]=0;if((c|0)!=1){Xa=b+16|0;return a}a=H(0)|0;A()|0;gb(a);x()}function FBa(a,b){a=a|0;b=b|0;var c=0,d=0;c=Xa-608|0;Xa=c;b=c+8|0;d=gBa(a,b);if(!d){sO(b)}b=-1;a:{if(!d){break a}b=0;if(!CO(c+8|0)){break a}b=-1;if(!ff(a,1024)){break a}b=CBa(a)}Xa=c+608|0;return b|0}function ysa(){var a=0;a:{b:{if(g[85488]&1){break b}if(!cd(85488)){break b}i[114610]=0;F(108,85484)|0;a=i[114610];i[114610]=0;if((a|0)==1){break a}bd(85488)}return}a=B()|0;A()|0;Xd(85488);E(a|0);x()}function fCa(a){var b=0,c=0;b=Xa-16|0;Xa=b;i[a>>2]=0;i[a+4>>2]=0;i[114610]=0;i[b+12>>2]=0;I(879,a+8|0,b+12|0,b+8|0)|0;c=i[114610];i[114610]=0;if((c|0)!=1){Xa=b+16|0;return a}a=H(0)|0;A()|0;gb(a);x()}function dHa(a,b){var c=0,d=0;c=Xa-16|0;Xa=c;i[c+12>>2]=674;i[c>>2]=674;d=i[rb(c+12|0,c)>>2];if(!wb(a,d)){d=cf(a)}_P(c,b);qg(a,i[c>>2],d);_P(c,b);yb(i[c>>2]+d|0,0,674-d|0);Ib(a,i[c+12>>2]);Xa=c+16|0}function cGa(a,b,c){var d=0;d=Xa-16|0;Xa=d;i[d>>2]=b;i[d+8>>2]=a;a:{if(!pb(d+8|0,d)){break a}while(1){if(ep(i[d+8>>2],c)){break a}_m(d+8|0);if(pb(d+8|0,d)){continue}break}}Xa=d+16|0;return i[d+8>>2]}function cCa(a){var b=0,c=0;b=Xa-16|0;Xa=b;i[a>>2]=0;i[a+4>>2]=0;i[114610]=0;i[b+12>>2]=0;I(881,a+8|0,b+12|0,b+8|0)|0;c=i[114610];i[114610]=0;if((c|0)!=1){Xa=b+16|0;return a}a=H(0)|0;A()|0;gb(a);x()}function Zma(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;c=Xa-16|0;Xa=c;af(a,c+14|0);_y(b,k[c+14>>1],16777216);if(k[c+14>>1]){while(1){di(a,vb(b,d));d=d+1|0;if(d>>>0<k[c+14>>1]){continue}break}}Zw(b);Xa=c+16|0}function WIa(a){var b=0,c=0;b=Xa-16|0;Xa=b;i[a>>2]=0;i[a+4>>2]=0;i[114610]=0;i[b+12>>2]=0;I(568,a+8|0,b+12|0,b+8|0)|0;c=i[114610];i[114610]=0;if((c|0)!=1){Xa=b+16|0;return a}a=H(0)|0;A()|0;gb(a);x()}function Qza(a){var b=0,c=0;b=Xa-16|0;Xa=b;i[a>>2]=0;i[a+4>>2]=0;i[114610]=0;i[b+12>>2]=0;I(948,a+8|0,b+12|0,b+8|0)|0;c=i[114610];i[114610]=0;if((c|0)!=1){Xa=b+16|0;return a}a=H(0)|0;A()|0;gb(a);x()}function OA(a){if(!((j[a|0]|j[a+1|0]<<8|(j[a+2|0]<<16|j[a+3|0]<<24))!=808603728|(j[a+4|0]+ -9&255)>>>0>6|((j[a+5|0]+ -9&255)>>>0>6|(j[a+6|0]+ -9&255)>>>0>6))){return(j[a+7|0]+ -9&255)>>>0<7}return 0}function EJ(a){var b=0,c=0;c=a+946300|0;a=a+906300|0;while(1){b=i[a>>2];a:{if(!b){break a}if(!($a[i[i[b>>2]+112>>2]](b)|0)){break a}$a[i[i[b>>2]+92>>2]](b)}a=a+160|0;if((c|0)!=(a|0)){continue}break}}function $K(a){var b=0,c=0;b=Xa-16|0;Xa=b;i[a>>2]=0;i[a+4>>2]=0;i[114610]=0;i[b+12>>2]=0;I(1260,a+8|0,b+12|0,b+8|0)|0;c=i[114610];i[114610]=0;if((c|0)!=1){Xa=b+16|0;return a}a=H(0)|0;A()|0;gb(a);x()}function ws(a){var b=0,c=0;b=Xa-16|0;Xa=b;i[a>>2]=0;i[a+4>>2]=0;i[114610]=0;i[b+12>>2]=0;I(932,a+8|0,b+12|0,b+8|0)|0;c=i[114610];i[114610]=0;if((c|0)!=1){Xa=b+16|0;return a}a=H(0)|0;A()|0;gb(a);x()}function pX(a,b,c){var d=0;a:{b:{if((b|0)==8){b=Zc(c);break b}d=28;if(b&3|($Ma(b>>>2|0)|0)!=1){break a}d=48;if(-64-b>>>0<c>>>0){break a}b=qX(b>>>0>16?b:16,c)}if(!b){return 48}i[a>>2]=b;d=0}return d}function lU(a,b){a:{if(l[a+12>>2]<=b>>>0){a=P(8)|0;i[114610]=0;F(352,a|0)|0;b=i[114610];i[114610]=0;if((b|0)!=1){break a}b=B()|0;A()|0;Q(a|0);E(b|0);x()}return j[i[a+8>>2]+b|0]}W(a|0,77368,265);x()}function jy(a){var b=0,c=0;b=Xa-16|0;Xa=b;i[a>>2]=0;i[a+4>>2]=0;i[b+12>>2]=0;i[114610]=0;I(936,a+8|0,b+12|0,b+8|0)|0;c=i[114610];i[114610]=0;if((c|0)!=1){Xa=b+16|0;return a}a=H(0)|0;A()|0;gb(a);x()}function eU(a){var b=0,c=0;b=Xa-16|0;Xa=b;i[a>>2]=0;i[a+4>>2]=0;i[114610]=0;i[b+12>>2]=0;I(354,a+8|0,b+12|0,b+8|0)|0;c=i[114610];i[114610]=0;if((c|0)!=1){Xa=b+16|0;return a}a=H(0)|0;A()|0;gb(a);x()}function Zy(a){var b=0,c=0;b=Xa-16|0;Xa=b;i[a>>2]=0;i[a+4>>2]=0;i[114610]=0;i[b+12>>2]=0;I(708,a+8|0,b+12|0,b+8|0)|0;c=i[114610];i[114610]=0;if((c|0)!=1){Xa=b+16|0;return a}a=H(0)|0;A()|0;gb(a);x()}function YV(a){var b=0,c=0;b=Xa-16|0;Xa=b;i[a>>2]=0;i[a+4>>2]=0;i[114610]=0;i[b+12>>2]=0;I(269,a+8|0,b+12|0,b+8|0)|0;c=i[114610];i[114610]=0;if((c|0)!=1){Xa=b+16|0;return a}a=H(0)|0;A()|0;gb(a);x()}function VZ(a){a=a|0;var b=0,c=0,d=0;b=Xa-16|0;Xa=b;i[b+12>>2]=a;a=ah(b+8|0,b+12|0);i[114610]=0;c=sD();d=i[114610];i[114610]=0;if((d|0)!=1){ne(a);Xa=b+16|0;return c|0}b=B()|0;A()|0;ne(a);E(b|0);x()}function Uz(a){var b=0,c=0;b=Xa-16|0;Xa=b;i[a>>2]=0;i[a+4>>2]=0;i[114610]=0;i[b+12>>2]=0;I(409,a+8|0,b+12|0,b+8|0)|0;c=i[114610];i[114610]=0;if((c|0)!=1){Xa=b+16|0;return a}a=H(0)|0;A()|0;gb(a);x()}function SS(a){var b=0,c=0;b=Xa-16|0;Xa=b;i[a>>2]=0;i[a+4>>2]=0;i[114610]=0;i[b+12>>2]=0;I(417,a+8|0,b+12|0,b+8|0)|0;c=i[114610];i[114610]=0;if((c|0)!=1){Xa=b+16|0;return a}a=H(0)|0;A()|0;gb(a);x()}function Lt(a){var b=0,c=0;b=Xa-16|0;Xa=b;i[a>>2]=0;i[a+4>>2]=0;i[114610]=0;i[b+12>>2]=0;I(355,a+8|0,b+12|0,b+8|0)|0;c=i[114610];i[114610]=0;if((c|0)!=1){Xa=b+16|0;return a}a=H(0)|0;A()|0;gb(a);x()}function uL(a,b,c,d,e,f){i[a+40>>2]=0;i[a+44>>2]=0;n[a+32>>3]=f;n[a+24>>3]=e;n[a+16>>3]=d;n[a+8>>3]=c;n[a>>3]=b;i[a+48>>2]=0;i[a+52>>2]=0;i[a+56>>2]=0;i[a+60>>2]=0;a=a- -64|0;i[a>>2]=0;i[a+4>>2]=0}function qC(a,b,c,d,e){var f=0;f=Xa-16|0;Xa=f;i[f+12>>2]=e;e=ah(f+8|0,f+12|0);i[114610]=0;a=Qn(a,b,c,d);b=i[114610];i[114610]=0;if((b|0)!=1){ne(e);Xa=f+16|0;return a}a=B()|0;A()|0;ne(e);E(a|0);x()}function nBa(a,b,c,d){var e=0;e=Xa-16|0;Xa=e;i[e>>2]=b;i[e+8>>2]=a;if(pb(e+8|0,e)){while(1){if(k[i[e+8>>2]>>1]==k[c>>1]){h[i[e+8>>2]>>1]=k[d>>1]}he(e+8|0);if(pb(e+8|0,e)){continue}break}}Xa=e+16|0}function fd(a,b){var c=0;if(k[a+24>>1]!=(b&65535)){h[a+22>>1]=k[a+22>>1]+ -1&127;if(128>k[a+20>>1]){h[a+20>>1]=k[a+20>>1]+1}c=(k[a+22>>1]<<2)+a|0;h[c+28>>1]=0;h[c+26>>1]=b-k[a+24>>1];h[a+24>>1]=b}}function f0(a,b,c,d,e){var f=0;f=Xa-16|0;Xa=f;i[f+12>>2]=e;e=ah(f+8|0,f+12|0);i[114610]=0;a=Su(a,b,c,d);b=i[114610];i[114610]=0;if((b|0)!=1){ne(e);Xa=f+16|0;return a}a=B()|0;A()|0;ne(e);E(a|0);x()}function eA(a){var b=0,c=0;b=Xa-16|0;Xa=b;i[a>>2]=0;i[a+4>>2]=0;i[114610]=0;i[b+12>>2]=0;I(31,a+8|0,b+12|0,b+8|0)|0;c=i[114610];i[114610]=0;if((c|0)!=1){Xa=b+16|0;return a}a=H(0)|0;A()|0;gb(a);x()}function Qx(a){var b=0,c=0;b=Xa-16|0;Xa=b;i[a>>2]=0;i[a+4>>2]=0;i[114610]=0;i[b+12>>2]=0;I(94,a+8|0,b+12|0,b+8|0)|0;c=i[114610];i[114610]=0;if((c|0)!=1){Xa=b+16|0;return a}a=H(0)|0;A()|0;gb(a);x()}function Gf(a,b){a=a|0;b=b|0;var c=0,d=0;c=Xa+ -64|0;Xa=c;d=yw(c+8|0,a);i[114610]=0;G(1582,a|0,b|0,d|0);a=i[114610];i[114610]=0;if((a|0)!=1){Yk(d);Xa=c- -64|0;return}a=B()|0;A()|0;Yk(d);E(a|0);x()}function yq(a){var b=0;if(i[a+76>>2]<0){b=i[a+4>>2];if(b>>>0<l[a+8>>2]){i[a+4>>2]=b+1;return j[b|0]}return av(a)}b=i[a+4>>2];a:{if(b>>>0<l[a+8>>2]){i[a+4>>2]=b+1;a=j[b|0];break a}a=av(a)}return a}function xy(a){var b=0,c=0;c=(j[a+24|0]>15)+(j[a+25|0]>64)|0;b=a+22|0;b=j[b|0]|j[b+1|0]<<8;a=a+26|0;a=j[a|0]|j[a+1|0]<<8;return c+((b<<24|b<<8&16711680)>>>15>>>0<(a<<8&16711680|a<<24)>>>16>>>0)|0}function wxa(a,b){var c=0;c=Xa-16|0;Xa=c;i[a>>2]=0;i[a+4>>2]=0;i[c+12>>2]=0;i[114610]=0;I(1027,a+8|0,c+12|0,b|0)|0;b=i[114610];i[114610]=0;if((b|0)!=1){Xa=c+16|0;return a}a=H(0)|0;A()|0;gb(a);x()}function hxa(a,b){var c=0,d=0;c=Xa-16|0;Xa=c;i[c+12>>2]=64;i[c>>2]=66;d=i[rb(c+12|0,c)>>2];if(!wb(a,d)){d=cf(a)}_s(c,b);qg(a,i[c>>2],d);_s(c,b);yb(i[c>>2]+d|0,0,66-d|0);Ib(a,i[c+12>>2]);Xa=c+16|0}function dba(a,b){var c=0;c=Xa-16|0;Xa=c;i[a>>2]=0;i[a+4>>2]=0;i[c+12>>2]=0;i[114610]=0;I(2124,a+8|0,c+12|0,b|0)|0;b=i[114610];i[114610]=0;if((b|0)!=1){Xa=c+16|0;return a}a=H(0)|0;A()|0;gb(a);x()}function Yaa(a,b){a=a|0;b=b|0;var c=0;c=Xa-16|0;Xa=c;a=i[a+24>>2];Dr(c,0,b);i[114610]=0;G(650,a|0,1,c|0);a=i[114610];i[114610]=0;if((a|0)!=1){eb(c);Xa=c+16|0;return}a=B()|0;A()|0;eb(c);E(a|0);x()}function Lh(a){var b=0;b=32767;a:{if(a>=p(32766.5)){break a}b=32768;if(a<=p(-32767.5)){break a}a=p(a+p(.5));b:{if(p(q(a))<p(2147483648)){b=~~a;break b}b=-2147483648}b=b+(b>>15)|0}return b<<16>>16}function Dja(a,b,c,d){var e=0,f=0,g=0,h=0;e=Xa-16|0;Xa=e;i[e+12>>2]=0;xc(a+12|0,d);if(b){f=oI(b)}i[a>>2]=f;c=o(c,52)+f|0;i[a+8>>2]=c;i[a+4>>2]=c;g=Mb(a),h=o(b,52)+f|0,i[g>>2]=h;Xa=e+16|0;return a}function Cp(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(fA(a)>>>0<b>>>0){Kc();x()}fb(a);b=(b+ -1>>>5|0)+1|0;c=b;if(1073741823<b>>>0){ic(11804);x()}c=Yb(c<<2,4);i[a+4>>2]=0;i[a>>2]=c;d=fb(a),e=b,i[d>>2]=e}function BK(a,b,c){var d=0,e=0;d=i[(o(b,896)+a|0)+1075640>>2];a:{if(!d){break a}b:{if((c|0)!=1){break b}a=i[(o(b,896)+a|0)+1075088>>2];if(!a){break b}if(j[a+35|0]&4){break a}}e=j[d+34|0]}return e}function sL(a,b){var c=0;c=Xa-16|0;Xa=c;i[a>>2]=0;i[a+4>>2]=0;i[c+12>>2]=0;i[114610]=0;I(1226,a+8|0,c+12|0,b|0)|0;b=i[114610];i[114610]=0;if((b|0)!=1){Xa=c+16|0;return a}a=H(0)|0;A()|0;gb(a);x()}function pI(a,b){var c=0;c=Xa-16|0;Xa=c;i[a>>2]=0;i[a+4>>2]=0;i[c+12>>2]=0;i[114610]=0;I(1591,a+8|0,c+12|0,b|0)|0;b=i[114610];i[114610]=0;if((b|0)!=1){Xa=c+16|0;return a}a=H(0)|0;A()|0;gb(a);x()}function lBa(a,b){var c=0,d=0;d=Xa-16|0;Xa=d;a:{if((a|0)==(b|0)){break a}c=a+1|0;if((c|0)==(b|0)){break a}while(1){a=j[a|0]<j[c|0]?c:a;c=c+1|0;if((c|0)!=(b|0)){continue}break}}Xa=d+16|0;return a}function gC(a,b){var c=0,d=0;c=i[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}Ck(a);i[114610]=0;c=c+ -4|0;d=i[114610];i[114610]=0;if((d|0)!=1){continue}break}a=H(0)|0;A()|0;gb(a);x()}i[a+4>>2]=b}function _K(a,b,c,d){var e=0,f=0,g=0,h=0;e=Xa-16|0;Xa=e;i[e+12>>2]=0;xc(a+12|0,d);if(b){f=ZK(b)}i[a>>2]=f;c=o(c,12)+f|0;i[a+8>>2]=c;i[a+4>>2]=c;g=Mb(a),h=o(b,12)+f|0,i[g>>2]=h;Xa=e+16|0;return a}function XL(a,b){var c=0;c=Xa-16|0;Xa=c;i[a>>2]=0;i[a+4>>2]=0;i[c+12>>2]=0;i[114610]=0;I(1197,a+8|0,c+12|0,b|0)|0;b=i[114610];i[114610]=0;if((b|0)!=1){Xa=c+16|0;return a}a=H(0)|0;A()|0;gb(a);x()}function W6(a,b){var c=0;c=Xa-16|0;Xa=c;i[a>>2]=0;i[a+4>>2]=0;i[c+12>>2]=0;i[114610]=0;I(2209,a+8|0,c+12|0,b|0)|0;b=i[114610];i[114610]=0;if((b|0)!=1){Xa=c+16|0;return a}a=H(0)|0;A()|0;gb(a);x()}function VIa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(rz(a)>>>0<b>>>0){Kc();x()}fb(a);c=b;if(715827882<c>>>0){ic(12706);x()}c=Yb(o(c,6),1);i[a>>2]=c;i[a+4>>2]=c;d=fb(a),e=c+o(b,6)|0,i[d>>2]=e;ct(a,0)}function SKa(a,b,c){var d=0;d=Xa-16|0;Xa=d;i[d+12>>2]=c;i[d>>2]=192;c=i[rb(d+12|0,d)>>2];if(!wb(a,c)){c=cf(a)}mt(d,b);qg(a,i[d>>2],c);mt(d,b);yb(i[d>>2]+c|0,0,192-c|0);Ib(a,i[d+12>>2]);Xa=d+16|0}function $f(a,b){a:{if(l[a+4>>2]<=b>>>0){a=P(8)|0;i[114610]=0;F(352,a|0)|0;b=i[114610];i[114610]=0;if((b|0)!=1){break a}b=B()|0;A()|0;Q(a|0);E(b|0);x()}return j[i[a>>2]+b|0]}W(a|0,77368,265);x()}function zga(a){var b=0;b=Xa-16|0;Xa=b;i[a>>2]=0;i[a+4>>2]=0;i[114610]=0;i[b+12>>2]=0;I(1743,a+8|0,b+12|0,b+8|0)|0;a=i[114610];i[114610]=0;if((a|0)!=1){Xa=b+16|0;return}a=H(0)|0;A()|0;gb(a);x()}function yxa(a){var b=0;b=Xa-16|0;Xa=b;i[a>>2]=0;i[a+4>>2]=0;i[114610]=0;i[b+12>>2]=0;I(1026,a+8|0,b+12|0,b+8|0)|0;a=i[114610];i[114610]=0;if((a|0)!=1){Xa=b+16|0;return}a=H(0)|0;A()|0;gb(a);x()}function yoa(a,b,c,d){var e=0,f=0,g=0,h=0;e=Xa-16|0;Xa=e;i[e+12>>2]=0;xc(a+12|0,d);if(b){f=$J(b)}i[a>>2]=f;c=(c<<5)+f|0;i[a+8>>2]=c;i[a+4>>2]=c;g=Mb(a),h=(b<<5)+f|0,i[g>>2]=h;Xa=e+16|0;return a}function x9(a){a=a|0;var b=0;a=a+24|0;b=dG(i[a>>2]);if(b>>>0>=Ti(Db(i[a>>2]+484360|0))>>>0){return k[i[a>>2]+1074436>>1]}b=k[$b(Db(i[a>>2]+484360|0),b)>>1];return(sp(i[a>>2]+484344|0,b)?b:-1)|0}function w6(a,b,c){var d=0;d=v6(a,b,c);if((d|0)==(b|0)){return b}a=d+2|0;if((b|0)!=(a|0)){while(1){if(k[a>>1]!=k[c>>1]){h[d>>1]=k[a>>1];d=d+2|0}a=a+2|0;if((b|0)!=(a|0)){continue}break}}return d}function vN(a,b){var c=0;c=Xa-16|0;Xa=c;i[a>>2]=0;i[a+4>>2]=0;i[c+12>>2]=0;i[114610]=0;I(994,a+8|0,c+12|0,b|0)|0;b=i[114610];i[114610]=0;if((b|0)!=1){Xa=c+16|0;return a}a=H(0)|0;A()|0;gb(a);x()}function tta(a){var b=0;b=Xa-16|0;Xa=b;i[a>>2]=0;i[a+4>>2]=0;i[114610]=0;i[b+12>>2]=0;I(1177,a+8|0,b+12|0,b+8|0)|0;a=i[114610];i[114610]=0;if((a|0)!=1){Xa=b+16|0;return}a=H(0)|0;A()|0;gb(a);x()}function qja(a){var b=0;b=Xa-16|0;Xa=b;i[a>>2]=0;i[a+4>>2]=0;i[114610]=0;i[b+12>>2]=0;I(1593,a+8|0,b+12|0,b+8|0)|0;a=i[114610];i[114610]=0;if((a|0)!=1){Xa=b+16|0;return}a=H(0)|0;A()|0;gb(a);x()}function nia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=Xa-16|0;Xa=d;e=1;a=a+32|0;if(l[i[b>>2]>>2]<rc(a)>>>0){a=Ol(d,dc(a,i[i[b>>2]>>2]),k[i[b>>2]+12>>1]);b=Eu(c,a);ob(a);e=b^1}Xa=d+16|0;return e|0}function mga(a){var b=0;b=Xa-16|0;Xa=b;i[a>>2]=0;i[a+4>>2]=0;i[114610]=0;i[b+12>>2]=0;I(1761,a+8|0,b+12|0,b+8|0)|0;a=i[114610];i[114610]=0;if((a|0)!=1){Xa=b+16|0;return}a=H(0)|0;A()|0;gb(a);x()}function jpa(a){var b=0;b=Xa-16|0;Xa=b;i[a>>2]=0;i[a+4>>2]=0;i[114610]=0;i[b+12>>2]=0;I(1370,a+8|0,b+12|0,b+8|0)|0;a=i[114610];i[114610]=0;if((a|0)!=1){Xa=b+16|0;return}a=H(0)|0;A()|0;gb(a);x()}function ema(a){var b=0;b=Xa-16|0;Xa=b;i[a>>2]=0;i[a+4>>2]=0;i[114610]=0;i[b+12>>2]=0;I(1517,a+8|0,b+12|0,b+8|0)|0;a=i[114610];i[114610]=0;if((a|0)!=1){Xa=b+16|0;return}a=H(0)|0;A()|0;gb(a);x()}function eCa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(Hm(a)>>>0<b>>>0){Kc();x()}fb(a);c=b;if(1073741823<c>>>0){ic(15535);x()}c=Yb(c<<2,1);i[a>>2]=c;i[a+4>>2]=c;d=fb(a),e=c+(b<<2)|0,i[d>>2]=e;Mj(a,0)}function Xta(a){var b=0;b=Xa-16|0;Xa=b;i[a>>2]=0;i[a+4>>2]=0;i[114610]=0;i[b+12>>2]=0;I(1167,a+8|0,b+12|0,b+8|0)|0;a=i[114610];i[114610]=0;if((a|0)!=1){Xa=b+16|0;return}a=H(0)|0;A()|0;gb(a);x()}function Xna(a){var b=0;b=Xa-16|0;Xa=b;i[a>>2]=0;i[a+4>>2]=0;i[114610]=0;i[b+12>>2]=0;I(1401,a+8|0,b+12|0,b+8|0)|0;a=i[114610];i[114610]=0;if((a|0)!=1){Xa=b+16|0;return}a=H(0)|0;A()|0;gb(a);x()}function Xma(a){var b=0;b=Xa-16|0;Xa=b;i[a>>2]=0;i[a+4>>2]=0;i[114610]=0;i[b+12>>2]=0;I(1436,a+8|0,b+12|0,b+8|0)|0;a=i[114610];i[114610]=0;if((a|0)!=1){Xa=b+16|0;return}a=H(0)|0;A()|0;gb(a);x()}function Vma(a){var b=0;b=Xa-16|0;Xa=b;i[a>>2]=0;i[a+4>>2]=0;i[114610]=0;i[b+12>>2]=0;I(1437,a+8|0,b+12|0,b+8|0)|0;a=i[114610];i[114610]=0;if((a|0)!=1){Xa=b+16|0;return}a=H(0)|0;A()|0;gb(a);x()}function Uwa(a){var b=0;b=Xa-16|0;Xa=b;i[a>>2]=0;i[a+4>>2]=0;i[114610]=0;i[b+12>>2]=0;I(1056,a+8|0,b+12|0,b+8|0)|0;a=i[114610];i[114610]=0;if((a|0)!=1){Xa=b+16|0;return}a=H(0)|0;A()|0;gb(a);x()}function Sxa(a){var b=0;b=Xa-16|0;Xa=b;i[a>>2]=0;i[a+4>>2]=0;i[114610]=0;i[b+12>>2]=0;I(1019,a+8|0,b+12|0,b+8|0)|0;a=i[114610];i[114610]=0;if((a|0)!=1){Xa=b+16|0;return}a=H(0)|0;A()|0;gb(a);x()}function Qaa(a){var b=0;b=Xa-16|0;Xa=b;i[a>>2]=0;i[a+4>>2]=0;i[114610]=0;i[b+12>>2]=0;I(2131,a+8|0,b+12|0,b+8|0)|0;a=i[114610];i[114610]=0;if((a|0)!=1){Xa=b+16|0;return}a=H(0)|0;A()|0;gb(a);x()}function PS(a,b){var c=0;c=Xa-16|0;Xa=c;i[a>>2]=0;i[a+4>>2]=0;i[c+12>>2]=0;i[114610]=0;I(419,a+8|0,c+12|0,b|0)|0;b=i[114610];i[114610]=0;if((b|0)!=1){Xa=c+16|0;return a}a=H(0)|0;A()|0;gb(a);x()}function Nka(a){var b=0;b=Xa-16|0;Xa=b;i[a>>2]=0;i[a+4>>2]=0;i[114610]=0;i[b+12>>2]=0;I(1559,a+8|0,b+12|0,b+8|0)|0;a=i[114610];i[114610]=0;if((a|0)!=1){Xa=b+16|0;return}a=H(0)|0;A()|0;gb(a);x()}function N_(a){var b=0,c=0;b=Xa-16|0;Xa=b;i[a>>2]=0;i[a+4>>2]=0;i[b+12>>2]=0;i[114610]=0;lC(a+16|0,b+12|0,b+8|0);c=i[114610];i[114610]=0;if((c|0)!=1){Xa=b+16|0;return a}a=H(0)|0;A()|0;gb(a);x()}function KG(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=te(12);b=i[b>>2];c=i[c>>2];i[114610]=0;b=I(2001,d|0,b|0,c|0)|0;c=i[114610];i[114610]=0;if((c|0)!=1){Vda(a,b);return}a=B()|0;A()|0;Cb(d);E(a|0);x()}function Jza(a,b,c,d){var e=0,f=0,g=0,h=0;e=Xa-16|0;Xa=e;i[e+12>>2]=0;xc(a+12|0,d);if(b){f=NN(b)}i[a>>2]=f;c=(c<<2)+f|0;i[a+8>>2]=c;i[a+4>>2]=c;g=Mb(a),h=(b<<2)+f|0,i[g>>2]=h;Xa=e+16|0;return a}function Goa(a){var b=0;b=Xa-16|0;Xa=b;i[a>>2]=0;i[a+4>>2]=0;i[114610]=0;i[b+12>>2]=0;I(1378,a+8|0,b+12|0,b+8|0)|0;a=i[114610];i[114610]=0;if((a|0)!=1){Xa=b+16|0;return}a=H(0)|0;A()|0;gb(a);x()}function Ena(a){var b=0;b=Xa-16|0;Xa=b;i[a>>2]=0;i[a+4>>2]=0;i[114610]=0;i[b+12>>2]=0;I(1418,a+8|0,b+12|0,b+8|0)|0;a=i[114610];i[114610]=0;if((a|0)!=1){Xa=b+16|0;return}a=H(0)|0;A()|0;gb(a);x()}function Dra(a){var b=0;b=Xa-16|0;Xa=b;i[a>>2]=0;i[a+4>>2]=0;i[114610]=0;i[b+12>>2]=0;I(1234,a+8|0,b+12|0,b+8|0)|0;a=i[114610];i[114610]=0;if((a|0)!=1){Xa=b+16|0;return}a=H(0)|0;A()|0;gb(a);x()}function Cna(a){var b=0;b=Xa-16|0;Xa=b;i[a>>2]=0;i[a+4>>2]=0;i[114610]=0;i[b+12>>2]=0;I(1420,a+8|0,b+12|0,b+8|0)|0;a=i[114610];i[114610]=0;if((a|0)!=1){Xa=b+16|0;return}a=H(0)|0;A()|0;gb(a);x()}function Aga(a){var b=0;b=Xa-16|0;Xa=b;i[a>>2]=0;i[a+4>>2]=0;i[114610]=0;i[b+12>>2]=0;I(1742,a+8|0,b+12|0,b+8|0)|0;a=i[114610];i[114610]=0;if((a|0)!=1){Xa=b+16|0;return}a=H(0)|0;A()|0;gb(a);x()}function $p(a,b,c){var d=0;d=Xa-16|0;Xa=d;a:{if(c){Bb(d,c);break a}Ab(d)}i[114610]=0;G(13,a|0,b|0,d|0);a=i[114610];i[114610]=0;if((a|0)!=1){eb(d);Xa=d+16|0;return}a=B()|0;A()|0;eb(d);E(a|0);x()}function wfa(a,b,c){a=a|0;b=b|0;c=p(c);var d=0;d=Xa-16|0;Xa=d;m[d+12>>2]=c;if((b|0)<=4){Id(d+12|0,p(0));c=m[d+12>>2];if((b|0)==4){c=Qd(c);m[d+12>>2]=c}m[((b<<2)+a|0)+4220>>2]=c;fH(a)}Xa=d+16|0}function wEa(a){var b=0;b=Xa-16|0;Xa=b;i[a>>2]=0;i[a+4>>2]=0;i[114610]=0;i[b+12>>2]=0;I(763,a+8|0,b+12|0,b+8|0)|0;a=i[114610];i[114610]=0;if((a|0)!=1){Xa=b+16|0;return}a=H(0)|0;A()|0;gb(a);x()}function w5(a,b){var c=0;c=yb(a,0,1512);if(b){a=i[b+4>>2];i[c+80>>2]=i[b>>2];i[c+84>>2]=a;a=a&-8;i[c+92>>2]=a;i[c+84>>2]=a}i[c+96>>2]=0;i[c+100>>2]=0;i[c+1420>>2]=-1;i[c+124>>2]=0;i[c+32>>2]=0}function uw(a,b,c,d){var e=0,f=0,g=0,h=0;e=Xa-16|0;Xa=e;i[e+12>>2]=0;xc(a+12|0,d);if(b){f=bI(b)}i[a>>2]=f;c=(c<<2)+f|0;i[a+8>>2]=c;i[a+4>>2]=c;g=Mb(a),h=(b<<2)+f|0,i[g>>2]=h;Xa=e+16|0;return a}function tt(a,b,c,d){var e=0,f=0,g=0,h=0;e=Xa-16|0;Xa=e;i[e+12>>2]=0;xc(a+12|0,d);if(b){f=gT(b)}i[a>>2]=f;c=(c<<1)+f|0;i[a+8>>2]=c;i[a+4>>2]=c;g=Mb(a),h=(b<<1)+f|0,i[g>>2]=h;Xa=e+16|0;return a}function swa(a,b,c){var d=0;d=Xa-16|0;Xa=d;i[d+12>>2]=c;i[d>>2]=36;c=i[rb(d+12|0,d)>>2];if(!wb(a,c)){c=cf(a)}Mp(d,b);qg(a,i[d>>2],c);Mp(d,b);yb(i[d>>2]+c|0,0,36-c|0);Ib(a,i[d+12>>2]);Xa=d+16|0}function sn(a,b,c,d){var e=0,f=0,g=0,h=0;e=Xa-16|0;Xa=e;i[e+12>>2]=0;xc(a+12|0,d);if(b){f=gA(b)}i[a>>2]=f;c=(c<<2)+f|0;i[a+8>>2]=c;i[a+4>>2]=c;g=Mb(a),h=(b<<2)+f|0,i[g>>2]=h;Xa=e+16|0;return a}function pDa(a){var b=0;b=Xa-16|0;Xa=b;i[a>>2]=0;i[a+4>>2]=0;i[114610]=0;i[b+12>>2]=0;I(818,a+8|0,b+12|0,b+8|0)|0;a=i[114610];i[114610]=0;if((a|0)!=1){Xa=b+16|0;return}a=H(0)|0;A()|0;gb(a);x()}function o8(a,b,c,d){var e=0,f=0,g=0,h=0;e=Xa-16|0;Xa=e;i[e+12>>2]=0;xc(a+12|0,d);if(b){f=TF(b)}i[a>>2]=f;c=(c<<4)+f|0;i[a+8>>2]=c;i[a+4>>2]=c;g=Mb(a),h=(b<<4)+f|0,i[g>>2]=h;Xa=e+16|0;return a}function nza(a){var b=0;b=Xa-16|0;Xa=b;i[a>>2]=0;i[a+4>>2]=0;i[114610]=0;i[b+12>>2]=0;I(977,a+8|0,b+12|0,b+8|0)|0;a=i[114610];i[114610]=0;if((a|0)!=1){Xa=b+16|0;return}a=H(0)|0;A()|0;gb(a);x()}function iY(a,b,c){var d=0,e=0,f=0;e=Xa-16|0;Xa=e;d=iq(a);a:{if(d>>>0>=c>>>0){d=xb(a);hY(d,b,c);i[e+12>>2]=0;ye(d+(c<<2)|0,e+12|0);yg(a,c);break a}f=a;a=lb(a);_B(f,d,c-d|0,a,0,a,c,b)}Xa=e+16|0}function iDa(a){var b=0;b=Xa-16|0;Xa=b;i[a>>2]=0;i[a+4>>2]=0;i[114610]=0;i[b+12>>2]=0;I(821,a+8|0,b+12|0,b+8|0)|0;a=i[114610];i[114610]=0;if((a|0)!=1){Xa=b+16|0;return}a=H(0)|0;A()|0;gb(a);x()}function hM(a,b,c,d){var e=0;e=Xa-16|0;Xa=e;d=vh(e,a,d);a=fb(a);i[114610]=0;J(1170,a|0,b|0,c|0,d+4|0);a=i[114610];i[114610]=0;if((a|0)!=1){sb(d);Xa=e+16|0;return}a=B()|0;A()|0;sb(d);E(a|0);x()}function fxa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=Xa-16|0;Xa=e;i[e>>2]=c;i[e+8>>2]=b;if(pb(e+8|0,e)){while(1){exa(d,i[e+8>>2]);jk(e+8|0);if(pb(e+8|0,e)){continue}break}}RM(a,d);Xa=e+16|0}function eza(a){var b=0;b=Xa-16|0;Xa=b;i[a>>2]=0;i[a+4>>2]=0;i[114610]=0;i[b+12>>2]=0;I(985,a+8|0,b+12|0,b+8|0)|0;a=i[114610];i[114610]=0;if((a|0)!=1){Xa=b+16|0;return}a=H(0)|0;A()|0;gb(a);x()}function eF(a,b){var c=0,d=0,e=0,f=p(0),g=p(0),h=0;if((b|0)>=1){h=a+2304|0;while(1){c=d<<2;e=c+a|0;c=c+h|0;f=m[c>>2];g=m[e>>2];m[e>>2]=f+g;m[c>>2]=g-f;d=d+1|0;if((d|0)!=(b|0)){continue}break}}}function cfa(a,b,c){a=a|0;b=b|0;c=p(c);var d=0;d=Xa-16|0;Xa=d;m[d+12>>2]=c;if((b|0)<=1){Id(d+12|0,p(0));c=m[d+12>>2];if((b|0)==1){c=Qd(c);m[d+12>>2]=c}m[((b<<2)+a|0)+4208>>2]=c;dH(a)}Xa=d+16|0}function cKa(a){var b=0;b=Xa-16|0;Xa=b;i[a>>2]=0;i[a+4>>2]=0;i[114610]=0;i[b+12>>2]=0;I(520,a+8|0,b+12|0,b+8|0)|0;a=i[114610];i[114610]=0;if((a|0)!=1){Xa=b+16|0;return}a=H(0)|0;A()|0;gb(a);x()}function Zr(a,b,c,d){var e=0,f=0,g=0,h=0;e=Xa-16|0;Xa=e;i[e+12>>2]=0;xc(a+12|0,d);if(b){f=YK(b)}i[a>>2]=f;c=(c<<2)+f|0;i[a+8>>2]=c;i[a+4>>2]=c;g=Mb(a),h=(b<<2)+f|0,i[g>>2]=h;Xa=e+16|0;return a}function Vsa(a,b){var c=0,d=0;c=Usa(a,b);i[114610]=0;C(4,a+12|0,b+12|0)|0;d=i[114610];i[114610]=0;if((d|0)!=1){i[a+24>>2]=i[b+24>>2];h[a+28>>1]=k[b+28>>1];return}a=B()|0;A()|0;df(c);E(a|0);x()}function VDa(a){var b=0;b=Xa-16|0;Xa=b;i[a>>2]=0;i[a+4>>2]=0;i[114610]=0;i[b+12>>2]=0;I(774,a+8|0,b+12|0,b+8|0)|0;a=i[114610];i[114610]=0;if((a|0)!=1){Xa=b+16|0;return}a=H(0)|0;A()|0;gb(a);x()}function Ura(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(Xt(a)>>>0<b>>>0){Kc();x()}fb(a);c=b;if(536870911<c>>>0){ic(20097);x()}c=Yb(c<<3,8);i[a>>2]=c;i[a+4>>2]=c;d=fb(a),e=c+(b<<3)|0,i[d>>2]=e;Wt(a,0)}function UHa(a){var b=0;b=Xa-16|0;Xa=b;i[a>>2]=0;i[a+4>>2]=0;i[114610]=0;i[b+12>>2]=0;I(610,a+8|0,b+12|0,b+8|0)|0;a=i[114610];i[114610]=0;if((a|0)!=1){Xa=b+16|0;return}a=H(0)|0;A()|0;gb(a);x()}function TZ(a,b,c,d){var e=0;e=Xa-16|0;Xa=e;i[e+12>>2]=d;d=ah(e+8|0,e+12|0);i[114610]=0;a=rD(a,b,c);b=i[114610];i[114610]=0;if((b|0)!=1){ne(d);Xa=e+16|0;return a}a=B()|0;A()|0;ne(d);E(a|0);x()}function TQ(a,b,c,d){var e=0,f=0,g=0,h=0;e=Xa-16|0;Xa=e;i[e+12>>2]=0;xc(a+12|0,d);if(b){f=yS(b)}i[a>>2]=f;c=(c<<4)+f|0;i[a+8>>2]=c;i[a+4>>2]=c;g=Mb(a),h=(b<<4)+f|0,i[g>>2]=h;Xa=e+16|0;return a}function TL(a,b,c,d){var e=0,f=0,g=0,h=0;e=Xa-16|0;Xa=e;i[e+12>>2]=0;xc(a+12|0,d);if(b){f=VL(b)}i[a>>2]=f;c=(c<<5)+f|0;i[a+8>>2]=c;i[a+4>>2]=c;g=Mb(a),h=(b<<5)+f|0,i[g>>2]=h;Xa=e+16|0;return a}function SP(a,b,c,d){var e=0,f=0,g=0,h=0;e=Xa-16|0;Xa=e;i[e+12>>2]=0;xc(a+12|0,d);if(b){f=TP(b)}i[a>>2]=f;c=o(c,6)+f|0;i[a+8>>2]=c;i[a+4>>2]=c;g=Mb(a),h=o(b,6)+f|0,i[g>>2]=h;Xa=e+16|0;return a}function QJa(a){var b=0;b=Xa-16|0;Xa=b;i[a>>2]=0;i[a+4>>2]=0;i[114610]=0;i[b+12>>2]=0;I(531,a+8|0,b+12|0,b+8|0)|0;a=i[114610];i[114610]=0;if((a|0)!=1){Xa=b+16|0;return}a=H(0)|0;A()|0;gb(a);x()}function KAa(a){var b=0;b=Xa-16|0;Xa=b;i[a>>2]=0;i[a+4>>2]=0;i[114610]=0;i[b+12>>2]=0;I(923,a+8|0,b+12|0,b+8|0)|0;a=i[114610];i[114610]=0;if((a|0)!=1){Xa=b+16|0;return}a=H(0)|0;A()|0;gb(a);x()}function Jra(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(aq(a)>>>0<b>>>0){Kc();x()}fb(a);c=b;if(268435455<c>>>0){ic(20097);x()}c=Yb(c<<4,8);i[a>>2]=c;i[a+4>>2]=c;d=fb(a),e=c+(b<<4)|0,i[d>>2]=e;Jl(a,0)}function H8(a){var b=0;b=Xa-16|0;Xa=b;i[a>>2]=0;i[a+4>>2]=0;i[114610]=0;i[b+12>>2]=0;I(2201,a+8|0,b+12|0,b+8|0)|0;a=i[114610];i[114610]=0;if((a|0)!=1){Xa=b+16|0;return}a=H(0)|0;A()|0;gb(a);x()}function Fu(a,b,c,d){var e=0;e=Xa-16|0;Xa=e;i[e+12>>2]=d;d=ah(e+8|0,e+12|0);i[114610]=0;a=Aj(a,b,c);b=i[114610];i[114610]=0;if((b|0)!=1){ne(d);Xa=e+16|0;return a}a=B()|0;A()|0;ne(d);E(a|0);x()}function DIa(a){var b=0;b=Xa-16|0;Xa=b;i[a>>2]=0;i[a+4>>2]=0;i[114610]=0;i[b+12>>2]=0;I(576,a+8|0,b+12|0,b+8|0)|0;a=i[114610];i[114610]=0;if((a|0)!=1){Xa=b+16|0;return}a=H(0)|0;A()|0;gb(a);x()}function BGa(a){var b=0;b=Xa-16|0;Xa=b;i[a>>2]=0;i[a+4>>2]=0;i[114610]=0;i[b+12>>2]=0;I(699,a+8|0,b+12|0,b+8|0)|0;a=i[114610];i[114610]=0;if((a|0)!=1){Xa=b+16|0;return}a=H(0)|0;A()|0;gb(a);x()}function Aea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=hg(86224);if(!d){return 0}i[114610]=0;a=N(1965,d|0,a|0,b|0,c|0)|0;b=i[114610];i[114610]=0;if((b|0)!=1){return a|0}a=B()|0;A()|0;Cb(d);E(a|0);x()}function $La(a){var b=0;b=Xa-16|0;Xa=b;i[a>>2]=0;i[a+4>>2]=0;i[114610]=0;i[b+12>>2]=0;I(416,a+8|0,b+12|0,b+8|0)|0;a=i[114610];i[114610]=0;if((a|0)!=1){Xa=b+16|0;return}a=H(0)|0;A()|0;gb(a);x()}function zaa(a,b,c,d){var e=0,f=0;e=Xa-16|0;Xa=e;f=i[b+12>>2];i[e+8>>2]=i[b+8>>2];i[e+12>>2]=f;f=i[b+4>>2];i[e>>2]=i[b>>2];i[e+4>>2]=f;xaa(a,e,c);m[a+28>>2]=d;i[a>>2]=84064;Xa=e+16|0;return a}function rfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=hg(4296);if(!d){return 0}i[114610]=0;a=N(1879,d|0,a|0,b|0,c|0)|0;b=i[114610];i[114610]=0;if((b|0)!=1){return a|0}a=B()|0;A()|0;Cb(d);E(a|0);x()}function oea(a,b,c,d){var e=0,f=0,g=0;if(d){while(1){e=g<<3;f=e+a|0;i[f>>2]=i[f>>2]+o(i[b+e>>2]>>4,c);e=e|4;f=e+a|0;i[f>>2]=i[f>>2]+o(i[b+e>>2]>>4,c);g=g+1|0;if((g|0)!=(d|0)){continue}break}}}function l1(a){var b=0;b=Xa-16|0;Xa=b;i[a>>2]=0;i[a+4>>2]=0;i[114610]=0;i[b+12>>2]=0;I(207,a+8|0,b+12|0,b+8|0)|0;a=i[114610];i[114610]=0;if((a|0)!=1){Xa=b+16|0;return}a=H(0)|0;A()|0;gb(a);x()}function kha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=hg(4304);if(!d){return 0}i[114610]=0;a=N(1700,d|0,a|0,b|0,c|0)|0;b=i[114610];i[114610]=0;if((b|0)!=1){return a|0}a=B()|0;A()|0;Cb(d);E(a|0);x()}function gga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=hg(4296);if(!d){return 0}i[114610]=0;a=N(1775,d|0,a|0,b|0,c|0)|0;b=i[114610];i[114610]=0;if((b|0)!=1){return a|0}a=B()|0;A()|0;Cb(d);E(a|0);x()}function gfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=hg(4228);if(!d){return 0}i[114610]=0;a=N(1892,d|0,a|0,b|0,c|0)|0;b=i[114610];i[114610]=0;if((b|0)!=1){return a|0}a=B()|0;A()|0;Cb(d);E(a|0);x()}function dU(a){var b=0;b=Xa-16|0;Xa=b;i[a>>2]=0;i[a+4>>2]=0;i[114610]=0;i[b+12>>2]=0;I(356,a+8|0,b+12|0,b+8|0)|0;a=i[114610];i[114610]=0;if((a|0)!=1){Xa=b+16|0;return}a=H(0)|0;A()|0;gb(a);x()}function d1(a){var b=0;b=Xa-16|0;Xa=b;i[a>>2]=0;i[a+4>>2]=0;i[114610]=0;i[b+12>>2]=0;I(208,a+8|0,b+12|0,b+8|0)|0;a=i[114610];i[114610]=0;if((a|0)!=1){Xa=b+16|0;return}a=H(0)|0;A()|0;gb(a);x()}function Zha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=hg(4268);if(!d){return 0}i[114610]=0;a=N(1637,d|0,a|0,b|0,c|0)|0;b=i[114610];i[114610]=0;if((b|0)!=1){return a|0}a=B()|0;A()|0;Cb(d);E(a|0);x()}function Xea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=hg(5048);if(!d){return 0}i[114610]=0;a=N(1915,d|0,a|0,b|0,c|0)|0;b=i[114610];i[114610]=0;if((b|0)!=1){return a|0}a=B()|0;A()|0;Cb(d);E(a|0);x()}function XV(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(Xt(a)>>>0<b>>>0){Kc();x()}fb(a);c=b;if(536870911<c>>>0){ic(11120);x()}c=Yb(c<<3,1);i[a>>2]=c;i[a+4>>2]=c;d=fb(a),e=c+(b<<3)|0,i[d>>2]=e;Wt(a,0)}function Vfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=hg(4280);if(!d){return 0}i[114610]=0;a=N(1808,d|0,a|0,b|0,c|0)|0;b=i[114610];i[114610]=0;if((b|0)!=1){return a|0}a=B()|0;A()|0;Cb(d);E(a|0);x()}function Ifa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=hg(4276);if(!d){return 0}i[114610]=0;a=N(1832,d|0,a|0,b|0,c|0)|0;b=i[114610];i[114610]=0;if((b|0)!=1){return a|0}a=B()|0;A()|0;Cb(d);E(a|0);x()}function Iea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=hg(4276);if(!d){return 0}i[114610]=0;a=N(1942,d|0,a|0,b|0,c|0)|0;b=i[114610];i[114610]=0;if((b|0)!=1){return a|0}a=B()|0;A()|0;Cb(d);E(a|0);x()}function F5(a){var b=0,c=0,d=0;b=Xa-16|0;Xa=b;yc(b+8|0,a+116|0);i[114610]=0;c=za(198,a|0)|0;a=A()|0;c=c|0;d=i[114610];i[114610]=0;if((d|0)!=1){Xa=b+16|0;_a=a;return c}a=B()|0;A()|0;E(a|0);x()}function Dg(a,b){var c=0,d=0;a=i[a>>2];b=qd(b);c=b;d=a+16|0;if(qb(d)>>>0>b>>>0){c=i[vb(d,c)>>2]!=0}else{c=0}if(!c){a=P(4)|0;nm(a);i[a>>2]=71772;W(a|0,71832,2564);x()}return i[vb(a+16|0,b)>>2]}function Caa(a,b,c,d){var e=0,f=0;e=Xa-16|0;Xa=e;f=i[b+12>>2];i[e+8>>2]=i[b+8>>2];i[e+12>>2]=f;f=i[b+4>>2];i[e>>2]=i[b>>2];i[e+4>>2]=f;Aaa(a,e,c);m[a+28>>2]=d;i[a>>2]=83960;Xa=e+16|0;return a}function BU(a){var b=0;b=Xa-16|0;Xa=b;i[a>>2]=0;i[a+4>>2]=0;i[114610]=0;i[b+12>>2]=0;I(345,a+8|0,b+12|0,b+8|0)|0;a=i[114610];i[114610]=0;if((a|0)!=1){Xa=b+16|0;return}a=H(0)|0;A()|0;gb(a);x()}function B4(a){var b=0;b=Xa-16|0;Xa=b;i[a>>2]=0;i[a+4>>2]=0;i[114610]=0;i[b+12>>2]=0;I(203,a+8|0,b+12|0,b+8|0)|0;a=i[114610];i[114610]=0;if((a|0)!=1){Xa=b+16|0;return}a=H(0)|0;A()|0;gb(a);x()}function Afa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=hg(4268);if(!d){return 0}i[114610]=0;a=N(1855,d|0,a|0,b|0,c|0)|0;b=i[114610];i[114610]=0;if((b|0)!=1){return a|0}a=B()|0;A()|0;Cb(d);E(a|0);x()}function tma(a){var b=0,c=0,d=0,e=0,f=0;a:{b=i[a+656>>2];c=g[b+26|0];if(!c){break a}d=j[a+819|0];if(!d){break a}e=a,f=Eb(i[a+684>>2]+((o((j[b+27|0]^-1)+d|0,c)|0)/2|0)|0,0,256),i[e+684>>2]=f}}function eo(a,b){var c=0,d=0,e=0;c=Xa-16|0;Xa=c;d=c,e=sd(b),i[d+12>>2]=e;i[114610]=0;I(2002,a|0,c+12|0,b|0)|0;b=i[114610];i[114610]=0;if((b|0)!=1){Xa=c+16|0;return a}a=H(0)|0;A()|0;gb(a);x()}function di(a,b){var c=0,d=0;c=Xa-16|0;Xa=c;i[c+12>>2]=0;a=xk(a,c+12|0,4);i[c+8>>2]=i[c+12>>2];d=b;b=c+8|0;i[d>>2]=j[b|0]|j[b+1|0]<<8|(j[b+2|0]<<16|j[b+3|0]<<24);Xa=c+16|0;return!_a&(a|0)==4}function co(a,b){var c=0,d=0,e=0;c=Xa-16|0;Xa=c;d=c,e=sd(b),i[d+12>>2]=e;i[114610]=0;I(2162,a|0,c+12|0,b|0)|0;b=i[114610];i[114610]=0;if((b|0)!=1){Xa=c+16|0;return a}a=H(0)|0;A()|0;gb(a);x()}function _w(a,b){var c=0;Pma(a,b);g[a+12|0]=j[b+12|0];c=j[b+13|0]|j[b+14|0]<<8|(j[b+15|0]<<16|j[b+16|0]<<24);g[a+13|0]=c;g[a+14|0]=c>>>8;g[a+15|0]=c>>>16;g[a+16|0]=c>>>24;g[a+17|0]=j[b+17|0]}function UP(a,b,c){a=a|0;b=b|0;c=c|0;a=j[c|0]|j[c+1|0]<<8|(j[c+2|0]<<16|j[c+3|0]<<24);g[b|0]=a;g[b+1|0]=a>>>8;g[b+2|0]=a>>>16;g[b+3|0]=a>>>24;a=j[c+4|0]|j[c+5|0]<<8;g[b+4|0]=a;g[b+5|0]=a>>>8}function PFa(a,b,c,d){var e=0,f=0,g=0,h=0;e=Xa-32|0;Xa=e;a=a+4|0;g=e,h=Jb(a),i[g+24>>2]=h;f=Ze(e+24|0,c);g=e,h=Jb(a),i[g+8>>2]=h;g=e,h=Ze(e+8|0,c),i[g+16>>2]=h;$i(f,Ze(e+16|0,d),b);Xa=e+32|0}function Kf(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=Xa-16|0;Xa=d;c=a;a:{if(!oe(b)){i[c+8>>2]=i[b+8>>2];e=i[b+4>>2];i[c>>2]=i[b>>2];i[c+4>>2]=e;break a}So(a,i[b>>2],i[b+4>>2])}Xa=d+16|0;return a|0}function IDa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=Xa+ -64|0;Xa=d;c=d+8|0;e=aDa(a,c);if(!e){gP(c)}c=-1;a:{if(!e){break a}c=0;if(!uP(d+8|0)){break a}c=Le(a,b,tP(d+8|0),_a)}Xa=d- -64|0;return c|0}function v3(){var a=0,b=0;a=Xa-16|0;Xa=a;b=P(16)|0;a=u3(a+8|0);i[114610]=0;I(2338,b|0,56160,a|0)|0;a=i[114610];i[114610]=0;if((a|0)!=1){W(b|0,56232,2339);x()}a=B()|0;A()|0;Q(b|0);E(a|0);x()}function od(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0;c=Xa-16|0;Xa=c;d=i[a>>2];e=a,f=(h=d,j=i[a+8>>2],k=Hb(c+8|0,b),g=i[i[d>>2]+32>>2],$a[g](h|0,j|0,k|0)|0)+i[a+8>>2]|0,i[e+8>>2]=f;Xa=c+16|0}function dp(a,b){var c=0,d=0,e=0;c=Xa-16|0;Xa=c;d=c,e=sd(b),i[d+12>>2]=e;i[114610]=0;I(727,a|0,c+12|0,b|0)|0;b=i[114610];i[114610]=0;if((b|0)!=1){Xa=c+16|0;return a}a=H(0)|0;A()|0;gb(a);x()}function U6(a,b){var c=0;a:{c=le(a);if((c|0)==(lb(b)|0)){i[114610]=0;a=S(344,b|0,0,-1,a|0,c|0)|0;b=i[114610];i[114610]=0;if((b|0)==1){break a}a=!a}else{a=0}return a}a=H(0)|0;A()|0;gb(a);x()}function Taa(a,b){var c=0;c=Xa-48|0;Xa=c;a:{if((b|0)==-1){Xk(a,i[Qo(c+8|0)+32>>2]);Km(a,i[Qo(c+8|0)+36>>2]);break a}if((b|0)<=0){Xk(a,0);Km(a,0);break a}b=o(b,1e3);Xk(a,b);Km(a,b)}Xa=c+48|0}function JM(a){var b=0,c=0;a:{b:{b=a&240;if((b|0)!=192){if((b|0)==240){break b}c=3;if((b|0)!=208){break a}}c=2;break a}c=1;a=a+15&255;if(a>>>0>2){break a}return 131842>>>(a<<3)&255}return c}function Iv(a,b,c){b=(b+9|0)%12|0;a=((b<<24>>24)/-10<<24>>24)+a|0;return(((((((a|0)/4|0)+c|0)+o(a,365)|0)+((a|0)/-100|0)|0)+((a|0)/400|0)|0)+((o(b,20054016)+327680>>16)/10<<16>>16)|0)+ -1|0}function Bd(a,b){var c=0;a:{c=le(b);if((c|0)==(lb(a)|0)){i[114610]=0;a=S(344,a|0,0,-1,b|0,c|0)|0;b=i[114610];i[114610]=0;if((b|0)==1){break a}a=!a}else{a=0}return a}a=H(0)|0;A()|0;gb(a);x()}function rV(a){a=a|0;var b=0,c=0;b=Xa-16|0;Xa=b;An(a);i[a>>2]=77168;i[114610]=0;I(281,a+12|0,b+8|0,b|0)|0;c=i[114610];i[114610]=0;if((c|0)!=1){Xa=b+16|0;return a|0}a=B()|0;A()|0;E(a|0);x()}function rU(a,b){a=a|0;b=b|0;var c=0,d=0;c=Xa-48|0;Xa=c;d=-1;a:{if(!LA(a,c+8|0)){break a}d=0;if(!GA(c+8|0)){break a}if(b){if(!qU(c+8|0,i[b>>2],i[b+4>>2])){break a}}d=1}Xa=c+48|0;return d|0}function mX(a){var b=0;b=j[a+74|0];g[a+74|0]=b+ -1|b;b=i[a>>2];if(b&8){i[a>>2]=b|32;return-1}i[a+4>>2]=0;i[a+8>>2]=0;b=i[a+44>>2];i[a+28>>2]=b;i[a+20>>2]=b;i[a+16>>2]=b+i[a+48>>2];return 0}function ila(a,b){a=a|0;b=b|0;var c=0;b=Xa-16|0;Xa=b;c=-1;a:{if(!fj(a,b+8|0)){break a}c=0;if(!RI(b+8|0)){break a}c=b;a=hN(a,b);if(!a){aR(c)}c=-1;if(!a){break a}c=QI(b)}Xa=b+16|0;return c|0}function fDa(a,b){var c=0,d=0;d=Xa-16|0;Xa=d;a:{if((a|0)==(b|0)){break a}c=a+8|0;if((c|0)==(b|0)){break a}while(1){a=Zz(a,c)?c:a;c=c+8|0;if((c|0)!=(b|0)){continue}break}}Xa=d+16|0;return a}function bIa(a,b){var c=0,d=0;d=Xa-16|0;Xa=d;a:{if((a|0)==(b|0)){break a}c=a+4|0;if((c|0)==(b|0)){break a}while(1){a=pd(c,a)?c:a;c=c+4|0;if((c|0)!=(b|0)){continue}break}}Xa=d+16|0;return a}function LMa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=Xa-512|0;Xa=d;c=d+8|0;e=GMa(a,c);if(!e){kT(c)}c=-1;a:{if(!e){break a}c=0;if(!qT(d+8|0)){break a}c=Le(a,b,pT(d+8|0),_a)}Xa=d+512|0;return c|0}function LC(a,b,c,d){var e=0;e=i[b+4>>2];i[a>>2]=i[b>>2];i[a+4>>2]=e;e=i[b+12>>2];i[a+8>>2]=i[b+8>>2];i[a+12>>2]=e;b=i[a+8>>2];d=i[a+12>>2]-(d+(b>>>0<c>>>0)|0)|0;i[a+8>>2]=b-c;i[a+12>>2]=d}function Kha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;c=i[b>>2];a:{if((Vg(b)|0)!=8){break a}d=c;if((j[d|0]|j[d+1|0]<<8|(j[d+2|0]<<16|j[d+3|0]<<24))!=1869112133){break a}Tb(a+4260|0,c,Vg(b));vr(a)}}function Gha(a,b,c){a=a|0;b=b|0;c=p(c);var d=0,e=0,f=p(0);d=Xa-16|0;Xa=d;e=d,f=p(p($a[i[i[a>>2]+48>>2]](a,b))+c),m[e+12>>2]=f;Id(d+12|0,p(0));$a[i[i[a>>2]+44>>2]](a,b,m[d+12>>2]);Xa=d+16|0}function FHa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=Xa-112|0;Xa=d;c=d+8|0;e=AHa(a,c);if(!e){OQ(c)}c=-1;a:{if(!e){break a}c=0;if(!RQ(d+8|0)){break a}c=Le(a,b,QQ(d+8|0),_a)}Xa=d+112|0;return c|0}function Cy(a,b){var c=0;a:{if(b){Cy(a,i[b>>2]);Cy(a,i[b+4>>2]);a=Pb(a);i[114610]=0;D(826,a|0,b+14|0);c=i[114610];i[114610]=0;if((c|0)==1){break a}wi(a,b,1)}return}a=H(0)|0;A()|0;gb(a);x()}function CD(a,b,c,d){a:{if(!a){break a}b:{switch(b+2|0){case 0:g[a|0]=c;return;case 1:h[a>>1]=c;return;case 2:case 3:i[a>>2]=c;return;case 5:break b;default:break a}}i[a>>2]=c;i[a+4>>2]=d}}function wG(a,b,c){var d=0;d=Xa-16|0;Xa=d;i[d+8>>2]=c;a:{if((a|0)==(b|0)){break a}while(1){if(U6(i[a>>2],i[d+8>>2])){break a}a=a+8|0;if((b|0)!=(a|0)){continue}break}a=b}Xa=d+16|0;return a}function t_(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a:{while(1){if((c|0)==(d|0)){break a}b:{if(l[c>>2]>127){break b}if(!(k[Mn()+(i[c>>2]<<1)>>1]&b)){break b}c=c+4|0;continue}break}d=c}return d|0}function o0(a,b,c,d){var e=0;e=Xa-16|0;Xa=e;i[e+8>>2]=b;while(1){a:{if(!Dq(a,e+8|0)){break a}if(!xj(d,8192,Gk(a))){break a}_l(a);continue}break}if(wj(a,e+8|0)){i[c>>2]=i[c>>2]|2}Xa=e+16|0}function mV(a,b){var c=0,d=0,e=0;c=Xa-16|0;Xa=c;d=c,e=sd(b),i[d+12>>2]=e;i[114610]=0;I(282,a|0,c+12|0,b|0)|0;a=i[114610];i[114610]=0;if((a|0)!=1){Xa=c+16|0;return}a=H(0)|0;A()|0;gb(a);x()}function j0(a,b,c,d){var e=0;e=Xa-16|0;Xa=e;i[e+8>>2]=b;b=6;a:{b:{if(wj(a,e+8|0)){break b}b=4;if((Rl(d,Gk(a))|0)!=37){break b}b=2;if(!wj(_l(a),e+8|0)){break a}}i[c>>2]=i[c>>2]|b}Xa=e+16|0}function Uk(a,b){var c=0,d=p(0),e=0;e=h[a+28>>1];c=a+4|0;qb(c);d=p(1);a:{if((e|0)>(b|0)){break a}if((k[a+28>>1]+qb(c)<<16)+ -65536>>16<(b|0)){break a}d=m[vb(c,b-h[a+28>>1]|0)>>2]}return d}function Jya(a,b){var c=0;tN(a,b);tN(a+12|0,b+12|0);by(a+24|0,b+24|0);h[a+52>>1]=k[b+52>>1];c=i[b+48>>2];i[a+44>>2]=i[b+44>>2];i[a+48>>2]=c;c=i[b+40>>2];i[a+36>>2]=i[b+36>>2];i[a+40>>2]=c}function H0(a,b,c,d){var e=0;e=Xa-16|0;Xa=e;i[e+8>>2]=b;while(1){a:{if(!Tn(a,e+8|0)){break a}if(!jg(d,8192,zj(a))){break a}Jk(a);continue}break}if(Fi(a,e+8|0)){i[c>>2]=i[c>>2]|2}Xa=e+16|0}function C0(a,b,c,d){var e=0;e=Xa-16|0;Xa=e;i[e+8>>2]=b;b=6;a:{b:{if(Fi(a,e+8|0)){break b}b=4;if((Sl(d,zj(a))|0)!=37){break b}b=2;if(!Fi(Jk(a),e+8|0)){break a}}i[c>>2]=i[c>>2]|b}Xa=e+16|0}function v_(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;while(1){if((b|0)!=(c|0)){a=d;if(l[b>>2]<=127){e=k[Mn()+(i[b>>2]<<1)>>1]}else{e=0}h[a>>1]=e;d=d+2|0;b=b+4|0;continue}break}return c|0}function uMa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=Xa-48|0;Xa=d;c=d+8|0;e=VLa(a,c);if(!e){MS(c)}c=-1;a:{if(!e){break a}c=0;if(!eT(d+8|0)){break a}c=Le(a,b,dT(d+8|0),_a)}Xa=d+48|0;return c|0}function NMa(a){var b=0;b=j[a+15|0];g[a+15|0]=0;g[a+60|0]=b>>>1&2|b<<1&4|(j[a+60|0]&240|b&1);g[a+80|0]=b>>>4&2|b>>>2&4|(j[a+80|0]&240|b>>>3&1);g[a+100|0]=b>>>5&4|(j[a+100|0]&224|b>>>6&1)}function Kga(a){var b=0,c=0,d=0,e=0;b=Xa-16|0;Xa=b;if(Re(a)){while(1){d=ul(a,c);e=ul(a,c);i[b+12>>2]=0;yga(d,(e+2048|0)-d>>2,b+12|0);c=c+1|0;if(c>>>0<Re(a)>>>0){continue}break}}Xa=b+16|0}function yk(a){var b=0,c=0;b=i[21329];c=a+3&-4;a=b+c|0;a:{if(a>>>0<=b>>>0?(c|0)>=1:0){break a}if(a>>>0>kNa()<<16>>>0){if(!(Ca(a|0)|0)){break a}}i[21329]=a;return b}i[114584]=48;return-1}function Wra(a){var b=0,c=0,d=0;b=Rra(a)<<24;a=0;while(1){d=b<<1|c>>>31;c=c<<1;b=(b|0)>-1;c=b?c:c^-1798752855;b=b?d:d^-1382821323;a=a+1|0;if((a|0)!=8){continue}break}a=Lra(c,b);return a}function Qda(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;f=Xa-16|0;Xa=f;i[f+8>>2]=i[a+8>>2];g=i[a+4>>2];i[f>>2]=i[a>>2];i[f+4>>2]=g;a=IG(f,b,c,d,0,0,0,0,e);Xa=f+16|0;return a|0}function Mda(a,b){var c=0,d=0,e=0;c=Xa-32|0;Xa=c;d=c,e=Iba(a,b),i[d+24>>2]=e;d=c,e=Zi(a),i[d+16>>2]=e;b=0;if(!al(c+24|0,c+16|0)){Hba(a,i[yc(c+8|0,i[c+24>>2])>>2]);b=1}Xa=c+32|0;return b}function KX(){var a=0;i[114610]=0;a=i[114610];i[114610]=0;a:{if((a|0)!=1){a=i[115917];if(!a){break a}if(!RB(a+48|0)){break a}QB(i[a+12>>2]);x()}a=H(0)|0;A()|0;gb(a);x()}QB(i[21327]);x()}function Ih(a,b){var c=0,d=0;c=j[a|0];d=j[b|0];a:{if(!c|(d|0)!=(c|0)){break a}while(1){d=j[b+1|0];c=j[a+1|0];if(!c){break a}b=b+1|0;a=a+1|0;if((c|0)==(d|0)){continue}break}}return c-d|0}function Ela(a){var b=0,c=0,d=0,e=0;d=nt(a);b=d&63;a:{if(!(d&64)){break a}c=6;while(1){e=nt(a);b=(e&127)<<c|b;if(c>>>0>24){break a}c=c+7|0;if(e&128){continue}break}}return d&128?0-b|0:b}function D5(a,b,c,d){var e=0,f=0;e=Xa-16|0;Xa=e;f=0;a:{if(!B5(a,c,e+8|0,d,e+4|0,e+12|0)){break a}f=A5(a,b,(o(i[e+12>>2],6)+a|0)+412|0,i[c>>2],i[d>>2],i[e+4>>2],c)}a=f;Xa=e+16|0;return a}function zDa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=Xa-16|0;Xa=c;i[c+8>>2]=b;d=c,e=Jb(a),i[d>>2]=e;b=Hs(c+8|0,c);b=i[a>>2]+(b<<2)|0;Ft(a,Oe(b+4|0,i[a+4>>2],b));a=Pe(b);Xa=c+16|0;return a|0}function kh(a){var b=0,c=0,d=0,e=0;d=id(a);b=d&63;a:{if(!(d&64)){break a}c=6;while(1){e=id(a);b=(e&127)<<c|b;if(c>>>0>24){break a}c=c+7|0;if(e&128){continue}break}}return d&128?0-b|0:b}function fra(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{if(j[b+30|0]!=4){break a}d=b+31|0;if(j[d|0]&4|j[d|0]&2){break a}Ic(a,8,1,0,11);return}d=a;a=b+31|0;Ic(d,j[a|0]&4?16:8,j[a|0]&2|1,0,c^1)}function RG(a,b){var c=0,d=0,e=0;if(a>p(.9999989867210388)){d=0}else{a=p(a*a);e=+a;c=ee(31415.926535897932/+b);d=Mm((32768-(w((1-c)*+p(a+a)+(c*c-1)*+p(a*a))+c*e)*32768)/(1-e))}return d}function FKa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=Xa-1968|0;Xa=d;c=d+8|0;e=CKa(a,c);if(!e){_R(c)}c=-1;a:{if(!e){break a}c=0;if(!cS(d+8|0)){break a}c=Le(a,b,1024,0)}Xa=d+1968|0;return c|0}function Coa(a,b){var c=0,d=0,e=0;if(DR(a)>>>0<b>>>0){Kc();x()}fb(a);c=b;if(178956970<c>>>0){ic(20368);x()}c=Yb(o(c,24),8);i[a>>2]=c;i[a+4>>2]=c;d=fb(a),e=c+o(b,24)|0,i[d>>2]=e;ht(a,0)}function $U(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Xa-32|0;Xa=d;i[d+24>>2]=b;Up(i[d+24>>2]);i[d+16>>2]=i[c+8>>2];b=i[c+4>>2];i[d+8>>2]=i[c>>2];i[d+12>>2]=b;_U(a,d+8|0);Xa=d+32|0;return a|0}function $5(a,b,c){var d=0,e=0,f=0;while(1){f=d;d=a+d|0;d=(f+Fv(d,c)|0)+_n(d)|0;if((d+4|0)>(b|0)){return(e|0)!=0}if(!$n(a,a+d|0)){return 0}e=e+1|0;if((e|0)!=10){continue}break}return 1}function kv(a,b,c,d,e){var f=0;f=lv(a,b,c,d);if(pd(e,d)){Gb(d,e);if(!pd(d,c)){return f+1|0}Gb(c,d);if(!pd(c,b)){return f+2|0}Gb(b,c);if(!pd(b,a)){return f+3|0}Gb(a,b);f=f+4|0}return f}function Yxa(a,b){a=a|0;b=b|0;var c=0,d=0;c=Lxa(a);a:{if(b){i[114610]=0;D(1018,a|0,b|0);d=i[114610];i[114610]=0;if((d|0)==1){break a}Jxa(a,b)}return a|0}a=B()|0;A()|0;Zx(c);E(a|0);x()}function Xu(a,b,c,d,e,f,g,h,j){var k=0;k=Xa-16|0;Xa=k;Ff(k,b,c,d,e,f,g,h,j^-2147483648);b=i[k+4>>2];i[a>>2]=i[k>>2];i[a+4>>2]=b;b=i[k+12>>2];i[a+8>>2]=i[k+8>>2];i[a+12>>2]=b;Xa=k+16|0}function Wp(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,j=0;d=i[a>>2];b=(f=d,g=jb(b),h=i[a+8>>2],j=c,e=i[i[d>>2]+28>>2],$a[e](f|0,g|0,h|0,j|0)|0);i[a+8>>2]=b+i[a+8>>2];return b|0}function y8(a,b){var c=0,d=0;c=Xa-32|0;Xa=c;i[c+24>>2]=b;b=i[c+24>>2];d=i[b+12>>2];i[c+16>>2]=i[b+8>>2];i[c+20>>2]=d;d=i[b+4>>2];i[c+8>>2]=i[b>>2];i[c+12>>2]=d;REa(a,c+8|0);Xa=c+32|0}function wA(a,b,c,d){var e=0,f=0,g=0,h=0;e=Xa-16|0;Xa=e;i[e+12>>2]=0;xc(a+12|0,d);if(b){f=uA(b)}i[a>>2]=f;c=c+f|0;i[a+8>>2]=c;i[a+4>>2]=c;g=Mb(a),h=b+f|0,i[g>>2]=h;Xa=e+16|0;return a}function u8(a,b){var c=0,d=0;c=Xa-32|0;Xa=c;i[c+24>>2]=b;b=i[c+24>>2];d=i[b+12>>2];i[c+16>>2]=i[b+8>>2];i[c+20>>2]=d;d=i[b+4>>2];i[c+8>>2]=i[b>>2];i[c+12>>2]=d;AEa(a,c+8|0);Xa=c+32|0}function u3(a){var b=0,c=0;b=Xa-16|0;Xa=b;a:{if(g[458448]&1){break a}if(!cd(458448)){break a}bd(458448)}Ac(b+8|0,1,85e3);c=i[b+12>>2];i[a>>2]=i[b+8>>2];i[a+4>>2]=c;Xa=b+16|0;return a}function aFa(a,b,c){var d=0,e=0;d=Xa-16|0;Xa=d;e=Oc(d);i[114610]=0;N(697,b|0,a|0,e|0,c|0)|0;a=i[114610];i[114610]=0;if((a|0)!=1){eb(e);Xa=d+16|0;return}a=B()|0;A()|0;eb(e);E(a|0);x()}function U5(a){var b=0,c=0,d=0;c=a+72|0;while(1){a=1;while(1){b=(a<<2)+c|0;m[b>>2]=-m[b>>2];b=a>>>0<16;a=a+2|0;if(b){continue}break}c=c+144|0;a=d>>>0<30;d=d+2|0;if(a){continue}break}}function Iu(a,b,c,d){var e=0,f=0,g=0,h=0;e=Xa-16|0;Xa=e;i[e+12>>2]=0;xc(a+12|0,d);if(b){f=Ii(b)}i[a>>2]=f;c=c+f|0;i[a+8>>2]=c;i[a+4>>2]=c;g=Mb(a),h=b+f|0,i[g>>2]=h;Xa=e+16|0;return a}function lma(a,b,c,d){var e=0,f=0;kma(a,b,d);if((b|0)!=(c|0)){f=b-a>>1;e=b;while(1){if(lo(d,k[e>>1],k[a>>1])){eJ(e,a);Qw(a,d,f,a)}e=e+2|0;if((e|0)!=(c|0)){continue}break}}jma(a,b,d)}function jZ(){var a=0;a:{if(g[463032]&1){break a}if(!cd(463032)){break a}a=463008;while(1){a=Ab(a)+12|0;if((a|0)!=463032){continue}break}bd(463032)}tc(463008,68200);tc(463020,68203)}function fna(a){a=a|0;var b=0;b=1;a=i[a+480180>>2];a:{b:{if((a|0)<=16383){if((a|0)==4|(a|0)!=32){break b}break a}if((a|0)==16384){break b}if((a|0)==16777216){break a}}b=2}return b|0}function fZ(){var a=0;a:{if(g[463064]&1){break a}if(!cd(463064)){break a}a=463040;while(1){a=Ke(a)+12|0;if((a|0)!=463064){continue}break}bd(463064)}Gc(463040,68208);Gc(463052,68220)}function cha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=Xa-16|0;Xa=c;a=Ji(a);d=1;a:{if(!a){break a}d=(f=a,g=$g(c+8|0,b),e=i[i[a>>2]+72>>2],$a[e](f|0,g|0)|0)}a=d;Xa=c+16|0;return a|0}function YKa(a,b){var c=0,d=0,e=0;c=Xa-16|0;Xa=c;d=wb(a,120);a:{if(d){e=Xa-16|0;Xa=e;Ob(c+8|0,b,120);Xa=e+16|0;od(a,c+8|0);break a}a=Xa-16|0;Xa=a;GKa(b);Xa=a+16|0}Xa=c+16|0;return d}function Pta(a,b){var c=0;a:{if(j[a+4|0]){c=i[a>>2];i[114610]=0;D(826,c|0,b+14|0);c=i[114610];i[114610]=0;if((c|0)==1){break a}}if(b){wi(i[a>>2],b,1)}return}a=H(0)|0;A()|0;gb(a);x()}function MG(a,b,c,d,e){a=a|0;b=b|0;c=+c;d=d|0;e=e|0;var f=0,g=0;f=Xa-16|0;Xa=f;i[f+8>>2]=i[a+8>>2];g=i[a+4>>2];i[f>>2]=i[a>>2];i[f+4>>2]=g;c=LG(f,b,c,d,e,0,0,0,0);Xa=f+16|0;return+c}function Kxa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(rxa()>>>0<b>>>0){Kc();x()}c=b;if(c>>>0>=477218589){ic(17372);x()}c=Yb(o(c,9),1);i[a>>2]=c;i[a+4>>2]=c;d=fb(a),e=c+o(b,9)|0,i[d>>2]=e}function KDa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Xa-16|0;Xa=d;i[d+12>>2]=c;c=0;a=$a[i[i[a>>2]+24>>2]](a)|0;if(a>>>0>b>>>0){i[d+8>>2]=a-b;c=i[rb(d+12|0,d+8|0)>>2]}Xa=d+16|0;return c|0}function q8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;if((b|0)!=(c|0)){a=i[d>>2];while(1){i[a>>2]=i[b>>2];Kf(a+4|0,b+4|0);a=i[d>>2]+16|0;i[d>>2]=a;b=b+16|0;if((c|0)!=(b|0)){continue}break}}}function eV(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=Xa-32|0;Xa=e;i[e+24>>2]=d;i[e+28>>2]=c;dV(e+8|0,b,e+28|0,e+24|0);St(e+16|0,e+8|0);Dl(a,e+16|0);hb(e+16|0);hb(e+8|0);Xa=e+32|0}function XGa(a,b){a=a|0;b=b|0;var c=0;c=Xa-16|0;Xa=c;ts(c,b);i[114610]=0;G(650,a|0,4,c|0);a=i[114610];i[114610]=0;if((a|0)!=1){eb(c);Xa=c+16|0;return}a=B()|0;A()|0;eb(c);E(a|0);x()}function QI(a){var b=0;a:{if((j[a|0]|j[a+1|0]<<8|(j[a+2|0]<<16|j[a+3|0]<<24))!=1179012417){b=0;if((j[a|0]|j[a+1|0]<<8|(j[a+2|0]<<16|j[a+3|0]<<24))!=538987841){break a}}b=1}return b}function MB(a,b,c,d){var e=0,f=0,g=0,h=0;f=i[a+4>>2];a=i[a>>2];g=a;h=b;e=0;a:{if(!c){break a}b=f>>8;e=b;if(!(f&1)){break a}e=i[b+i[c>>2]>>2]}$a[i[i[a>>2]+28>>2]](g,h,e+c|0,f&2?d:2)}function GGa(a,b){a=a|0;b=b|0;var c=0;c=Xa-32|0;Xa=c;i[c+24>>2]=0;i[c+28>>2]=0;i[c+16>>2]=0;i[c+20>>2]=0;i[c+8>>2]=0;i[c+12>>2]=0;i[c>>2]=0;i[c+4>>2]=0;rQ(b,c,32);qQ(a,c);Xa=c+32|0}function GAa(a,b){var c=0,d=0;c=Xa-16|0;Xa=c;d=Xa-16|0;Xa=d;Ob(c+8|0,b,1030);Xa=d+16|0;b=nb(c+8|0);d=Vb(a,Hb(c,c+8|0));if((b|0)==(d|0)){Ib(a,nb(c+8|0))}Xa=c+16|0;return(b|0)==(d|0)}function BI(a,b){var c=0,d=0;d=a;c=b;if((a|0)!=(b|0)){kka(d,i[c>>2],i[c+4>>2])}i[a+12>>2]=i[b+12>>2];i[a+16>>2]=i[b+16>>2];i[a+20>>2]=i[b+20>>2];AI(a+24|0,b+24|0);vi(a+36|0,b+36|0)}function yHa(a,b){var c=0,d=0;c=Xa-16|0;Xa=c;d=Xa-16|0;Xa=d;Ob(c+8|0,b,771);Xa=d+16|0;b=nb(c+8|0);d=Vb(a,Hb(c,c+8|0));if((b|0)==(d|0)){Ib(a,nb(c+8|0))}Xa=c+16|0;return(b|0)==(d|0)}function xha(a,b){var c=0,d=0;c=Xa-16|0;Xa=c;i[c+12>>2]=b;d=sha(a);if(d>>>0>=b>>>0){a=Fj(a);if(a>>>0<d>>>1>>>0){i[c+8>>2]=a<<1;d=i[Jc(c+8|0,c+12|0)>>2]}Xa=c+16|0;return d}Kc();x()}function s5(a){a=a|0;var b=0,c=0;b=Xa-16|0;Xa=b;Li(b,0,a);i[114610]=0;a=F(202,b|0)|0;c=i[114610];i[114610]=0;if((c|0)!=1){eb(b);Xa=b+16|0;return a|0}a=B()|0;A()|0;eb(b);E(a|0);x()}function nEa(a,b){var c=0,d=0;c=Xa-16|0;Xa=c;i[c+12>>2]=b;d=gEa(a);if(d>>>0>=b>>>0){a=jl(a);if(a>>>0<d>>>1>>>0){i[c+8>>2]=a<<1;d=i[Jc(c+8|0,c+12|0)>>2]}Xa=c+16|0;return d}Kc();x()}function i0(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;c=Xa-128|0;Xa=c;i[c+12>>2]=c+116;aD(a+8|0,c+16|0,c+12|0,e,f,g);a=CY(c+16|0,i[c+12>>2],b);Xa=c+128|0;return a|0}function h0(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;c=Xa-416|0;Xa=c;i[c+12>>2]=c+416;g0(a+8|0,c+16|0,c+12|0,e,f,g);a=BY(c+16|0,i[c+12>>2],b);Xa=c+416|0;return a|0}function gHa(a,b){var c=0,d=0;c=Xa-16|0;Xa=c;d=Xa-16|0;Xa=d;Ob(c+8|0,b,384);Xa=d+16|0;b=nb(c+8|0);d=Vb(a,Hb(c,c+8|0));if((b|0)==(d|0)){Ib(a,nb(c+8|0))}Xa=c+16|0;return(b|0)==(d|0)}function bw(a){a=a|0;var b=0;a:{if(!a){a=P(8)|0;i[114610]=0;F(2028,a|0)|0;b=i[114610];i[114610]=0;if((b|0)!=1){break a}b=B()|0;A()|0;Q(a|0);E(b|0);x()}return}W(a|0,83464,2017);x()}function bDa(a,b){var c=0,d=0;c=Xa-16|0;Xa=c;d=Xa-16|0;Xa=d;Ob(c+8|0,b,284);Xa=d+16|0;b=nb(c+8|0);d=Vb(a,Hb(c,c+8|0));if((b|0)==(d|0)){Ib(a,nb(c+8|0))}Xa=c+16|0;return(b|0)==(d|0)}function _Q(a){var b=0;b=Xa-16|0;Xa=b;g[a|0]=0;g[a+1|0]=0;g[a+2|0]=0;g[a+3|0]=0;g[a+4|0]=0;g[a+5|0]=0;g[a+6|0]=0;g[a+7|0]=0;g[a+8|0]=0;g[a+9|0]=0;g[a+10|0]=0;g[a+11|0]=0;Xa=b+16|0}function WBa(a,b){var c=0,d=0;c=Xa-16|0;Xa=c;d=Xa-16|0;Xa=d;Ob(c+8|0,b,422);Xa=d+16|0;b=nb(c+8|0);d=Vb(a,Hb(c,c+8|0));if((b|0)==(d|0)){Ib(a,nb(c+8|0))}Xa=c+16|0;return(b|0)==(d|0)}function VJa(a,b){var c=0,d=0;c=Xa-16|0;Xa=c;d=Xa-16|0;Xa=d;Ob(c+8|0,b,136);Xa=d+16|0;b=nb(c+8|0);d=Vb(a,Hb(c,c+8|0));if((b|0)==(d|0)){Ib(a,nb(c+8|0))}Xa=c+16|0;return(b|0)==(d|0)}function TBa(a,b){var c=0,d=0;c=Xa-16|0;Xa=c;d=Xa-16|0;Xa=d;Ob(c+8|0,b,826);Xa=d+16|0;b=nb(c+8|0);d=Vb(a,Hb(c,c+8|0));if((b|0)==(d|0)){Ib(a,nb(c+8|0))}Xa=c+16|0;return(b|0)==(d|0)}function Rya(a,b){var c=0,d=0;c=Xa-16|0;Xa=c;i[c+12>>2]=b;d=Lya(a);if(d>>>0>=b>>>0){a=Tm(a);if(a>>>0<d>>>1>>>0){i[c+8>>2]=a<<1;d=i[Jc(c+8|0,c+12|0)>>2]}Xa=c+16|0;return d}Kc();x()}function GY(a,b){var c=0;a:{while(1){if(i[a+8>>2]==(b|0)){break a}i[a+8>>2]=i[a+8>>2]+ -4;i[114610]=0;c=i[114610];i[114610]=0;if((c|0)!=1){continue}break}a=H(0)|0;A()|0;gb(a);x()}}function GG(a){a=a|0;var b=0;a:{if(!a){a=P(8)|0;i[114610]=0;F(2016,a|0)|0;b=i[114610];i[114610]=0;if((b|0)!=1){break a}b=B()|0;A()|0;Q(a|0);E(b|0);x()}return}W(a|0,83452,2017);x()}function EAa(a,b){var c=0,d=0;c=Xa-16|0;Xa=c;d=Xa-16|0;Xa=d;Ob(c+8|0,b,274);Xa=d+16|0;b=nb(c+8|0);d=Vb(a,Hb(c,c+8|0));if((b|0)==(d|0)){Ib(a,nb(c+8|0))}Xa=c+16|0;return(b|0)==(d|0)}function Dka(a,b){var c=0,d=0;c=Xa-16|0;Xa=c;d=Xa-16|0;Xa=d;Ob(c+8|0,b,225);Xa=d+16|0;b=nb(c+8|0);d=Vb(a,Hb(c,c+8|0));if((b|0)==(d|0)){Ib(a,nb(c+8|0))}Xa=c+16|0;return(b|0)==(d|0)}function Cka(a,b){var c=0,d=0;c=Xa-16|0;Xa=c;d=Xa-16|0;Xa=d;Ob(c+8|0,b,326);Xa=d+16|0;b=nb(c+8|0);d=Vb(a,Hb(c,c+8|0));if((b|0)==(d|0)){Ib(a,nb(c+8|0))}Xa=c+16|0;return(b|0)==(d|0)}function CAa(a,b){var c=0,d=0;c=Xa-16|0;Xa=c;d=Xa-16|0;Xa=d;Ob(c+8|0,b,106);Xa=d+16|0;b=nb(c+8|0);d=Vb(a,Hb(c,c+8|0));if((b|0)==(d|0)){Ib(a,nb(c+8|0))}Xa=c+16|0;return(b|0)==(d|0)}function AFa(a,b){var c=0,d=0;c=Xa-16|0;Xa=c;d=Xa-16|0;Xa=d;Ob(c+8|0,b,554);Xa=d+16|0;b=nb(c+8|0);d=Vb(a,Hb(c,c+8|0));if((b|0)==(d|0)){Ib(a,nb(c+8|0))}Xa=c+16|0;return(b|0)==(d|0)}function xAa(a,b){var c=0,d=0;c=Xa-16|0;Xa=c;d=Xa-16|0;Xa=d;Ob(c+8|0,b,26);Xa=d+16|0;b=nb(c+8|0);d=Vb(a,Hb(c,c+8|0));if((b|0)==(d|0)){Ib(a,nb(c+8|0))}Xa=c+16|0;return(b|0)==(d|0)}function u5(){var a=0,b=0,c=0;while(1){b=a<<24;c=0;while(1){b=b>>31&79764919^b<<1;c=c+1|0;if((c|0)!=8){continue}break}i[(a<<2)+457312>>2]=b;a=a+1|0;if((a|0)!=256){continue}break}}function sAa(a,b){var c=0,d=0;c=Xa-16|0;Xa=c;i[c+12>>2]=b;d=Xt(a);if(d>>>0>=b>>>0){a=ti(a);if(a>>>0<d>>>1>>>0){i[c+8>>2]=a<<1;d=i[Jc(c+8|0,c+12|0)>>2]}Xa=c+16|0;return d}Kc();x()}function rHa(a,b){var c=0,d=0;c=Xa-16|0;Xa=c;d=Xa-16|0;Xa=d;Ob(c+8|0,b,62);Xa=d+16|0;b=nb(c+8|0);d=Vb(a,Hb(c,c+8|0));if((b|0)==(d|0)){Ib(a,nb(c+8|0))}Xa=c+16|0;return(b|0)==(d|0)}function oy(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,j=0;c=Xa-16|0;Xa=c;d=a,e=(g=a,h=i[a+12>>2],j=Hb(c+8|0,b),f=i[i[a>>2]+32>>2],$a[f](g|0,h|0,j|0)|0)+i[a+12>>2]|0,i[d+12>>2]=e;Xa=c+16|0}function jxa(a,b){var c=0;c=ws(a);g[a+16|0]=0;h[a+14>>1]=0;h[a+12>>1]=b;i[114610]=0;G(1030,c|0,b|0,0);b=i[114610];i[114610]=0;if((b|0)!=1){return a}a=B()|0;A()|0;Td(c);E(a|0);x()}function hS(a){var b=0;b=Xa-16|0;Xa=b;g[a|0]=0;g[a+1|0]=0;g[a+2|0]=0;g[a+3|0]=0;g[a+4|0]=0;g[a+5|0]=0;g[a+6|0]=0;g[a+7|0]=0;g[a+7|0]=0;g[a+8|0]=0;g[a+9|0]=0;g[a+10|0]=0;Xa=b+16|0}function fR(a,b){var c=0,d=0;c=Xa-16|0;Xa=c;i[c+12>>2]=b;d=JIa(a);if(d>>>0>=b>>>0){a=nl(a);if(a>>>0<d>>>1>>>0){i[c+8>>2]=a<<1;d=i[Jc(c+8|0,c+12|0)>>2]}Xa=c+16|0;return d}Kc();x()}function d6(a,b){var c=0,d=0,e=0,f=0,g=0;d=i[b+8>>2]>>>3|0;e=i[b+4>>2]+7>>>3|0;c=d-e|0;f=(c|0)>511;g=f?511:c;if((c|0)>=1){yi(a+6156|0,((f?d+ -511|0:e)+b|0)+12|0,g)}i[a+6144>>2]=g}function TLa(a,b){var c=0,d=0;c=Xa-16|0;Xa=c;d=Xa-16|0;Xa=d;Ob(c+8|0,b,37);Xa=d+16|0;b=nb(c+8|0);d=Vb(a,Hb(c,c+8|0));if((b|0)==(d|0)){Ib(a,nb(c+8|0))}Xa=c+16|0;return(b|0)==(d|0)}function PHa(a,b){var c=0,d=0;c=Xa-16|0;Xa=c;d=Xa-16|0;Xa=d;Ob(c+8|0,b,15);Xa=d+16|0;b=nb(c+8|0);d=Vb(a,Hb(c,c+8|0));if((b|0)==(d|0)){Ib(a,nb(c+8|0))}Xa=c+16|0;return(b|0)==(d|0)}function ODa(a,b){var c=0,d=0;c=Xa-16|0;Xa=c;d=Xa-16|0;Xa=d;Ob(c+8|0,b,91);Xa=d+16|0;b=nb(c+8|0);d=Vb(a,Hb(c,c+8|0));if((b|0)==(d|0)){Ib(a,nb(c+8|0))}Xa=c+16|0;return(b|0)==(d|0)}function NKa(a,b){var c=0,d=0;c=Xa-16|0;Xa=c;d=Xa-16|0;Xa=d;Ob(c+8|0,b,17);Xa=d+16|0;b=nb(c+8|0);d=Vb(a,Hb(c,c+8|0));if((b|0)==(d|0)){Ib(a,nb(c+8|0))}Xa=c+16|0;return(b|0)==(d|0)}function NHa(a,b){var c=0,d=0;c=Xa-16|0;Xa=c;d=Xa-16|0;Xa=d;Ob(c+8|0,b,34);Xa=d+16|0;b=nb(c+8|0);d=Vb(a,Hb(c,c+8|0));if((b|0)==(d|0)){Ib(a,nb(c+8|0))}Xa=c+16|0;return(b|0)==(d|0)}function LCa(a,b){var c=0,d=0;c=Xa-16|0;Xa=c;d=Xa-16|0;Xa=d;Ob(c+8|0,b,42);Xa=d+16|0;b=nb(c+8|0);d=Vb(a,Hb(c,c+8|0));if((b|0)==(d|0)){Ib(a,nb(c+8|0))}Xa=c+16|0;return(b|0)==(d|0)}function KJa(a,b){var c=0,d=0;c=Xa-16|0;Xa=c;d=Xa-16|0;Xa=d;Ob(c+8|0,b,50);Xa=d+16|0;b=nb(c+8|0);d=Vb(a,Hb(c,c+8|0));if((b|0)==(d|0)){Ib(a,nb(c+8|0))}Xa=c+16|0;return(b|0)==(d|0)}function Gza(a,b){var c=0,d=0;c=Xa-16|0;Xa=c;d=Xa-16|0;Xa=d;Ob(c+8|0,b,71);Xa=d+16|0;b=nb(c+8|0);d=Vb(a,Hb(c,c+8|0));if((b|0)==(d|0)){Ib(a,nb(c+8|0))}Xa=c+16|0;return(b|0)==(d|0)}function Eka(a,b){var c=0,d=0;c=Xa-16|0;Xa=c;d=Xa-16|0;Xa=d;Ob(c+8|0,b,73);Xa=d+16|0;b=nb(c+8|0);d=Vb(a,Hb(c,c+8|0));if((b|0)==(d|0)){Ib(a,nb(c+8|0))}Xa=c+16|0;return(b|0)==(d|0)}function DMa(a,b){var c=0,d=0;c=Xa-16|0;Xa=c;d=Xa-16|0;Xa=d;Ob(c+8|0,b,25);Xa=d+16|0;b=nb(c+8|0);d=Vb(a,Hb(c,c+8|0));if((b|0)==(d|0)){Ib(a,nb(c+8|0))}Xa=c+16|0;return(b|0)==(d|0)}function Bka(a,b){var c=0,d=0;c=Xa-16|0;Xa=c;d=Xa-16|0;Xa=d;Ob(c+8|0,b,60);Xa=d+16|0;b=nb(c+8|0);d=Vb(a,Hb(c,c+8|0));if((b|0)==(d|0)){Ib(a,nb(c+8|0))}Xa=c+16|0;return(b|0)==(d|0)}function AAa(a,b){var c=0,d=0;c=Xa-16|0;Xa=c;d=Xa-16|0;Xa=d;Ob(c+8|0,b,72);Xa=d+16|0;b=nb(c+8|0);d=Vb(a,Hb(c,c+8|0));if((b|0)==(d|0)){Ib(a,nb(c+8|0))}Xa=c+16|0;return(b|0)==(d|0)}function z3(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=Xa-16|0;Xa=d;e=i[c+4>>2];c=i[c>>2];i[d>>2]=c;i[d+4>>2]=e;i[d+8>>2]=c;i[d+12>>2]=e;UB(a,d,b);i[a>>2]=56132;Xa=d+16|0;return a|0}function vI(a,b){var c=0,d=0;c=Xa-16|0;Xa=c;i[c+12>>2]=b;d=rI(a);if(d>>>0>=b>>>0){a=Mi(a);if(a>>>0<d>>>1>>>0){i[c+8>>2]=a<<1;d=i[Jc(c+8|0,c+12|0)>>2]}Xa=c+16|0;return d}Kc();x()}function u_(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;while(1){a:{if((c|0)!=(d|0)){if(l[c>>2]>127){break a}if(!(k[Mn()+(i[c>>2]<<1)>>1]&b)){break a}}else{c=d}return c|0}c=c+4|0;continue}}function qi(a,b){var c=0,d=0;c=Xa-16|0;Xa=c;i[c+12>>2]=b;d=sA(a);if(d>>>0>=b>>>0){a=zf(a);if(a>>>0<d>>>1>>>0){i[c+8>>2]=a<<1;d=i[Jc(c+8|0,c+12|0)>>2]}Xa=c+16|0;return d}Kc();x()}function pl(a,b){var c=0,d=0;c=Xa-16|0;Xa=c;i[c+12>>2]=b;d=Jz(a);if(d>>>0>=b>>>0){a=xf(a);if(a>>>0<d>>>1>>>0){i[c+8>>2]=a<<1;d=i[Jc(c+8|0,c+12|0)>>2]}Xa=c+16|0;return d}Kc();x()}function oBa(a,b){var c=0,d=0;c=Xa-16|0;Xa=c;if(oe(a)){Uf(a,i[a>>2],Jj(a))}i[a+8>>2]=i[b+8>>2];d=i[b+4>>2];i[a>>2]=i[b>>2];i[a+4>>2]=d;Te(b,0);g[c+15|0]=0;Rd(b,c+15|0);Xa=c+16|0}function nya(a){var b=0,c=0;b=Xa-16|0;Xa=b;if(hN(a,b+8|0)){a=b+8|0;a=j[a|0]|j[a+1|0]<<8|(j[a+2|0]<<16|j[a+3|0]<<24);c=a<<24|a<<8&16711680|(a>>>8&65280|a>>>24)}Xa=b+16|0;return c}function jja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=Xa-16|0;Xa=d;e=k[a+28>>1];h[d+8>>1]=e;f=d,g=(qb(a+4|0)+e|0)+ -1|0,h[f+10>>1]=g;a=jI(a,b,c,d+8|0);Xa=d+16|0;return a|0}function jV(a,b){var c=0,d=0;c=Xa-16|0;Xa=c;d=Xa-16|0;Xa=d;Ob(c+8|0,b,20);Xa=d+16|0;b=nb(c+8|0);d=Vb(a,Hb(c,c+8|0));if((b|0)==(d|0)){Ib(a,nb(c+8|0))}Xa=c+16|0;return(b|0)==(d|0)}function ge(a,b){var c=0,d=0;c=Xa-16|0;Xa=c;i[c+12>>2]=b;d=Hm(a);if(d>>>0>=b>>>0){a=gd(a);if(a>>>0<d>>>1>>>0){i[c+8>>2]=a<<1;d=i[Jc(c+8|0,c+12|0)>>2]}Xa=c+16|0;return d}Kc();x()}function ek(a,b){var c=0,d=0;c=Xa-16|0;Xa=c;i[c+12>>2]=b;d=DR(a);if(d>>>0>=b>>>0){a=Be(a);if(a>>>0<d>>>1>>>0){i[c+8>>2]=a<<1;d=i[Jc(c+8|0,c+12|0)>>2]}Xa=c+16|0;return d}Kc();x()}function bq(a,b){var c=0,d=0;c=Xa-16|0;Xa=c;i[c+12>>2]=b;d=aq(a);if(d>>>0>=b>>>0){a=xh(a);if(a>>>0<d>>>1>>>0){i[c+8>>2]=a<<1;d=i[Jc(c+8|0,c+12|0)>>2]}Xa=c+16|0;return d}Kc();x()}function WN(a){var b=0;a:{if((j[a|0]|j[a+1|0]<<8|(j[a+2|0]<<16|j[a+3|0]<<24))!=441273424|j[a+5|0]!=16){break a}b=a+54|0;if(!j[b|0]|j[b|0]>32){break a}return j[a+4|0]>95}return 0}function U0(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=Xa-16|0;Xa=g;i[g+8>>2]=624576549;i[g+12>>2]=1394948685;a=Ci(a,b,c,d,e,f,g+8|0,g+16|0);Xa=g+16|0;return a|0}function Ny(a,b){var c=0,d=0;c=Xa-16|0;Xa=c;i[c+12>>2]=b;d=rz(a);if(d>>>0>=b>>>0){a=hi(a);if(a>>>0<d>>>1>>>0){i[c+8>>2]=a<<1;d=i[Jc(c+8|0,c+12|0)>>2]}Xa=c+16|0;return d}Kc();x()}function Lw(a,b){a:{if(b){Lw(a,i[b>>2]);Lw(a,i[b+4>>2]);a=Pb(a);i[114610]=0;D(1525,a|0,b+16|0);a=i[114610];i[114610]=0;if((a|0)==1){break a}YI(b)}return}a=H(0)|0;A()|0;gb(a);x()}function KY(a,b){var c=0,d=0;c=Xa-16|0;Xa=c;i[c+12>>2]=b;d=kC(a);if(d>>>0>=b>>>0){a=Bk(a);if(a>>>0<d>>>1>>>0){i[c+8>>2]=a<<1;d=i[Jc(c+8|0,c+12|0)>>2]}Xa=c+16|0;return d}Kc();x()}function Cj(a,b,c){var d=0;d=Xa-16|0;Xa=d;i[d+8>>2]=c;a:{if((a|0)==(b|0)){break a}while(1){if(L8(d+8|0,a)){break a}a=a+8|0;if((b|0)!=(a|0)){continue}break}a=b}Xa=d+16|0;return a}function Bl(a,b){var c=0,d=0;c=Xa-16|0;Xa=c;i[c+12>>2]=b;d=ZA(a);if(d>>>0>=b>>>0){a=Yg(a);if(a>>>0<d>>>1>>>0){i[c+8>>2]=a<<1;d=i[Jc(c+8|0,c+12|0)>>2]}Xa=c+16|0;return d}Kc();x()}function $l(a,b){var c=0,d=0;c=Xa-16|0;Xa=c;i[c+12>>2]=b;d=WD(a);if(d>>>0>=b>>>0){a=Rf(a);if(a>>>0<d>>>1>>>0){i[c+8>>2]=a<<1;d=i[Jc(c+8|0,c+12|0)>>2]}Xa=c+16|0;return d}Kc();x()}function uta(a,b){a=a|0;b=b|0;var c=0;tta(a);c=a;g[a+16|0]=0;i[a+12>>2]=b;i[114610]=0;L(1175,a|0);b=i[114610];i[114610]=0;if((b|0)!=1){return a|0}a=B()|0;A()|0;es(c);E(a|0);x()}function qHa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=Xa-576|0;Xa=d;c=d;e=iHa(a,d);if(!e){DQ(c)}c=-1;a:{if(!e){break a}c=0;if(!GQ(d)){break a}c=Le(a,b,FQ(d),_a)}Xa=d+576|0;return c|0}function jFa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Xa-16|0;Xa=d;i[d+12>>2]=c;Uy(a,b,c);c=0;a=i[a+16>>2];if(a>>>0>b>>>0){i[d+8>>2]=a-b;c=i[rb(d+8|0,d+12|0)>>2]}Xa=d+16|0;return c|0}function d4(a,b){a=a|0;b=b|0;i[a+4>>2]=b;g[a|0]=0;if(hf(i[i[b>>2]+ -12>>2]+b|0)){if(i[(i[i[b>>2]+ -12>>2]+b|0)+72>>2]){Eq(i[(i[i[b>>2]+ -12>>2]+b|0)+72>>2])}g[a|0]=1}return a|0}function af(a,b){a=a|0;b=b|0;var c=0,d=0;c=Xa-16|0;Xa=c;h[c+14>>1]=0;a=xk(a,c+14|0,2);h[c+12>>1]=k[c+14>>1];d=b;b=c+12|0;h[d>>1]=j[b|0]|j[b+1|0]<<8;Xa=c+16|0;return!_a&(a|0)==2}function aY(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Xa-16|0;Xa=d;$a[i[i[a>>2]+12>>2]](d+8|0,a,b);a=d+8|0;if(ae(i[a+4>>2],i[c+4>>2])){a=i[a>>2]==i[c>>2]}else{a=0}Xa=d+16|0;return a|0}function _u(a,b){var c=0;c=QD(a+4|0);i[a>>2]=56004;i[c>>2]=56024;i[114610]=0;D(2389,i[13998]+a|0,b|0);a=i[114610];i[114610]=0;if((a|0)!=1){return}a=B()|0;A()|0;kg(c);E(a|0);x()}function Zza(a,b,c,d){var e=0;e=Xa-48|0;Xa=e;a:{if(i[b+4>>2]==i[d+4>>2]){Yza(a,td(e+40|0,b),td(e+32|0,c),td(e+24|0,d));break a}Xza(a,td(e+16|0,b),td(e+8|0,c),td(e,d))}Xa=e+48|0}function Y4(a,b){var c=0,d=0,e=0,f=0;if((a|0)>=8){c=a>>3;c=(c|0)>1?c:1;d=36-Pk(a)|0;a=0;while(1){e=(a<<1)+b|0,f=Mk(a)>>>d<<2,h[e>>1]=f;a=a+1|0;if((c|0)!=(a|0)){continue}break}}}function N3(a,b){a=a|0;b=b|0;i[a+4>>2]=b;g[a|0]=0;if(hf(i[i[b>>2]+ -12>>2]+b|0)){if(i[(i[i[b>>2]+ -12>>2]+b|0)+72>>2]){hE(i[(i[i[b>>2]+ -12>>2]+b|0)+72>>2])}g[a|0]=1}return a|0}function Eya(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=Xa-608|0;Xa=d;c=d;e=zya(a,d);if(!e){oN(c)}c=-1;a:{if(!e){break a}c=0;if(!qN(d)){break a}c=Le(a,b,pN(d),_a)}Xa=d+608|0;return c|0}function Cu(a,b){var c=0,d=0;c=Xa-16|0;Xa=c;h[b>>1]=0;g[c+15|0]=0;Bg(a,c+15|0);d=j[c+15|0];h[b>>1]=d>>>1;if(d&1){g[c+15|0]=0;Bg(a,c+15|0);h[b>>1]=k[b>>1]|j[c+15|0]<<7}Xa=c+16|0}function Bz(a){var b=0,c=0;b=Xa-16|0;Xa=b;if(Rp(a,b+8|0)){a=b+8|0;a=j[a|0]|j[a+1|0]<<8|(j[a+2|0]<<16|j[a+3|0]<<24);c=a<<24|a<<8&16711680|(a>>>8&65280|a>>>24)}Xa=b+16|0;return c}function BCa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=Xa-16|0;Xa=d;e=TO(d,b);b=Xa-16|0;Xa=b;XBa(d+8|0,TO(b,e));Xa=b+16|0;bu(a,d+8|0);i[a+12>>2]=c;i[a+8>>2]=0;Xa=d+16|0;return a|0}function $u(a,b){var c=0;c=jr(a+4|0);i[a>>2]=55956;i[c>>2]=55976;i[114610]=0;D(2388,i[13986]+a|0,b|0);a=i[114610];i[114610]=0;if((a|0)!=1){return}a=B()|0;A()|0;kg(c);E(a|0);x()}function $Ga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=Xa-192|0;Xa=d;c=d;e=zFa(a,d);if(!e){ZP(c)}c=-1;a:{if(!e){break a}c=0;if(!AQ(d)){break a}c=Le(a,b,zQ(d),_a)}Xa=d+192|0;return c|0}function uI(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=65535;a:{if(!pg(a,b)){break a}c=ww(a,i[se(a,b)+12>>2],c);d=65535;if((c|0)==65535){break a}b=se(a,b);BI(se(a,c),b);d=c}return d|0}function _na(a){var b=0,c=0;b=Xa-16|0;Xa=b;i[114610]=0;i[b+12>>2]=0;I(1400,a|0,b+12|0,b+8|0)|0;c=i[114610];i[114610]=0;if((c|0)!=1){Xa=b+16|0;return a}a=H(0)|0;A()|0;gb(a);x()}function P9(a,b){var c=0,d=0,e=0,f=0;c=W6(a,fb(b));i[a>>2]=i[b>>2];i[a+4>>2]=i[b+4>>2];d=i[fb(b)>>2];e=fb(c),f=d,i[e>>2]=f;e=fb(b),f=0,i[e>>2]=f;i[b>>2]=0;i[b+4>>2]=0;return a}function M$(a,b){var c=0,d=0;c=Xa-16|0;Xa=c;if(oe(a)){Ln(i[a>>2],Jj(a))}i[a+8>>2]=i[b+8>>2];d=i[b+4>>2];i[a>>2]=i[b>>2];i[a+4>>2]=d;Te(b,0);i[c+12>>2]=0;ye(b,c+12|0);Xa=c+16|0}function Csa(a){var b=0,c=0;b=Xa-16|0;Xa=b;i[114610]=0;i[b+12>>2]=0;I(1199,a|0,b+12|0,b+8|0)|0;c=i[114610];i[114610]=0;if((c|0)!=1){Xa=b+16|0;return a}a=H(0)|0;A()|0;gb(a);x()}function A7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=Xa-16|0;Xa=e;OF(b,c,d,m[a+24>>2]);IF(a,b,c,d);i[e+8>>2]=i[a+20>>2];b=i[a+16>>2];i[e>>2]=i[a+12>>2];i[e+4>>2]=b;Xa=e+16|0}function $na(a){var b=0,c=0;b=Xa-16|0;Xa=b;i[114610]=0;i[b+12>>2]=0;I(1399,a|0,b+12|0,b+8|0)|0;c=i[114610];i[114610]=0;if((c|0)!=1){Xa=b+16|0;return a}a=H(0)|0;A()|0;gb(a);x()}function rba(a){var b=0,c=0;b=Xa-32|0;Xa=b;vk(b);c=xg(b);i[114610]=0;G(9,a|0,0,c|0);a=i[114610];i[114610]=0;if((a|0)!=1){Ie(b);Xa=b+32|0;return}a=B()|0;A()|0;Ie(b);E(a|0);x()}function kG(a){var b=0,c=0;b=Xa-16|0;Xa=b;i[114610]=0;i[b+12>>2]=0;I(2169,a|0,b+12|0,b+8|0)|0;c=i[114610];i[114610]=0;if((c|0)!=1){Xa=b+16|0;return a}a=H(0)|0;A()|0;gb(a);x()}function jG(a){var b=0,c=0;b=Xa-16|0;Xa=b;i[114610]=0;i[b+12>>2]=0;I(2170,a|0,b+12|0,b+8|0)|0;c=i[114610];i[114610]=0;if((c|0)!=1){Xa=b+16|0;return a}a=H(0)|0;A()|0;gb(a);x()}function iG(a){var b=0,c=0;b=Xa-16|0;Xa=b;i[114610]=0;i[b+12>>2]=0;I(2171,a|0,b+12|0,b+8|0)|0;c=i[114610];i[114610]=0;if((c|0)!=1){Xa=b+16|0;return a}a=H(0)|0;A()|0;gb(a);x()}function hP(a){var b=0;b=i[a+4>>2];if(!b){if(!Pg(a)){while(1){a=i[a+8>>2];if(!Pg(a)){continue}break}}return i[a+8>>2]}a=b;while(1){b=a;a=i[a>>2];if(a){continue}break}return b}function dxa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=Xa-80|0;Xa=d;c=d;e=Kwa(a,d);if(!e){WP(c)}c=-1;a:{if(!e){break a}c=0;if(!QM(d)){break a}c=Le(a,b,PM(d),_a)}Xa=d+80|0;return c|0}function _X(a,b){var c=0,d=0,e=0;c=Xa-1040|0;Xa=c;e=i[114584];d=ZX(cY(b,c+16|0),c+16|0);if(!j[d|0]){i[c>>2]=b;Uu(c+16|0,1024,70892,c);d=c+16|0}i[114584]=e;Bb(a,d);Xa=c+1040|0}function _H(a,b){var c=0,d=0,e=0;c=Xa-16|0;Xa=c;d=yc(c+8|0,b);Js(d);if(i[a>>2]==(b|0)){i[a>>2]=i[d>>2]}e=fb(a);i[e>>2]=i[e>>2]+ -1;xia(i[Pb(a)>>2],b);Xa=c+16|0;return i[d>>2]}function Yea(a){var b=0,c=0;b=i[a+16>>2];c=b+ -1|0;i[a+16>>2]=c;if((b|0)<=0){i[a+16>>2]=c+i[a+12>>2]}b=i[a+20>>2];c=b+ -1|0;i[a+20>>2]=c;if((b|0)<=0){i[a+20>>2]=c+i[a+12>>2]}}function Cea(a){a=a|0;var b=0,c=p(0);g[a+4202|0]=1;b=a,c=Fm(p(p(p(we(i[a+16>>2])>>>0)*p(20938023226335645e-21))+p(-.005025125574320555)),p(0),p(1)),m[b+4272>>2]=c;_G(a);ZG(a)}function zia(a,b,c){var d=0;d=Xa-16|0;Xa=d;i[d+12>>2]=b;i[114610]=0;I(1623,a|0,d+12|0,c|0)|0;b=i[114610];i[114610]=0;if((b|0)!=1){Xa=d+16|0;return a}a=H(0)|0;A()|0;gb(a);x()}function roa(a,b,c){var d=0;d=Xa-16|0;Xa=d;i[d+12>>2]=b;i[114610]=0;I(1384,a|0,d+12|0,c|0)|0;b=i[114610];i[114610]=0;if((b|0)!=1){Xa=d+16|0;return a}a=H(0)|0;A()|0;gb(a);x()}function mL(a,b,c){var d=0;d=Xa-16|0;Xa=d;i[d+12>>2]=c;if(k[a+28>>1]!=(b|0)){$r(a+12|0);h[a+28>>1]=b}c=a+12|0;if(Uc(c)){oL(c,Ax(a,k[$b(Fo(a),b)>>1]))}xra(c,d+12|0);Xa=d+16|0}function joa(a,b,c){var d=0;d=Xa-16|0;Xa=d;i[d+12>>2]=b;i[114610]=0;I(1388,a|0,d+12|0,c|0)|0;b=i[114610];i[114610]=0;if((b|0)!=1){Xa=d+16|0;return a}a=H(0)|0;A()|0;gb(a);x()}function aBa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=Xa-128|0;Xa=d;c=d;e=IAa(a,d);if(!e){jO(c)}c=-1;a:{if(!e){break a}c=0;if(!pO(d)){break a}c=Le(a,b,256,0)}Xa=d+128|0;return c|0}function Sqa(a,b,c){var d=0;d=Xa-16|0;Xa=d;i[d+12>>2]=b;i[114610]=0;I(1259,a|0,d+12|0,c|0)|0;b=i[114610];i[114610]=0;if((b|0)!=1){Xa=d+16|0;return a}a=H(0)|0;A()|0;gb(a);x()}function Qta(a,b,c){var d=0;d=Xa-16|0;Xa=d;i[d+12>>2]=b;i[114610]=0;I(1169,a|0,d+12|0,c|0)|0;b=i[114610];i[114610]=0;if((b|0)!=1){Xa=d+16|0;return a}a=H(0)|0;A()|0;gb(a);x()}function Qla(a,b,c){var d=0;d=Xa-16|0;Xa=d;i[d+12>>2]=b;i[114610]=0;I(1527,a|0,d+12|0,c|0)|0;b=i[114610];i[114610]=0;if((b|0)!=1){Xa=d+16|0;return a}a=H(0)|0;A()|0;gb(a);x()}function Hya(a){var b=0,c=0;b=Xa-16|0;Xa=b;i[114610]=0;i[b+12>>2]=0;I(83,a|0,b+12|0,b+8|0)|0;c=i[114610];i[114610]=0;if((c|0)!=1){Xa=b+16|0;return a}a=H(0)|0;A()|0;gb(a);x()}function Aya(a){var b=0,c=0;b=Xa-16|0;Xa=b;i[114610]=0;i[b+12>>2]=0;I(84,a|0,b+12|0,b+8|0)|0;c=i[114610];i[114610]=0;if((c|0)!=1){Xa=b+16|0;return a}a=H(0)|0;A()|0;gb(a);x()}function zB(a){var b=0;a:{if(!(l[a>>2]<=18285140|l[a>>2]>=18350592)){b=1;if(i[a>>2]!=18350080){break a}}a=i[a>>2];b=0;if(a>>>0<=18350592){break a}b=(a|0)!=(a&-256)}return b}function vC(a){a=a|0;var b=0,c=0;i[a>>2]=62416;b=a+16|0;while(1){if(c>>>0<qb(b)>>>0){if(i[vb(b,c)>>2]){El(i[vb(b,c)>>2])}c=c+1|0;continue}break}eb(a+176|0);KC(b);return a|0}function hW(a,b,c,d){var e=0;if(!d){return-1}b=(4294967295<b>>>0?0:b)+a|0;e=-1;a:{while(1){if((a|0)==(b|0)){break a}b=b+ -1|0;if(!Bn(c,d,b)){continue}break}e=b-a|0}return e}function fza(a,b){a=a|0;b=b|0;var c=0,d=0;c=1;d=a;a=b+47|0;b=Ic(d,j[a|0]&4?16:8,1,0,0);a:{b:{if(j[a|0]&8){break b}c=2;if(j[a|0]&16){break b}if(j[a|0]&127){break a}}cj(b,c)}}function ax(a,b){var c=0;c=Xa-16|0;Xa=c;i[114610]=0;i[c+12>>2]=b;I(1431,a|0,c+12|0,c+8|0)|0;b=i[114610];i[114610]=0;if((b|0)!=1){Xa=c+16|0;return a}a=H(0)|0;A()|0;gb(a);x()}function TIa(a,b){a=a|0;b=b|0;g[b|0]=0;g[b+1|0]=0;g[b+2|0]=0;g[b+3|0]=0;g[b+4|0]=0;g[b+5|0]=0;g[b+4|0]=6;g[b+5|0]=0;g[b|0]=67633152;g[b+1|0]=264192;g[b+2|0]=1032;g[b+3|0]=4}function Sra(a,b){var c=0,d=0;c=Xa-16|0;Xa=c;i[c>>2]=b;i[c+8>>2]=a;if(pb(c+8|0,c)){while(1){d=n[i[c+8>>2]>>3]+d;Dx(c+8|0);if(pb(c+8|0,c)){continue}break}}Xa=c+16|0;return d}function Rfa(a,b,c){var d=0;d=Xa-16|0;Xa=d;ega(d,b,c);i[114610]=0;G(13,a|0,0,d|0);a=i[114610];i[114610]=0;if((a|0)!=1){eb(d);Xa=d+16|0;return}a=B()|0;A()|0;eb(d);E(a|0);x()}function RQ(a){a:{if((j[a|0]|j[a+1|0]<<8|(j[a+2|0]<<16|j[a+3|0]<<24))!=-28163770){break a}if(Xc(a+44|0,12960,3)){break a}a=a+47|0;return(j[a|0]|j[a+1|0]<<8)>>>0>97}return 0}function KFa(a,b,c){var d=0;d=Xa-16|0;Xa=d;i[d+12>>2]=b;i[114610]=0;I(733,a|0,d+12|0,c|0)|0;b=i[114610];i[114610]=0;if((b|0)!=1){Xa=d+16|0;return a}a=H(0)|0;A()|0;gb(a);x()}function In(a,b){var c=0,d=0,e=0;c=0;a:{if(!a){break a}d=XMa(a,0,b,0);e=_a;c=d;if((a|b)>>>0<65536){break a}c=e?-1:d}b=c;a=Zc(b);if(!(!a|!(j[a+ -4|0]&3))){yb(a,0,b)}return a}function ICa(a,b,c){var d=0;d=Xa-16|0;Xa=d;i[d+12>>2]=b;i[114610]=0;I(834,a|0,d+12|0,c|0)|0;b=i[114610];i[114610]=0;if((b|0)!=1){Xa=d+16|0;return a}a=H(0)|0;A()|0;gb(a);x()}function Gaa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;Ac(a+12|0,0,0);d=a+20|0;c=d;e=c+16|0;while(1){c=ak(c)+4|0;if((e|0)!=(c|0)){continue}break}vJ(d+16|0,b);i[a+40>>2]=1;return a|0}function E8(a,b,c){var d=0;d=Xa-16|0;Xa=d;i[d+12>>2]=b;i[114610]=0;I(2202,a|0,d+12|0,c|0)|0;b=i[114610];i[114610]=0;if((b|0)!=1){Xa=d+16|0;return a}a=H(0)|0;A()|0;gb(a);x()}function C8(a,b,c){var d=0;d=Xa-16|0;Xa=d;i[d+12>>2]=b;i[114610]=0;I(2204,a|0,d+12|0,c|0)|0;b=i[114610];i[114610]=0;if((b|0)!=1){Xa=d+16|0;return a}a=H(0)|0;A()|0;gb(a);x()}function BQ(a,b){var c=0;c=Xa-32|0;Xa=c;i[c+24>>2]=a;i[c+28>>2]=b;i[c+16>>2]=0;i[c+20>>2]=0;i[c+8>>2]=-1;i[c+12>>2]=0;a=yQ(c+16|0,dz(c+24|0,c+8|0));Xa=c+32|0;return i[a>>2]}function tV(a,b,c){var d=0;d=Xa-16|0;Xa=d;i[d+12>>2]=b;i[114610]=0;I(280,a|0,d+12|0,c|0)|0;b=i[114610];i[114610]=0;if((b|0)!=1){Xa=d+16|0;return a}a=H(0)|0;A()|0;gb(a);x()}function sna(a,b){var c=0;c=Xa-16|0;Xa=c;i[114610]=0;i[c+12>>2]=b;I(1423,a|0,c+12|0,c+8|0)|0;a=i[114610];i[114610]=0;if((a|0)!=1){Xa=c+16|0;return}a=H(0)|0;A()|0;gb(a);x()}function rga(a,b){var c=0;c=Xa-16|0;Xa=c;i[114610]=0;i[c+12>>2]=b;I(1758,a|0,c+12|0,c+8|0)|0;a=i[114610];i[114610]=0;if((a|0)!=1){Xa=c+16|0;return}a=H(0)|0;A()|0;gb(a);x()}function cp(a){var b=0,c=0;c=i[a+4>>2];b=i[c>>2];i[a+4>>2]=b;if(b){Ym(b,a)}i[c+8>>2]=i[a+8>>2];a:{if(Pg(a)){b=i[a+8>>2];break a}b=i[a+8>>2]+4|0}i[b>>2]=c;i[c>>2]=a;Ym(a,c)}function cla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=Xa-16|0;Xa=c;i[c+12>>2]=b;d=c,e=rR(Jb(a),Kb(a),c+12|0),i[d+8>>2]=e;d=c,e=Kb(a),i[d>>2]=e;a=pb(c+8|0,c);Xa=c+16|0;return a|0}function bp(a){var b=0,c=0;c=i[a>>2];b=i[c+4>>2];i[a>>2]=b;if(b){Ym(b,a)}i[c+8>>2]=i[a+8>>2];a:{if(Pg(a)){b=i[a+8>>2];break a}b=i[a+8>>2]+4|0}i[b>>2]=c;i[c+4>>2]=a;Ym(a,c)}function bV(a,b,c){var d=0;d=Xa-16|0;Xa=d;i[d+12>>2]=b;i[114610]=0;I(286,a|0,d+12|0,c|0)|0;b=i[114610];i[114610]=0;if((b|0)!=1){Xa=d+16|0;return a}a=H(0)|0;A()|0;gb(a);x()}function Zfa(a,b,c){var d=0;d=Xa-16|0;Xa=d;rH(d,b,c);i[114610]=0;G(13,a|0,0,d|0);a=i[114610];i[114610]=0;if((a|0)!=1){eb(d);Xa=d+16|0;return}a=B()|0;A()|0;eb(d);E(a|0);x()}function Vda(a,b){var c=0;c=Xa-16|0;Xa=c;i[114610]=0;i[c+12>>2]=b;I(2003,a|0,c+12|0,c+8|0)|0;a=i[114610];i[114610]=0;if((a|0)!=1){Xa=c+16|0;return}a=H(0)|0;A()|0;gb(a);x()}function OV(a,b,c){var d=0;d=Xa-16|0;Xa=d;i[d+12>>2]=b;i[114610]=0;I(274,a|0,d+12|0,c|0)|0;b=i[114610];i[114610]=0;if((b|0)!=1){Xa=d+16|0;return a}a=H(0)|0;A()|0;gb(a);x()}function Kfa(a,b,c){var d=0;d=Xa-16|0;Xa=d;lw(d,b,c);i[114610]=0;G(13,a|0,0,d|0);a=i[114610];i[114610]=0;if((a|0)!=1){eb(d);Xa=d+16|0;return}a=B()|0;A()|0;eb(d);E(a|0);x()}function Ioa(a,b){var c=0;c=Xa-16|0;Xa=c;i[114610]=0;i[c+12>>2]=b;I(1375,a|0,c+12|0,c+8|0)|0;a=i[114610];i[114610]=0;if((a|0)!=1){Xa=c+16|0;return}a=H(0)|0;A()|0;gb(a);x()}function Haa(a,b){var c=0;c=Xa-16|0;Xa=c;i[114610]=0;i[c+12>>2]=b;I(2138,a|0,c+12|0,c+8|0)|0;a=i[114610];i[114610]=0;if((a|0)!=1){Xa=c+16|0;return}a=H(0)|0;A()|0;gb(a);x()}function Gba(a,b,c,d){var e=0,f=0;e=Xa-16|0;Xa=e;if(c){while(1){f=Xr(fb(a),c+16|0,b);d=f?d:c;c=i[(f?4:0)+c>>2];if(c){continue}break}}a=i[yc(e+8|0,d)>>2];Xa=e+16|0;return a}function Faa(a,b){var c=0;c=Xa-16|0;Xa=c;i[114610]=0;i[c+12>>2]=b;I(2139,a|0,c+12|0,c+8|0)|0;a=i[114610];i[114610]=0;if((a|0)!=1){Xa=c+16|0;return}a=H(0)|0;A()|0;gb(a);x()}function FFa(a,b,c,d){var e=0,f=0;e=Xa-16|0;Xa=e;if(c){while(1){f=Zm(fb(a),c+16|0,b);d=f?d:c;c=i[(f?4:0)+c>>2];if(c){continue}break}}a=i[yc(e+8|0,d)>>2];Xa=e+16|0;return a}function Eaa(a,b){var c=0;c=Xa-16|0;Xa=c;i[114610]=0;i[c+12>>2]=b;I(2140,a|0,c+12|0,c+8|0)|0;a=i[114610];i[114610]=0;if((a|0)!=1){Xa=c+16|0;return}a=H(0)|0;A()|0;gb(a);x()}function Cia(a,b,c,d){var e=0,f=0;e=Xa-16|0;Xa=e;if(c){while(1){f=wr(fb(a),c+16|0,b);d=f?d:c;c=i[(f?4:0)+c>>2];if(c){continue}break}}a=i[yc(e+8|0,d)>>2];Xa=e+16|0;return a}function Cfa(a,b,c){var d=0;d=Xa-16|0;Xa=d;pr(d,b,c);i[114610]=0;G(13,a|0,0,d|0);a=i[114610];i[114610]=0;if((a|0)!=1){eb(d);Xa=d+16|0;return}a=B()|0;A()|0;eb(d);E(a|0);x()}function Asa(a,b){var c=0;c=Xa-16|0;Xa=c;i[114610]=0;i[c+12>>2]=b;I(1201,a|0,c+12|0,c+8|0)|0;a=i[114610];i[114610]=0;if((a|0)!=1){Xa=c+16|0;return}a=H(0)|0;A()|0;gb(a);x()}function yx(a,b,c){var d=0,e=0,f=0;d=Xa-32|0;Xa=d;i[d+16>>2]=c;i[d+24>>2]=b;e=d,f=ld(a),i[e+8>>2]=f;b=a;a=En(d+24|0,d+8|0);$V(b,a,En(d+16|0,d+24|0));Ze(d+8|0,a);Xa=d+32|0}function x3(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=a;a=b+28|0;d=Nn(d,a);uC(a,c);i[114610]=0;D(2313,b|0,1);a=i[114610];i[114610]=0;if((a|0)==1){a=B()|0;A()|0;ub(d);E(a|0);x()}}function de(a,b){var c=0;c=i[a>>2];i[a>>2]=b;a:{if(!c){break a}a=i[Pb(a)>>2];i[114610]=0;L(a|0,c|0);a=i[114610];i[114610]=0;if((a|0)!=1){break a}a=H(0)|0;A()|0;gb(a);x()}}function bK(a,b,c){a=a|0;b=b|0;c=c|0;a=i[c+4>>2];i[b>>2]=i[c>>2];i[b+4>>2]=a;a=i[c+20>>2];i[b+16>>2]=i[c+16>>2];i[b+20>>2]=a;a=i[c+12>>2];i[b+8>>2]=i[c+8>>2];i[b+12>>2]=a}function UMa(a,b,c){var d=0,e=0;d=b>>31;e=a^d;a=b>>31;VMa(e-d|0,(b^a)-((e>>>0<d>>>0)+a|0)|0,c,0-(c>>>0<0)|0);_a=Za;b=d^Ya;c=b-d|0;_a=(a^_a)-((b>>>0<d>>>0)+a|0)|0;return c}function TDa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=$a[i[i[a>>2]+24>>2]](a)|0;a:{if(!c){d=1;if((a|0)==(b|0)){break a}}d=0;if(a>>>0<=b>>>0){break a}d=a-b>>>0>=c>>>0}return d|0}function O9(a,b){var c=0;c=Xa-16|0;Xa=c;i[114610]=0;i[c+12>>2]=b;I(2177,a|0,c+12|0,c+8|0)|0;a=i[114610];i[114610]=0;if((a|0)!=1){Xa=c+16|0;return}a=H(0)|0;A()|0;gb(a);x()}function Mq(a,b){var c=0,d=0,e=0;e=a;a:{if(b>>>0<=31){c=i[a>>2];d=i[a+4>>2];break a}c=i[a+4>>2];i[a+4>>2]=0;i[a>>2]=c;b=b+ -32|0;d=0}i[e+4>>2]=d>>>b;i[a>>2]=d<<32-b|c>>>b}function Gga(a,b){a=a|0;b=b|0;var c=0,d=0;c=Xa-16|0;Xa=c;i[c+12>>2]=0;d=c+12|0;g[d|0]=b;g[d+1|0]=b>>>8;g[d+2|0]=b>>>16;g[d+3|0]=b>>>24;a=wH(a,c+12|0);Xa=c+16|0;return a|0}function r_(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;while(1){if((b|0)!=(c|0)){d=b;a=i[b>>2];if(a>>>0<=127){a=i[kq()+(i[b>>2]<<2)>>2]}i[d>>2]=a;b=b+4|0;continue}break}return c|0}function o_(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;while(1){if((b|0)!=(c|0)){d=b;a=i[b>>2];if(a>>>0<=127){a=i[jq()+(i[b>>2]<<2)>>2]}i[d>>2]=a;b=b+4|0;continue}break}return c|0}function nba(a){var b=0;b=Xa-16|0;Xa=b;$p(b,0,7349);i[114610]=0;G(9,a|0,0,b|0);a=i[114610];i[114610]=0;if((a|0)!=1){eb(b);Xa=b+16|0;return}a=B()|0;A()|0;eb(b);E(a|0);x()}function lba(a){var b=0;b=Xa-16|0;Xa=b;$p(b,0,9345);i[114610]=0;G(9,a|0,0,b|0);a=i[114610];i[114610]=0;if((a|0)!=1){eb(b);Xa=b+16|0;return}a=B()|0;A()|0;eb(b);E(a|0);x()}function ZV(a,b){var c=0;c=Xa-16|0;Xa=c;i[114610]=0;i[c+12>>2]=b;I(268,a|0,c+12|0,c+8|0)|0;a=i[114610];i[114610]=0;if((a|0)!=1){Xa=c+16|0;return}a=H(0)|0;A()|0;gb(a);x()}function Tua(a,b){var c=0;c=Xa-16|0;Xa=c;i[114610]=0;i[c+12>>2]=b;I(97,a|0,c+12|0,c+8|0)|0;a=i[114610];i[114610]=0;if((a|0)!=1){Xa=c+16|0;return}a=H(0)|0;A()|0;gb(a);x()}function Rxa(a,b){var c=0;c=Xa-16|0;Xa=c;i[114610]=0;i[c+12>>2]=b;I(90,a|0,c+12|0,c+8|0)|0;a=i[114610];i[114610]=0;if((a|0)!=1){Xa=c+16|0;return}a=H(0)|0;A()|0;gb(a);x()}function FR(a,b,c){var d=0;d=j[b|0]|j[b+1|0]<<8|(j[b+2|0]<<16|j[b+3|0]<<24);b=j[b+4|0]|j[b+5|0]<<8|(j[b+6|0]<<16|j[b+7|0]<<24);i[a>>2]=d;i[a+4>>2]=b;zl(a+8|0,c);return a}function hha(a,b){var c=0;c=Xa-16|0;Xa=c;Iia(c,b);i[114610]=0;G(13,a|0,0,c|0);a=i[114610];i[114610]=0;if((a|0)!=1){eb(c);Xa=c+16|0;return}a=B()|0;A()|0;eb(c);E(a|0);x()}function bo(a){var b=0;b=Xa-16|0;Xa=b;i[114610]=0;i[b+12>>2]=0;I(2176,a|0,b+12|0,b+8|0)|0;a=i[114610];i[114610]=0;if((a|0)!=1){Xa=b+16|0;return}a=H(0)|0;A()|0;gb(a);x()}function Xc(a,b,c){var d=0,e=0,f=0;a:{if(!c){break a}while(1){d=j[a|0];e=j[b|0];if((d|0)==(e|0)){b=b+1|0;a=a+1|0;c=c+ -1|0;if(c){continue}break a}break}f=d-e|0}return f}function Vo(a,b,c){var d=0;d=j[a|0]|j[a+1|0]<<8;if(((d<<24|d<<8&16711680)>>>16|0)>=(b|0)){a=j[a|0]|j[a+1|0]<<8;a=((a<<24|a<<8&16711680)>>>16|0)<=(c|0)}else{a=0}return a}function Fwa(a,b){a=a|0;b=b|0;var c=0,d=0;c=te(2500);i[114610]=0;b=I(92,c|0,b|0,0)|0;d=i[114610];i[114610]=0;if((d|0)!=1){Tua(a,b);return}a=B()|0;A()|0;Cb(c);E(a|0);x()}function Aha(a,b){var c=0;c=Xa-16|0;Xa=c;mja(c,b);i[114610]=0;G(13,a|0,0,c|0);a=i[114610];i[114610]=0;if((a|0)!=1){eb(c);Xa=c+16|0;return}a=B()|0;A()|0;eb(c);E(a|0);x()}function AM(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Xa-16|0;Xa=d;if((b|0)!=(c|0)){while(1){i[d+12>>2]=i[b>>2];Wx(a,d+12|0);b=b+4|0;if((c|0)!=(b|0)){continue}break}}Xa=d+16|0}function $w(a){var b=0;b=Xa-16|0;Xa=b;i[114610]=0;i[b+12>>2]=0;I(1432,a|0,b+12|0,b+8|0)|0;a=i[114610];i[114610]=0;if((a|0)!=1){Xa=b+16|0;return}a=H(0)|0;A()|0;gb(a);x()}function y7(a,b){a:{switch(i[a+40>>2]){case 0:w7(b,a);return;case 2:Lv(b,fb(a));return;case 3:u7(b,xg(a));return;case 1:Lv(b,fb(a));return;default:break a}}Lv(b,fb(a))}function x7(a,b){a:{switch(i[a+40>>2]){case 0:p7(b,a);return;case 2:Kv(b,fb(a));return;case 3:o7(b,xg(a));return;case 1:Kv(b,fb(a));return;default:break a}}Kv(b,fb(a))}function wV(a){var b=0;b=Xa-16|0;Xa=b;i[114610]=0;i[b+12>>2]=0;I(278,a|0,b+12|0,b+8|0)|0;a=i[114610];i[114610]=0;if((a|0)!=1){Xa=b+16|0;return}a=H(0)|0;A()|0;gb(a);x()}function vha(a,b){var c=0;c=Xa-16|0;Xa=c;gI(c,b);i[114610]=0;G(13,a|0,0,c|0);a=i[114610];i[114610]=0;if((a|0)!=1){eb(c);Xa=c+16|0;return}a=B()|0;A()|0;eb(c);E(a|0);x()}function oha(a,b){var c=0;c=Xa-16|0;Xa=c;Aw(c,b);i[114610]=0;G(13,a|0,0,c|0);a=i[114610];i[114610]=0;if((a|0)!=1){eb(c);Xa=c+16|0;return}a=B()|0;A()|0;eb(c);E(a|0);x()}function mna(a,b){a=a|0;b=b|0;var c=0;c=Xa-16|0;Xa=c;i[114610]=0;a=C(1425,a|0,b|0)|0;b=i[114610];i[114610]=0;if((b|0)!=1){Xa=c+16|0;return a|0}a=B()|0;A()|0;E(a|0);x()}function mc(a,b){var c=0,d=0;c=Xa-16|0;Xa=c;if(i[a+4>>2]==i[b+4>>2]){d=i[b+4>>2];b=i[b>>2];i[c>>2]=b;i[c+4>>2]=d;i[c+8>>2]=b;i[c+12>>2]=d;d=!J8(a,c)}Xa=c+16|0;return d}function i7(a,b){a:{switch(i[a+40>>2]){case 0:Vq(b,a);return;case 2:Vq(b,fb(a));return;case 3:f7(b,xg(a));return;case 1:Vq(b,fb(a));return;default:break a}}Vq(b,fb(a))}function h7(a,b){a:{switch(i[a+40>>2]){case 0:b7(b,a);return;case 2:Jv(b,fb(a));return;case 3:a7(b,xg(a));return;case 1:Jv(b,fb(a));return;default:break a}}Jv(b,fb(a))}function fF(a){var b=0,c=0;a:{if(j[a|0]!=255){break a}b=j[a+1|0];if(!(b&6)|(b&240)!=240&(b&254)!=226){break a}a=j[a+2|0];if((a&240)==240){break a}c=(a&12)!=12}return c}function e9(a,b){a=a|0;b=b|0;var c=0;c=-1;a:{if((b|0)<0){break a}a=a+24|0;if((Ti(Db(i[a>>2]+484360|0))|0)<=(b|0)){break a}c=k[$b(Db(i[a>>2]+484360|0),b)>>1]}return c|0}function _7(a,b){a:{switch(i[a+40>>2]){case 0:S7(b,a);return;case 2:Nv(b,fb(a));return;case 3:R7(b,xg(a));return;case 1:Nv(b,fb(a));return;default:break a}}Nv(b,fb(a))}function Yia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=Xa-16|0;Xa=c;d=c,e=Cs(i[b>>2]),i[d+12>>2]=e;i[c+8>>2]=0;d=a,e=i[_r(c+12|0,c+8|0,32392)>>2],i[d+36>>2]=e;go(a);Xa=c+16|0}function QH(a,b){var c=0;c=Xa-16|0;Xa=c;zja(c,b);i[114610]=0;G(13,a|0,0,c|0);a=i[114610];i[114610]=0;if((a|0)!=1){eb(c);Xa=c+16|0;return}a=B()|0;A()|0;eb(c);E(a|0);x()}function Pla(a,b){var c=0;c=Xa-16|0;Xa=c;mh(c+8|0,b);i[114610]=0;a=C(1528,a|0,c+8|0)|0;b=i[114610];i[114610]=0;if((b|0)!=1){Xa=c+16|0;return a}a=H(0)|0;A()|0;gb(a);x()}function MT(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Xa-16|0;Xa=d;i[a>>2]=0;i[a+4>>2]=0;i[d+12>>2]=0;Fc(a+8|0,d+12|0,d+8|0);if(b){Cp(a,b);mA(a,b,j[c|0])}Xa=d+16|0;return a|0}function L7(a,b){a:{switch(i[a+40>>2]){case 0:Wq(b,a);return;case 2:Wq(b,fb(a));return;case 3:J7(b,xg(a));return;case 1:Wq(b,fb(a));return;default:break a}}Wq(b,fb(a))}function Kq(a,b){var c=0,d=0,e=0;e=a;a:{if(b>>>0<=31){c=i[a+4>>2];d=i[a>>2];break a}c=i[a>>2];i[a+4>>2]=c;i[a>>2]=0;b=b+ -32|0;d=0}i[e>>2]=d<<b;i[a+4>>2]=c<<b|d>>>32-b}function K7(a,b){a:{switch(i[a+40>>2]){case 0:G7(b,a);return;case 2:Mv(b,fb(a));return;case 3:F7(b,xg(a));return;case 1:Mv(b,fb(a));return;default:break a}}Mv(b,fb(a))}function Dwa(a,b){var c=0;c=Xa-16|0;Xa=c;mh(c+8|0,b);i[114610]=0;a=C(1061,a|0,c+8|0)|0;b=i[114610];i[114610]=0;if((b|0)!=1){Xa=c+16|0;return a}a=H(0)|0;A()|0;gb(a);x()}function $7(a,b){a:{switch(i[a+40>>2]){case 0:Y7(b,a);return;case 2:Ov(b,fb(a));return;case 3:X7(b,xg(a));return;case 1:Ov(b,fb(a));return;default:break a}}Ov(b,fb(a))}function hea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,j=0;if(b){f=i[b+24>>2];g=i[b+8>>2];h=i[b+4>>2];j=i[b>>2];e=i[b+12>>2]}else{e=0}OG(a,j,h,g,e,f,b,c,d)}function V6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;if((b|0)!=(c|0)){e=i[d>>2];while(1){Ry(a,e,b);e=i[d>>2]+12|0;i[d>>2]=e;b=b+12|0;if((c|0)!=(b|0)){continue}break}}}function Th(a,b,c){var d=0;d=i[b+4>>2];i[a>>2]=i[b>>2];i[a+4>>2]=d;d=i[b+12>>2];i[a+8>>2]=i[b+8>>2];i[a+12>>2]=d;n[a>>3]=n[a>>3]-n[c>>3];n[a+8>>3]=n[a+8>>3]-n[c+8>>3]}function TKa(a,b){var c=0;c=Xa-16|0;Xa=c;Xa=c+16|0;return(j[b|0]|j[b+1|0]<<8|(j[b+2|0]<<16|j[b+3|0]<<24))>>>0<(j[a|0]|j[a+1|0]<<8|(j[a+2|0]<<16|j[a+3|0]<<24))>>>0?b:a}function Dsa(a,b){a=a|0;b=b|0;var c=0;c=Csa(a);g[a+530|0]=0;i[114610]=0;D(1198,a|0,b|0);b=i[114610];i[114610]=0;if((b|0)!=1){return a|0}a=B()|0;A()|0;$e(c);E(a|0);x()}function CJa(a,b,c){var d=0;if((b|0)>=1){while(1){d=i[c>>2];g[a|0]=d;g[a+1|0]=d>>>8;g[a+2|0]=d>>>16;g[a+3|0]=d>>>24;a=a+4|0;d=(b|0)>1;b=b+ -1|0;if(d){continue}break}}}function Bsa(a,b){var c=0,d=0;c=te(3848);b=i[b>>2];i[114610]=0;b=C(1200,c|0,b|0)|0;d=i[114610];i[114610]=0;if((d|0)!=1){Asa(a,b);return}a=B()|0;A()|0;Cb(c);E(a|0);x()}function ABa(a,b){var c=0;c=Xa-32|0;Xa=c;a:{if(wb(a,1024)){py(c+24|0,b);od(a,c+24|0);break a}i[c+16>>2]=0;i[c+20>>2]=0;i[c+8>>2]=0;i[c+12>>2]=0;dBa(b,c+8|0)}Xa=c+32|0}function waa(a,b,c,d){var e=0,f=0;e=Xa-16|0;Xa=e;i[e+8>>2]=i[b+8>>2];f=i[b+4>>2];i[e>>2]=i[b>>2];i[e+4>>2]=f;vaa(a,e,c);m[a+24>>2]=d;i[a>>2]=84136;Xa=e+16|0;return a}function uaa(a,b,c,d){var e=0,f=0;e=Xa-16|0;Xa=e;i[e+8>>2]=i[b+8>>2];f=i[b+4>>2];i[e>>2]=i[b>>2];i[e+4>>2]=f;taa(a,e,c);m[a+24>>2]=d;i[a>>2]=84208;Xa=e+16|0;return a}function rFa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;Uy(a,b,c);a=i[a+16>>2];a:{if(!c){d=1;if((a|0)==(b|0)){break a}}d=0;if(a>>>0<=b>>>0){break a}d=a-b>>>0>=c>>>0}return d|0}function iW(a,b,c,d){var e=0,f=0;f=-1;a:{if(0>=b>>>0){break a}e=b;b=a;e=e+b|0;while(1){if(Bn(c,d,b)){b=b+1|0;if((e|0)!=(b|0)){continue}break a}break}f=b-a|0}return f}function OU(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Xa-16|0;Xa=d;i[d+12>>2]=c;c=0;a=i[a+16>>2];if(a>>>0>b>>>0){i[d+8>>2]=a-b;c=i[rb(d+12|0,d+8|0)>>2]}Xa=d+16|0;return c|0}function O2(a,b,c){var d=0,e=0,f=0;e=i[a+84>>2];d=c+256|0;f=Pq(e,0,d);d=f?f-e|0:d;c=d>>>0<c>>>0?d:c;Tb(b,e,c);b=e+d|0;i[a+84>>2]=b;i[a+8>>2]=b;i[a+4>>2]=c+e;return c}function Dna(a,b){var c=0,d=0;c=te(532);b=i[b>>2];i[114610]=0;b=C(1419,c|0,b|0)|0;d=i[114610];i[114610]=0;if((d|0)!=1){sna(a,b);return}a=B()|0;A()|0;Cb(c);E(a|0);x()}function zra(a,b){var c=0,d=0,e=0;ora(a);el(a,b);i[a>>2]=i[b>>2];i[a+4>>2]=i[b+4>>2];c=i[fb(b)>>2];d=fb(a),e=c,i[d>>2]=e;d=fb(b),e=0,i[d>>2]=e;i[b>>2]=0;i[b+4>>2]=0}function xxa(a,b){var c=0,d=0,e=0;c=wxa(a,fb(b));i[a>>2]=i[b>>2];i[a+4>>2]=i[b+4>>2];a=i[fb(b)>>2];d=fb(c),e=a,i[d>>2]=e;d=fb(b),e=0,i[d>>2]=e;i[b>>2]=0;i[b+4>>2]=0}function x4(a,b){var c=0,d=0;c=Xa-16|0;Xa=c;d=Xa-16|0;Xa=d;b=t4(b);Xa=d+16|0;i[c+8>>2]=b;i[c+12>>2]=_a;b=i[c+12>>2];i[a>>2]=i[c+8>>2];i[a+4>>2]=b;Xa=c+16|0;return a}function usa(a){var b=0,c=0,d=0,e=0;b=Xa-16|0;Xa=b;d=b,e=XMa(i[a>>2],i[a+4>>2],1e3,0),i[d>>2]=e;i[b+4>>2]=_a;c=Qj(b+8|0,b);a=i[c>>2];Xa=b+16|0;_a=i[c+4>>2];return a}function u4(a,b){var c=0,d=0;c=Xa-16|0;Xa=c;d=Xa-16|0;Xa=d;b=s4(b);Xa=d+16|0;i[c+8>>2]=b;i[c+12>>2]=_a;b=i[c+12>>2];i[a>>2]=i[c+8>>2];i[a+4>>2]=b;Xa=c+16|0;return a}function kba(a){var b=0;b=Xa-16|0;Xa=b;_p(b,0);i[114610]=0;G(9,a|0,0,b|0);a=i[114610];i[114610]=0;if((a|0)!=1){eb(b);Xa=b+16|0;return}a=B()|0;A()|0;eb(b);E(a|0);x()}function jba(a){var b=0;b=Xa-16|0;Xa=b;_p(b,2);i[114610]=0;G(9,a|0,0,b|0);a=i[114610];i[114610]=0;if((a|0)!=1){eb(b);Xa=b+16|0;return}a=B()|0;A()|0;eb(b);E(a|0);x()}function iba(a){var b=0;b=Xa-16|0;Xa=b;_p(b,3);i[114610]=0;G(9,a|0,0,b|0);a=i[114610];i[114610]=0;if((a|0)!=1){eb(b);Xa=b+16|0;return}a=B()|0;A()|0;eb(b);E(a|0);x()}function i_(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;while(1){if((b|0)!=(c|0)){d=b;a=g[b|0];if((a|0)>=0){a=i[kq()+(g[b|0]<<2)>>2]}g[d|0]=a;b=b+1|0;continue}break}return c|0}function g_(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;while(1){if((b|0)!=(c|0)){d=b;a=g[b|0];if((a|0)>=0){a=i[jq()+(g[b|0]<<2)>>2]}g[d|0]=a;b=b+1|0;continue}break}return c|0}function dza(a,b){var c=0,d=0,e=0;cza(a);el(a,b);i[a>>2]=i[b>>2];i[a+4>>2]=i[b+4>>2];c=i[fb(b)>>2];d=fb(a),e=c,i[d>>2]=e;d=fb(b),e=0,i[d>>2]=e;i[b>>2]=0;i[b+4>>2]=0}function Ola(a,b){a:{if(j[a+4|0]){a=i[a>>2];i[114610]=0;D(1525,a|0,b+16|0);a=i[114610];i[114610]=0;if((a|0)==1){break a}}if(b){YI(b)}return}a=H(0)|0;A()|0;gb(a);x()}function Mka(a,b){var c=0,d=0,e=0;Lka(a);el(a,b);i[a>>2]=i[b>>2];i[a+4>>2]=i[b+4>>2];c=i[fb(b)>>2];d=fb(a),e=c,i[d>>2]=e;d=fb(b),e=0,i[d>>2]=e;i[b>>2]=0;i[b+4>>2]=0}function JN(a){if(!((j[a|0]|j[a+1|0]<<8|(j[a+2|0]<<16|j[a+3|0]<<24))!=541938512|(j[a+8|0]|j[a+9|0]<<8|(j[a+10|0]<<16|j[a+11|0]<<24))!=1162627398)){return 1}return 0}function GV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Xa-16|0;Xa=d;i[d+12>>2]=c;c=0;a=i[a+8>>2];if(a>>>0>b>>>0){i[d+8>>2]=a-b;c=i[rb(d+12|0,d+8|0)>>2]}Xa=d+16|0;return c|0}function FM(a){var b=0,c=0;a:{if(j[a|0]!=255){break a}b=j[a+1|0];if(!(b&6)|(b&224)!=224|(b&24)==8){break a}a=j[a+2|0];if((a&12)==12){break a}c=(a&240)!=240}return c}function Ara(a,b){var c=0,d=0,e=0;d=a;c=i[a+4>>2];e=c>>>8|0;a=i[a>>2];c=(c&255)<<24|a>>>8;a=(((a^b)&255)<<3)+85504|0;b=i[a>>2];a=i[a+4>>2]^e;i[d>>2]=b^c;i[d+4>>2]=a}function xja(a,b){var c=0;wja(a,b);i[a+20>>2]=i[b+20>>2];c=i[b+16>>2];i[a+12>>2]=i[b+12>>2];i[a+16>>2]=c;vja(a+24|0,b+24|0);Lc(a+36|0,b+36|0);i[a+48>>2]=i[b+48>>2]}function wo(a){var b=0,c=0;b=Xa-16|0;Xa=b;a:{if(!(i[a+480208>>2]&16)){break a}kb(b+8|0,a+1074308|0,7);if(!ib(b+8|0)){break a}c=i[a+480180>>2]!=4}Xa=b+16|0;return c}function wja(a,b){var c=0,d=0,e=0;c=pI(a,fb(b));i[a>>2]=i[b>>2];i[a+4>>2]=i[b+4>>2];a=i[fb(b)>>2];d=fb(c),e=a,i[d>>2]=e;d=fb(b),e=0,i[d>>2]=e;i[b>>2]=0;i[b+4>>2]=0}function vja(a,b){var c=0,d=0,e=0;c=PS(a,fb(b));i[a>>2]=i[b>>2];i[a+4>>2]=i[b+4>>2];a=i[fb(b)>>2];d=fb(c),e=a,i[d>>2]=e;d=fb(b),e=0,i[d>>2]=e;i[b>>2]=0;i[b+4>>2]=0}function t4(a){var b=0,c=0,d=0,e=0;b=Xa-16|0;Xa=b;d=b,e=XMa(i[a>>2],i[a+4>>2],1e6,0),i[d>>2]=e;i[b+4>>2]=_a;c=Qj(b+8|0,b);a=i[c>>2];Xa=b+16|0;_a=i[c+4>>2];return a}function s4(a){var b=0,c=0,d=0,e=0;b=Xa-16|0;Xa=b;d=b,e=XMa(i[a>>2],i[a+4>>2],1e9,0),i[d>>2]=e;i[b+4>>2]=_a;c=Qj(b+8|0,b);a=i[c>>2];Xa=b+16|0;_a=i[c+4>>2];return a}function lka(a,b){var c=0,d=0,e=0;zI(a);el(a,b);i[a>>2]=i[b>>2];i[a+4>>2]=i[b+4>>2];c=i[fb(b)>>2];d=fb(a),e=c,i[d>>2]=e;d=fb(b),e=0,i[d>>2]=e;i[b>>2]=0;i[b+4>>2]=0}function Yta(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a=a+108|0;c=a+128|0;if((a|0)!=(c|0)){while(1){d=a,e=kp(j[a|0]+b|0),g[d|0]=e;a=a+1|0;if((c|0)!=(a|0)){continue}break}}}function Vra(a,b){var c=0,d=0,e=0;c=sL(a,fb(b));i[a>>2]=i[b>>2];i[a+4>>2]=i[b+4>>2];a=i[fb(b)>>2];d=fb(c),e=a,i[d>>2]=e;d=fb(b),e=0,i[d>>2]=e;i[b>>2]=0;i[b+4>>2]=0}function Rsa(a,b){var c=0,d=0,e=0;c=XL(a,fb(b));i[a>>2]=i[b>>2];i[a+4>>2]=i[b+4>>2];a=i[fb(b)>>2];d=fb(c),e=a,i[d>>2]=e;d=fb(b),e=0,i[d>>2]=e;i[b>>2]=0;i[b+4>>2]=0}function Pma(a,b){var c=0,d=0,e=0;bP(a);el(a,b);i[a>>2]=i[b>>2];i[a+4>>2]=i[b+4>>2];c=i[fb(b)>>2];d=fb(a),e=c,i[d>>2]=e;d=fb(b),e=0,i[d>>2]=e;i[b>>2]=0;i[b+4>>2]=0}function Mk(a){a=a>>>1&1431655765|a<<1&-1431655766;a=a>>>2&858993459|a<<2&-858993460;a=a>>>4&252645135|a<<4&-252645136;return aNa(a>>>8&16711935|a<<8&-16711936,16)}function Maa(a,b){var c=0,d=0,e=0;e8(a);el(a,b);i[a>>2]=i[b>>2];i[a+4>>2]=i[b+4>>2];c=i[fb(b)>>2];d=fb(a),e=c,i[d>>2]=e;d=fb(b),e=0,i[d>>2]=e;i[b>>2]=0;i[b+4>>2]=0}function Ke(a){var b=0,c=0;b=Xa-16|0;Xa=b;i[114610]=0;I(114,a|0,b+8|0,b|0)|0;c=i[114610];i[114610]=0;if((c|0)!=1){Gm(a);Xa=b+16|0;return a}a=H(0)|0;A()|0;gb(a);x()}function EG(a,b){var c=0,d=0,e=0,f=0;c=i[a+24>>2];if((c|0)==i[a+28>>2]){return e=a,f=cg(b),d=i[i[a>>2]+52>>2],$a[d](e|0,f|0)|0}i[a+24>>2]=c+1;g[c|0]=b;return cg(b)}function Cpa(a,b){var c=0,d=0,e=0;WK(a);el(a,b);i[a>>2]=i[b>>2];i[a+4>>2]=i[b+4>>2];c=i[fb(b)>>2];d=fb(a),e=c,i[d>>2]=e;d=fb(b),e=0,i[d>>2]=e;i[b>>2]=0;i[b+4>>2]=0}function wd(a,b,c){var d=0;d=Xa-16|0;Xa=d;i[d+12>>2]=b;i[114610]=0;Pn(a,d+12|0,c);b=i[114610];i[114610]=0;if((b|0)!=1){Xa=d+16|0;return a}a=H(0)|0;A()|0;gb(a);x()}function tba(a){var b=0;b=Xa-16|0;Xa=b;lW(b);i[114610]=0;G(9,a|0,0,b|0);a=i[114610];i[114610]=0;if((a|0)!=1){eb(b);Xa=b+16|0;return}a=B()|0;A()|0;eb(b);E(a|0);x()}function tN(a,b){var c=0,d=0,e=0;c=vN(a,fb(b));i[a>>2]=i[b>>2];i[a+4>>2]=i[b+4>>2];a=i[fb(b)>>2];d=fb(c),e=a,i[d>>2]=e;d=fb(b),e=0,i[d>>2]=e;i[b>>2]=0;i[b+4>>2]=0}function pba(a){var b=0;b=Xa-16|0;Xa=b;wW(b);i[114610]=0;G(9,a|0,0,b|0);a=i[114610];i[114610]=0;if((a|0)!=1){eb(b);Xa=b+16|0;return}a=B()|0;A()|0;eb(b);E(a|0);x()}function oua(a,b,c,d){var e=0;a:{if(d==p(1)){break a}c=o(b,c);if(!c){break a}e=+d;b=0;while(1){n[a>>3]=n[a>>3]*e;a=a+8|0;b=b+1|0;if((c|0)!=(b|0)){continue}break}}}function oba(a){var b=0;b=Xa-16|0;Xa=b;vW(b);i[114610]=0;G(9,a|0,0,b|0);a=i[114610];i[114610]=0;if((a|0)!=1){eb(b);Xa=b+16|0;return}a=B()|0;A()|0;eb(b);E(a|0);x()}function Vb(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;c=Xa-16|0;Xa=c;d=i[a>>2];a=(f=d,g=i[a+8>>2],h=Hb(c+8|0,b),e=i[i[d>>2]+32>>2],$a[e](f|0,g|0,h|0)|0);Xa=c+16|0;return a}function PJ(a){i[a>>2]=0;i[a+4>>2]=0;i[a+88>>2]=0;i[a+8>>2]=0;i[a+12>>2]=0;rL(a+112|0,48e3);i[a+668>>2]=0;Yw(a+724|0);Yw(a+736|0);Yw(a+748|0);aj(a+810|0);return a}function Lwa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Sm(a);i[114610]=0;G(91,a|0,b|0,c|0);b=i[114610];i[114610]=0;if((b|0)!=1){return a|0}a=B()|0;A()|0;Sd(d);E(a|0);x()}function Ib(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=wb(a,b);if(c){i[a+8>>2]=i[a+8>>2]+b;return c|0}b=a;a=i[a>>2];d=b,e=$a[i[i[a>>2]+24>>2]](a)|0,i[d+8>>2]=e;return c|0}function Ata(a,b,c){a:{if(!fs(b,c)){break a}while(1){if(k[zta(b)>>1]!=65535){break a}$L(b+4|0);if(fs(b,c)){continue}break}}c=i[b+4>>2];i[a>>2]=i[b>>2];i[a+4>>2]=c}function Ab(a){var b=0,c=0;b=Xa-16|0;Xa=b;i[114610]=0;I(14,a|0,b+8|0,b|0)|0;c=i[114610];i[114610]=0;if((c|0)!=1){Gm(a);Xa=b+16|0;return a}a=H(0)|0;A()|0;gb(a);x()}function AG(a){a=a|0;var b=0,c=0,d=0;b=te(1304568);i[114610]=0;c=F(2134,b|0)|0;d=i[114610];i[114610]=0;if((d|0)!=1){Haa(a,c);return}a=B()|0;A()|0;Cb(b);E(a|0);x()}function yba(a,b,c,d,e){var f=0,g=0;f=Xa-16|0;Xa=f;g=i[a+12>>2];i[f+8>>2]=i[a+8>>2];i[f+12>>2]=g;g=i[a+4>>2];i[f>>2]=i[a>>2];i[f+4>>2]=g;mua(f,b,c,d,e);Xa=f+16|0}function te(a){a=a|0;var b=0;a=a?a:1;a:{while(1){b=Zc(a);if(b){break a}b=i[115919];if(b){$a[b|0]();continue}break}a=P(4)|0;zk(a);W(a|0,71348,2008);x()}return b|0}function tX(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Xa-16|0;Xa=d;i[d+12>>2]=i[c>>2];a=$a[i[i[a>>2]+16>>2]](a,b,d+12|0)|0;if(a){i[c>>2]=i[d+12>>2]}Xa=d+16|0;return a|0}function rY(a,b){a=a|0;b=b|0;nm(a);i[a>>2]=71388;b=xb(b);i[114610]=0;C(2837,a+4|0,b|0)|0;b=i[114610];i[114610]=0;if((b|0)!=1){return a|0}a=B()|0;A()|0;E(a|0);x()}function dF(a,b){var c=0;c=Xa-16|0;Xa=c;i[114610]=0;I(197,a|0,c+8|0,b|0)|0;b=i[114610];i[114610]=0;if((b|0)!=1){Gm(a);Xa=c+16|0;return a}a=H(0)|0;A()|0;gb(a);x()}function bT(a){var b=0,c=0;a:{if(Xc(a,12061,3)){break a}b=a+3|0;if(j[b|0]<8|j[b|0]>14){break a}a=a+40|0;if(j[b|0]>9?!(j[a|0]<33?j[a|0]:0):0){break a}c=1}return c}function Zv(a,b){var c=0;c=Xa-16|0;Xa=c;i[114610]=0;I(150,a|0,c+8|0,b|0)|0;b=i[114610];i[114610]=0;if((b|0)!=1){Gm(a);Xa=c+16|0;return a}a=H(0)|0;A()|0;gb(a);x()}function Rs(a){var b=0;b=Xa-16|0;Xa=b;Ac(b+8|0,a,0);i[114610]=0;G(674,b+8|0,110,0);a=i[114610];i[114610]=0;if((a|0)!=1){Xa=b+16|0;return}a=H(0)|0;A()|0;gb(a);x()}function Qo(a){i[a+8>>2]=0;i[a+12>>2]=0;i[a>>2]=128;i[a+4>>2]=256;i[a+32>>2]=363;i[a+36>>2]=952;i[a+16>>2]=48e3;i[a+20>>2]=2;i[a+24>>2]=128;i[a+28>>2]=0;return a}function Oc(a){var b=0,c=0;b=Xa-16|0;Xa=b;i[114610]=0;I(1,a|0,b+8|0,b|0)|0;c=i[114610];i[114610]=0;if((c|0)!=1){Gm(a);Xa=b+16|0;return a}a=H(0)|0;A()|0;gb(a);x()}function xta(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Xa-16|0;Xa=d;h[d+12>>1]=c;h[d+14>>1]=b;Ag(d+14|0,k[i[i[a+24>>2]+8>>2]+12>>1]);wta(a,k[d+14>>1],d+12|0);Xa=d+16|0}function ula(a,b,c){var d=0,e=0,f=0;d=Xa-16|0;Xa=d;f=ke(b);e=i[c+4>>2];c=i[c>>2];i[d>>2]=c;i[d+4>>2]=e;i[d+8>>2]=c;i[d+12>>2]=e;tla(a,b,f+ -1&65535,d);Xa=d+16|0}function mAa(a,b){a=a|0;b=b|0;var c=0,d=0;d=Xa-80|0;Xa=d;c=-1;a:{if(!wR(a,d+8|0)){break a}c=0;if(!cO(d+8|0)){break a}c=Le(a,b,bO(d+8|0),_a)}Xa=d+80|0;return c|0}function MM(a,b){var c=0;c=i[a+4>>2];a:{if((b|0)>=0){b=b+c|0;i[a>>2]=i[a>>2]+(b>>>3&536870908);break a}b=b+c|0;i[a>>2]=i[a>>2]+((b+ -31|0)/32<<2)}i[a+4>>2]=b&31}function zO(a){if((j[a|0]|j[a+1|0]<<8|(j[a+2|0]<<16|j[a+3|0]<<24))==1297239878){return(j[a+8|0]|j[a+9|0]<<8|(j[a+10|0]<<16|j[a+11|0]<<24))==1279545165}return 0}function zH(a,b){var c=0;c=Xa-16|0;Xa=c;i[c+12>>2]=b;i[c+8>>2]=127;b=rb(c+12|0,c+8|0);m[i[a+20>>2]+144>>2]=p(p(l[b>>2])*p(-.007874015718698502))+p(1);Xa=c+16|0}function yp(a,b,c){a=a|0;b=b|0;c=c|0;g[a+11|0]=c;g[a+10|0]=b;g[a+12|0]=j[a+12|0]&251;h[a+8>>1]=65535;i[a>>2]=0;i[a+4>>2]=0;g[a+12|0]=j[a+12|0]&252|1;return a|0}function Xla(a){_I();Oe(219712,285248,a+131112|0);Oe(285248,350784,a+196648|0);Oe(350784,416320,a+262184|0);Oe(88624,219712,a+24|0);Tb(a+327720|0,416320,40960)}function UX(a,b,c){a=a|0;b=b|0;c=c|0;b=c;a:{if((c|0)>=257){VB();c=85304;break a}b:{if(g[463660]&1){break b}if(!cd(463660)){break b}bd(463660)}c=85300}Ac(a,b,c)}function wga(a,b){a=a|0;b=b|0;var c=0,d=0;c=Xa-16|0;Xa=c;d=b+1304396|0;if(!$c(d)){vga(c+8|0);OJ(d,sd(c+8|0));Hr(c+8|0)}a=tga(i[d>>2],a,b);Xa=c+16|0;return a|0}function vka(a,b,c){a:{if(!b){break a}if(c>>>0<b>>>0|l[i[sm(a)+8>>2]+40>>2]<b>>>0){break a}if(l[i[sm(a)+8>>2]+40>>2]<c>>>0){break a}i[a+20>>2]=c;i[a+16>>2]=b}}function nY(a,b){var c=0,d=0;c=Xa-16|0;Xa=c;a:{if(oe(a)){d=i[a>>2];g[c+15|0]=0;Rd(b+d|0,c+15|0);ce(a,b);break a}g[c+14|0]=0;Rd(a+b|0,c+14|0);Te(a,b)}Xa=c+16|0}function kEa(a,b){a=a|0;b=b|0;var c=0;IP(a);c=b+4|0;eEa(fb(a),i[a>>2],i[a+4>>2],c);Gb(a,c);Gb(a+4|0,b+8|0);Gb(fb(a),Mb(b));i[b>>2]=i[b+4>>2];Yj(a);jl(a);jl(a)}function aB(a){a=a|0;var b=0,c=0;b=Oc(a);i[114610]=0;F(277,a+12|0)|0;c=i[114610];i[114610]=0;if((c|0)!=1){wV(a+28|0);return a|0}a=B()|0;A()|0;eb(b);E(a|0);x()}function QC(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=Xa-16|0;Xa=a;i[a+8>>2]=b;while(1){if(c>>>0<d>>>0){PC(a+8|0,c);c=c+1|0;continue}break}Xa=a+16|0;return i[a+8>>2]}function Pya(a,b){a=a|0;b=b|0;var c=0;DN(a);c=b+4|0;Kya(fb(a),i[a>>2],i[a+4>>2],c);Gb(a,c);Gb(a+4|0,b+8|0);Gb(fb(a),Mb(b));i[b>>2]=i[b+4>>2];Tj(a);Tm(a);Tm(a)}function KIa(a,b){a=a|0;b=b|0;var c=0;dR(a);c=b+4|0;IIa(fb(a),i[a>>2],i[a+4>>2],c);Gb(a,c);Gb(a+4|0,b+8|0);Gb(fb(a),Mb(b));i[b>>2]=i[b+4>>2];ii(a);nl(a);nl(a)}function zha(a,b){a=a|0;b=b|0;var c=0;JH(a);c=b+4|0;ki(fb(a),i[a>>2],i[a+4>>2],c);Gb(a,c);Gb(a+4|0,b+8|0);Gb(fb(a),Mb(b));i[b>>2]=i[b+4>>2];Re(a);Fj(a);Fj(a)}function q2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=0;while(1){if((b|0)!=(c|0)){a=i[b>>2]+(a<<4)|0;d=a&-268435456;a=(d|d>>>24)^a;b=b+4|0;continue}break}return a|0}function am(a,b){var c=0;c=i[i[b>>2]+ -12>>2];i[114610]=0;b=i[(b+c|0)+24>>2];c=i[114610];i[114610]=0;if((c|0)!=1){i[a>>2]=b;return a}a=H(0)|0;A()|0;gb(a);x()}function ZG(a){a=a|0;var b=0;i[a+4240>>2]=0;i[a+4244>>2]=0;b=a+4264|0;i[b>>2]=0;i[b+4>>2]=0;b=a+4256|0;i[b>>2]=0;i[b+4>>2]=0;a=a+4248|0;i[a>>2]=0;i[a+4>>2]=0}function SZ(a){a=a|0;var b=0;a=i[a+8>>2];if(!a){return 1}i[114610]=0;a=F(2576,a|0)|0;b=i[114610];i[114610]=0;if((b|0)!=1){return a|0}a=H(0)|0;A()|0;gb(a);x()}function RMa(a,b){var c=0,d=0;c=Xa-16|0;Xa=c;a:{if(!b){break a}if(!wb(a,b)){break a}g[c+15|0]=0;Bf(a,c+15|0);g[c+8|0]=j[c+15|0];d=j[c+8|0]}Xa=c+16|0;return d}function QMa(a,b){var c=0,d=0;c=Xa-16|0;Xa=c;a:{if(!b){break a}if(!wb(a,b)){break a}g[c+15|0]=0;Bf(a,c+15|0);g[c+8|0]=j[c+15|0];d=g[c+8|0]}Xa=c+16|0;return d}function Pl(a){a=a|0;var b=0;b=P(8)|0;i[114610]=0;C(2062,b|0,a|0)|0;a=i[114610];i[114610]=0;if((a|0)!=1){W(b|0,71676,265);x()}a=B()|0;A()|0;Q(b|0);E(a|0);x()}function K_(){var a=0,b=0;rd(463120);i[115780]=62488;i[114610]=0;a=R(2445)|0;b=i[114610];i[114610]=0;if((b|0)!=1){i[115782]=a;return}a=B()|0;A()|0;E(a|0);x()}function JAa(a,b,c){var d=0,e=0;d=Xa-16|0;Xa=d;vAa(b,c);c=wb(a,c<<3);if(c){e=Xa-16|0;Xa=e;Ob(d+8|0,i[b>>2],bg(b)<<3);Xa=e+16|0;od(a,d+8|0)}Xa=d+16|0;return c}function z0(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=a;a=$a[i[i[a+8>>2]+20>>2]](a+8|0)|0;return Bi(g,b,c,d,e,f,xb(a),xb(a)+(lb(a)<<2)|0)|0}function vua(a,b,c,d,e){var f=0;if(d){while(1){m[b>>2]=p(i[a>>2])*e;m[c>>2]=p(i[a+4>>2])*e;c=c+4|0;a=a+8|0;b=b+4|0;f=f+1|0;if((f|0)!=(d|0)){continue}break}}}function t2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=0;while(1){if((b|0)!=(c|0)){a=g[b|0]+(a<<4)|0;d=a&-268435456;a=(d|d>>>24)^a;b=b+1|0;continue}break}return a|0}function qg(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,j=0;d=i[a>>2];return(f=d,g=jb(b),h=i[a+8>>2],j=c,e=i[i[d>>2]+28>>2],$a[e](f|0,g|0,h|0,j|0)|0)|0}function jma(a,b,c){var d=0,e=0;d=b-a|0;if((d|0)>=3){d=d>>>1|0;while(1){eJ(a,b+ -2|0);Qw(a,c,d+ -1|0,a);b=b+ -2|0;e=(d|0)>2;d=d+ -1|0;if(e){continue}break}}}function fh(a){var b=0,c=0;b=a*a;c=b*a;return p(c*(b*b)*(b*2718311493989822e-21+ -.00019839334836096632)+(c*(b*.008333329385889463+ -.16666666641626524)+a))}function f4(a,b,c,d){var e=0;e=Xa-16|0;Xa=e;i[e+12>>2]=d;d=lb(b);if(d>>>0<c>>>0){Ml();x()}b=xb(b);i[e+4>>2]=d-c;So(a,b+c|0,i[rb(e+12|0,e+4|0)>>2]);Xa=e+16|0}function _oa(a){var b=0,c=0;b=250;c=a;a:{while(1){if(i[c>>2]){break a}c=c+4|0;b=b+ -32|0;if(b>>>0>31){continue}break}return(i[a+28>>2]&67108863)!=0}return 1}function zt(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=Xa-16|0;Xa=d;g[d+15|0]=b;g[d+14|0]=127;e=a,f=j[Xb(d+15|0,d+14|0)|0]|(c?-128:0),g[e+22|0]=f;Xa=d+16|0}function tya(a,b){var c=0,d=0;if(ke(a)>>>0>b>>>0){while(1){if(rh(se(a,c))){sya(Jb(se(a,c)),Kb(se(a,c)))}d=d+1|0;c=d&65535;if(c>>>0<=b>>>0){continue}break}}}function of(a,b,c){a:{switch(b+ -1|0){case 0:if(c){return Yh(a,1)}return Yh(a,0);case 1:if(c){return Yh(a,3)}return Yh(a,2);default:break a}}return Yh(a,4)}function fB(a){var b=0;b=Xa-16|0;Xa=b;g[a|0]=0;g[a+1|0]=0;g[a+2|0]=0;g[a+3|0]=0;g[a+4|0]=0;g[a+5|0]=0;g[a+6|0]=0;g[a+7|0]=0;g[a+8|0]=0;g[a+9|0]=0;Xa=b+16|0}function eW(a,b,c,d){var e=0;e=(4294967295<b>>>0?0:b)+a|0;b=-1;a:{while(1){if((a|0)==(e|0)){break a}e=e+ -1|0;if(Bn(c,d,e)){continue}break}b=e-a|0}return b}function _j(a,b,c,d){i[d+8>>2]=b;i[d>>2]=0;i[d+4>>2]=0;i[c>>2]=d;if(i[i[a>>2]>>2]){i[a>>2]=i[i[a>>2]>>2]}JFa(i[Pb(a)>>2],i[c>>2]);a=fb(a);i[a>>2]=i[a>>2]+1}function YO(a){var b=0;a:{if(Xc(a,15531,3)){break a}b=a+4|0;if((j[b|0]|j[b+1|0]<<8|(j[b+2|0]<<16|j[b+3|0]<<24))>>>0<423){break a}return j[a+3|0]<6}return 0}function Oj(a,b,c){var d=0;d=Xa-16|0;Xa=d;i[d+12>>2]=c;if(l[b+4>>2]<0){zi(20324);x()}c=i[b>>2];i[d+8>>2]=i[b+4>>2];Ac(a,c,i[rb(d+12|0,d+8|0)>>2]);Xa=d+16|0}function K5(a,b,c,d){var e=0,f=0,g=p(0);if((b|0)>=1){while(1){f=(e<<2)+a|0;g=m[f>>2];m[f+2304>>2]=g*d;m[f>>2]=g*c;e=e+1|0;if((e|0)!=(b|0)){continue}break}}}function IL(a,b){a=a|0;b=b|0;var c=0;c=Xa-16|0;Xa=c;i[c+12>>2]=b;a:{if(Si(a)){Bsa(c+8|0,c+12|0);ks(a,c+8|0);$e(c+8|0);break a}QL(i[a>>2],b)}HL(a);Xa=c+16|0}function At(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=Xa-16|0;Xa=d;g[d+15|0]=b;g[d+14|0]=127;e=a,f=j[Xb(d+15|0,d+14|0)|0]|(c?-128:0),g[e+21|0]=f;Xa=d+16|0}function xaa(a,b,c){_q(a);i[a+8>>2]=c;i[a+4>>2]=0;i[a>>2]=84112;c=i[b+4>>2];i[a+12>>2]=i[b>>2];i[a+16>>2]=c;c=i[b+12>>2];i[a+20>>2]=i[b+8>>2];i[a+24>>2]=c}function wea(a,b,c){a=a|0;b=b|0;c=p(c);var d=0;d=Xa-16|0;Xa=d;m[d+12>>2]=c;if((b|0)<=3){Id(d+12|0,p(0));m[((b<<2)+a|0)+4208>>2]=m[d+12>>2];XG(a)}Xa=d+16|0}function sk(a,b){var c=0;c=i[i[b>>2]+ -12>>2];i[114610]=0;b=F(27,b+c|0)|0;c=i[114610];i[114610]=0;if((c|0)!=1){i[a>>2]=b;return a}a=H(0)|0;A()|0;gb(a);x()}function ksa(a,b,c){var d=0;d=Xa-16|0;Xa=d;i[d+8>>2]=c;i[d>>2]=b;if(pb(d,d+8|0)){while(1){AL(a,j[i[d>>2]]);Tf(d);if(pb(d,d+8|0)){continue}break}}Xa=d+16|0}function d9(a,b){a=a|0;b=b|0;var c=0;a:{if(!$q(b)){break a}a=a+24|0;if(!pg(i[a>>2]+484344|0,b&65535)){break a}c=i[Fb(i[a>>2]+484344|0,b)+12>>2]}return c|0}function SK(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a:{if(d>>>0>=64){d=-1;if(i[a+480180>>2]&2){break a}}i[b+56>>2]=0;d=Do(a,k[b+60>>1],i[b+48>>2],c,0)}return d|0}function Rj(a,b){var c=0,d=0;a:{b=Sj(a,b);if((b|0)==255){break a}if(Si(a)){break a}c=a+4|0;d=Nb(c,b);g[d|0]=j[d|0]&223;Ng(i[a>>2],bs(b)|176,j[Nb(c,b)|0])}}function Qsa(a,b,c,d){var e=0;if((b|0)!=(c|0)){e=i[d>>2];while(1){c=c+ -32|0;UL(a,e+ -32|0,c);e=i[d>>2]+ -32|0;i[d>>2]=e;if((b|0)!=(c|0)){continue}break}}}function Qfa(a,b,c){a=a|0;b=b|0;c=p(c);var d=0;d=Xa-16|0;Xa=d;m[d+12>>2]=c;if((b|0)<=5){Id(d+12|0,p(0));m[((b<<2)+a|0)+4208>>2]=m[d+12>>2];kH(a)}Xa=d+16|0}function QDa(a,b,c,d){var e=0;if((b|0)!=(c|0)){e=i[d>>2];while(1){c=c+ -24|0;xP(a,e+ -24|0,c);e=i[d>>2]+ -24|0;i[d>>2]=e;if((b|0)!=(c|0)){continue}break}}}function PU(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=i[a+16>>2];a:{if(!c){d=1;if((a|0)==(b|0)){break a}}d=0;if(a>>>0<=b>>>0){break a}d=a-b>>>0>=c>>>0}return d|0}function OJa(a,b,c,d){var e=0;if((b|0)!=(c|0)){e=i[d>>2];while(1){c=c+ -24|0;gn(a,e+ -24|0,c);e=i[d>>2]+ -24|0;i[d>>2]=e;if((b|0)!=(c|0)){continue}break}}}function O1(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=Xa-16|0;Xa=e;i[e+12>>2]=b;i[e+8>>2]=d;b=ah(e,e+12|0);a=BD(a,c,i[e+8>>2]);ne(b);Xa=e+16|0;return a|0}function Jaa(a,b){var c=0,d=0;c=te(44);i[114610]=0;b=C(2135,c|0,b|0)|0;d=i[114610];i[114610]=0;if((d|0)!=1){Faa(a,b);return}a=B()|0;A()|0;Cb(c);E(a|0);x()}function Efa(a,b,c){a=a|0;b=b|0;c=p(c);var d=0;d=Xa-16|0;Xa=d;m[d+12>>2]=c;if((b|0)<=4){Id(d+12|0,p(0));m[((b<<2)+a|0)+4208>>2]=m[d+12>>2];hH(a)}Xa=d+16|0}function Dea(a,b,c){a=a|0;b=b|0;c=p(c);var d=0;d=Xa-16|0;Xa=d;m[d+12>>2]=c;if((b|0)<=2){Id(d+12|0,p(0));m[((b<<2)+a|0)+4208>>2]=m[d+12>>2];_G(a)}Xa=d+16|0}function DE(a){var b=0,c=0,d=0;if(Hg(g[i[a>>2]])){while(1){b=i[a>>2];d=g[b|0];i[a>>2]=b+1;c=(o(c,10)+d|0)+ -48|0;if(Hg(g[b+1|0])){continue}break}}return c}function Aaa(a,b,c){_q(a);i[a+8>>2]=c;i[a+4>>2]=0;i[a>>2]=84016;c=i[b+4>>2];i[a+12>>2]=i[b>>2];i[a+16>>2]=c;c=i[b+12>>2];i[a+20>>2]=i[b+8>>2];i[a+24>>2]=c}function xi(a,b,c,d){var e=0,f=0;e=o(b,c);f=e;a:{if(i[d+76>>2]<=-1){a=ou(a,e,d);break a}a=ou(a,e,d)}if((f|0)==(a|0)){return b?c:0}return(a>>>0)/(b>>>0)|0}function po(a,b){var c=0;i[a>>2]=76688;i[a>>2]=77104;c=i[b+8>>2];i[a+4>>2]=i[b+4>>2];i[a+8>>2]=c;c=i[b+16>>2];i[a+12>>2]=i[b+12>>2];i[a+16>>2]=c;return a}function oV(a,b,c,d){var e=0;if((b|0)!=(c|0)){e=i[d>>2];while(1){c=c+ -32|0;XA(a,e+ -32|0,c);e=i[d>>2]+ -32|0;i[d>>2]=e;if((b|0)!=(c|0)){continue}break}}}function o3(a,b,c,d){var e=0;if((b|0)!=(c|0)){e=i[d>>2];while(1){c=c+ -12|0;fv(a,e+ -12|0,c);e=i[d>>2]+ -12|0;i[d>>2]=e;if((b|0)!=(c|0)){continue}break}}}function l8(a,b,c,d){var e=0;if((b|0)!=(c|0)){e=i[d>>2];while(1){c=c+ -16|0;SF(a,e+ -16|0,c);e=i[d>>2]+ -16|0;i[d>>2]=e;if((b|0)!=(c|0)){continue}break}}}function dC(a,b){a=a|0;b=b|0;nm(a);i[a>>2]=71388;i[114610]=0;C(2837,a+4|0,b|0)|0;b=i[114610];i[114610]=0;if((b|0)!=1){return a|0}a=B()|0;A()|0;E(a|0);x()}function Zk(a){var b=0,c=0,d=0;b=Xa-16|0;Xa=b;c=i[a+1074400>>2];d=i[a+1074416>>2];i[b+12>>2]=1;a=i[Jc(a+1074396|0,b+12|0)>>2];Xa=b+16|0;return o(a,c+d|0)}function Yq(a){var b=0,c=0,d=0;b=aNa(i[a>>2],1)^270549120;c=i[a+4>>2];d=(b+(c<<2)|0)+2019860093|0;i[a>>2]=d;b=a;a=o(aNa(d,16),5)+c|0;i[b+4>>2]=a;return a}function TEa(a,b){a=a|0;b=b|0;var c=0,d=0;d=Xa-16|0;Xa=d;c=-1;a:{if(!fj(a,d+8|0)){break a}c=0;if(!SEa(d+8|0)){break a}c=Le(a,b,36,0)}Xa=d+16|0;return c|0}function HV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=i[a+8>>2];a:{if(!c){d=1;if((a|0)==(b|0)){break a}}d=0;if(a>>>0<=b>>>0){break a}d=a-b>>>0>=c>>>0}return d|0}function Cv(a,b){var c=0;while(1){c=(b|0)<120?b:120;a=p(p(m[((c&3)<<2)+43520>>2]*a)*p(1073741824>>>(c>>2)|0));b=b-c|0;if((b|0)>0){continue}break}return a}function zpa(a){if(!(p(2147483648)>a)){return 2147483647}if(!(p(-2147483648)<a)){return-2147483648}if(p(q(a))<p(2147483648)){return~~a}return-2147483648}function vga(a){var b=0,c=0,d=0;b=te(12);i[114610]=0;c=F(1752,b|0)|0;d=i[114610];i[114610]=0;if((d|0)!=1){rga(a,c);return}a=B()|0;A()|0;Cb(b);E(a|0);x()}function kra(a,b){a=a|0;b=b|0;var c=0;Hi(a);c=b+4|0;ira(fb(a),i[a>>2],i[a+4>>2],c);Gb(a,c);Gb(a+4|0,b+8|0);Gb(fb(a),Mb(b));i[b>>2]=i[b+4>>2];Sn(a,cc(a))}function h3(a,b){a=a|0;b=b|0;var c=0,d=0;b=Zu(b);i[a+36>>2]=b;c=a,d=vm(b),i[c+44>>2]=d;c=a,d=Zl(i[a+36>>2]),g[c+53|0]=d;if(i[a+44>>2]>=9){Pl(56948);x()}}function fm(a,b){var c=0,d=0;b=b+7&-8;d=i[a+80>>2];a:{if(d){b=i[a+92>>2]-b|0;c=0;if((b|0)<i[a+88>>2]){break a}i[a+92>>2]=b;return b+d|0}c=Zc(b)}return c}function d3(a,b){a=a|0;b=b|0;var c=0,d=0;b=Yu(b);i[a+36>>2]=b;c=a,d=vm(b),i[c+44>>2]=d;c=a,d=Zl(i[a+36>>2]),g[c+53|0]=d;if(i[a+44>>2]>=9){Pl(56948);x()}}function bia(a,b){a=a|0;b=b|0;var c=0;_e(a);c=b+4|0;$ha(fb(a),i[a>>2],i[a+4>>2],c);Gb(a,c);Gb(a+4|0,b+8|0);Gb(fb(a),Mb(b));i[b>>2]=i[b+4>>2];Mj(a,qb(a))}function Tsa(a,b){a=a|0;b=b|0;var c=0;Al(a);c=b+4|0;Qsa(fb(a),i[a>>2],i[a+4>>2],c);Gb(a,c);Gb(a+4|0,b+8|0);Gb(fb(a),Mb(b));i[b>>2]=i[b+4>>2];Sp(a,be(a))}function SDa(a,b){a=a|0;b=b|0;var c=0;qh(a);c=b+4|0;QDa(fb(a),i[a>>2],i[a+4>>2],c);Gb(a,c);Gb(a+4|0,b+8|0);Gb(fb(a),Mb(b));i[b>>2]=i[b+4>>2];ht(a,nd(a))}function Oxa(a,b){a=a|0;b=b|0;var c=0;Hi(a);c=b+4|0;uxa(fb(a),i[a>>2],i[a+4>>2],c);Gb(a,c);Gb(a+4|0,b+8|0);Gb(fb(a),Mb(b));i[b>>2]=i[b+4>>2];Sn(a,cc(a))}function OE(a,b,c,d,e,f){var h=0,k=0;h=i[a+32>>2];k=h+(c<<2)|0;a:{if(!j[a+23|0]){break a}k=h;h=d<<2;i[k+h>>2]=b;g[i[a+8>>2]+d|0]=e;b=c;k=f+h|0}i[k>>2]=b}function JHa(a,b){a=a|0;b=b|0;var c=0;wk(a);c=b+4|0;IHa(fb(a),i[a>>2],i[a+4>>2],c);Gb(a,c);Gb(a+4|0,b+8|0);Gb(fb(a),Mb(b));i[b>>2]=i[b+4>>2];Jl(a,Wc(a))}function Dma(a){var b=0;a:{if(!i[a+16>>2]){break a}b=i[a+20>>2];if(b>>>0>4|!(1<<b&22)){break a}a=i[a+28>>2];if(a>>>0>4){break a}return 23>>>a&1}return 0}function DY(a,b,c){var d=0;d=Xa-16|0;Xa=d;w2(d,b,c,Ud());b=i[d+4>>2];i[a>>2]=i[d>>2];i[a+4>>2]=b;b=i[d+12>>2];i[a+8>>2]=i[d+8>>2];i[a+12>>2]=b;Xa=d+16|0}function Bxa(a,b){a=a|0;b=b|0;var c=0;Hi(a);c=b+4|0;zxa(fb(a),i[a>>2],i[a+4>>2],c);Gb(a,c);Gb(a+4|0,b+8|0);Gb(fb(a),Mb(b));i[b>>2]=i[b+4>>2];Sn(a,cc(a))}function Bja(a,b){a=a|0;b=b|0;var c=0;yJ(a);c=b+4|0;yja(fb(a),i[a>>2],i[a+4>>2],c);Gb(a,c);Gb(a+4|0,b+8|0);Gb(fb(a),Mb(b));i[b>>2]=i[b+4>>2];qI(a,bf(a))}function woa(a,b){a=a|0;b=b|0;var c=0;Al(a);c=b+4|0;ki(fb(a),i[a>>2],i[a+4>>2],c);Gb(a,c);Gb(a+4|0,b+8|0);Gb(fb(a),Mb(b));i[b>>2]=i[b+4>>2];Sp(a,be(a))}function vc(a,b){a=a|0;b=b|0;var c=0,d=0;a:{if(l[a+8>>2]<b>>>0){d=i[a>>2];c=0;if($a[i[i[d>>2]+24>>2]](d)>>>0<b>>>0){break a}}i[a+8>>2]=b;c=1}return c|0}function pAa(a,b){a=a|0;b=b|0;var c=0;Vp(a);c=b+4|0;ki(fb(a),i[a>>2],i[a+4>>2],c);Gb(a,c);Gb(a+4|0,b+8|0);Gb(fb(a),Mb(b));i[b>>2]=i[b+4>>2];Wt(a,bg(a))}function np(a,b){a=a|0;b=b|0;var c=0;qh(a);c=b+4|0;OJa(fb(a),i[a>>2],i[a+4>>2],c);Gb(a,c);Gb(a+4|0,b+8|0);Gb(fb(a),Mb(b));i[b>>2]=i[b+4>>2];ht(a,nd(a))}function l_(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;while(1){if((b|0)!=(c|0)){a=i[b>>2];g[e|0]=a>>>0<128?a:d;e=e+1|0;b=b+4|0;continue}break}return c|0}function fFa(a,b){a=a|0;b=b|0;var c=0;$s(a);c=b+4|0;PP(fb(a),i[a>>2],i[a+4>>2],c);Gb(a,c);Gb(a+4|0,b+8|0);Gb(fb(a),Mb(b));i[b>>2]=i[b+4>>2];ct(a,If(a))}function T0(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=a;a=$a[i[i[a+8>>2]+20>>2]](a+8|0)|0;return Ci(g,b,c,d,e,f,xb(a),xb(a)+lb(a)|0)|0}function Pda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=Xa-32|0;Xa=c;d=c,e=bL(b),i[d+16>>2]=e;Nda(c+24|0,a,b,c+16|0,c+8|0);a=Qg(c+24|0);Xa=c+32|0;return a+12|0}function EL(a){var b=0,c=0,d=0;b=a+26|0;c=j[b|0]+27|0;if(j[b|0]){while(1){c=j[(a+d|0)+27|0]+c|0;d=d+1|0;if(d>>>0<j[b|0]){continue}break}}return c&65535}function $ha(a,b,c,d){var e=0;if((b|0)!=(c|0)){e=i[d>>2];while(1){c=c+ -4|0;XH(a,e+ -4|0,c);e=i[d>>2]+ -4|0;i[d>>2]=e;if((b|0)!=(c|0)){continue}break}}}function zya(a,b){var c=0,d=0;c=Xa-16|0;Xa=c;nN(c+8|0,b);b=nb(c+8|0);d=Tc(a,Hb(c,c+8|0));if((b|0)==(d|0)){Dc(a,nb(c+8|0))}Xa=c+16|0;return(b|0)==(d|0)}function zka(a,b){var c=0,d=0;c=Xa-16|0;Xa=c;JI(c+8|0,b);b=nb(c+8|0);d=Vb(a,Hb(c,c+8|0));if((b|0)==(d|0)){Ib(a,nb(c+8|0))}Xa=c+16|0;return(b|0)==(d|0)}function zHa(a,b){var c=0,d=0;c=Xa-16|0;Xa=c;NQ(c+8|0,b);b=nb(c+8|0);d=Vb(a,Hb(c,c+8|0));if((b|0)==(d|0)){Ib(a,nb(c+8|0))}Xa=c+16|0;return(b|0)==(d|0)}function zFa(a,b){var c=0,d=0;c=Xa-16|0;Xa=c;mt(c+8|0,b);b=nb(c+8|0);d=Tc(a,Hb(c,c+8|0));if((b|0)==(d|0)){Dc(a,nb(c+8|0))}Xa=c+16|0;return(b|0)==(d|0)}function zAa(a,b){var c=0,d=0;c=Xa-16|0;Xa=c;hO(c+8|0,b);b=nb(c+8|0);d=Vb(a,Hb(c,c+8|0));if((b|0)==(d|0)){Ib(a,nb(c+8|0))}Xa=c+16|0;return(b|0)==(d|0)}function yya(a,b){var c=0,d=0;c=Xa-16|0;Xa=c;nN(c+8|0,b);b=nb(c+8|0);d=Vb(a,Hb(c,c+8|0));if((b|0)==(d|0)){Ib(a,nb(c+8|0))}Xa=c+16|0;return(b|0)==(d|0)}function yV(a,b){a=a|0;b=b|0;var c=0;Al(a);c=b+4|0;oV(fb(a),i[a>>2],i[a+4>>2],c);Gb(a,c);Gb(a+4|0,b+8|0);Gb(fb(a),Mb(b));i[b>>2]=i[b+4>>2];Sp(a,be(a))}function yIa(a,b){var c=0,d=0;c=Xa-16|0;Xa=c;IS(c+8|0,b);b=nb(c+8|0);d=Vb(a,Hb(c,c+8|0));if((b|0)==(d|0)){Ib(a,nb(c+8|0))}Xa=c+16|0;return(b|0)==(d|0)}function xHa(a,b){var c=0,d=0;c=Xa-16|0;Xa=c;LQ(c+8|0,b);b=nb(c+8|0);d=Vb(a,Hb(c,c+8|0));if((b|0)==(d|0)){Ib(a,nb(c+8|0))}Xa=c+16|0;return(b|0)==(d|0)}function xFa(a,b){var c=0,d=0;c=Xa-16|0;Xa=c;mt(c+8|0,b);b=nb(c+8|0);d=Vb(a,Hb(c,c+8|0));if((b|0)==(d|0)){Ib(a,nb(c+8|0))}Xa=c+16|0;return(b|0)==(d|0)}function uJa(a,b){var c=0,d=0;c=Xa-16|0;Xa=c;yR(c+8|0,b);b=nb(c+8|0);d=Tc(a,Hb(c,c+8|0));if((b|0)==(d|0)){Dc(a,nb(c+8|0))}Xa=c+16|0;return(b|0)==(d|0)}function tJa(a,b){var c=0,d=0;c=Xa-16|0;Xa=c;yR(c+8|0,b);b=nb(c+8|0);d=Vb(a,Hb(c,c+8|0));if((b|0)==(d|0)){Ib(a,nb(c+8|0))}Xa=c+16|0;return(b|0)==(d|0)}function tHa(a,b){var c=0,d=0;c=Xa-16|0;Xa=c;HQ(c+8|0,b);b=nb(c+8|0);d=Tc(a,Hb(c,c+8|0));if((b|0)==(d|0)){Dc(a,nb(c+8|0))}Xa=c+16|0;return(b|0)==(d|0)}function tDa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=Xa-32|0;Xa=c;d=c,e=Zg(b),i[d+16>>2]=e;gDa(c+24|0,a,b,c+16|0,c+8|0);a=Ks(c+24|0);Xa=c+32|0;return a+2|0}function sIa(a,b){var c=0,d=0;c=Xa-16|0;Xa=c;lz(c+8|0,b);b=nb(c+8|0);d=Tc(a,Hb(c,c+8|0));if((b|0)==(d|0)){Dc(a,nb(c+8|0))}Xa=c+16|0;return(b|0)==(d|0)}function sHa(a,b){var c=0,d=0;c=Xa-16|0;Xa=c;HQ(c+8|0,b);b=nb(c+8|0);d=Vb(a,Hb(c,c+8|0));if((b|0)==(d|0)){Ib(a,nb(c+8|0))}Xa=c+16|0;return(b|0)==(d|0)}function rIa(a,b){var c=0,d=0;c=Xa-16|0;Xa=c;lz(c+8|0,b);b=nb(c+8|0);d=Vb(a,Hb(c,c+8|0));if((b|0)==(d|0)){Ib(a,nb(c+8|0))}Xa=c+16|0;return(b|0)==(d|0)}function qpa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=Xa-32|0;Xa=c;d=c,e=bL(b),i[d+16>>2]=e;dpa(c+24|0,a,b,c+16|0,c+8|0);a=Ks(c+24|0);Xa=c+32|0;return a+4|0}function qU(a,b,c){a=a+4|0;a=j[a|0]|j[a+1|0]<<8|(j[a+2|0]<<16|j[a+3|0]<<24);return!c&(a<<24|a<<8&16711680|(a>>>8&65280|a>>>24))+ -8>>>0<=b>>>0|0<c>>>0}function qIa(a,b){var c=0,d=0;c=Xa-16|0;Xa=c;yz(c+8|0,b);b=nb(c+8|0);d=Vb(a,Hb(c,c+8|0));if((b|0)==(d|0)){Ib(a,nb(c+8|0))}Xa=c+16|0;return(b|0)==(d|0)}function pBa(a,b){var c=0,d=0;c=Xa-16|0;Xa=c;vO(c+8|0,b);b=nb(c+8|0);d=Vb(a,Hb(c,c+8|0));if((b|0)==(d|0)){Ib(a,nb(c+8|0))}Xa=c+16|0;return(b|0)==(d|0)}function n8(a,b){a=a|0;b=b|0;var c=0;wk(a);c=b+4|0;l8(fb(a),i[a>>2],i[a+4>>2],c);Gb(a,c);Gb(a+4|0,b+8|0);Gb(fb(a),Mb(b));i[b>>2]=i[b+4>>2];Jl(a,Wc(a))}function mpa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=Xa-32|0;Xa=c;d=c,e=Zg(b),i[d+16>>2]=e;apa(c+24|0,a,b,c+16|0,c+8|0);a=Qg(c+24|0);Xa=c+32|0;return a+8|0}function mBa(a,b){var c=0,d=0;c=Xa-16|0;Xa=c;py(c+8|0,b);b=nb(c+8|0);d=Vb(a,Hb(c,c+8|0));if((b|0)==(d|0)){Ib(a,nb(c+8|0))}Xa=c+16|0;return(b|0)==(d|0)}function lya(a,b){var c=0,d=0;c=Xa-16|0;Xa=c;ok(c+8|0,b);b=nb(c+8|0);d=Tc(a,Hb(c,c+8|0));if((b|0)==(d|0)){Dc(a,nb(c+8|0))}Xa=c+16|0;return(b|0)==(d|0)}function kya(a,b){var c=0,d=0;c=Xa-16|0;Xa=c;tO(c+8|0,b);b=nb(c+8|0);d=Tc(a,Hb(c,c+8|0));if((b|0)==(d|0)){Dc(a,nb(c+8|0))}Xa=c+16|0;return(b|0)==(d|0)}function kFa(a,b){var c=0,d=0;c=Xa-16|0;Xa=c;Oy(c+8|0,b);b=nb(c+8|0);d=Vb(a,Hb(c,c+8|0));if((b|0)==(d|0)){Ib(a,nb(c+8|0))}Xa=c+16|0;return(b|0)==(d|0)}function kBa(a,b){var c=0,d=0;c=Xa-16|0;Xa=c;vO(c+8|0,b);b=nb(c+8|0);d=Tc(a,Hb(c,c+8|0));if((b|0)==(d|0)){Dc(a,nb(c+8|0))}Xa=c+16|0;return(b|0)==(d|0)}function jBa(a,b){var c=0,d=0;c=Xa-16|0;Xa=c;tO(c+8|0,b);b=nb(c+8|0);d=Vb(a,Hb(c,c+8|0));if((b|0)==(d|0)){Ib(a,nb(c+8|0))}Xa=c+16|0;return(b|0)==(d|0)}function isa(a,b){var c=0,d=0;c=Xa-16|0;Xa=c;zL(c+8|0,b);b=nb(c+8|0);d=Vb(a,Hb(c,c+8|0));if((b|0)==(d|0)){Ib(a,nb(c+8|0))}Xa=c+16|0;return(b|0)==(d|0)}function iHa(a,b){var c=0,d=0;c=Xa-16|0;Xa=c;CQ(c+8|0,b);b=nb(c+8|0);d=Tc(a,Hb(c,c+8|0));if((b|0)==(d|0)){Dc(a,nb(c+8|0))}Xa=c+16|0;return(b|0)==(d|0)}function iFa(a,b){var c=0,d=0;c=Xa-16|0;Xa=c;VP(c+8|0,b);b=nb(c+8|0);d=Vb(a,Hb(c,c+8|0));if((b|0)==(d|0)){Ib(a,nb(c+8|0))}Xa=c+16|0;return(b|0)==(d|0)}function hHa(a,b){var c=0,d=0;c=Xa-16|0;Xa=c;CQ(c+8|0,b);b=nb(c+8|0);d=Vb(a,Hb(c,c+8|0));if((b|0)==(d|0)){Ib(a,nb(c+8|0))}Xa=c+16|0;return(b|0)==(d|0)}function h8(a,b){a=a|0;b=b|0;var c=0;qh(a);c=b+4|0;g8(fb(a),i[a>>2],i[a+4>>2],c);Gb(a,c);Gb(a+4|0,b+8|0);Gb(fb(a),Mb(b));i[b>>2]=i[b+4>>2];ht(a,nd(a))}function gh(a,b,c){i[b+12>>2]=i[b+12>>2]+c;i[b+8>>2]=i[b+8>>2]-c;c=i[b+4>>2];i[a>>2]=i[b>>2];i[a+4>>2]=c;c=i[b+12>>2];i[a+8>>2]=i[b+8>>2];i[a+12>>2]=c}function gBa(a,b){var c=0,d=0;c=Xa-16|0;Xa=c;rO(c+8|0,b);b=nb(c+8|0);d=Tc(a,Hb(c,c+8|0));if((b|0)==(d|0)){Dc(a,nb(c+8|0))}Xa=c+16|0;return(b|0)==(d|0)}function fya(a,b){var c=0,d=0;c=Xa-16|0;Xa=c;LQ(c+8|0,b);b=nb(c+8|0);d=Tc(a,Hb(c,c+8|0));if((b|0)==(d|0)){Dc(a,nb(c+8|0))}Xa=c+16|0;return(b|0)==(d|0)}function fLa(a,b,c){var d=0,e=0;d=Xa-16|0;Xa=d;cU(b,c);c=wb(a,c);if(c){e=Xa-16|0;Xa=e;Ob(d+8|0,i[b>>2],rc(b));Xa=e+16|0;od(a,d+8|0)}Xa=d+16|0;return c}function fBa(a,b){var c=0,d=0;c=Xa-16|0;Xa=c;py(c+8|0,b);b=nb(c+8|0);d=Tc(a,Hb(c,c+8|0));if((b|0)==(d|0)){Dc(a,nb(c+8|0))}Xa=c+16|0;return(b|0)==(d|0)}function eBa(a,b){var c=0,d=0;c=Xa-16|0;Xa=c;rO(c+8|0,b);b=nb(c+8|0);d=Vb(a,Hb(c,c+8|0));if((b|0)==(d|0)){Ib(a,nb(c+8|0))}Xa=c+16|0;return(b|0)==(d|0)}function cDa(a,b){var c=0,d=0;c=Xa-16|0;Xa=c;fP(c+8|0,b);b=nb(c+8|0);d=Vb(a,Hb(c,c+8|0));if((b|0)==(d|0)){Ib(a,nb(c+8|0))}Xa=c+16|0;return(b|0)==(d|0)}function bEa(a,b){var c=0,d=0;c=Xa-16|0;Xa=c;Ky(c+8|0,b);b=nb(c+8|0);d=Vb(a,Hb(c,c+8|0));if((b|0)==(d|0)){Ib(a,nb(c+8|0))}Xa=c+16|0;return(b|0)==(d|0)}function aDa(a,b){var c=0,d=0;c=Xa-16|0;Xa=c;fP(c+8|0,b);b=nb(c+8|0);d=Tc(a,Hb(c,c+8|0));if((b|0)==(d|0)){Dc(a,nb(c+8|0))}Xa=c+16|0;return(b|0)==(d|0)}function aA(a,b){a=a|0;b=b|0;var c=0;xp(a);c=b+4|0;ki(fb(a),i[a>>2],i[a+4>>2],c);Gb(a,c);Gb(a+4|0,b+8|0);Gb(fb(a),Mb(b));i[b>>2]=i[b+4>>2];Sz(a,rc(a))}function ZEa(a,b){var c=0,d=0;c=Xa-16|0;Xa=c;MP(c+8|0,b);b=nb(c+8|0);d=Vb(a,Hb(c,c+8|0));if((b|0)==(d|0)){Ib(a,nb(c+8|0))}Xa=c+16|0;return(b|0)==(d|0)}function Yz(a,b){a=a|0;b=b|0;var c=0;pk(a);c=b+4|0;ki(fb(a),i[a>>2],i[a+4>>2],c);Gb(a,c);Gb(a+4|0,b+8|0);Gb(fb(a),Mb(b));i[b>>2]=i[b+4>>2];It(a,Wb(a))}function YHa(a,b){var c=0,d=0;c=Xa-16|0;Xa=c;VQ(c+8|0,b);b=nb(c+8|0);d=Tc(a,Hb(c,c+8|0));if((b|0)==(d|0)){Dc(a,nb(c+8|0))}Xa=c+16|0;return(b|0)==(d|0)}function YDa(a,b){var c=0,d=0;c=Xa-16|0;Xa=c;Kz(c+8|0,b);b=nb(c+8|0);d=Tc(a,Hb(c,c+8|0));if((b|0)==(d|0)){Dc(a,nb(c+8|0))}Xa=c+16|0;return(b|0)==(d|0)}function XHa(a,b){var c=0,d=0;c=Xa-16|0;Xa=c;VQ(c+8|0,b);b=nb(c+8|0);d=Vb(a,Hb(c,c+8|0));if((b|0)==(d|0)){Ib(a,nb(c+8|0))}Xa=c+16|0;return(b|0)==(d|0)}function VLa(a,b){var c=0,d=0;c=Xa-16|0;Xa=c;LS(c+8|0,b);b=nb(c+8|0);d=Tc(a,Hb(c,c+8|0));if((b|0)==(d|0)){Dc(a,nb(c+8|0))}Xa=c+16|0;return(b|0)==(d|0)}function ULa(a,b){var c=0,d=0;c=Xa-16|0;Xa=c;LS(c+8|0,b);b=nb(c+8|0);d=Vb(a,Hb(c,c+8|0));if((b|0)==(d|0)){Ib(a,nb(c+8|0))}Xa=c+16|0;return(b|0)==(d|0)}function TFa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=Xa-32|0;Xa=c;d=c,e=Zg(b),i[d+16>>2]=e;NFa(c+24|0,a,b,c+16|0,c+8|0);a=Qg(c+24|0);Xa=c+32|0;return a+4|0}function Swa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=Xa-16|0;Xa=e;a:{if(j[d|0]){Nwa(a,td(e+8|0,b),$h(c,b));break a}Mwa(a,td(e,b),$h(c,b))}Xa=e+16|0}function RLa(a,b){var c=0,d=0;c=Xa-16|0;Xa=c;JS(c+8|0,b);b=nb(c+8|0);d=Tc(a,Hb(c,c+8|0));if((b|0)==(d|0)){Dc(a,nb(c+8|0))}Xa=c+16|0;return(b|0)==(d|0)}function QW(a,b){a=a|0;b=b|0;var c=0;wk(a);c=b+4|0;ki(fb(a),i[a>>2],i[a+4>>2],c);Gb(a,c);Gb(a+4|0,b+8|0);Gb(fb(a),Mb(b));i[b>>2]=i[b+4>>2];Jl(a,Wc(a))}function QLa(a,b){var c=0,d=0;c=Xa-16|0;Xa=c;JS(c+8|0,b);b=nb(c+8|0);d=Vb(a,Hb(c,c+8|0));if((b|0)==(d|0)){Ib(a,nb(c+8|0))}Xa=c+16|0;return(b|0)==(d|0)}function QKa(a,b){var c=0,d=0;c=Xa-16|0;Xa=c;Kz(c+8|0,b);b=nb(c+8|0);d=Vb(a,Hb(c,c+8|0));if((b|0)==(d|0)){Ib(a,nb(c+8|0))}Xa=c+16|0;return(b|0)==(d|0)}function PKa(a,b){var c=0,d=0;c=Xa-16|0;Xa=c;gS(c+8|0,b);b=nb(c+8|0);d=Tc(a,Hb(c,c+8|0));if((b|0)==(d|0)){Dc(a,nb(c+8|0))}Xa=c+16|0;return(b|0)==(d|0)}function OKa(a,b){var c=0,d=0;c=Xa-16|0;Xa=c;gS(c+8|0,b);b=nb(c+8|0);d=Vb(a,Hb(c,c+8|0));if((b|0)==(d|0)){Ib(a,nb(c+8|0))}Xa=c+16|0;return(b|0)==(d|0)}function Nza(a,b){var c=0,d=0;c=Xa-16|0;Xa=c;PN(c+8|0,b);b=nb(c+8|0);d=Tc(a,Hb(c,c+8|0));if((b|0)==(d|0)){Dc(a,nb(c+8|0))}Xa=c+16|0;return(b|0)==(d|0)}function NIa(a,b){var c=0,d=0;c=Xa-16|0;Xa=c;_s(c+8|0,b);b=nb(c+8|0);d=Tc(a,Hb(c,c+8|0));if((b|0)==(d|0)){Dc(a,nb(c+8|0))}Xa=c+16|0;return(b|0)==(d|0)}function Mza(a,b){var c=0,d=0;c=Xa-16|0;Xa=c;PN(c+8|0,b);b=nb(c+8|0);d=Vb(a,Hb(c,c+8|0));if((b|0)==(d|0)){Ib(a,nb(c+8|0))}Xa=c+16|0;return(b|0)==(d|0)}function MIa(a,b){var c=0,d=0;c=Xa-16|0;Xa=c;_s(c+8|0,b);b=nb(c+8|0);d=Vb(a,Hb(c,c+8|0));if((b|0)==(d|0)){Ib(a,nb(c+8|0))}Xa=c+16|0;return(b|0)==(d|0)}function MDa(a,b){var c=0,d=0;c=Xa-16|0;Xa=c;Jy(c+8|0,b);b=nb(c+8|0);d=Vb(a,Hb(c,c+8|0));if((b|0)==(d|0)){Ib(a,nb(c+8|0))}Xa=c+16|0;return(b|0)==(d|0)}function Lg(a,b){a=a|0;b=b|0;var c=0;_e(a);c=b+4|0;ki(fb(a),i[a>>2],i[a+4>>2],c);Gb(a,c);Gb(a+4|0,b+8|0);Gb(fb(a),Mb(b));i[b>>2]=i[b+4>>2];Mj(a,qb(a))}function Kwa(a,b){var c=0,d=0;c=Xa-16|0;Xa=c;VP(c+8|0,b);b=nb(c+8|0);d=Tc(a,Hb(c,c+8|0));if((b|0)==(d|0)){Dc(a,nb(c+8|0))}Xa=c+16|0;return(b|0)==(d|0)}function JKa(a,b){var c=0,d=0;c=Xa-16|0;Xa=c;Pp(c+8|0,b);b=nb(c+8|0);d=Tc(a,Hb(c,c+8|0));if((b|0)==(d|0)){Dc(a,nb(c+8|0))}Xa=c+16|0;return(b|0)==(d|0)}function Iwa(a,b){var c=0,d=0;c=Xa-16|0;Xa=c;Dy(c+8|0,b);b=nb(c+8|0);d=Vb(a,Hb(c,c+8|0));if((b|0)==(d|0)){Ib(a,nb(c+8|0))}Xa=c+16|0;return(b|0)==(d|0)}function IKa(a,b){var c=0,d=0;c=Xa-16|0;Xa=c;Hz(c+8|0,b);b=nb(c+8|0);d=Tc(a,Hb(c,c+8|0));if((b|0)==(d|0)){Dc(a,nb(c+8|0))}Xa=c+16|0;return(b|0)==(d|0)}function IAa(a,b){var c=0,d=0;c=Xa-16|0;Xa=c;iO(c+8|0,b);b=nb(c+8|0);d=Tc(a,Hb(c,c+8|0));if((b|0)==(d|0)){Dc(a,nb(c+8|0))}Xa=c+16|0;return(b|0)==(d|0)}function Hxa(a,b){var c=0,d=0;c=Xa-16|0;Xa=c;ZM(c+8|0,b);b=nb(c+8|0);d=Tc(a,Hb(c,c+8|0));if((b|0)==(d|0)){Dc(a,nb(c+8|0))}Xa=c+16|0;return(b|0)==(d|0)}function HY(a,b){a=a|0;b=b|0;var c=0;zC(a);c=b+4|0;ki(Ck(a),i[a>>2],i[a+4>>2],c);Gb(a,c);Gb(a+4|0,b+8|0);Gb(hq(a),Mb(b));i[b>>2]=i[b+4>>2];iC(a,qb(a))}function HKa(a,b){var c=0,d=0;c=Xa-16|0;Xa=c;Hz(c+8|0,b);b=nb(c+8|0);d=Vb(a,Hb(c,c+8|0));if((b|0)==(d|0)){Ib(a,nb(c+8|0))}Xa=c+16|0;return(b|0)==(d|0)}function HAa(a,b){var c=0,d=0;c=Xa-16|0;Xa=c;iO(c+8|0,b);b=nb(c+8|0);d=Vb(a,Hb(c,c+8|0));if((b|0)==(d|0)){Ib(a,nb(c+8|0))}Xa=c+16|0;return(b|0)==(d|0)}function Gya(a,b){var c=0,d=0;c=Xa-16|0;Xa=c;rN(c+8|0,b);b=nb(c+8|0);d=Tc(a,Hb(c,c+8|0));if((b|0)==(d|0)){Dc(a,nb(c+8|0))}Xa=c+16|0;return(b|0)==(d|0)}function Gxa(a,b){var c=0,d=0;c=Xa-16|0;Xa=c;ZM(c+8|0,b);b=nb(c+8|0);d=Vb(a,Hb(c,c+8|0));if((b|0)==(d|0)){Ib(a,nb(c+8|0))}Xa=c+16|0;return(b|0)==(d|0)}function GMa(a,b){var c=0,d=0;c=Xa-16|0;Xa=c;jT(c+8|0,b);b=nb(c+8|0);d=Tc(a,Hb(c,c+8|0));if((b|0)==(d|0)){Dc(a,nb(c+8|0))}Xa=c+16|0;return(b|0)==(d|0)}function Fya(a,b){var c=0,d=0;c=Xa-16|0;Xa=c;rN(c+8|0,b);b=nb(c+8|0);d=Vb(a,Hb(c,c+8|0));if((b|0)==(d|0)){Ib(a,nb(c+8|0))}Xa=c+16|0;return(b|0)==(d|0)}function FMa(a,b){var c=0,d=0;c=Xa-16|0;Xa=c;jT(c+8|0,b);b=nb(c+8|0);d=Vb(a,Hb(c,c+8|0));if((b|0)==(d|0)){Ib(a,nb(c+8|0))}Xa=c+16|0;return(b|0)==(d|0)}function CKa(a,b){var c=0,d=0;c=Xa-16|0;Xa=c;ZR(c+8|0,b);b=nb(c+8|0);d=Tc(a,Hb(c,c+8|0));if((b|0)==(d|0)){Dc(a,nb(c+8|0))}Xa=c+16|0;return(b|0)==(d|0)}function BKa(a,b){var c=0,d=0;c=Xa-16|0;Xa=c;ZR(c+8|0,b);b=nb(c+8|0);d=Vb(a,Hb(c,c+8|0));if((b|0)==(d|0)){Ib(a,nb(c+8|0))}Xa=c+16|0;return(b|0)==(d|0)}function Aka(a,b){var c=0,d=0;c=Xa-16|0;Xa=c;JI(c+8|0,b);b=nb(c+8|0);d=Tc(a,Hb(c,c+8|0));if((b|0)==(d|0)){Dc(a,nb(c+8|0))}Xa=c+16|0;return(b|0)==(d|0)}function AIa(a,b){var c=0,d=0;c=Xa-16|0;Xa=c;Xz(c+8|0,b);b=nb(c+8|0);d=Vb(a,Hb(c,c+8|0));if((b|0)==(d|0)){Ib(a,nb(c+8|0))}Xa=c+16|0;return(b|0)==(d|0)}function AHa(a,b){var c=0,d=0;c=Xa-16|0;Xa=c;NQ(c+8|0,b);b=nb(c+8|0);d=Tc(a,Hb(c,c+8|0));if((b|0)==(d|0)){Dc(a,nb(c+8|0))}Xa=c+16|0;return(b|0)==(d|0)}function $D(a,b){a=a|0;b=b|0;var c=0;Hi(a);c=b+4|0;o3(fb(a),i[a>>2],i[a+4>>2],c);Gb(a,c);Gb(a+4|0,b+8|0);Gb(fb(a),Mb(b));i[b>>2]=i[b+4>>2];Sn(a,cc(a))}function zi(a){var b=0;b=P(8)|0;i[114610]=0;C(214,b|0,a|0)|0;a=i[114610];i[114610]=0;if((a|0)!=1){W(b|0,71608,24);x()}a=B()|0;A()|0;Q(b|0);E(a|0);x()}function y2(a,b,c){var d=0;d=Xa-16|0;Xa=d;Pu(d,b,c,2);b=i[d+4>>2];i[a>>2]=i[d>>2];i[a+4>>2]=b;b=i[d+12>>2];i[a+8>>2]=i[d+8>>2];i[a+12>>2]=b;Xa=d+16|0}function wU(a,b){var c=0,d=0;c=Xa-16|0;Xa=c;Mp(c+8|0,b);b=nb(c+8|0);d=Tc(a,Hb(c,c+8|0));if((b|0)==(d|0)){Dc(a,nb(c+8|0))}Xa=c+16|0;return(b|0)==(d|0)}function vU(a,b){var c=0,d=0;c=Xa-16|0;Xa=c;Mp(c+8|0,b);b=nb(c+8|0);d=Vb(a,Hb(c,c+8|0));if((b|0)==(d|0)){Ib(a,nb(c+8|0))}Xa=c+16|0;return(b|0)==(d|0)}function vP(a,b){var c=0,d=0;c=Xa-16|0;Xa=c;jz(c+8|0,b);b=nb(c+8|0);d=Vb(a,Hb(c,c+8|0));if((b|0)==(d|0)){Ib(a,nb(c+8|0))}Xa=c+16|0;return(b|0)==(d|0)}function sY(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=le(b);d=te(c+13|0);i[d+8>>2]=0;i[d+4>>2]=c;i[d>>2]=c;e=a,f=Tb(d+12|0,b,c+1|0),i[e>>2]=f;return a|0}function iI(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=Xa-32|0;Xa=c;d=c,e=Zg(b),i[d+16>>2]=e;bja(c+24|0,a,b,c+16|0,c+8|0);a=Qg(c+24|0);Xa=c+32|0;return a+4|0}function hN(a,b){var c=0,d=0;c=Xa-16|0;Xa=c;_g(c+8|0,b);b=nb(c+8|0);d=Tc(a,Hb(c,c+8|0));if((b|0)==(d|0)){Dc(a,nb(c+8|0))}Xa=c+16|0;return(b|0)==(d|0)}function d_(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;while(1){if((b|0)!=(c|0)){a=g[b|0];g[e|0]=(a|0)>-1?a:d;e=e+1|0;b=b+1|0;continue}break}return c|0}function cba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(aq(a)>>>0<b>>>0){Kc();x()}fb(a);c=TF(b);i[a>>2]=c;i[a+4>>2]=c;d=fb(a),e=(b<<4)+c|0,i[d>>2]=e;Jl(a,0)}function Zna(a){i[a>>2]=0;i[a+4>>2]=0;i[a+32>>2]=0;i[a+36>>2]=1072693248;i[a+24>>2]=0;i[a+28>>2]=0;i[a+16>>2]=0;i[a+20>>2]=0;i[a+8>>2]=0;i[a+12>>2]=0}function YLa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(aq(a)>>>0<b>>>0){Kc();x()}fb(a);c=yS(b);i[a>>2]=c;i[a+4>>2]=c;d=fb(a),e=(b<<4)+c|0,i[d>>2]=e;Jl(a,0)}function WAa(a,b){a=a|0;b=b|0;a:{if(a>>>0>=515){a=Cf(b);Cf(b);break a}a=_f(b);_f(b)}if(a){while(1){if(a&1){Ib(b,260)}a=a>>>1|0;if(a){continue}break}}}function Ut(a,b){var c=0,d=0;c=Xa-16|0;Xa=c;Tt(c+8|0,b);b=nb(c+8|0);d=Vb(a,Hb(c,c+8|0));if((b|0)==(d|0)){Ib(a,nb(c+8|0))}Xa=c+16|0;return(b|0)==(d|0)}function Tc(a,b){var c=0,d=0,e=0,f=0,g=0;c=Xa-16|0;Xa=c;a=(e=a,f=i[a+12>>2],g=Hb(c+8|0,b),d=i[i[a>>2]+32>>2],$a[d](e|0,f|0,g|0)|0);Xa=c+16|0;return a}function Rp(a,b){var c=0,d=0;c=Xa-16|0;Xa=c;_g(c+8|0,b);b=nb(c+8|0);d=Vb(a,Hb(c,c+8|0));if((b|0)==(d|0)){Ib(a,nb(c+8|0))}Xa=c+16|0;return(b|0)==(d|0)}function Pza(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(Hm(a)>>>0<b>>>0){Kc();x()}fb(a);c=NN(b);i[a>>2]=c;i[a+4>>2]=c;d=fb(a),e=(b<<2)+c|0,i[d>>2]=e;Mj(a,0)}function Mla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=i[b+4>>2];i[a>>2]=i[b>>2];i[a+4>>2]=d;d=i[b+12>>2];i[a+8>>2]=i[b+8>>2];i[a+12>>2]=d;Ex(a,n[c>>3])}



function JU(a,b){var c=0,d=0;c=Xa-16|0;Xa=c;Tt(c+8|0,b);b=nb(c+8|0);d=Tc(a,Hb(c,c+8|0));if((b|0)==(d|0)){Dc(a,nb(c+8|0))}Xa=c+16|0;return(b|0)==(d|0)}function Hu(a){var b=0,c=0;i[114610]=0;c=R(2566)|0;b=i[114610];i[114610]=0;if((b|0)!=1){b=a;a=i[c>>2];i[b>>2]=a;Fl(a);return}a=H(0)|0;A()|0;gb(a);x()}function GJ(a){if(i[a+480224>>2]==2){return+l[a+1074420>>2]*1e-4}return+l[a+24620>>2]*60/(+l[a+1074404>>2]*+(o(i[a+1074408>>2],i[a+1074416>>2])>>>0))}function G9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(WD(a)>>>0<b>>>0){Kc();x()}fb(a);c=ZK(b);i[a>>2]=c;i[a+4>>2]=c;d=fb(a),e=o(b,12)+c|0,i[d>>2]=e;Sn(a,0)}function G8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;if(c){e=d<<2;a=0;while(1){if(d){yb(i[(a<<2)+b>>2],0,e)}a=a+1|0;if((c|0)!=(a|0)){continue}break}}}function FV(a,b){var c=0,d=0;c=Xa-16|0;Xa=c;eB(c+8|0,b);b=nb(c+8|0);d=Tc(a,Hb(c,c+8|0));if((b|0)==(d|0)){Dc(a,nb(c+8|0))}Xa=c+16|0;return(b|0)==(d|0)}function F8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;if(c){e=d<<3;a=0;while(1){if(d){yb(i[(a<<2)+b>>2],0,e)}a=a+1|0;if((c|0)!=(a|0)){continue}break}}}function Ep(a,b){var c=0,d=0;c=Xa-16|0;Xa=c;ok(c+8|0,b);b=nb(c+8|0);d=Vb(a,Hb(c,c+8|0));if((b|0)==(d|0)){Ib(a,nb(c+8|0))}Xa=c+16|0;return(b|0)==(d|0)}function EV(a,b){var c=0,d=0;c=Xa-16|0;Xa=c;cB(c+8|0,b);b=nb(c+8|0);d=Tc(a,Hb(c,c+8|0));if((b|0)==(d|0)){Dc(a,nb(c+8|0))}Xa=c+16|0;return(b|0)==(d|0)}function Bf(a,b){var c=0,d=0;c=Xa-16|0;Xa=c;Pp(c+8|0,b);b=nb(c+8|0);d=Vb(a,Hb(c,c+8|0));if((b|0)==(d|0)){Ib(a,nb(c+8|0))}Xa=c+16|0;return(b|0)==(d|0)}function BV(a,b){var c=0,d=0;c=Xa-16|0;Xa=c;eB(c+8|0,b);b=nb(c+8|0);d=Vb(a,Hb(c,c+8|0));if((b|0)==(d|0)){Ib(a,nb(c+8|0))}Xa=c+16|0;return(b|0)==(d|0)}function AV(a,b){var c=0,d=0;c=Xa-16|0;Xa=c;cB(c+8|0,b);b=nb(c+8|0);d=Vb(a,Hb(c,c+8|0));if((b|0)==(d|0)){Ib(a,nb(c+8|0))}Xa=c+16|0;return(b|0)==(d|0)}function AEa(a,b){var c=0;HGa(a);i[a>>2]=76572;c=i[b+4>>2];i[a+24>>2]=i[b>>2];i[a+28>>2]=c;c=i[b+12>>2];i[a+32>>2]=i[b+8>>2];i[a+36>>2]=c;g[a+40|0]=0}function xya(a,b){a=a|0;b=b|0;var c=0,d=0;d=Xa-96|0;Xa=d;c=-1;a:{if(!XN(a,d)){break a}c=0;if(!mN(d)){break a}c=Le(a,b,lN(d),_a)}Xa=d+96|0;return c|0}function r4(a,b){a=a|0;b=b|0;var c=0,d=0;c=i[a+40>>2];while(1){if(c){c=c+ -1|0;d=c<<2;$a[i[i[a+32>>2]+d>>2]](b,a,i[d+i[a+36>>2]>>2]);continue}break}}function oxa(a,b){a=a|0;b=b|0;var c=0,d=0;d=Xa-48|0;Xa=d;c=-1;a:{if(!gN(a,d)){break a}c=0;if(!VM(d)){break a}c=Le(a,b,UM(d),_a)}Xa=d+48|0;return c|0}function oQ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(rz(a)>>>0<b>>>0){Kc();x()}fb(a);c=TP(b);i[a>>2]=c;i[a+4>>2]=c;d=fb(a),e=o(b,6)+c|0,i[d>>2]=e;ct(a,0)}function ly(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(sA(a)>>>0<b>>>0){Kc();x()}fb(a);c=gT(b);i[a>>2]=c;i[a+4>>2]=c;d=fb(a),e=(b<<1)+c|0,i[d>>2]=e;It(a,0)}function kma(a,b,c){var d=0,e=0;b=b-a|0;if((b|0)>=3){d=b>>1;b=(d+ -2|0)/2|0;while(1){Qw(a,c,d,(b<<1)+a|0);e=(b|0)>0;b=b+ -1|0;if(e){continue}break}}}function jya(a,b){a=a|0;b=b|0;var c=0,d=0;d=Xa-48|0;Xa=d;c=-1;a:{if(!gN(a,d)){break a}c=0;if(!fN(d)){break a}c=Le(a,b,eN(d),_a)}Xa=d+48|0;return c|0}function ic(a){var b=0;b=P(8)|0;i[114610]=0;C(23,b|0,a|0)|0;a=i[114610];i[114610]=0;if((a|0)!=1){W(b|0,71556,24);x()}a=B()|0;A()|0;Q(b|0);E(a|0);x()}function Wza(a,b){a=a|0;b=b|0;var c=0,d=0;d=Xa-96|0;Xa=d;c=-1;a:{if(!XN(a,d)){break a}c=0;if(!WN(d)){break a}c=Le(a,b,VN(d),_a)}Xa=d+96|0;return c|0}function US(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(Hm(a)>>>0<b>>>0){Kc();x()}fb(a);c=YK(b);i[a>>2]=c;i[a+4>>2]=c;d=fb(a),e=(b<<2)+c|0,i[d>>2]=e;Mj(a,0)}function Q$(a){var b=0,c=0;b=Xa-16|0;Xa=b;a:{if(oe(a)){c=i[a>>2];i[b+12>>2]=0;ye(c,b+12|0);ce(a,0);break a}i[b+8>>2]=0;ye(a,b+8|0);Te(a,0)}Xa=b+16|0}function M_(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(kC(a)>>>0<b>>>0){Kc();x()}c=jC(Ck(a),b);i[a>>2]=c;i[a+4>>2]=c;d=hq(a),e=(b<<2)+c|0,i[d>>2]=e;iC(a,0)}function Ce(a){var b=0,c=0;b=Xa-16|0;Xa=b;a:{if(oe(a)){c=i[a>>2];g[b+15|0]=0;Rd(c,b+15|0);ce(a,0);break a}g[b+14|0]=0;Rd(a,b+14|0);Te(a,0)}Xa=b+16|0}function vX(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;if(Nf(a,i[b+8>>2],f)){ru(b,c,d,e);return}a=i[a+8>>2];$a[i[i[a>>2]+20>>2]](a,b,c,d,e,f)}function vJa(a,b){var c=0,d=0;c=Xa-16|0;Xa=c;d=wb(a,64);a:{if(d){yz(c+8|0,b);od(a,c+8|0);break a}a=Xa-16|0;Xa=a;sJa(b);Xa=a+16|0}Xa=c+16|0;return d}function paa(a){a=a|0;var b=0,c=0;b=Xa-16|0;Xa=b;c=i[a+4>>2];a=i[a>>2];i[b>>2]=a;i[b+4>>2]=c;i[b+8>>2]=a;i[b+12>>2]=c;a=bma(b);Xa=b+16|0;return a|0}function m8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=i[b>>2];i[a>>2]=d;i[i[d+ -12>>2]+a>>2]=i[b+4>>2];i[a+4>>2]=0;ir(i[i[a>>2]+ -12>>2]+a|0,c);return a|0}function lsa(a,b){var c=0,d=0;c=Xa-16|0;Xa=c;d=wb(a,27);a:{if(d){zL(c+8|0,b);od(a,c+8|0);break a}a=Xa-16|0;Xa=a;csa(b);Xa=a+16|0}Xa=c+16|0;return d}function gLa(a,b,c){var d=0;d=Xa-16|0;Xa=d;i[d+12>>2]=c;c=0;if(Bf(a,d+8|0)){i[d+4>>2]=j[d+8|0];c=LKa(a,b,i[rb(d+4|0,d+12|0)>>2])}Xa=d+16|0;return c}function dMa(a,b){var c=0,d=0;c=Xa-16|0;Xa=c;d=wb(a,16);a:{if(d){IS(c+8|0,b);od(a,c+8|0);break a}a=Xa-16|0;Xa=a;PLa(b);Xa=a+16|0}Xa=c+16|0;return d}function cIa(a,b){var c=0,d=0;c=Xa-16|0;Xa=c;d=wb(a,64);a:{if(d){yz(c+8|0,b);od(a,c+8|0);break a}a=Xa-16|0;Xa=a;QHa(b);Xa=a+16|0}Xa=c+16|0;return d}function Mx(a,b,c){a=a|0;b=b|0;c=c|0;a:{if(!ie(a)){break a}Nm(a);if(c){wka(a,b)}if((Kp(a)|0)==2){Jta(a,b);return}if((Kp(a)|0)!=1){break a}Ita(a,b)}}function IU(a,b){a=a|0;b=b|0;var c=0;b=Xa-48|0;Xa=b;c=-1;a:{if(!LA(a,b+8|0)){break a}c=0;if(!TI(b+8|0)){break a}c=Fla(a,b+8|0)}Xa=b+48|0;return c|0}function BY(a,b,c){var d=0;d=Xa-16|0;Xa=d;i[d+8>>2]=c;while(1){if((a|0)!=(b|0)){ZD(d+8|0,i[a>>2]);a=a+4|0;continue}break}Xa=d+16|0;return i[d+8>>2]}function BJa(a){var b=0;b=i[a+4>>2];a=i[a>>2];i[114610]=0;a=C(533,a|0,b|0)|0;b=i[114610];i[114610]=0;if((b|0)!=1){return a}a=H(0)|0;A()|0;gb(a);x()}function yza(a){var b=0;b=i[a+4>>2];a=i[a>>2];i[114610]=0;a=C(79,a|0,b|0)|0;b=i[114610];i[114610]=0;if((b|0)!=1){return a}a=H(0)|0;A()|0;gb(a);x()}function wwa(a){var b=0,c=0;kQ(a);a:{while(1){c=a+b|0;if(j[c|0]){b=b+1|0;if((b|0)!=32){continue}break a}break}if(b>>>0>31){break a}yb(c,0,32-b|0)}}function ov(a,b){var c=0,d=0;c=b&1?a:1;if(b+1>>>0>=3){d=b;while(1){a=a*a;d=(d|0)/2|0;c=d&1?a*c:c;if(d+1>>>0>2){continue}break}}return(b|0)<0?1/c:c}function jla(a,b){a=a|0;b=b|0;var c=0;if(!(j[b+14|0]&48|j[b+17|0]!=173)){Ic(a,8,1,0,11);return}c=a;a=b+14|0;Ic(c,j[a|0]&16?16:8,j[a|0]&32?3:1,0,2)}function jLa(a,b,c){var d=0;d=Xa-16|0;Xa=d;i[d+12>>2]=c;c=0;if(Bf(a,d+8|0)){i[d+4>>2]=j[d+8|0];c=kS(a,b,i[rb(d+4|0,d+12|0)>>2])}Xa=d+16|0;return c}function iX(a,b,c,d,e,f,g,h,i,j,k,l){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;return Tda(a,b,c,d,e,f,g,h,i,j,k,l)|0}function iLa(a,b,c){var d=0;d=Xa-16|0;Xa=d;i[d+12>>2]=c;c=0;if(Bf(a,d+8|0)){i[d+4>>2]=j[d+8|0];c=fS(a,b,i[rb(d+4|0,d+12|0)>>2])}Xa=d+16|0;return c}function hLa(a,b,c){var d=0;d=Xa-16|0;Xa=d;i[d+12>>2]=c;c=0;if(Bf(a,d+8|0)){i[d+4>>2]=j[d+8|0];c=eS(a,b,i[rb(d+4|0,d+12|0)>>2])}Xa=d+16|0;return c}function gCa(a,b){var c=0,d=0;c=Xa-16|0;Xa=c;d=wb(a,2);a:{if(d){ok(c+8|0,b);od(a,c+8|0);break a}a=Xa-16|0;Xa=a;VBa(b);Xa=a+16|0}Xa=c+16|0;return d}function bKa(a,b,c){var d=0;d=Xa-16|0;Xa=d;i[d+12>>2]=c;c=0;if(Bf(a,d+8|0)){i[d+4>>2]=j[d+8|0];c=KR(a,b,i[rb(d+4|0,d+12|0)>>2])}Xa=d+16|0;return c}function ZJa(a,b){var c=0,d=0;c=Xa-16|0;Xa=c;d=wb(a,8);a:{if(d){Tt(c+8|0,b);od(a,c+8|0);break a}a=Xa-16|0;Xa=a;DJa(b);Xa=a+16|0}Xa=c+16|0;return d}function Y8(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0;h=Xa-32|0;Xa=h;_F(h+8|0,b,c,d,e,f,g);Lc(a,h+20|0);Im(h+8|0);Xa=h+32|0}function XLa(a,b){var c=0,d=0;c=Xa-16|0;Xa=c;d=wb(a,3);a:{if(d){Xz(c+8|0,b);od(a,c+8|0);break a}a=Xa-16|0;Xa=a;ALa(b);Xa=a+16|0}Xa=c+16|0;return d}function PA(a){var b=0;b=i[a+4>>2];a=i[a>>2];i[114610]=0;a=C(288,a|0,b|0)|0;b=i[114610];i[114610]=0;if((b|0)!=1){return a}a=H(0)|0;A()|0;gb(a);x()}function MO(a){var b=0;b=i[a+4>>2];a=i[a>>2];i[114610]=0;a=C(883,a|0,b|0)|0;b=i[114610];i[114610]=0;if((b|0)!=1){return a}a=H(0)|0;A()|0;gb(a);x()}function MAa(a,b){var c=0,d=0;c=Xa-16|0;Xa=c;d=wb(a,6);a:{if(d){jz(c+8|0,b);od(a,c+8|0);break a}a=Xa-16|0;Xa=a;FAa(b);Xa=a+16|0}Xa=c+16|0;return d}function M8(a,b){a=a|0;b=b|0;var c=0,d=0;c=Xa-32|0;Xa=c;d=i[b+4>>2];i[c+8>>2]=i[b>>2];i[c+12>>2]=d;So(a,i[c+8>>2],i[c+12>>2]);Xa=c+32|0;return a|0}function Lra(a,b){var c=0,d=0,e=0;while(1){d=d<<1|c>>>31;c=a&1|c<<1;a=(b&1)<<31|a>>>1;b=b>>>1|0;e=e+1|0;if((e|0)!=64){continue}break}_a=d;return c}function J_(){var a=0;rd(463344);i[114610]=0;F(2560,463352)|0;a=i[114610];i[114610]=0;if((a|0)!=1){i[115836]=65484;return}a=B()|0;A()|0;E(a|0);x()}function I_(){var a=0;rd(463360);i[114610]=0;F(2560,463368)|0;a=i[114610];i[114610]=0;if((a|0)!=1){i[115840]=65640;return}a=B()|0;A()|0;E(a|0);x()}function Gx(a,b,c){var d=0,e=0,f=0;d=Sj(a,b);if((d|0)!=255){e=Mc(a+22|0,d),f=c,h[e>>1]=f;a=a+58|0;e=Nb(a,b),f=255,g[e|0]=f;e=Nb(a,c),f=d,g[e|0]=f}}function CY(a,b,c){var d=0;d=Xa-16|0;Xa=d;i[d+8>>2]=c;while(1){if((a|0)!=(b|0)){_D(d+8|0,g[a|0]);a=a+1|0;continue}break}Xa=d+16|0;return i[d+8>>2]}function zxa(a,b,c,d){if((b|0)!=(c|0)){a=i[d>>2];while(1){c=c+ -12|0;xxa(a+ -12|0,c);a=i[d>>2]+ -12|0;i[d>>2]=a;if((b|0)!=(c|0)){continue}break}}}function yja(a,b,c,d){if((b|0)!=(c|0)){a=i[d>>2];while(1){c=c+ -52|0;xja(a+ -52|0,c);a=i[d>>2]+ -52|0;i[d>>2]=a;if((b|0)!=(c|0)){continue}break}}}function v6(a,b,c){a:{if((a|0)==(b|0)){break a}c=k[c>>1];while(1){if((c|0)==k[a>>1]){break a}a=a+2|0;if((b|0)!=(a|0)){continue}break}a=b}return a}function nb(a){var b=0;b=i[a+4>>2];a=i[a>>2];i[114610]=0;a=C(34,a|0,b|0)|0;b=i[114610];i[114610]=0;if((b|0)!=1){return a}a=H(0)|0;A()|0;gb(a);x()}function lv(a,b,c,d){var e=0;e=bm(a,b,c);if(pd(d,c)){Gb(c,d);if(!pd(c,b)){return e+1|0}Gb(b,c);if(!pd(b,a)){return e+2|0}Gb(a,b);e=e+3|0}return e}function jJa(a){a=a|0;var b=0,c=0,d=0;b=Xa-16|0;Xa=b;h[b+14>>1]=1;c=b,d=ft(a),h[c+12>>1]=d;a=k[ri(b+14|0,b+12|0)>>1];Xa=b+16|0;return a+ -1&65535}function dH(a){var b=0;b=(we(i[a+16>>2])>>>0)/(_h(p(m[a+4208>>2]*p(999)))+1>>>0)|0;b=b>>>0>2?b:2;i[a+4216>>2]=b;i[a+4220>>2]=b>>>1;kc(a+4224|0,b)}function Z8(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0;h=Xa-32|0;Xa=h;_F(h+8|0,b,c,d,e,f,g);Lc(a,h+8|0);Im(h+8|0);Xa=h+32|0}function Vg(a){var b=0;b=i[a+4>>2];a=i[a>>2];i[114610]=0;a=C(29,a|0,b|0)|0;b=i[114610];i[114610]=0;if((b|0)!=1){return a}a=H(0)|0;A()|0;gb(a);x()}function NE(a,b){a:{b:{if(j[a+23|0]){a=1;if((b|0)!=255){break b}V(52142,50448,1165,52157);x()}if((b|0)!=255){break a}a=0}return a}return b>>>0>10}function LK(a,b){var c=0,d=0;c=Tb(a,b,602);a=0;while(1){d=o(a,896);Mr((d+c|0)+608|0,(b+d|0)+608|0);a=a+1|0;if((a|0)!=256){continue}break}return c}function Kya(a,b,c,d){if((b|0)!=(c|0)){a=i[d>>2];while(1){c=c+ -56|0;Jya(a+ -56|0,c);a=i[d>>2]+ -56|0;i[d>>2]=a;if((b|0)!=(c|0)){continue}break}}}function $Ba(a,b,c){var d=0;d=ni(a+8|0);i[114610]=0;G(421,a|0,b|0,c|0);a=i[114610];i[114610]=0;if((a|0)!=1){return}a=B()|0;A()|0;ug(d);E(a|0);x()}function y5(a,b){var c=0;b=b<<1;c=a+1092|0;a:{b:{if((b|0)==i[a+112>>2]){break b}c=0;if((b|0)!=i[a+116>>2]){break a}c=a+1096|0}c=i[c>>2]}return c}function ira(a,b,c,d){if((b|0)!=(c|0)){a=i[d>>2];while(1){c=c+ -12|0;by(a+ -12|0,c);a=i[d>>2]+ -12|0;i[d>>2]=a;if((b|0)!=(c|0)){continue}break}}}function ena(a,b,c){g[a+6|0]=255;i[a+16>>2]=0;h[a+4>>1]=0;i[a>>2]=0;if(!((b|0)==65535|(c|0)==-1)){i[a+8>>2]=c;i[a+16>>2]=2;h[a+12>>1]=b}return a}function av(a){var b=0,c=0;b=Xa-16|0;Xa=b;c=-1;a:{if(UD(a)){break a}if(($a[i[a+32>>2]](a,b+15|0,1)|0)!=1){break a}c=j[b+15|0]}Xa=b+16|0;return c}function IHa(a,b,c,d){if((b|0)!=(c|0)){a=i[d>>2];while(1){c=c+ -16|0;zl(a+ -16|0,c);a=i[d>>2]+ -16|0;i[d>>2]=a;if((b|0)!=(c|0)){continue}break}}}function Bg(a,b){a=a|0;b=b|0;var c=0;c=Xa-16|0;Xa=c;g[c+15|0]=0;a=xk(a,c+15|0,1);g[c+8|0]=j[c+15|0];g[b|0]=j[c+8|0];Xa=c+16|0;return!_a&(a|0)==1}function BD(a,b,c){var d=0;d=Xa-144|0;Xa=d;d=yb(d,0,144);i[d+76>>2]=-1;i[d+44>>2]=a;i[d+32>>2]=2414;i[d+84>>2]=a;a=R2(d,b,c);Xa=d+144|0;return a}function $n(a,b){var c=0;a:{if(!fF(b)|(j[b+1|0]^j[a+1|0])>>>0>1){break a}b=j[b+2|0];a=j[a+2|0];if((b^a)&12){break a}c=b>>>0<16^a>>>0>15}return c}function um(a,b,c){a:{if((a|0)==(b|0)){break a}c=j[c|0];while(1){if((c|0)==j[a|0]){break a}a=a+1|0;if((b|0)!=(a|0)){continue}break}a=b}return a}function ty(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Xa-16|0;Xa=d;h[d+14>>1]=b;h[d+12>>1]=c;if((b|0)!=(c|0)){nBa(Jb(a),Kb(a),d+14|0,d+12|0)}Xa=d+16|0}function tIa(a,b){a=a|0;b=b|0;var c=0;a=Ic(a,8,1,0,1);c=2;b=b+13|0;a:{if(!(j[b|0]&64)){c=0;if(!(j[b|0]&2)){break a}}cj(a,c)}if(j[b|0]&4){mz(a)}}function pu(a,b,c,d,e,f){var g=0,h=0,j=0;g=i[a+4>>2];h=g>>8;a=i[a>>2];j=a;if(g&1){h=i[i[d>>2]+h>>2]}$a[i[i[a>>2]+20>>2]](j,b,c,d+h|0,g&2?e:2,f)}function cw(a){a=a|0;var b=0,c=0;i[a>>2]=81568;b=a+4960|0;c=a+4504|0;while(1){b=b+ -24|0;uf(b);if((b|0)!=(c|0)){continue}break}ve(a);return a|0}function Zoa(a,b,c){var d=0;d=Sm(a);i[114610]=0;G(109,a|0,b|0,c|0);b=i[114610];i[114610]=0;if((b|0)!=1){return a}a=B()|0;A()|0;Sd(d);E(a|0);x()}function V5(a,b,c,d){if(d){cF(a,b,48736,d);b=o(d,36)+b|0;a=o(d,72)+a|0}if((c|0)==2){L5(a,b,32-d|0);return}cF(a,b,o((c|0)==3,72)+48736|0,32-d|0)}function Ht(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(Jz(a)>>>0<b>>>0){Kc();x()}fb(a);c=uA(b);i[a>>2]=c;i[a+4>>2]=c;d=fb(a),e=b+c|0,i[d>>2]=e;Sz(a,0)}function Fo(a){var b=0,c=0,d=0;c=j[a+30|0];d=ph(i[a+24>>2]+484360|0);b=i[a+24>>2]+484360|0;if(c>>>0>=d>>>0){return Db(b)}return bi(b,j[a+30|0])}function Fn(a,b){var c=0;c=a;a=b+4|0;return VV(c,j[b|0]|j[b+1|0]<<8|(j[b+2|0]<<16|j[b+3|0]<<24),j[a|0]|j[a+1|0]<<8|(j[a+2|0]<<16|j[a+3|0]<<24))}function BR(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(Jz(a)>>>0<b>>>0){Kc();x()}fb(a);c=rS(b);i[a>>2]=c;i[a+4>>2]=c;d=fb(a),e=b+c|0,i[d>>2]=e;Sz(a,0)}function mwa(a,b,c){var d=0;d=Sm(a);i[114610]=0;G(93,a|0,b|0,c|0);b=i[114610];i[114610]=0;if((b|0)!=1){return a}a=B()|0;A()|0;Sd(d);E(a|0);x()}function Hwa(a,b,c){a=a|0;b=b|0;c=c|0;a=j[c|0]|j[c+1|0]<<8|(j[c+2|0]<<16|j[c+3|0]<<24);g[b|0]=a;g[b+1|0]=a>>>8;g[b+2|0]=a>>>16;g[b+3|0]=a>>>24}function wGa(a,b){var c=0,d=0;c=Xa-16|0;Xa=c;d=wb(a,12);a:{if(d){lz(c+8|0,b);od(a,c+8|0);break a}g[c+7|0]=0;bj(b,12,c+7|0)}Xa=c+16|0;return d}function w2(a,b,c,d){d=Xa-16|0;Xa=d;y2(d,b,c);b=i[d+4>>2];i[a>>2]=i[d>>2];i[a+4>>2]=b;b=i[d+12>>2];i[a+8>>2]=i[d+8>>2];i[a+12>>2]=b;Xa=d+16|0}function uLa(a,b){var c=0;c=Xa-16|0;Xa=c;i[a>>2]=0;i[a+4>>2]=0;i[c+12>>2]=0;Fc(a+8|0,c+12|0,c+8|0);if(b){Cp(a,b);mA(a,b,0)}Xa=c+16|0;return a}function ooa(a,b){var c=0,d=0,e=0;d=j[a|0];e=j[b|0];c=1;a:{if(d>>>0<e>>>0){break a}c=0;if(e>>>0<d>>>0){break a}c=k[a+2>>1]<k[b+2>>1]}return c}function ZX(a,b){a:{b:{switch(a+1|0){case 0:a=i[114584];break;case 1:break a;default:break b}}b=70688;if((a|0)==28){break a}Da();x()}return b}function Wga(a){a=a|0;var b=0;b=Xa-16|0;Xa=b;EH(b+8|0,a,0);if(Vg(b+8|0)){a=i[a+20>>2];i[a+148>>2]=-1;uJ(a+4|0,i[b+8>>2],i[b+12>>2])}Xa=b+16|0}function I2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;e=i[a+20>>2];d=i[a+16>>2]-e|0;d=d>>>0>c>>>0?c:d;Tb(e,b,d);i[a+20>>2]=d+i[a+20>>2];return c|0}function vla(a,b){var c=0,d=0,e=0;c=Xa-16|0;Xa=c;h[a+4>>1]=0;i[a>>2]=b;kb(c+8|0,b+1074308|0,0);d=a,e=ib(c+8|0),g[d+6|0]=e;Xa=c+16|0;return a}function pT(a){var b=0,c=0;c=XMa(j[a+111|0],0,1536,0);b=_a;a=XMa(j[a+110|0],0,25,0);c=c+a|0;b=_a+b|0;b=c>>>0<a>>>0?b+1|0:b;a=c;_a=b;return a}function nX(a,b,c,d){var e=0,f=0;f=d&65535;d=d>>>16&32767;a:{if((d|0)!=32767){e=4;if(d){break a}return a|c|(b|f)?3:2}e=!(a|c|(b|f))}return e}function g5(a,b,c){var d=0,e=0;if((b|0)>=1){d=(b<<2)+a|0;while(1){i[(e<<2)+a>>2]=d;d=c+d|0;e=e+1|0;if((e|0)!=(b|0)){continue}break}}return a}function AP(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;return(e=a,f=i[c>>2],g=b,h=nb(c),d=i[i[a>>2]+28>>2],$a[d](e|0,f|0,g|0,h|0)|0)|0}function sr(a){var b=0;b=n[a+4248>>3]/+(we(i[a+16>>2])>>>0);n[a+4264>>3]=b;if(j[a+4240|0]){n[a+4264>>3]=b*.016666666666666666*n[a+4288>>3]}}function pia(a){a=a|0;var b=0,c=0,d=0;b=Xa-16|0;Xa=b;if(!dd(a,4)){Bu(a)}c=b,d=Jb(a+44|0),i[c>>2]=d;a=i[Ad(b+8|0,b)>>2];Xa=b+16|0;return a|0}function oia(a){a=a|0;var b=0,c=0,d=0;b=Xa-16|0;Xa=b;if(!dd(a,4)){Bu(a)}c=b,d=Kb(a+44|0),i[c>>2]=d;a=i[Ad(b+8|0,b)>>2];Xa=b+16|0;return a|0}function eq(a,b,c,d,e){var f=0,g=0,h=0;f=i[a+4>>2];g=f>>8;a=i[a>>2];h=a;if(f&1){g=i[i[c>>2]+g>>2]}$a[i[i[a>>2]+24>>2]](h,b,c+g|0,f&2?d:2,e)}function cO(a){a:{if(Xc(a,16608,3)|j[a+3|0]>31|(g[a+27|0]<0|j[a+32|0]>64)){break a}a=a+33|0;if(j[a|0]>32){break a}return j[a|0]!=0}return 0}function _ra(){var a=0,b=0,c=0,d=0;while(1){b=(a<<3)+85504|0;c=b,d=Wra(a&255),i[c>>2]=d;i[b+4>>2]=_a;a=a+1|0;if((a|0)!=256){continue}break}}function Ui(a){if(!(2147483647>a)){return 2147483647}if(!(-2147483648<a)){return-2147483648}if(q(a)<2147483648){return~~a}return-2147483648}function EBa(a){var b=0,c=0,d=0;c=a+20|0;while(1){d=b;b=g[a|0];b=d+((b&255)!=0&(b|0)<32)|0;a=a+1|0;if((c|0)!=(a|0)){continue}break}return b}function DBa(a){var b=0,c=0,d=0;c=a+22|0;while(1){d=b;b=g[a|0];b=d+((b&255)!=0&(b|0)<32)|0;a=a+1|0;if((c|0)!=(a|0)){continue}break}return b}function sua(a,b){var c=0,d=0;if(b){while(1){d=c<<3;i[(c<<2)+a>>2]=(i[(d|4)+a>>2]+i[a+d>>2]|0)/2;c=c+1|0;if((c|0)!=(b|0)){continue}break}}}function sE(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;if(c){d=a;while(1){i[d>>2]=i[b>>2];d=d+4|0;b=b+4|0;c=c+ -1|0;if(c){continue}break}}return a|0}function rMa(a,b){var c=0,d=0;c=Xa-16|0;Xa=c;a:{if(wb(a,256)){d=Xa-16|0;Xa=d;Ob(c+8|0,b,256);Xa=d+16|0;od(a,c+8|0);break a}sC(b)}Xa=c+16|0}function osa(a){var b=0,c=0;b=Xa-16|0;Xa=b;c=i[a+4>>2];i[b>>2]=i[a>>2];i[b+4>>2]=c;c=Qj(b+8|0,b);a=i[c>>2];Xa=b+16|0;_a=i[c+4>>2];return a}function mya(a){var b=0,c=0;b=Xa-16|0;Xa=b;if(lya(a,b+8|0)){a=b+8|0;a=j[a|0]|j[a+1|0]<<8;c=(a<<24|a<<8&16711680)>>>16|0}Xa=b+16|0;return c}function jza(a,b){a=a|0;b=b|0;var c=0,d=0;b=Xa-160|0;Xa=b;d=-1;c=a;a=b+8|0;c=Gya(c,a);if(!c){sN(a)}if(c){d=CN(b+8|0)}Xa=b+160|0;return d|0}function eh(a){var b=0;a=a*a;b=a*a;return p(a*-.499999997251031+1+b*.04166662332373906+a*b*(a*2439044879627741e-20+ -.001388676377460993))}function c_(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;a=Xa-16|0;Xa=a;i[a+12>>2]=e;i[a+8>>2]=d-c;b=rb(a+12|0,a+8|0);Xa=a+16|0;return i[b>>2]}function Vha(a,b){a=a|0;b=b|0;var c=0;c=Re(a);if(c>>>0<b>>>0){Cha(a,b-c|0);return}if(c>>>0>b>>>0){b=i[a>>2]+(b<<11)|0;Re(a);KH(a,b);OH(a)}}function Vc(a,b){a=a|0;b=b|0;var c=0;c=Xa-16|0;Xa=c;i[c+8>>2]=a;i[c+12>>2]=b;i[c>>2]=-1;i[c+4>>2]=0;a=$z(c+8|0,c);Xa=c+16|0;return i[a>>2]}function TGa(a,b){a=a|0;b=b|0;var c=0;c=ii(a);if(c>>>0<b>>>0){zGa(a,b-c|0);return}if(c>>>0>b>>>0){b=i[a>>2]+o(b,48)|0;ii(a);hR(a,b);sR(a)}}function SG(a){var b=0,c=p(0);if(!a){return p(1)}if((a|0)>=-99999){b=+(a|0)*.0016609640474436812;c=p(zg(b-bNa(b+.5)))}else{c=p(0)}return c}function Rja(a,b){var c=0,d=0,e=0;if(rI(a)>>>0<b>>>0){Kc();x()}fb(a);c=oI(b);i[a>>2]=c;i[a+4>>2]=c;d=fb(a),e=o(b,52)+c|0,i[d>>2]=e;qI(a,0)}function AJa(a,b){a=a|0;b=b|0;var c=0,d=0;b=Xa-624|0;Xa=b;d=-1;c=a;a=b+8|0;c=uJa(c,a);if(!c){zR(a)}if(c){d=AR(b+8|0)}Xa=b+624|0;return d|0}function $xa(a,b){a=a|0;b=b|0;var c=0;c=cc(a);if(c>>>0<b>>>0){Pxa(a,b-c|0);return}if(c>>>0>b>>>0){b=i[a>>2]+o(b,12)|0;cc(a);YM(a,b);os(a)}}function yu(a,b){nm(a);i[a>>2]=71368;i[114610]=0;C(2837,a+4|0,b|0)|0;a=i[114610];i[114610]=0;if((a|0)!=1){return}a=B()|0;A()|0;E(a|0);x()}function pta(a,b){var c=0,d=0,e=0;if(ZA(a)>>>0<b>>>0){Kc();x()}fb(a);c=VL(b);i[a>>2]=c;i[a+4>>2]=c;d=fb(a),e=(b<<5)+c|0,i[d>>2]=e;Sp(a,0)}function noa(a,b){var c=0;c=Xa-16|0;Xa=c;i[c+8>>2]=b;b=i[c+8>>2];b=k[b>>1]|k[b+2>>1]<<16;h[a+4>>1]=0;h[a>>1]=b;h[a+2>>1]=b>>>16;Xa=c+16|0}function aHa(a,b){a=a|0;b=b|0;var c=0;c=Xa-32|0;Xa=c;g[c+16|0]=44;i[c+8>>2]=-1;i[c+12>>2]=0;i[c>>2]=1042;i[c+4>>2]=2;Rfa(a,b,c);Xa=c+32|0}function _i(a){a=a|0;var b=0;b=Xa-16|0;Xa=b;i[b+12>>2]=a;i[b+8>>2]=0;i[b+4>>2]=255;a=j[wf(b+8|0,Nd(b+12|0,b+4|0))|0];Xa=b+16|0;return a|0}function Zia(a,b){var c=0,d=0,e=0;if(Hm(a)>>>0<b>>>0){Kc();x()}fb(a);c=bI(b);i[a>>2]=c;i[a+4>>2]=c;d=fb(a),e=(b<<2)+c|0,i[d>>2]=e;Mj(a,0)}function Uha(a,b){a=a|0;b=b|0;var c=0;c=qb(a);if(c>>>0<b>>>0){Bha(a,b-c|0);return}if(c>>>0>b>>>0){b=i[a>>2]+(b<<2)|0;qb(a);HH(a,b);vg(a)}}function TCa(a,b){var c=0,d=0,e=0;if(Hm(a)>>>0<b>>>0){Kc();x()}fb(a);c=gA(b);i[a>>2]=c;i[a+4>>2]=c;d=fb(a),e=(b<<2)+c|0,i[d>>2]=e;Mj(a,0)}function I4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=b;b=i[b>>2]+15&-16;i[c>>2]=b+16;d=a,e=nv(i[b>>2],i[b+4>>2],i[b+8>>2],i[b+12>>2]),n[d>>3]=e}function HK(a){a=50-(o(j[(a>>>4|0)+20352|0],a&15)>>>4|0)|0;a=a>>>0>23863?65536:23863/(a>>>0)|0;return gc((a+119315e4>>>0)/(a<<1>>>0)|0,0)}function GEa(a,b){a=a|0;b=b|0;var c=0;c=Wc(a);if(c>>>0<b>>>0){tEa(a,b-c|0);return}if(c>>>0>b>>>0){b=i[a>>2]+(b<<4)|0;Wc(a);xS(a,b);FB(a)}}function Bc(a){var b=0;b=Xa-16|0;Xa=b;i[b+12>>2]=a;i[b+8>>2]=-32768;i[b+4>>2]=32767;a=h[wf(b+8|0,Nd(b+12|0,b+4|0))>>1];Xa=b+16|0;return a}function pp(a){var b=0,c=0;b=Xa-16|0;Xa=b;if(Ep(a,b+8|0)){a=b+8|0;a=j[a|0]|j[a+1|0]<<8;c=(a<<24|a<<8&16711680)>>>16|0}Xa=b+16|0;return c}function pIa(a,b){a=a|0;b=b|0;var c=0,d=0;b=Xa-32|0;Xa=b;d=-1;c=a;a=b+8|0;c=YHa(c,a);if(!c){WQ(a)}if(c){d=ZQ(b+8|0)}Xa=b+32|0;return d|0}function mfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=i[b>>2];i[a>>2]=d;i[i[d+ -12>>2]+a>>2]=i[b+4>>2];ir(i[i[a>>2]+ -12>>2]+a|0,c);return a|0}function kpa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Xa-16|0;Xa=d;if(b>>>0>=250){zi(20436);x()}kb(d+8|0,a,b);Od(d+8|0,c);Xa=d+16|0;return a|0}function hKa(a,b){a=a|0;b=b|0;var c=0;c=Xa-32|0;Xa=c;g[c+16|0]=44;i[c+8>>2]=-1;i[c+12>>2]=0;i[c>>2]=1058;i[c+4>>2]=2;pr(a,b,c);Xa=c+32|0}function gja(a,b){a=a|0;b=b|0;var c=0;c=Xa-32|0;Xa=c;g[c+16|0]=44;i[c+8>>2]=-1;i[c+12>>2]=0;i[c>>2]=1058;i[c+4>>2]=1;Uq(a,b,c);Xa=c+32|0}function bLa(a,b){a=a|0;b=b|0;var c=0;c=Xa-32|0;Xa=c;g[c+16|0]=44;i[c+8>>2]=-1;i[c+12>>2]=0;i[c>>2]=1025;i[c+4>>2]=2;Lz(a,b,c);Xa=c+32|0}function a9(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=Xa-32|0;Xa=g;$F(g+8|0,b,c,d,e,f);Lc(a,g+20|0);Im(g+8|0);Xa=g+32|0}function QEa(a,b){a=a|0;b=b|0;var c=0,d=0;b=Xa-16|0;Xa=b;d=-1;c=a;a=b+8|0;c=YDa(c,a);if(!c){iS(a)}if(c){d=KP(b+8|0)}Xa=b+16|0;return d|0}function O6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=Pv(a+8|0,b,c,d,2);if(16>a>>>0){a=j[a+32224|0]}else{a=0}if(a>>>0<=4){return a+1|0}return 0}function N6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=Pv(a+8|0,b,c,d,3);if(43>a>>>0){a=j[a+32176|0]}else{a=0}if(a>>>0<=4){return a+1|0}return 0}function L4(a,b,c,d){if(a|b){while(1){c=c+ -1|0;g[c|0]=j[(a&15)+55584|0]|d;a=(b&15)<<28|a>>>4;b=b>>>4|0;if(a|b){continue}break}}return c}function DGa(a,b){a=a|0;b=b|0;var c=0;c=Xa-32|0;Xa=c;g[c+16|0]=44;i[c+8>>2]=-1;i[c+12>>2]=0;i[c>>2]=1042;i[c+4>>2]=2;Uq(a,b,c);Xa=c+32|0}function Cya(a,b){a=a|0;b=b|0;var c=0;c=Xa-32|0;Xa=c;g[c+16|0]=44;i[c+8>>2]=-1;i[c+12>>2]=0;i[c>>2]=1042;i[c+4>>2]=2;Lz(a,b,c);Xa=c+32|0}function Awa(a,b){a=a|0;b=b|0;var c=0;c=Xa-32|0;Xa=c;g[c+16|0]=44;i[c+8>>2]=-1;i[c+12>>2]=0;i[c>>2]=1058;i[c+4>>2]=3;SO(a,b,c);Xa=c+32|0}function zba(a,b,c,d,e){var f=0,g=0;f=Xa-16|0;Xa=f;i[f+8>>2]=i[a+8>>2];g=i[a+4>>2];i[f>>2]=i[a>>2];i[f+4>>2]=g;nua(f,b,c,d,e);Xa=f+16|0}function wKa(a,b){a=a|0;b=b|0;var c=0;c=Xa-32|0;Xa=c;g[c+16|0]=44;i[c+8>>2]=-1;i[c+12>>2]=0;i[c>>2]=274;i[c+4>>2]=0;Lz(a,b,c);Xa=c+32|0}function vpa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Xa-16|0;Xa=d;if(b>>>0>=43){zi(20436);x()}kb(d+8|0,a,b);Od(d+8|0,c);Xa=d+16|0;return a|0}function vB(a){a=a|0;var b=0;a=Oc(a);i[114610]=0;C(238,a|0,7090)|0;b=i[114610];i[114610]=0;if((b|0)==1){b=B()|0;A()|0;eb(a);E(b|0);x()}}function upa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Xa-16|0;Xa=d;if(b>>>0>=16){zi(20436);x()}lj(d+8|0,a,b);Od(d+8|0,c);Xa=d+16|0;return a|0}function tb(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Xa-16|0;Xa=d;if(b>>>0>=110){zi(12352);x()}kb(d+8|0,a,b);Od(d+8|0,c);Xa=d+16|0;return a|0}function s6(a,b){a=a|0;b=b|0;var c=0;c=Xa-32|0;Xa=c;g[c+16|0]=44;i[c+8>>2]=-1;i[c+12>>2]=0;i[c>>2]=1025;i[c+4>>2]=4;Uq(a,b,c);Xa=c+32|0}function kHa(a,b){a=a|0;b=b|0;var c=0;c=Xa-32|0;Xa=c;g[c+16|0]=44;i[c+8>>2]=-1;i[c+12>>2]=0;i[c>>2]=257;i[c+4>>2]=0;Gw(a,b,c);Xa=c+32|0}function j6(a,b){a=a|0;b=b|0;var c=0;c=Xa-32|0;Xa=c;g[c+16|0]=44;i[c+8>>2]=-1;i[c+12>>2]=0;i[c>>2]=1025;i[c+4>>2]=2;Uq(a,b,c);Xa=c+32|0}function dj(a){var b=0;b=a+28|0;a=b;if((j[a|0]|j[a+1|0]<<8|(j[a+2|0]<<16|j[a+3|0]<<24))>>>0>=128){a=j[b|0]^-128}else{a=255}return a&255}function b9(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=Xa-32|0;Xa=g;$F(g+8|0,b,c,d,e,f);Lc(a,g+8|0);Im(g+8|0);Xa=g+32|0}function _8(a,b,c){b=Kf(a,b);i[114610]=0;C(120,a+12|0,c|0)|0;a=i[114610];i[114610]=0;if((a|0)!=1){return}a=B()|0;A()|0;eb(b);E(a|0);x()}function KW(a,b){a=a|0;b=b|0;var c=0;c=Xa-32|0;Xa=c;g[c+16|0]=44;i[c+8>>2]=-1;i[c+12>>2]=0;i[c>>2]=1058;i[c+4>>2]=2;Gw(a,b,c);Xa=c+32|0}function Hd(a,b){a=a|0;b=b|0;return(j[a|0]|j[a+1|0]<<8|(j[a+2|0]<<16|j[a+3|0]<<24))==(j[b|0]|j[b+1|0]<<8|(j[b+2|0]<<16|j[b+3|0]<<24))|0}function F_(a,b){a=a|0;b=b|0;var c=0;c=qb(a);if(c>>>0<b>>>0){D_(a,b-c|0);return}if(c>>>0>b>>>0){b=i[a>>2]+(b<<2)|0;qb(a);gC(a,b);GC(a)}}function Ds(a,b){a=a|0;b=b|0;var c=0;c=Xa-32|0;Xa=c;g[c+16|0]=44;i[c+8>>2]=-1;i[c+12>>2]=0;i[c>>2]=1058;i[c+4>>2]=2;rH(a,b,c);Xa=c+32|0}function Dc(a,b){var c=0,d=0,e=0;c=ff(a,b);if(c){i[a+12>>2]=i[a+12>>2]+b;return c}d=a,e=$a[i[i[a>>2]+24>>2]](a)|0,i[d+12>>2]=e;return c}function Ay(a,b){a=a|0;b=b|0;var c=0;c=Xa-32|0;Xa=c;g[c+16|0]=44;i[c+8>>2]=-1;i[c+12>>2]=0;i[c>>2]=1058;i[c+4>>2]=2;SO(a,b,c);Xa=c+32|0}function zb(a,b){var c=0,d=0,e=0;d=a;e=a;c=i[a+4>>2]+i[b+4>>2]|0;b=i[b>>2];a=b+i[a>>2]|0;if(a>>>0<b>>>0){c=c+1|0}i[e>>2]=a;i[d+4>>2]=c}function uia(a,b,c){var d=0;d=Xa-16|0;Xa=d;i[d+12>>2]=0;i[d+8>>2]=c;i[d+4>>2]=4;xk(a,d+12|0,i[rb(d+8|0,d+4|0)>>2]);i[b>>2]=0;Xa=d+16|0}function lpa(a,b){a=a|0;b=b|0;var c=0,d=0;d=Xa-16|0;Xa=d;if(!(!a|!b)){c=Nr(a);a=$oa(a,b);c=o(Nr(b),(c|0)/(a|0)|0)}Xa=d+16|0;return c|0}function Zga(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;if(!(!d|!Jd(c&255))){GH(a,8,p(0))}a=Ji(a);if(a){$a[i[i[a>>2]+88>>2]](a,b,c,d,e)}}function P2(a,b){var c=0;c=Xa-16|0;i[c+12>>2]=a;i[c+8>>2]=a;if(b>>>0>=2){a=((b<<2)+a|0)+ -4|0;i[c+8>>2]=a}i[c+8>>2]=a+4;return i[a>>2]}function LW(a,b){a=a|0;b=b|0;var c=0;c=Xa-32|0;Xa=c;g[c+16|0]=44;i[c+8>>2]=-1;i[c+12>>2]=0;i[c>>2]=290;i[c+4>>2]=0;Gw(a,b,c);Xa=c+32|0}function yB(){var a=0,b=0,c=0;a=Xa-16|0;Xa=a;b=Bb(a,10940);c=0;a:{if(!lb(b)){break a}c=(Ef(b,10950)|0)!=-1}eb(b);Xa=a+16|0;return c|0}function dS(a){var b=0;b=Xa-16|0;Xa=b;g[a|0]=0;g[a+1|0]=0;g[a+2|0]=0;g[a+3|0]=0;g[a+3|0]=0;g[a+4|0]=0;g[a+5|0]=0;g[a+6|0]=0;Xa=b+16|0}function _Ba(a){var b=0;b=Xa-16|0;Xa=b;i[b+12>>2]=a;i[b+8>>2]=-128;i[b+4>>2]=127;a=g[wf(b+8|0,Nd(b+12|0,b+4|0))|0];Xa=b+16|0;return a}function IBa(a,b,c){var d=0;if((a|0)!=(b|0)){while(1){d=j[a|0];g[c|0]=d>>>0>32?d:32;c=c+1|0;a=a+1|0;if((b|0)!=(a|0)){continue}break}}}function Cf(a){var b=0,c=0;b=Xa-16|0;Xa=b;if(Rp(a,b+8|0)){a=b+8|0;c=j[a|0]|j[a+1|0]<<8|(j[a+2|0]<<16|j[a+3|0]<<24)}Xa=b+16|0;return c}function Bp(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Xa-16|0;Xa=d;a:{if(!b){break a}if(c){zT(td(d+8|0,a),b);break a}yT(td(d,a),b)}Xa=d+16|0}function wn(a,b,c){var d=0;a:{if(b>>>0>c>>>0){break a}d=i[a>>2];if(d>>>0<b>>>0){i[a>>2]=b;return}if(d>>>0<=c>>>0){break a}i[a>>2]=c}}function vR(a){var b=0;b=a;if((j[b|0]|j[b+1|0]<<8|(j[b+2|0]<<16|j[b+3|0]<<24))==1179468868){return(j[a+4|0]+ -1&255)>>>0<10}return 0}function Qja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=bf(a);if(d>>>0<b>>>0){Oja(a,b-d|0,c);return}if(d>>>0>b>>>0){wI(a,i[a>>2]+o(b,52)|0)}}function Poa(a,b){g[a+860|0]=b;g[a+832|0]=b;g[a+831|0]=b;g[a+829|0]=b;g[a+828|0]=b;h[a+800>>1]=b;g[a+846|0]=b>>>4;g[a+847|0]=b<<2&60}function Kd(a,b,c){var d=0;a:{if((b|0)>(c|0)){break a}d=i[a>>2];if((d|0)<(b|0)){i[a>>2]=b;return}if((d|0)<=(c|0)){break a}i[a>>2]=c}}function Je(a,b,c,d,e){var f=0;f=Xa-16|0;Xa=f;i[f+12>>2]=c;i[f+8>>2]=e;c=ah(f,f+12|0);a=uq(a,b,d,i[f+8>>2]);ne(c);Xa=f+16|0;return a}function H5(a){i[a+1420>>2]=0;i[a+992>>2]=0;i[a+1504>>2]=0;i[a+1508>>2]=0;i[a+1412>>2]=0;i[a+1416>>2]=0;g[a+1377|0]=0;i[a+1064>>2]=0}function xW(){var a=0,b=0;a=Xa-16|0;Xa=a;i[a+8>>2]=19465472;a:{if(zB(a+8|0)){break a}if(yB()){break a}b=xB()^1}Xa=a+16|0;return b|0}function vAa(a,b){var c=0;c=bg(a);if(c>>>0<b>>>0){uAa(a,b-c|0);return}if(c>>>0>b>>>0){b=i[a>>2]+(b<<3)|0;bg(a);fO(a,b);ti(a);bg(a)}}function jAa(a,b){var c=0;c=Xa-16|0;Xa=c;a:{if(wb(a,128)){MP(c+8|0,b);od(a,c+8|0);break a}a=Xa-16|0;Xa=a;iAa(b);Xa=a+16|0}Xa=c+16|0}function gv(a){a=a|0;var b=0;b=i[a+12>>2];if((b|0)==i[a+16>>2]){return $a[i[i[a>>2]+40>>2]](a)|0}i[a+12>>2]=b+1;return cg(g[b|0])|0}function ata(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=be(a);if(d>>>0<b>>>0){Zsa(a,b-d|0,c);return}if(d>>>0>b>>>0){bM(a,i[a>>2]+(b<<5)|0)}}function ama(a,b){var c=0;c=78880;while(1){if(i[c>>2]==(b|0)){JJ(a,i[c+8>>2]);return}c=c+12|0;if((c|0)!=78928){continue}break}Oc(a)}function Hha(a){a=a|0;a=Xa-16|0;Xa=a;i[a+12>>2]=1869112133;Xa=a+16|0;a=a+12|0;return j[a|0]|j[a+1|0]<<8|(j[a+2|0]<<16|j[a+3|0]<<24)}function FGa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=If(a);if(d>>>0<b>>>0){pGa(a,b-d|0,c);return}if(d>>>0>b>>>0){Xy(a,i[a>>2]+o(b,6)|0)}}function DKa(a,b){var c=0;c=Xa-16|0;Xa=c;a:{if(wb(a,512)){Gz(c+8|0,b);od(a,c+8|0);break a}a=Xa-16|0;Xa=a;AKa(b);Xa=a+16|0}Xa=c+16|0}function z8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Xa-16|0;Xa=d;i[d>>2]=c;i[d+8>>2]=b;Up(i[d+8>>2]);y8(a,i[d>>2]);Xa=d+16|0;return a|0}function v8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Xa-16|0;Xa=d;i[d>>2]=c;i[d+8>>2]=b;Up(i[d+8>>2]);u8(a,i[d>>2]);Xa=d+16|0;return a|0}function mI(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=qb(a);if(d>>>0<b>>>0){oja(a,b-d|0,c);return}if(d>>>0>b>>>0){vw(a,i[a>>2]+(b<<2)|0)}}function MV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Xa-16|0;Xa=d;i[d>>2]=c;i[d+8>>2]=b;Up(i[d+8>>2]);LV(a,i[d>>2]);Xa=d+16|0;return a|0}function Kn(a,b){a=a|0;b=b|0;var c=0;c=rc(a);if(c>>>0<b>>>0){pY(a,b-c|0);return}if(c>>>0>b>>>0){b=i[a>>2]+b|0;rc(a);CB(a,b);Yo(a)}}function ne(a){a:{a=i[a>>2];if(a){i[114610]=0;Ru(a);a=i[114610];i[114610]=0;if((a|0)==1){break a}}return}a=H(0)|0;A()|0;gb(a);x()}function bra(a,b){var c=0;c=Xa-16|0;Xa=c;a:{if(wb(a,7)){Hz(c+8|0,b);od(a,c+8|0);break a}a=Xa-16|0;Xa=a;_qa(b);Xa=a+16|0}Xa=c+16|0}function aja(a,b){var c=0,d=0;c=Xa-16|0;Xa=c;i[c+8>>2]=b;b=i[c+8>>2];d=_H(a,b);a=Pb(a);Os(Qg(c+8|0));Xg(a,b,1);Xa=c+16|0;return d}function NR(a,b,c,d,e){g[a+4|0]=b;g[a|0]=1869112133;g[a+1|0]=7301219;g[a+2|0]=28520;g[a+3|0]=111;g[a+7|0]=e;g[a+6|0]=d;g[a+5|0]=c}function FT(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;return(c=aNa(0-aNa(b^1230262859,25)|0,4)^1247037516,d=b,e=(a&4088)>>>0>=520,e?c:d)|0}function vaa(a,b,c){_q(a);i[a+8>>2]=c;i[a+4>>2]=0;i[a>>2]=84184;c=i[b+4>>2];i[a+12>>2]=i[b>>2];i[a+16>>2]=c;i[a+20>>2]=i[b+8>>2]}function taa(a,b,c){_q(a);i[a+8>>2]=c;i[a+4>>2]=0;i[a>>2]=84256;c=i[b+4>>2];i[a+12>>2]=i[b>>2];i[a+16>>2]=c;i[a+20>>2]=i[b+8>>2]}function tE(a,b,c,d,e){if(d>>>0<=b>>>0){if(!e){return d}b=a+b|0;c=e4(a+d|0,b,c,c+e|0);a=(b|0)==(c|0)?-1:c-a|0}else{a=-1}return a}function by(a,b){var c=0,d=0;i[a>>2]=i[b>>2];i[a+4>>2]=i[b+4>>2];i[a+8>>2]=i[b+8>>2];i[b>>2]=0;i[b+4>>2]=0;c=fb(b),d=0,i[c>>2]=d}function Ona(a){var b=0,c=0;c=a+946300|0;a=a+906300|0;while(1){b=i[a>>2];if(b){Nga(b)}a=a+160|0;if((c|0)!=(a|0)){continue}break}}function M3(a,b){var c=0;c=i[a+24>>2];if((c|0)==i[a+28>>2]){return $a[i[i[a>>2]+52>>2]](a,b)|0}i[a+24>>2]=c+4;i[c>>2]=b;return b}function Bt(a,b){var c=0,d=0,e=0;c=Xa-16|0;Xa=c;e=i[b+4>>2];d=i[b>>2];g[c+15|0]=0;d=um(d,d+e|0,c+15|0);Uh(a,i[b>>2],d);Xa=c+16|0}function zv(a,b,c){var d=0;d=i[a+32>>2];if(d+c>>>0>l[a+40>>2]){i[a+96>>2]=1;return 0}Tb(b,d,c);i[a+32>>2]=i[a+32>>2]+c;return 1}function zM(a){var b=0;b=i[a+16>>2];a=i[a+32>>2];b=XMa(b,b>>31,a,a>>31)+5e5|0;a=_a;return gc(YMa(b,b>>>0<5e5?a+1|0:a,1e6,0),_a)}function yM(a){var b=0;b=i[a+16>>2];a=i[a+36>>2];b=XMa(b,b>>31,a,a>>31)+5e5|0;a=_a;return gc(YMa(b,b>>>0<5e5?a+1|0:a,1e6,0),_a)}function ng(a,b){a=a|0;b=b|0;var c=0;c=Xa-16|0;Xa=c;if(b>>>0>=110){zi(12596);x()}kb(c+8|0,a,b);Od(c+8|0,0);Xa=c+16|0;return a|0}function n_(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;while(1){if((b|0)!=(c|0)){i[d>>2]=g[b|0];d=d+4|0;b=b+1|0;continue}break}return c|0}function hY(a,b,c){a:{if(c){i[114610]=0;bC(a,b,c);a=i[114610];i[114610]=0;if((a|0)==1){break a}}return}a=H(0)|0;A()|0;gb(a);x()}function gY(a,b,c){a:{if(b){i[114610]=0;cC(a,c,b);a=i[114610];i[114610]=0;if((a|0)==1){break a}}return}a=H(0)|0;A()|0;gb(a);x()}function gD(a,b,c,d,e,f){a=$a[i[i[a+8>>2]+4>>2]](a+8|0)|0;a=tq(c,d,a,a+288|0,f,e,0)-a|0;if((a|0)<=287){i[b>>2]=((a|0)/12|0)%12}}function cD(a,b,c,d,e,f){a=$a[i[i[a+8>>2]+4>>2]](a+8|0)|0;a=rq(c,d,a,a+288|0,f,e,0)-a|0;if((a|0)<=287){i[b>>2]=((a|0)/12|0)%12}}function Ji(a){var b=0,c=0;b=dj(i[a+20>>2]);if(!(b>>>0>249|b>>>0<=j[a+4200|0])){c=i[(i[a+16>>2]+o(b,160)|0)+906300>>2]}return c}function Gh(a,b,c){a:{if(c){i[114610]=0;sE(a,b,c);a=i[114610];i[114610]=0;if((a|0)==1){break a}}return}a=H(0)|0;A()|0;gb(a);x()}function BL(a,b,c){a=a|0;b=b|0;c=c|0;if((b|0)!=(c|0)){while(1){AL(a,j[b|0]);b=b+1|0;if((c|0)!=(b|0)){continue}break}}return a|0}function wHa(a,b){a=a|0;b=b|0;var c=0,d=0;b=Xa-160|0;Xa=b;c=-1;d=b;a=tHa(a,b);if(!a){IQ(d)}if(a){c=KQ(b)}Xa=b+160|0;return c|0}function qta(a){var b=0,c=0;if(i[a>>2]){be(a);_L(a);du(a);Xg(fb(a),i[a>>2],Yg(a));b=fb(a),c=0,i[b>>2]=c;i[a>>2]=0;i[a+4>>2]=0}}function pna(a){var b=0,c=0;if(i[a>>2]){rc(a);yA(a);Yo(a);Uf(fb(a),i[a>>2],xf(a));b=fb(a),c=0,i[b>>2]=c;i[a>>2]=0;i[a+4>>2]=0}}function ora(a){var b=0,c=0;if(i[a>>2]){cc(a);gL(a);os(a);dh(fb(a),i[a>>2],Rf(a));b=fb(a),c=0,i[b>>2]=c;i[a>>2]=0;i[a+4>>2]=0}}function hX(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;return Sda(a,b,c,d,e,f,g,h,i,j)|0}function h5(a){a:{if((fe(a)|0)!=79){break a}if((fe(a)|0)!=103){break a}if((fe(a)|0)!=103){break a}return(fe(a)|0)==83}return 0}function f_(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;while(1){if((b|0)!=(c|0)){g[d|0]=j[b|0];d=d+1|0;b=b+1|0;continue}break}return c|0}function fX(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;return Rda(a,b,c,d,e,f,g,h,i,j)|0}function eya(a,b){a=a|0;b=b|0;var c=0,d=0;b=Xa-208|0;Xa=b;c=-1;d=b;a=Hxa(a,b);if(!a){_M(d)}if(a){c=dN(b)}Xa=b+208|0;return c|0}function cza(a){var b=0,c=0;if(i[a>>2]){nd(a);BN(a);To(a);Df(fb(a),i[a>>2],Be(a));b=fb(a),c=0,i[b>>2]=c;i[a>>2]=0;i[a+4>>2]=0}}function Sja(a){var b=0,c=0;if(i[a>>2]){bf(a);xJ(a);sI(a);Xw(fb(a),i[a>>2],Mi(a));b=fb(a),c=0,i[b>>2]=c;i[a>>2]=0;i[a+4>>2]=0}}function RL(a,b,c,d,e){i[a+12>>2]=e;i[a+8>>2]=d;i[a+4>>2]=c;i[a>>2]=b;if(b){ce(b,a)}if(c){ce(c,a)}if(d){ce(d,a)}if(e){ce(e,a)}}function QB(a){i[114610]=0;K(a|0);a=i[114610];i[114610]=0;if((a|0)!=1){i[114610]=0;x()}a=H(0)|0;A()|0;M(a|0)|0;i[114610]=0;x()}function OMa(a,b,c,d){if((mk(11872)|0)==(b|0)){Ib(d,c);return}if(!xT(a,b,c,d)){Ib(d,c);return}if((mk(11877)|0)==(b|0)){NMa(a)}}function Lka(a){var b=0,c=0;if(i[a>>2]){nd(a);NI(a);To(a);Df(fb(a),i[a>>2],Be(a));b=fb(a),c=0,i[b>>2]=c;i[a>>2]=0;i[a+4>>2]=0}}function KGa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=rc(a);if(d>>>0<b>>>0){uGa(a,b-d|0,c);return}if(d>>>0>b>>>0){Jt(a,i[a>>2]+b|0)}}function Doa(a){var b=0,c=0;if(i[a>>2]){nd(a);eK(a);To(a);uo(fb(a),i[a>>2],Be(a));b=fb(a),c=0,i[b>>2]=c;i[a>>2]=0;i[a+4>>2]=0}}function Cra(a,b){var c=0;c=cc(a);if(c>>>0<b>>>0){yra(a,b-c|0);return}if(c>>>0>b>>>0){b=i[a>>2]+o(b,12)|0;cc(a);fL(a,b);os(a)}}function xpa(a){g[a+26|0]=0;h[a+24>>1]=0;i[a+16>>2]=0;i[a+20>>2]=-1;i[a+8>>2]=-1;i[a+12>>2]=-1;i[a>>2]=0;i[a+4>>2]=0;return a}function vFa(a,b){var c=0;c=qb(a);if(c>>>0<b>>>0){uFa(a,b-c|0);return}if(c>>>0>b>>>0){b=i[a>>2]+(b<<2)|0;qb(a);YP(a,b);vg(a)}}function tI(a){a=a|0;var b=0,c=0;b=ke(a);while(1){c=b;if(c&65535){b=c+ -1|0;if(!pg(a,b&65535)){continue}}break}return c&65535}function mU(a,b,c,d){var e=0,f=0;e=(b|0)/8|0;a=e+a|0;f=$f(d,a);return($f(d,a+1|0)<<8|f<<16|$f(d,a+2|0))<<(b-(e<<3)|0)+8>>32-c}function m4(a){a=a|0;var b=0;if(($a[i[i[a>>2]+36>>2]](a)|0)==-1){return-1}b=a;a=i[a+12>>2];i[b+12>>2]=a+1;return cg(g[a|0])|0}function e8(a){var b=0,c=0;if(i[a>>2]){nd(a);QF(a);To(a);uo(fb(a),i[a>>2],Be(a));b=fb(a),c=0,i[b>>2]=c;i[a>>2]=0;i[a+4>>2]=0}}function cY(a,b){var c=0;a=qY(a,i[21199]);c=le(a);if(c>>>0>=1024){Tb(b,a,1023);g[b+1023|0]=0;return 68}Tb(b,a,c+1|0);return 0}function Vj(a,b){var c=0;a:{if(l[a+12>>2]<b>>>0){c=0;if($a[i[i[a>>2]+24>>2]](a)>>>0<b>>>0){break a}}i[a+12>>2]=b;c=1}return c}function RCa(a,b){var c=0;c=Wb(a);if(c>>>0<b>>>0){QCa(a,b-c|0);return}if(c>>>0>b>>>0){b=i[a>>2]+(b<<1)|0;Wb(a);$O(a,b);vp(a)}}function Lza(a,b){var c=0;c=qb(a);if(c>>>0<b>>>0){Kza(a,b-c|0);return}if(c>>>0>b>>>0){b=i[a>>2]+(b<<2)|0;qb(a);MN(a,b);vg(a)}}function HLa(a,b){var c=0;c=Wb(a);if(c>>>0<b>>>0){GLa(a,b-c|0);return}if(c>>>0>b>>>0){b=i[a>>2]+(b<<1)|0;Wb(a);CS(a,b);vp(a)}}function BX(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;if(Nf(a,i[b+8>>2],0)){su(b,c,d);return}a=i[a+8>>2];$a[i[i[a>>2]+28>>2]](a,b,c,d)}function $Ca(a,b){var c=0;c=qb(a);if(c>>>0<b>>>0){_Ca(a,b-c|0);return}if(c>>>0>b>>>0){b=i[a>>2]+(b<<2)|0;qb(a);eP(a,b);vg(a)}}function qMa(a,b){a=a|0;b=b|0;var c=0,d=0;b=Xa-48|0;Xa=b;c=-1;d=b;a=RLa(a,b);if(!a){KS(d)}if(a){c=bT(b)}Xa=b+48|0;return c|0}function nE(a){i[a>>2]=55792;Hu(a+4|0);i[a+24>>2]=0;i[a+28>>2]=0;i[a+16>>2]=0;i[a+20>>2]=0;i[a+8>>2]=0;i[a+12>>2]=0;return a}function l6(a){a=a|0;var b=0;if(!a){return-2}b=i[a+28>>2];if(!b){return 0}$a[i[a+36>>2]](i[a+40>>2],b);i[a+28>>2]=0;return 0}function hD(a,b,c,d,e,f){a=$a[i[i[a+8>>2]>>2]](a+8|0)|0;a=tq(c,d,a,a+168|0,f,e,0)-a|0;if((a|0)<=167){i[b>>2]=((a|0)/12|0)%7}}function eN(a){var b=0,c=0;b=j[a+33|0];c=b>>>24|0;a=j[a+31|0]?1120:1056;b=a+(b<<8)|0;c=b>>>0<a>>>0?c+1|0:c;a=b;_a=c;return a}function dD(a,b,c,d,e,f){a=$a[i[i[a+8>>2]>>2]](a+8|0)|0;a=rq(c,d,a,a+168|0,f,e,0)-a|0;if((a|0)<=167){i[b>>2]=((a|0)/12|0)%7}}function cC(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;if(c){d=a;while(1){i[d>>2]=b;d=d+4|0;c=c+ -1|0;if(c){continue}break}}return a|0}function c9(a,b){var c=0;c=Xa-32|0;Xa=c;g[c+16|0]=44;i[c+8>>2]=-1;i[c+12>>2]=0;i[c>>2]=1058;i[c+4>>2]=1;$ga(a,b,c);Xa=c+32|0}function WEa(a,b){var c=0;a:{if(!b){break a}if(!wb(a,b)){break a}if(b>>>0<=3){return VEa(a,b)}c=Cf(a);Ib(a,b+ -4|0)}return c}function VJ(a){a=a|0;i[a>>2]=0;ni(a+4|0);i[a+152>>2]=0;i[a+156>>2]=0;i[a+144>>2]=0;i[a+148>>2]=0;yb(a+16|0,0,128);return a|0}function Lma(a,b){var c=0,d=0;i[a>>2]=i[b>>2];c=b+4|0;d=a+4|0;if((c|0)!=(d|0)){uJ(d,i[c>>2],i[c+4>>2])}Tb(a+16|0,b+16|0,144)}function Hq(a){i[a>>2]=55728;Hu(a+4|0);i[a+24>>2]=0;i[a+28>>2]=0;i[a+16>>2]=0;i[a+20>>2]=0;i[a+8>>2]=0;i[a+12>>2]=0;return a}function Hna(a){var b=0,c=0;b=Xa-16|0;Xa=b;c=a+1304392|0;if(!$c(c)){Dna(b+8|0,a+24620|0);NJ(c,sd(b+8|0));Gr(b+8|0)}Xa=b+16|0}function Af(a,b,c,d){var e=0;a=((b|0)/8|0)+a|0;e=$f(d,a);return(($f(d,a+1|0)<<8|e<<16|$f(d,a+2|0))<<(b&7)&16777215)>>>24-c|0}function t3(a,b){i[a+20>>2]=0;i[a+24>>2]=b;i[a+12>>2]=0;i[a+4>>2]=4098;i[a+8>>2]=6;i[a+16>>2]=!b;yb(a+32|0,0,40);Hu(a+28|0)}function _U(a,b){var c=0,d=0;c=Xa-16|0;Xa=c;d=a;a=tk(c+8|0,i[b>>2]);WU(d,a,i[i[b+4>>2]>>2],i[i[b+8>>2]>>2]);hb(a);Xa=c+16|0}function YEa(a,b){var c=0;a:{if(!b){break a}if(!wb(a,b)){break a}if(b>>>0<=3){return tT(a,b)}c=Cf(a);Ib(a,b+ -4|0)}return c}function XEa(a,b){var c=0;a:{if(!b){break a}if(!wb(a,b)){break a}if(b>>>0<=1){return sT(a,1)}c=_f(a);Ib(a,b+ -2|0)}return c}function Txa(a,b){var c=0;c=Xa-16|0;Xa=c;b=j[b|0]|j[b+1|0]<<8;h[c+14>>1]=(b<<24|b<<8&16711680)>>>16;vha(a,c+14|0);Xa=c+16|0}function PY(a,b){var c=0;c=Wc(a);if(c>>>0<b>>>0){uY(a,b-c|0);return}if(c>>>0>b>>>0){b=i[a>>2]+(b<<4)|0;Wc(a);GB(a,b);FB(a)}}function Cs(a){a=a|0;var b=0;b=Xa-16|0;Xa=b;i[b+12>>2]=a;i[b+8>>2]=2147483647;a=i[rb(b+12|0,b+8|0)>>2];Xa=b+16|0;return a|0}function Br(a){a=+a;var b=0,c=0,d=0;d=a*a;a=0;b=1;c=1;while(1){a=a+2;c=d*c/(a*a);b=c+b;if(c>b*1e-7){continue}break}return+b}function xM(a){a=a|0;i[a+700>>2]=0;h[a+862>>1]=0;i[a+688>>2]=0;i[a>>2]=0;i[a+4>>2]=0;i[a+8>>2]=0;i[a+12>>2]=0;i[a+16>>2]=0}function wMa(a,b){var c=0;c=Xa-16|0;Xa=c;a:{if(wb(a,3)){Xz(c+8|0,b);od(a,c+8|0);break a}g[c+7|0]=0;bj(b,3,c+7|0)}Xa=c+16|0}function vEa(a){var b=0;b=Yj(a);if(b>>>0<64){qEa(a,64-b|0);return}if(b>>>0>64){b=i[a>>2]+2112|0;Yj(a);FP(a,b);jl(a);Yj(a)}}function my(a){i[a>>2]=0;i[a+4>>2]=0;i[a+24>>2]=0;i[a+28>>2]=0;i[a+16>>2]=0;i[a+20>>2]=0;i[a+8>>2]=0;i[a+12>>2]=0;return a}function mw(a){var b=0,c=0;n[a+4272>>3]=n[a+4280>>3];b=a,c=+p(p(gha(a+4296|0)|0)*p(-4.656612873077393e-10)),n[b+4280>>3]=c}function SLa(a,b){var c=0;c=Xa-16|0;Xa=c;a:{if(wb(a,4)){_g(c+8|0,b);od(a,c+8|0);break a}g[c+7|0]=0;bj(b,4,c+7|0)}Xa=c+16|0}function GHa(a,b){var c=0;c=Xa-16|0;Xa=c;a:{if(wb(a,6)){jz(c+8|0,b);od(a,c+8|0);break a}g[c+7|0]=0;bj(b,6,c+7|0)}Xa=c+16|0}function Fza(a,b){var c=0;c=Xa-16|0;Xa=c;a:{if(wb(a,5)){Kz(c+8|0,b);od(a,c+8|0);break a}g[c+7|0]=0;bj(b,5,c+7|0)}Xa=c+16|0}function A2(a,b){var c=0,d=p(0);c=Xa-16|0;Xa=c;Pu(c,a,b,0);d=DD(i[c>>2],i[c+4>>2],i[c+8>>2],i[c+12>>2]);Xa=c+16|0;return d}function $I(a,b){var c=0;if(!(j[a|0]!=j[b|0]|n[a+8>>3]!=n[b+8>>3]|j[a+16|0]!=j[b+16|0])){c=i[a+20>>2]==i[b+20>>2]}return c}function lY(a,b){var c=0,d=0;c=Xa-16|0;Xa=c;g[c+15|0]=0;d=-1;if(b>>>0>0){b=Bn(a,b,c+15|0);d=b?b-a|0:-1}Xa=c+16|0;return d}function kx(a,b){var c=0;c=Xa-16|0;Xa=c;kb(c+8|0,a+1074308|0,7);a=ib(c+8|0);Xa=c+16|0;return i[(b<<2)+(a?25296:26320)>>2]}function kK(a,b){var c=0;c=Xa-16|0;Xa=c;kb(c+8|0,a+1074308|0,7);a=ib(c+8|0);Xa=c+16|0;return i[(b<<2)+(a?25168:25232)>>2]}function jx(a,b){var c=0;c=Xa-16|0;Xa=c;kb(c+8|0,a+1074308|0,7);a=ib(c+8|0);Xa=c+16|0;return i[(b<<2)+(a?26320:25296)>>2]}function jK(a,b){var c=0;c=Xa-16|0;Xa=c;kb(c+8|0,a+1074308|0,7);a=ib(c+8|0);Xa=c+16|0;return i[(b<<2)+(a?25232:25168)>>2]}function iua(a){if(!(p(4294967296)>a)){return-1}if(!(p(0)<a)){return 0}if(a<p(4294967296)&a>=p(0)){return~~a>>>0}return 0}function Wna(a){var b=0,c=0;b=Xa-16|0;Xa=b;c=a+128e3|0;while(1){Oma(a);a=a+32|0;if((c|0)!=(a|0)){continue}break}Xa=b+16|0}function LAa(a,b){var c=0,d=0;c=Xa-16|0;Xa=c;d=wb(a,32);a:{if(d){hO(c+8|0,b);od(a,c+8|0);break a}gO(b)}Xa=c+16|0;return d}function Ju(a,b,c){c=i[c>>2];while(1){a:{if((a|0)!=(b|0)){if((c|0)!=i[a>>2]){break a}}else{a=b}return a}a=a+4|0;continue}}function mM(a,b,c,d,e,f,h){g[a+17|0]=h;g[a+16|0]=f;i[a+12>>2]=e;i[a+8>>2]=d;i[a+4>>2]=c;i[a>>2]=b;if(d){jM(a,1);jM(a,0)}}function lM(a,b,c,d,e,f,h){g[a+17|0]=h;g[a+16|0]=f;i[a+12>>2]=e;i[a+8>>2]=d;i[a+4>>2]=c;i[a>>2]=b;if(d){iM(a,1);iM(a,0)}}function h4(a){a=a|0;var b=0;if(($a[i[i[a>>2]+36>>2]](a)|0)==-1){return-1}b=a;a=i[a+12>>2];i[b+12>>2]=a+4;return i[a>>2]}function dsa(a){var b=0,c=0;a=a<<24;while(1){b=a<<1;a=(a|0)>-1?b:b^79764919;c=c+1|0;if((c|0)!=8){continue}break}return a}function dEa(a,b){i[114610]=0;G(25,a|0,o(b,33)|0,1);a=i[114610];i[114610]=0;if((a|0)!=1){return}a=H(0)|0;A()|0;gb(a);x()}function cpa(a,b){var c=0,d=0,e=0;while(1){d=(c<<2)+a|0,e=lua(b),i[d>>2]=e;c=c+1|0;if((c|0)!=12){continue}break}return a}function cV(a){a=a|0;var b=0;a:{if(!ae(-1,i[a+76>>2])){a=i[a+76>>2];break a}b=a;a=xH(a,32);i[b+76>>2]=a}return a<<24>>24}function cE(a){var b=0;b=i[a+12>>2];if((b|0)==i[a+16>>2]){return $a[i[i[a>>2]+40>>2]](a)|0}i[a+12>>2]=b+4;return i[b>>2]}function cBa(a,b){var c=0;c=Xa-16|0;Xa=c;a:{if(ff(a,2)){ok(c+8|0,b);oy(a,c+8|0);break a}g[c+7|0]=0;HS(b,c+7|0)}Xa=c+16|0}function _S(a,b){a=a|0;b=b|0;var c=0;c=Wb(a);if(c>>>0<b>>>0){cMa(a,b-c|0);return}if(c>>>0>b>>>0){wp(a,i[a>>2]+(b<<1)|0)}}function WF(a,b){i[114610]=0;G(25,a|0,o(b,324)|0,4);a=i[114610];i[114610]=0;if((a|0)!=1){return}a=H(0)|0;A()|0;gb(a);x()}function Tma(a,b){i[114610]=0;G(25,a|0,o(b,52)|0,4);a=i[114610];i[114610]=0;if((a|0)!=1){return}a=H(0)|0;A()|0;gb(a);x()}function SCa(a,b){i[114610]=0;G(25,a|0,o(b,20)|0,4);a=i[114610];i[114610]=0;if((a|0)!=1){return}a=H(0)|0;A()|0;gb(a);x()}function RJa(a){a=a+4|0;a=j[a|0]|j[a+1|0]<<8|(j[a+2|0]<<16|j[a+3|0]<<24);return a<<24|a<<8&16711680|(a>>>8&65280|a>>>24)}function RI(a){var b=0;b=a;if((j[b|0]|j[b+1|0]<<8|(j[b+2|0]<<16|j[b+3|0]<<24))==1179011410){return pz(a)>>>0>80}return 0}function QM(a){var b=0;b=a+68|0;if(!(!(j[b|0]|j[b+1|0]<<8)|(j[b|0]|j[b+1|0]<<8)>>>0>127)){return!Xc(a,17949,17)}return 0}function OLa(a,b){var c=0;c=Xa-16|0;Xa=c;a:{if(wb(a,2)){ok(c+8|0,b);od(a,c+8|0);break a}g[c+7|0]=0;HS(b,c+7|0)}Xa=c+16|0}function K4(a,b,c){if(a|b){while(1){c=c+ -1|0;g[c|0]=a&7|48;a=(b&7)<<29|a>>>3;b=b>>>3|0;if(a|b){continue}break}}return c}function Ij(a,b,c){var d=0;d=i[b+4>>2];i[a>>2]=i[b>>2];i[a+4>>2]=d;d=i[b+12>>2];i[a+8>>2]=i[b+8>>2];i[a+12>>2]=d;Jw(a,c)}function HIa(a,b){i[114610]=0;G(25,a|0,o(b,48)|0,4);a=i[114610];i[114610]=0;if((a|0)!=1){return}a=H(0)|0;A()|0;gb(a);x()}function Foa(a,b){i[114610]=0;G(25,a|0,o(b,24)|0,8);a=i[114610];i[114610]=0;if((a|0)!=1){return}a=H(0)|0;A()|0;gb(a);x()}function Epa(a){if(!(p(65535)>a)){return 65535}if(!(p(0)<a)){return 0}if(a<p(4294967296)&a>=p(0)){return~~a>>>0}return 0}function $Fa(a,b){var c=0,d=0;c=Xa-16|0;Xa=c;d=wb(a,4);a:{if(d){_g(c+8|0,b);od(a,c+8|0);break a}OP(b)}Xa=c+16|0;return d}function zN(a,b){i[114610]=0;G(25,a|0,o(b,56)|0,4);a=i[114610];i[114610]=0;if((a|0)!=1){return}a=H(0)|0;A()|0;gb(a);x()}function z2(a,b){var c=0,d=0;c=Xa-16|0;Xa=c;Pu(c,a,b,1);d=nv(i[c>>2],i[c+4>>2],i[c+8>>2],i[c+12>>2]);Xa=c+16|0;return d}function xV(a){i[a>>2]=0;i[a+4>>2]=0;i[a+24>>2]=0;i[a+28>>2]=0;i[a+16>>2]=0;i[a+20>>2]=0;i[a+8>>2]=0;i[a+12>>2]=0;aB(a)}function una(a,b){a=a|0;b=b|0;if(b>>>0>255){return 20509}a=i[((b<<2)+a|0)+900380>>2];if(!a){return 20509}return a+492|0}function pxa(a,b){i[114610]=0;G(25,a|0,o(b,9)|0,1);a=i[114610];i[114610]=0;if((a|0)!=1){return}a=H(0)|0;A()|0;gb(a);x()}function jd(a){var b=0;b=Xa-16|0;Xa=b;i[b+12>>2]=83600;i[b+8>>2]=83704;i[a>>2]=i[b+12>>2];i[a+4>>2]=i[b+8>>2];Xa=b+16|0}function iB(a,b){i[114610]=0;G(25,a|0,o(b,24)|0,4);a=i[114610];i[114610]=0;if((a|0)!=1){return}a=H(0)|0;A()|0;gb(a);x()}function dta(a,b,c){var d=0;_S(c,i[a>>2]);if(i[a>>2]){while(1){SL(b,$b(c,d));d=d+1|0;if(d>>>0<l[a>>2]){continue}break}}}function Zh(a,b,c){a:{if((Sj(a,b)|0)==255){break a}Rj(a,b);Jo(a,b,0,0);if(!c){break a}a=Nb(a+58|0,b);g[a|0]=j[a|0]|128}}function Xxa(a,b){a=a|0;b=b|0;var c=0;h[a+34>>1]=0;c=Xa-16|0;Xa=c;Ixa(a+43|0);Xa=c+16|0;i[a+20>>2]=0;kd(a,b);return a|0}function U2(a,b){i[114610]=0;G(25,a|0,o(b,12)|0,4);a=i[114610];i[114610]=0;if((a|0)!=1){return}a=H(0)|0;A()|0;gb(a);x()}function RIa(a,b){i[114610]=0;G(25,a|0,o(b,6)|0,1);a=i[114610];i[114610]=0;if((a|0)!=1){return}a=H(0)|0;A()|0;gb(a);x()}function Pna(a,b){mb(a,b);mb(a+12|0,b+12|0);mb(a+24|0,b+24|0);mb(a+36|0,b+36|0);mb(a+48|0,b+48|0);i[a+60>>2]=i[b+60>>2]}function Lf(a,b){a=a|0;b=b|0;var c=0;c=qb(a);if(c>>>0<b>>>0){RT(a,b-c|0);return}if(c>>>0>b>>>0){Ft(a,i[a>>2]+(b<<2)|0)}}function KP(a){var b=0;b=a;if((j[b|0]|j[b+1|0]<<8|(j[b+2|0]<<16|j[b+3|0]<<24))==1279544644){return j[a+4|0]<32}return 0}function Id(a,b){var c=p(0);a:{if(b>p(1)){break a}c=m[a>>2];if(!(c>=b)){m[a>>2]=b;return}if(c<=p(1)){break a}m[a>>2]=1}}function AR(a){var b=0;a:{if(Xc(a,12667,20)){break a}b=a+25|0;if(!j[b|0]|j[b|0]>8){break a}return g[a+47|0]>-1}return 0}function sz(a){a=a|0;var b=0;b=Xa-16|0;Xa=b;i[b+12>>2]=a;i[b+8>>2]=65535;a=k[rb(b+12|0,b+8|0)>>1];Xa=b+16|0;return a|0}function sJa(a){var b=0,c=0;b=Xa-16|0;Xa=b;c=a- -64|0;while(1){Ne(a);a=a+1|0;if((c|0)!=(a|0)){continue}break}Xa=b+16|0}function kua(a,b,c){var d=0;d=64;i[a+764>>2]=64;if(b){d=k[b+32>>1];i[a+764>>2]=d}if(c){i[a+764>>2]=o(i[c+4>>2],d)>>>6}}function fe(a){var b=0;b=i[a+32>>2];a:{if(b>>>0>=l[a+40>>2]){i[a+96>>2]=1;a=0;break a}i[a+32>>2]=b+1;a=j[b|0]}return a}function esa(){var a=0,b=0,c=0;while(1){b=(a<<2)+87568|0,c=dsa(a&255),i[b>>2]=c;a=a+1|0;if((a|0)!=256){continue}break}}function QHa(a){var b=0,c=0;b=Xa-16|0;Xa=b;c=a- -64|0;while(1){Tz(a);a=a+2|0;if((c|0)!=(a|0)){continue}break}Xa=b+16|0}function FY(a){var b=0,c=0,d=0;c=i[a+4>>2];b=i[a>>2];a=i[a+8>>2];b=b+(a>>1)|0;d=b;if(a&1){c=i[c+i[b>>2]>>2]}$a[c|0](d)}function kP(a){a=a|0;var b=0;b=Xa-16|0;Xa=b;h[b+14>>1]=a;h[b+12>>1]=255;a=j[ef(b+14|0,b+12|0)|0];Xa=b+16|0;return a|0}function iAa(a){var b=0,c=0;b=Xa-16|0;Xa=b;c=a+128|0;while(1){Ne(a);a=a+1|0;if((c|0)!=(a|0)){continue}break}Xa=b+16|0}function bBa(a){var b=0,c=0;b=Xa-16|0;Xa=b;c=a+512|0;while(1){Ne(a);a=a+1|0;if((c|0)!=(a|0)){continue}break}Xa=b+16|0}function YR(a){var b=0;b=a;if((j[b|0]|j[b+1|0]<<8|(j[b+2|0]<<16|j[b+3|0]<<24))==810369604){return j[a+4|0]<4}return 0}function Ub(a,b){var c=0;nm(a);i[a+4>>2]=0;i[a>>2]=83556;c=a;a=Zc(lb(b)+1|0);i[c+4>>2]=a;if(a){Tb(a,xb(b),lb(b)+1|0)}}function GKa(a){var b=0,c=0;b=Xa-16|0;Xa=b;c=a+120|0;while(1){Ne(a);a=a+1|0;if((c|0)!=(a|0)){continue}break}Xa=b+16|0}function DS(a,b){a=a|0;b=b|0;var c=0;c=i[b+4>>2];if(c){Ob(a,c,i[b>>2]);return}b=b+8|0;if(!Uc(b)){ui(a,b);return}tf(a)}function AY(a){var b=0;b=a+8|0;if(!i[b>>2]){$a[i[i[a>>2]+16>>2]](a);return}if((au(b)|0)==-1){$a[i[i[a>>2]+16>>2]](a)}}function AKa(a){var b=0,c=0;b=Xa-16|0;Xa=b;c=a+512|0;while(1){Fz(a);a=a+4|0;if((c|0)!=(a|0)){continue}break}Xa=b+16|0}function yga(a,b,c){var d=0;if((b|0)>=1){while(1){m[a>>2]=m[c>>2];a=a+4|0;d=(b|0)>1;b=b+ -1|0;if(d){continue}break}}}function qha(a,b){i[114610]=0;G(25,a|0,b<<11,4);a=i[114610];i[114610]=0;if((a|0)!=1){return}a=H(0)|0;A()|0;gb(a);x()}function iZ(a){var b=0,c=0;b=Xa-16|0;Xa=b;c=a+256|0;while(1){Ne(a);a=a+1|0;if((c|0)!=(a|0)){continue}break}Xa=b+16|0}function epa(a,b,c){var d=0;if((b|0)>=1){while(1){i[a>>2]=i[c>>2];a=a+4|0;d=(b|0)>1;b=b+ -1|0;if(d){continue}break}}}function csa(a){var b=0,c=0;b=Xa-16|0;Xa=b;c=a+27|0;while(1){Ne(a);a=a+1|0;if((c|0)!=(a|0)){continue}break}Xa=b+16|0}function Yma(a){var b=0,c=0;b=Xa-16|0;Xa=b;c=a+20|0;while(1){Ne(a);a=a+1|0;if((c|0)!=(a|0)){continue}break}Xa=b+16|0}function Tra(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=Xa-16|0;Xa=e;d=Qp(e,a,d);kn(fb(a),b,c,d+4|0);sb(d);Xa=e+16|0}function Sj(a,b){a=a+58|0;if(g[Nb(a,b)|0]<0){return 255}if(j[Nb(a,b)|0]!=255){a=j[Nb(a,b)|0]&127}else{a=255}return a}function PLa(a){var b=0,c=0;b=Xa-16|0;Xa=b;c=a+16|0;while(1){Ne(a);a=a+1|0;if((c|0)!=(a|0)){continue}break}Xa=b+16|0}function NBa(a){var b=0,c=0;b=Xa-16|0;Xa=b;if(Ep(a,b+8|0)){a=b+8|0;c=(j[a|0]|j[a+1|0]<<8)<<16>>16}Xa=b+16|0;return c}function Lna(a,b){var c=0;c=Xa-16|0;Xa=c;Jn(c+8|0,$g(c,b));Kna(a,c+8|0);i[a+16>>2]=0;i[a+12>>2]=0;Xa=c+16|0;return a}function Koa(a){if(!(p(255)>a)){return 255}if(!(p(0)<a)){return 0}if(a<p(4294967296)&a>=p(0)){return~~a>>>0}return 0}function Ixa(a){var b=0,c=0;b=Xa-16|0;Xa=b;c=a+22|0;while(1){Ne(a);a=a+1|0;if((c|0)!=(a|0)){continue}break}Xa=b+16|0}function IE(a,b,c){var d=0,e=0,f=0;e=c*c;n[a>>3]=e;f=c;d=c*134217729;c=d+(c-d);d=f-c;n[b>>3]=d*d+(c*c-e+(c+c)*d)}



function DAa(a){var b=0,c=0;b=Xa-16|0;Xa=b;c=a+32|0;while(1){Ne(a);a=a+1|0;if((c|0)!=(a|0)){continue}break}Xa=b+16|0}function CMa(a,b){var c=0;c=Xa-16|0;Xa=c;h[c+12>>1]=65535;h[c+14>>1]=b;BMa(a,k[ef(12e3,c+14|0)>>1],c+12|0);Xa=c+16|0}function zw(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=Xa-16|0;Xa=e;d=jp(e,a,d);yI(fb(a),b,c,d+4|0);sb(d);Xa=e+16|0}function wFa(a,b){i[114610]=0;G(25,a|0,b<<2,1);a=i[114610];i[114610]=0;if((a|0)!=1){return}a=H(0)|0;A()|0;gb(a);x()}function tp(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=Xa-16|0;Xa=e;d=Yd(e,a,d);kn(fb(a),b,c,d+4|0);sb(d);Xa=e+16|0}function hBa(a,b){i[114610]=0;G(25,a|0,b<<5,8);a=i[114610];i[114610]=0;if((a|0)!=1){return}a=H(0)|0;A()|0;gb(a);x()}function eu(a,b){var c=0,d=0,e=0;c=Xa-16|0;Xa=c;i[c>>2]=i[b>>2];d=c,e=i[b>>2]+PA(b)|0,i[d+4>>2]=e;TV(a,c);Xa=c+16|0}function cy(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=Xa-16|0;Xa=e;d=ql(e,a,d);kn(fb(a),b,c,d+4|0);sb(d);Xa=e+16|0}function ck(a,b){a=a|0;b=b|0;var c=0;c=rc(a);if(c>>>0<b>>>0){_Ia(a,b-c|0);return}if(c>>>0>b>>>0){jR(a,i[a>>2]+b|0)}}function _qa(a){var b=0,c=0;b=Xa-16|0;Xa=b;c=a+7|0;while(1){Ne(a);a=a+1|0;if((c|0)!=(a|0)){continue}break}Xa=b+16|0}function _Ea(a){var b=0,c=0;b=Xa-16|0;Xa=b;c=a+4|0;while(1){Ne(a);a=a+1|0;if((c|0)!=(a|0)){continue}break}Xa=b+16|0}function WL(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=Xa-16|0;Xa=e;d=vh(e,a,d);kn(fb(a),b,c,d+4|0);sb(d);Xa=e+16|0}function W0(a,b){a:{if((a|0)==(b|0)){break a}while(1){b=b+ -1|0;if(a>>>0>=b>>>0){break a}Sg(a,b);a=a+1|0;continue}}}function VBa(a){var b=0,c=0;b=Xa-16|0;Xa=b;c=a+2|0;while(1){Ne(a);a=a+1|0;if((c|0)!=(a|0)){continue}break}Xa=b+16|0}function V0(a,b){a:{if((a|0)==(b|0)){break a}while(1){b=b+ -4|0;if(a>>>0>=b>>>0){break a}Gb(a,b);a=a+4|0;continue}}}function Oga(a){a=a|0;var b=0,c=0;i[i[a+20>>2]>>2]=a;c=i[a+12>>2];b=i[c>>2];i[a+4>>2]=b;if(b){i[b+8>>2]=a}i[c>>2]=a}function Mra(a,b){i[114610]=0;G(25,a|0,b<<3,8);a=i[114610];i[114610]=0;if((a|0)!=1){return}a=H(0)|0;A()|0;gb(a);x()}function JD(a,b,c,d,e,f,g,h,j){i[a>>2]=b;i[a+4>>2]=c;i[a+8>>2]=d;i[a+12>>2]=e&65535|(j>>>16&32768|e>>>16&32767)<<16}function ILa(a,b){i[114610]=0;G(25,a|0,b<<1,1);a=i[114610];i[114610]=0;if((a|0)!=1){return}a=H(0)|0;A()|0;gb(a);x()}function Fra(a,b){i[114610]=0;G(25,a|0,b<<4,8);a=i[114610];i[114610]=0;if((a|0)!=1){return}a=H(0)|0;A()|0;gb(a);x()}function FAa(a){var b=0,c=0;b=Xa-16|0;Xa=b;c=a+6|0;while(1){Ne(a);a=a+1|0;if((c|0)!=(a|0)){continue}break}Xa=b+16|0}function Esa(a,b){i[114610]=0;G(25,a|0,b<<2,4);a=i[114610];i[114610]=0;if((a|0)!=1){return}a=H(0)|0;A()|0;gb(a);x()}function DJa(a){var b=0,c=0;b=Xa-16|0;Xa=b;c=a+8|0;while(1){Ne(a);a=a+1|0;if((c|0)!=(a|0)){continue}break}Xa=b+16|0}function ALa(a){var b=0,c=0;b=Xa-16|0;Xa=b;c=a+3|0;while(1){Ne(a);a=a+1|0;if((c|0)!=(a|0)){continue}break}Xa=b+16|0}function xka(a,b,c){var d=0;if((b|0)>=1){while(1){g[a|0]=j[c|0];a=a+1|0;d=(b|0)>1;b=b+ -1|0;if(d){continue}break}}}function gV(a,b){i[114610]=0;G(25,a|0,b<<3,1);a=i[114610];i[114610]=0;if((a|0)!=1){return}a=H(0)|0;A()|0;gb(a);x()}function fia(a,b){a=a|0;b=b|0;var c=0;a:{if(qb(a)>>>0>511){break a}if(!$c(b)){break a}c=i[b>>2];YH(a,b)}return c|0}function _ia(a){var b=0,c=0;if(i[a>>2]){Sh(a);xe(fb(a),i[a>>2],gd(a));b=fb(a),c=0,i[b>>2]=c;i[a>>2]=0;i[a+4>>2]=0}}function YT(a,b){i[114610]=0;G(25,a|0,b<<1,2);a=i[114610];i[114610]=0;if((a|0)!=1){return}a=H(0)|0;A()|0;gb(a);x()}function WA(a,b){i[114610]=0;G(25,a|0,b<<5,4);a=i[114610];i[114610]=0;if((a|0)!=1){return}a=H(0)|0;A()|0;gb(a);x()}function Oha(a,b,c){a=a|0;b=b|0;c=p(c);var d=0,e=0;if((b|0)<=3){d=(a+b|0)+4264|0,e=hK(p(c*p(255))),g[d|0]=e;vr(a)}}function Ksa(a){i[a+16>>2]=0;i[a+20>>2]=0;i[a+36>>2]=0;g[a+40|0]=1;i[a+24>>2]=0;i[a+28>>2]=0;h[a+32>>1]=0;return a}function Ega(a,b){var c=0;c=Xa-16|0;Xa=c;cI(c+8|0,Hb(c,b));bu(a,c+8|0);i[a+12>>2]=0;i[a+8>>2]=0;Xa=c+16|0;return a}function DB(a,b){i[114610]=0;G(25,a|0,b<<4,4);a=i[114610];i[114610]=0;if((a|0)!=1){return}a=H(0)|0;A()|0;gb(a);x()}function BT(a,b){i[114610]=0;G(25,a|0,b<<2,2);a=i[114610];i[114610]=0;if((a|0)!=1){return}a=H(0)|0;A()|0;gb(a);x()}function $ja(a){var b=0,c=0;if(i[a>>2]){$r(a);xe(fb(a),i[a>>2],gd(a));b=fb(a),c=0,i[b>>2]=c;i[a>>2]=0;i[a+4>>2]=0}}function zI(a){var b=0,c=0;if(i[a>>2]){CI(a);bt(fb(a),i[a>>2],hi(a));b=fb(a),c=0,i[b>>2]=c;i[a>>2]=0;i[a+4>>2]=0}}function xwa(a){a=a|0;var b=0;b=GM(a);if((b|0)!=(a|0)){while(1){wwa(a);a=a+32|0;if((b|0)!=(a|0)){continue}break}}}function oDa(a,b,c){var d=0;d=Xa-16|0;Xa=d;$Ca(b,c);c=wb(a,c<<2);if(c){Py(d+8|0,b);od(a,d+8|0)}Xa=d+16|0;return c}function mla(a,b){a=a|0;b=b|0;g[b+38|0]=j[a+202|0];g[b+39|0]=j[a+203|0];g[b+40|0]=j[a+204|0];g[b+41|0]=j[a+205|0]}function ija(a){var b=0;b=Xa-16|0;Xa=b;h[b+14>>1]=a;h[b+12>>1]=32767;a=h[ef(b+14|0,b+12|0)>>1];Xa=b+16|0;return a}function hDa(a,b,c){var d=0;d=Xa-16|0;Xa=d;RCa(b,c);c=wb(a,c<<1);if(c){BS(d+8|0,b);od(a,d+8|0)}Xa=d+16|0;return c}function gM(a){var b=0,c=0;if(i[a>>2]){rp(a);un(fb(a),i[a>>2],zf(a));b=fb(a),c=0,i[b>>2]=c;i[a>>2]=0;i[a+4>>2]=0}}function gH(a){a=a|0;i[a+4244>>2]=0;i[a+4248>>2]=0;i[a+4228>>2]=0;i[a+4232>>2]=0;a=a+4252|0;i[a>>2]=0;i[a+4>>2]=0}function bP(a){var b=0,c=0;if(i[a>>2]){CP(a);yt(fb(a),i[a>>2],gd(a));b=fb(a),c=0,i[b>>2]=c;i[a>>2]=0;i[a+4>>2]=0}}function _La(a,b,c){var d=0;d=Xa-16|0;Xa=d;HLa(b,c);c=wb(a,c<<1);if(c){BS(d+8|0,b);od(a,d+8|0)}Xa=d+16|0;return c}function _D(a,b){a=a|0;b=b|0;var c=0;c=i[a>>2];a:{if(!c){break a}if(!ae(EG(c,b),-1)){break a}i[a>>2]=0}return a|0}function ZD(a,b){a=a|0;b=b|0;var c=0;c=i[a>>2];a:{if(!c){break a}if(!ae(M3(c,b),-1)){break a}i[a>>2]=0}return a|0}function XFa(a,b,c){var d=0;d=qb(a);if(d>>>0<b>>>0){CFa(a,b-d|0,c);return}if(d>>>0>b>>>0){bQ(a,i[a>>2]+(b<<2)|0)}}function WK(a){var b=0,c=0;if(i[a>>2]){Vr(a);Uf(fb(a),i[a>>2],xf(a));b=fb(a),c=0,i[b>>2]=c;i[a>>2]=0;i[a+4>>2]=0}}function VV(a,b,c){a:{if(rc(a)>>>0<=b>>>0){break a}if(rc(a)>>>0<c>>>0){break a}return rc(a)-b>>>0>=c>>>0}return 0}function Ur(a){var b=0;b=1;a:{switch(j[a+3|0]+ -4|0){default:b=j[a+2|0]==11;break;case 0:case 2:break a}}return b}function PK(a,b){var c=0;c=b&15;if(c){g[a+847|0]=c<<2}b=b&240;if(b){g[a+846|0]=b>>>4}i[a+88>>2]=i[a+88>>2]|262144}function Oza(a,b,c){var d=0;d=Xa-16|0;Xa=d;Lza(b,c);c=wb(a,c<<2);if(c){Py(d+8|0,b);od(a,d+8|0)}Xa=d+16|0;return c}function Lj(a,b){var c=0;c=b&15;if(c){g[a+844|0]=c<<2}b=b&240;if(b){g[a+843|0]=b>>>4}i[a+88>>2]=i[a+88>>2]|131072}function Dn(a,b){var c=0;c=Xa-16|0;Xa=c;Jn(c+8|0,$g(c,b));bu(a,c+8|0);i[a+12>>2]=0;i[a+8>>2]=0;Xa=c+16|0;return a}function C4(a,b){i[114610]=0;G(25,a|0,b|0,1);a=i[114610];i[114610]=0;if((a|0)!=1){return}a=H(0)|0;A()|0;gb(a);x()}function BMa(a,b,c){var d=0;d=Wb(a);if(d>>>0<b>>>0){AMa(a,b-d|0,c);return}if(d>>>0>b>>>0){wp(a,i[a>>2]+(b<<1)|0)}}function AGa(a,b,c){var d=0;d=Xa-16|0;Xa=d;vFa(b,c);c=wb(a,c<<2);if(c){Py(d+8|0,b);od(a,d+8|0)}Xa=d+16|0;return c}function mf(a,b,c){var d=0;a:{if(b>c){break a}d=n[a>>3];if(!(d>=b)){n[a>>3]=b;return}if(d<=c){break a}n[a>>3]=c}}function UCa(a){var b=0;b=Xa-16|0;Xa=b;g[a|0]=0;g[a+1|0]=0;g[a+2|0]=0;g[a+3|0]=0;g[a+4|0]=0;g[a+5|0]=0;Xa=b+16|0}function Rra(a){var b=0,c=0;while(1){b=a&1|b<<1;a=(a&254)>>>1|0;c=c+1|0;if((c|0)!=8){continue}break}return b&255}function rda(a){a=a|0;var b=0,c=0;b=Xa-16|0;Xa=b;c=Bb(b,38099);Ub(a,c);eb(c);i[a>>2]=83536;Xa=b+16|0;return a|0}function pG(a){var b=0;a:{while(1){if(!i[(b<<2)+a>>2]){break a}b=b+1|0;if((b|0)!=4){continue}break}b=4}return b}function mk(a){a=j[a|0]|j[a+1|0]<<8|(j[a+2|0]<<16|j[a+3|0]<<24);return a<<24|a<<8&16711680|(a>>>8&65280|a>>>24)}function kq(){var a=0;i[114610]=0;a=i[114610];i[114610]=0;if((a|0)!=1){return i[14752]}a=H(0)|0;A()|0;gb(a);x()}function jq(){var a=0;i[114610]=0;a=i[114610];i[114610]=0;if((a|0)!=1){return i[15140]}a=H(0)|0;A()|0;gb(a);x()}function hJ(a,b){a:{switch(b+ -1|0){default:return a+724|0;case 0:return a+736|0;case 1:break a}}return a+748|0}function Y2(a,b){a=a|0;b=b|0;var c=0,d=0;$a[i[i[a>>2]+24>>2]](a)|0;b=Yu(b);i[a+36>>2]=b;c=a,d=Zl(b),g[c+44|0]=d}function Oo(a,b){var c=0;c=Xa-16|0;Xa=c;i[c+8>>2]=i[a>>2];i[c+8>>2]=i[c+8>>2]+(b<<2);Xa=c+16|0;return i[c+8>>2]}function OX(a){var b=0,c=0,d=0;b=Xa-16|0;Xa=b;c=i[yc(b+8|0,i[a+4>>2])>>2],d=1,g[c|0]=d;g[i[a+8>>2]]=1;Xa=b+16|0}function Mn(){var a=0;i[114610]=0;a=i[114610];i[114610]=0;if((a|0)!=1){return i[14556]}a=H(0)|0;A()|0;gb(a);x()}function Mma(a,b,c){var d=0;if((b|0)>=1){while(1){Lma(a,c);a=a+160|0;d=(b|0)>1;b=b+ -1|0;if(d){continue}break}}}function Ida(a){a=a|0;var b=0,c=0;b=Xa-16|0;Xa=b;c=Bb(b,38080);Ub(a,c);eb(c);i[a>>2]=83516;Xa=b+16|0;return a|0}function GJa(a,b,c){if((a|0)!=(b|0)){while(1){CR(c,a);c=c+2|0;a=a+2|0;if((b|0)!=(a|0)){continue}break}}return c}function Dz(a,b){a=a|0;b=b|0;var c=0;c=Xa-16|0;Xa=c;i[c+12>>2]=b;b=a;a=Bb(c,i[c+12>>2]);ny(b,a);eb(a);Xa=c+16|0}function Cg(a){a:{a=i[a+4>>2]&74;if(a){if((a|0)==64){return 8}if((a|0)!=8){break a}return 16}return 0}return 10}function $2(a,b){a=a|0;b=b|0;var c=0,d=0;$a[i[i[a>>2]+24>>2]](a)|0;b=Zu(b);i[a+36>>2]=b;c=a,d=Zl(b),g[c+44|0]=d}function vx(a){i[114610]=0;G(25,a|0,40,4);a=i[114610];i[114610]=0;if((a|0)!=1){return}a=H(0)|0;A()|0;gb(a);x()}function mQ(a,b,c){a=a|0;b=b|0;c=c|0;a:{switch(c+1|0){case 0:case 2:bh(a,b);return;default:break a}}bFa(a,b,c)}function kI(a){var b=0;b=Xa-16|0;Xa=b;i[b+12>>2]=a;i[b+8>>2]=32767;a=h[rb(b+12|0,b+8|0)>>1];Xa=b+16|0;return a}function fs(a,b){var c=0;c=Xa-16|0;Xa=c;i[c+8>>2]=i[a+4>>2];i[c>>2]=i[b+4>>2];a=pb(c+8|0,c);Xa=c+16|0;return a}function fD(a,b,c,d,e){b=Ch(b,c,d,e,4);if(!(j[d|0]&4)){i[a>>2]=((b|0)<69?b+2e3|0:(b|0)<100?b+1900|0:b)+ -1900}}function dt(a,b){var c=0;c=Xa-16|0;Xa=c;i[c+12>>2]=(o(a,b)>>>0)/255;Kd(c+12|0,0,15);Xa=c+16|0;return j[c+12|0]}function bD(a,b,c,d,e){b=Bh(b,c,d,e,4);if(!(j[d|0]&4)){i[a>>2]=((b|0)<69?b+2e3|0:(b|0)<100?b+1900|0:b)+ -1900}}function aM(a,b,c){a=a|0;b=b|0;c=c|0;a:{switch(c+1|0){case 0:case 3:SL(a,b);return;default:break a}}Osa(a,b,c)}function YI(a){i[114610]=0;G(25,a|0,28,4);a=i[114610];i[114610]=0;if((a|0)!=1){return}a=H(0)|0;A()|0;gb(a);x()}function Wma(a,b,c){var d=0;if((b|0)>=1){while(1){Mr(a,c);a=a+896|0;d=(b|0)>1;b=b+ -1|0;if(d){continue}break}}}function PX(a){var b=0;a:{a=i[a+8>>2];b=j[a|0];if((b|0)!=1){if(b&2){break a}g[a|0]=2;a=1}else{a=0}return a}x()}function Od(a,b){var c=0;c=i[a+4>>2];if(b){a=i[a>>2];i[a>>2]=i[a>>2]|c;return}a=i[a>>2];i[a>>2]=i[a>>2]&(c^-1)}function Nf(a,b,c){if(!c){return i[a+4>>2]==i[b+4>>2]}if((a|0)==(b|0)){return 1}return!Ih(i[a+4>>2],i[b+4>>2])}function NY(a,b){i[114610]=0;bv(a,b<<2,4);a=i[114610];i[114610]=0;if((a|0)!=1){return}a=H(0)|0;A()|0;gb(a);x()}function tm(a){var b=0;while(1){if(j[b+32240|0]==(a|0)){return b}b=b+1|0;if(b>>>0<43){continue}break}return 0}function hC(a,b,c){i[114610]=0;fC(a,b,c);a=i[114610];i[114610]=0;if((a|0)!=1){return}a=H(0)|0;A()|0;gb(a);x()}function YBa(a){if(!(4294967295>a)){return-1}if(!(0<a)){return 0}if(a<4294967296&a>=0){return~~a>>>0}return 0}function EO(a,b){g[a+6|0]=255;i[a+16>>2]=0;h[a+4>>1]=0;i[a>>2]=0;if(!(b<0)){n[a+8>>3]=b;i[a+16>>2]=3}return a}function oP(a,b){a=a|0;b=b|0;var c=0;c=Xa-16|0;Xa=c;h[c+14>>1]=b;if((ft(a)|0)!=65535){nS(a,c+14|0)}Xa=c+16|0}function jE(a){var b=0;b=i[a+12>>2];if((b|0)==i[a+16>>2]){return $a[i[i[a>>2]+36>>2]](a)|0}return cg(g[b|0])}function bA(a,b){a:{switch(b+ -1|0){default:return a+48|0;case 0:return a+68|0;case 1:break a}}return a+88|0}function Tk(a,b){var c=0;c=qb(a);if(c>>>0<b>>>0){kja(a,b-c|0);return}if(c>>>0>b>>>0){vw(a,i[a>>2]+(b<<2)|0)}}function Nx(a){Xta(a);g[a+12|0]=0;g[a+13|0]=0;g[a+14|0]=0;g[a+15|0]=0;g[a+16|0]=65280;g[a+17|0]=255;return a}function Lo(a,b){a=a|0;b=b|0;if(Wb(a)>>>0>b>>>0){a=pg(i[a+24>>2]+484344|0,k[lk(a,b)>>1])}else{a=0}return a|0}function Hba(a,b){var c=0;c=Xa-16|0;Xa=c;i[c+8>>2]=b;b=i[c+8>>2];_H(a,b);Pb(a);Im(Qg(c+8|0));vx(b);Xa=c+16|0}function Dpa(a){if(!(65535>a)){return 65535}if(!(0<a)){return 0}if(a<4294967296&a>=0){return~~a>>>0}return 0}function Aoa(a,b){var c=0;if(!b){return a}while(1){c=b;b=(a>>>0)%(b>>>0)|0;a=c;if(b){continue}break}return c}function uwa(a){var b=0;b=GM(a);if((b|0)!=(a|0)){while(1){vwa(a);a=a+32|0;if((b|0)!=(a|0)){continue}break}}}function gMa(a,b){a=a|0;b=b|0;var c=0;c=Xa-16|0;Xa=c;i[c>>2]=b;i[c+8>>2]=a;zLa(i[c+8>>2],i[c>>2]);Xa=c+16|0}function dua(a){var b=0,c=0;b=a+108|0;a=0;while(1){c=Nb(b,a);a=a+1|0;g[c|0]=a;if(a>>>0<128){continue}break}}function Vm(a){var b=0;b=Xa-16|0;Xa=b;i[b+12>>2]=a;i[b+8>>2]=255;a=j[rb(b+12|0,b+8|0)|0];Xa=b+16|0;return a}function Jg(a,b){var c=0;c=a;b=i[a+16>>2]+b|0;a=i[a+12>>2];b=(b|0)%(a|0)|0;return m[hc(c,(b>>31&a)+b|0)>>2]}function HJa(a,b,c){if((a|0)!=(b|0)){while(1){c=c+ -2|0;b=b+ -2|0;CR(c,b);if((a|0)!=(b|0)){continue}break}}}function FH(a){a=a|0;var b=0,c=0,d=0;b=n[a+4264>>3]*+l[i[a+16>>2]+1074376>>2];c=a,d=b-bNa(b),n[c+4256>>3]=d}function $E(a,b,c,d){m[d+4>>2]=c+a;a=p(a+p(c*p(-.5)));b=p(b*p(.8660253882408142));m[d+8>>2]=a-b;m[d>>2]=a+b}function zKa(a,b){a=a|0;b=b|0;var c=0;b=Xa-16|0;Xa=b;c=-1;if(fj(a,b+8|0)){c=YR(b+8|0)}Xa=b+16|0;return c|0}function xo(a){var b=0,c=0,d=0;b=a;a=i[a>>2];c=b,d=jb(o(a,214013)+2531011|0),i[c>>2]=d;return a>>>16&32767}function tY(a){a=a|0;a=Xa-16|0;Xa=a;if(Ea(a+12|0,4)|0){TB(i[114584],68555);x()}Xa=a+16|0;return i[a+12>>2]}function rJa(a,b){a=a|0;b=b|0;var c=0;b=Xa-80|0;Xa=b;c=-1;if(wR(a,b+8|0)){c=vR(b+8|0)}Xa=b+80|0;return c|0}function iF(a){var b=0;b=i[(j[a+2|0]&12)+42420>>2];a=j[a+1|0];return b>>>((a>>>3^-1)&1)>>>((a>>>4^-1)&1)|0}function goa(a,b){var c=0,d=0;c=Xa-16|0;Xa=c;i[c+8>>2]=b;d=n[i[c+8>>2]>>3];i[a+8>>2]=0;n[a>>3]=d;Xa=c+16|0}function Ze(a,b){var c=0;c=Xa-16|0;Xa=c;i[c+8>>2]=i[a>>2];i[c+8>>2]=i[c+8>>2]+b;Xa=c+16|0;return i[c+8>>2]}function Fv(a,b){var c=0;c=(o(o(Dv(a),Ev(a)),125)>>>0)/(iF(a)>>>0)|0;a=(j[a+1|0]&6)==6?c&-4:c;return a?a:b}function ECa(a,b){a=a|0;b=b|0;var c=0;b=Xa-16|0;Xa=b;c=-1;if(fj(a,b+8|0)){c=YO(b+8|0)}Xa=b+16|0;return c|0}function yw(a,b){Zy(a);i[a+20>>2]=0;i[a+12>>2]=0;i[a+16>>2]=0;hx(a+24|0);Ab(a+36|0);i[a+48>>2]=b;return a}function yBa(a,b){var c=0;c=Xa-16|0;Xa=c;a:{if(ff(a,512)){Gz(c+8|0,b);oy(a,c+8|0);break a}qO(b)}Xa=c+16|0}function wBa(a,b){var c=0;c=Xa-16|0;Xa=c;a:{if(wb(a,512)){Gz(c+8|0,b);od(a,c+8|0);break a}qO(b)}Xa=c+16|0}function rC(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i[e>>2]=c;i[h>>2]=f;return 3}function l5(a,b,c,d,e){var f=0;e=e-d|0;f=e>>31;a=(o(a-b|0,f^e+f)|0)/(c-b|0)|0;return((e|0)<0?0-a|0:a)+d|0}function eE(a){var b=0;b=i[a+12>>2];if((b|0)==i[a+16>>2]){return $a[i[i[a>>2]+36>>2]](a)|0}return i[b>>2]}function _t(a,b){a=a|0;b=b|0;var c=0;b=b+ -1|0;c=1085;a:{if(b>>>0>4){break a}c=i[(b<<2)+76372>>2]}Bb(a,c)}function _f(a){var b=0,c=0;b=Xa-16|0;Xa=b;if(Ep(a,b+8|0)){a=b+8|0;c=j[a|0]|j[a+1|0]<<8}Xa=b+16|0;return c}function RV(a,b,c,d){if(!d|0>=b>>>0){a=-1}else{b=a+b|0;c=kV(a,b,c,c+d|0);a=(b|0)==(c|0)?-1:c-a|0}return a}function NU(a,b){a=a|0;b=b|0;var c=0;b=Xa-16|0;Xa=b;c=-1;if(fj(a,b+8|0)){c=OA(b+8|0)}Xa=b+16|0;return c|0}function Lta(a,b){var c=0;a=Kta(a,b);a:{if(!a){break a}b=xY(a);if(!b){break a}c=yb(b,0,a)- -64|0}return c}function F1(a){i[a>>2]=0;i[a+4>>2]=0;i[a+20>>2]=0;h[a+16>>1]=65535;i[a+8>>2]=0;i[a+12>>2]=0;i[a+24>>2]=11}function Eoa(a){var b=0,c=0;Jr(a,qe(a));b=fb(a),c=0,i[b>>2]=c;b=a,c=Pb(a),i[b>>2]=c;b=Pb(a),c=0,i[b>>2]=c}function Bs(a,b){a=a|0;b=b|0;var c=0;c=Xa-16|0;Xa=c;nn(c+8|0,a);i[c+4>>2]=i[c+8>>2];As(c+4|0,b);Xa=c+16|0}function lh(a,b,c){var d=0,e=0,f=0,g=0;d=n[c>>3];e=n[b>>3];f=n[c+8>>3];g=n[b+8>>3];cl(a,d*e-f*g,e*f+d*g)}function gha(a){var b=0,c=0,d=0;while(1){b=xo(a)^b<<15;d=c>>>0<17;c=c+15|0;if(d){continue}break}return b}function dDa(a){if(!(255>a)){return 255}if(!(0<a)){return 0}if(a<4294967296&a>=0){return~~a>>>0}return 0}function _y(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Xa-16|0;Xa=d;i[d+12>>2]=c;XFa(a,b,d+12|0);Zw(a);Xa=d+16|0}function SGa(a,b){a=a|0;b=b|0;var c=0;a=kFa(a,b);if(!a){c=Xa-16|0;Xa=c;yb(b,0,4896);Xa=c+16|0}return a|0}function PAa(a,b){a=a|0;b=b|0;var c=0;a=GAa(a,b);if(!a){c=Xa-16|0;Xa=c;yb(b,0,1030);Xa=c+16|0}return a|0}function Mf(a,b){var c=0,d=0;c=i[a>>2];d=i[b>>2];_a=i[a+4>>2]-(i[b+4>>2]+(c>>>0<d>>>0)|0)|0;return c-d|0}function L_(a,b,c){var d=0;d=Xa-16|0;Xa=d;if(b>>>0>=12){zi(6934);x()}lj(d+8|0,a,b);Od(d+8|0,c);Xa=d+16|0}function KL(a){h[a+70>>1]=j[((k[i[a+4>>2]+22>>1]<<4|k[i[a+4>>2]+20>>1]>>>6)&65535)+19952|0]>>>k[a+68>>1]}function CM(a,b,c){if((b|0)!=(c|0)){while(1){Ara(a,jb(j[b|0]));b=b+1|0;if((c|0)!=(b|0)){continue}break}}}function uCa(a,b){a=a|0;b=b|0;var c=0;a=TBa(a,b);if(!a){c=Xa-16|0;Xa=c;yb(b,0,826);Xa=c+16|0}return a|0}function eJ(a,b){var c=0;c=Xa-16|0;Xa=c;h[c+14>>1]=k[a>>1];h[a>>1]=k[b>>1];h[b>>1]=k[c+14>>1];Xa=c+16|0}function ala(a,b){a=a|0;b=b|0;var c=0;a=Dka(a,b);if(!a){c=Xa-16|0;Xa=c;yb(b,0,225);Xa=c+16|0}return a|0}function a4(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return $a[i[i[a>>2]+16>>2]](a,b,c,d,e,f)|0}function ZAa(a,b){a=a|0;b=b|0;var c=0;a=EAa(a,b);if(!a){c=Xa-16|0;Xa=c;yb(b,0,274);Xa=c+16|0}return a|0}function Z3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return $a[i[i[a>>2]+24>>2]](a,b,c,d,e,f)|0}function Xka(a,b){a=a|0;b=b|0;var c=0;a=Cka(a,b);if(!a){c=Xa-16|0;Xa=c;yb(b,0,326);Xa=c+16|0}return a|0}function VAa(a,b){a=a|0;b=b|0;var c=0;a=CAa(a,b);if(!a){c=Xa-16|0;Xa=c;yb(b,0,106);Xa=c+16|0}return a|0}function UO(a,b){var c=0;c=l[a>>2]<l[b>>2];a=i[a+4>>2];b=i[b+4>>2];return(a|0)<(b|0)?1:(a|0)<=(b|0)?c:0}function U3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return $a[i[i[a>>2]+28>>2]](a,b,c,d,e,f)|0}function P3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return $a[i[i[a>>2]+44>>2]](a,b,c,d,e,f)|0}function LBa(a,b){var c=0;c=Xa-16|0;Xa=c;a:{if(ff(a,4)){_g(c+8|0,b);oy(a,c+8|0);break a}OP(b)}Xa=c+16|0}function Gb(a,b){var c=0;c=Xa-16|0;Xa=c;i[c+12>>2]=i[a>>2];i[a>>2]=i[b>>2];i[b>>2]=i[c+12>>2];Xa=c+16|0}function F3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return $a[i[i[a>>2]+20>>2]](a,b,c,d,e,f)|0}function Cn(a,b,c){var d=0;d=Xa-16|0;Xa=d;a=tf(a);i[a+4>>2]=c;i[a>>2]=b;i[d+4>>2]=b;i[d>>2]=b;Xa=d+16|0}function ACa(a,b){a=a|0;b=b|0;var c=0;a=WBa(a,b);if(!a){c=Xa-16|0;Xa=c;yb(b,0,422);Xa=c+16|0}return a|0}function vDa(a,b){a=a|0;b=b|0;var c=0;a=LCa(a,b);if(!a){c=Xa-16|0;Xa=c;yb(b,0,42);Xa=c+16|0}return a|0}function uy(a,b,c){var d=0,e=0;d=Xa-1024|0;Xa=d;if(mBa(a,d)){e=ry(d,c)>>>0<=b>>>0}Xa=d+1024|0;return e}function rP(a,b){a=a|0;b=b|0;var c=0;a=bDa(a,b);if(!a){c=Xa-16|0;Xa=c;yb(b,0,284);Xa=c+16|0}return a|0}function p_(a,b,c){var d=0;if(i[a>>2]){while(1){bh(b,c+d|0);d=d+1|0;if(d>>>0<l[a>>2]){continue}break}}}function nM(a){var b=0,c=0;while(1){c=(b<<2)+a|0;b=b+1|0;i[c+68>>2]=b<<11;if((b|0)!=9){continue}break}}function iIa(a,b){a=a|0;b=b|0;var c=0;a=NHa(a,b);if(!a){c=Xa-16|0;Xa=c;yb(b,0,34);Xa=c+16|0}return a|0}function dla(a,b){a=a|0;b=b|0;var c=0;a=Eka(a,b);if(!a){c=Xa-16|0;Xa=c;yb(b,0,73);Xa=c+16|0}return a|0}function cU(a,b){var c=0;c=rc(a);if(c>>>0<b>>>0){XT(a,b-c|0);return}if(c>>>0>b>>>0){Jt(a,i[a>>2]+b|0)}}function Zwa(a,b){a=a|0;b=b|0;var c=0;a=Iwa(a,b);if(!a){c=Xa-16|0;Xa=c;yb(b,0,40);Xa=c+16|0}return a|0}function Vka(a,b){a=a|0;b=b|0;var c=0;a=Bka(a,b);if(!a){c=Xa-16|0;Xa=c;yb(b,0,60);Xa=c+16|0}return a|0}function UAa(a,b){a=a|0;b=b|0;var c=0;a=AAa(a,b);if(!a){c=Xa-16|0;Xa=c;yb(b,0,72);Xa=c+16|0}return a|0}function Sza(a,b){a=a|0;b=b|0;var c=0;a=Gza(a,b);if(!a){c=Xa-16|0;Xa=c;yb(b,0,71);Xa=c+16|0}return a|0}function Ru(a){a=a|0;var b=0;b=i[21199];if(a){i[21199]=(a|0)==-1?458380:a}return((b|0)==458380?-1:b)|0}function QX(a){var b=0,c=0;b=Xa-16|0;Xa=b;if(!j[i[yc(b+8|0,i[a+4>>2])>>2]]){c=PX(a)}Xa=b+16|0;return c}function MEa(a,b){a=a|0;b=b|0;var c=0;a=ODa(a,b);if(!a){c=Xa-16|0;Xa=c;yb(b,0,91);Xa=c+16|0}return a|0}function Lxa(a){var b=0;b=Xa-16|0;Xa=b;i[a>>2]=0;i[a+4>>2]=0;i[b+12>>2]=0;ls(a+8|0);Xa=b+16|0;return a}function Hta(a,b){if((a|0)!=(b|0)){Gta(a,Jb(b),Kb(b));vi(a+12|0,b+12|0);h[a+28>>1]=k[b+28>>1]}return a}function GCa(a,b){var c=0;c=Xa-16|0;Xa=c;i[c+8>>2]=b;b=k[i[c+8>>2]>>1];h[a+2>>1]=0;h[a>>1]=b;Xa=c+16|0}function z_(a,b){var c=0,d=0;c=Xa-16|0;Xa=c;if(i[a>>2]!=-1){d=c+8|0;yc(d,b);yc(c,d);zY(a,c)}Xa=c+16|0}function u0(a,b,c,d,e){b=Bh(b,c,d,e,2);c=i[d>>2];if(!(c&4|b+ -1>>>0>30)){i[a>>2]=b;return}i[d>>2]=c|4}function s0(a,b,c,d,e){b=Bh(b,c,d,e,2);c=i[d>>2];if(!(c&4|b+ -1>>>0>11)){i[a>>2]=b;return}i[d>>2]=c|4}function q0(a,b,c,d,e){b=Bh(b,c,d,e,2);c=i[d>>2];if(!(c&4|(b|0)>12)){i[a>>2]=b+ -1;return}i[d>>2]=c|4}function ip(a,b){a=a|0;b=b|0;var c=0;a=qIa(a,b);if(!a){c=Xa-16|0;Xa=c;yb(b,0,64);Xa=c+16|0}return a|0}function UR(a,b){a=a|0;b=b|0;var c=0;a=KJa(a,b);if(!a){c=Xa-16|0;Xa=c;yb(b,0,50);Xa=c+16|0}return a|0}function N0(a,b,c,d,e){b=Ch(b,c,d,e,2);c=i[d>>2];if(!(c&4|b+ -1>>>0>30)){i[a>>2]=b;return}i[d>>2]=c|4}function L0(a,b,c,d,e){b=Ch(b,c,d,e,2);c=i[d>>2];if(!(c&4|b+ -1>>>0>11)){i[a>>2]=b;return}i[d>>2]=c|4}function J0(a,b,c,d,e){b=Ch(b,c,d,e,2);c=i[d>>2];if(!(c&4|(b|0)>12)){i[a>>2]=b+ -1;return}i[d>>2]=c|4}function Ev(a){var b=0;b=j[a+1|0];return j[(o(b>>>1&3,15)+o(b>>>3&1,45)+(j[a+2|0]>>>4)|0)+42417|0]<<1}function Ax(a,b){if(pg(i[a+24>>2]+484344|0,b)){a=i[Fb(i[a+24>>2]+484344|0,b)+12>>2]}else{a=1}return a}function yl(a){g[a|0]=0;g[a+1|0]=0;g[a+2|0]=0;g[a+3|0]=0;g[a+4|0]=0;g[a+5|0]=0;g[a+6|0]=0;g[a+7|0]=0}function iS(a){var b=0;b=Xa-16|0;Xa=b;g[a|0]=0;g[a+1|0]=0;g[a+2|0]=0;g[a+3|0]=0;g[a+4|0]=0;Xa=b+16|0}function dGa(a,b){a=a|0;b=b|0;var c=0;c=Xa-16|0;Xa=c;a=i[yc(c+8|0,RFa(a,b))>>2];Xa=c+16|0;return a|0}function cua(a){var b=0;a:{b=g[a|0];if((b|0)<-32){g[a|0]=-32;return}if((b|0)<=32){break a}g[a|0]=32}}function Q0(a){var b=0;b=Xa-16|0;Xa=b;i[a>>2]=0;a=a+32|0;eD(a,32);g[b+15|0]=0;A0(a,b+15|0);Xa=b+16|0}function Pha(a,b){a=a|0;b=b|0;return p((b|0)<=3?p(p(j[(a+b|0)+4264|0])*p(.003921568859368563)):p(0))}function wH(a,b){a=a|0;b=b|0;var c=0;c=Xa-16|0;Xa=c;_g(c+8|0,b);a=Fga(a,c+8|0);Xa=c+16|0;return a|0}function tw(a,b){a=a|0;b=b|0;var c=0;c=Xa-16|0;Xa=c;a=i[yc(c+8|0,fja(a,b))>>2];Xa=c+16|0;return a|0}function dT(a){var b=0;b=j[a+35|0];a=b>>>21|0;b=(b<<11)+2624|0;if(b>>>0<2624){a=a+1|0}_a=a;return b}function aua(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Xa-16|0;Xa=d;Uta(d+8|0,b,c,c);pM(a,d+8|0);Xa=d+16|0}function Zz(a,b){var c=0,d=0;c=i[a+4>>2];d=i[b+4>>2];return(c|0)==(d|0)&l[a>>2]<l[b>>2]|c>>>0<d>>>0}function Zla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Xa-16|0;Xa=d;Tla(d+8|0,b,c,c);pM(a,d+8|0);Xa=d+16|0}function Wja(a,b){a=a|0;b=b|0;g[b|0]=0;g[b+1|0]=0;g[b+2|0]=0;g[b+3|0]=0;g[b+4|0]=0;g[b+5|0]=0;aj(b)}function Mo(a){a=a|0;var b=0;Om(a);b=Lta(i[a>>2],xn(a));i[a+20>>2]=b;if(!b){return 0}return hk(a)|0}function Mba(a,b){a=a|0;b=b|0;var c=0;c=i[a+4>>2];b=xb(b);if(c){$a[c|0](b,i[a+8>>2]);return}hr(b,a)}function Lc(a,b){var c=0;c=i[b+4>>2];i[a>>2]=i[b>>2];i[a+4>>2]=c;i[a+8>>2]=i[b+8>>2];Gm(b);return a}function w_(a,b,c){a=a|0;b=b|0;c=c|0;if(c>>>0<=127){a=(k[Mn()+(c<<1)>>1]&b)!=0}else{a=0}return a|0}function vBa(a,b){a=a|0;b=b|0;var c=0;b=Xa-16|0;Xa=b;c=-1;if(oz(a,b)){c=zO(b)}Xa=b+16|0;return c|0}function r0(a,b,c,d,e){b=Bh(b,c,d,e,3);c=i[d>>2];if(!(c&4|(b|0)>365)){i[a>>2]=b;return}i[d>>2]=c|4}function nma(a,b,c,d,e){a:{if((e|0)==128|c>>>0<2){break a}fJ(a,d,e);if(c>>>0<4){break a}fJ(b,d,e)}}function Yf(a){var b=0;b=a+44|0;wk(b);if(i[b>>2]){GB(b,i[b>>2]);wi(fb(b),i[b>>2],xh(b))}VA(a+32|0)}function Xga(a,b,c){a=a|0;b=b|0;c=c|0;a=Ji(a);if(!a){return 0}return $a[i[i[a>>2]+96>>2]](a,b,c)|0}function Vh(a){a=a|0;var b=0,c=0;while(1){c=b&65535;Nna(a,c);b=b+1|0;if(c>>>0<126){continue}break}}function Vea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;$a[i[i[b>>2]+8>>2]](b,c);d=a;a=b+4|0;Nn(d,a);uC(a,c)}function VW(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;return $a[a|0](b,c,d,e,f,g)|0}function Oba(a,b){if(a){b=$a[i[i[b>>2]+8>>2]](b)|0;a:{if(b){b=Ed(b);break a}b=Ed(34133)}i[a>>2]=b}}function K0(a,b,c,d,e){b=Ch(b,c,d,e,3);c=i[d>>2];if(!(c&4|(b|0)>365)){i[a>>2]=b;return}i[d>>2]=c|4}function JBa(a,b){a=a|0;b=b|0;var c=0,d=0;c=Xa-16|0;Xa=c;d=a;a=Lc(c,b);ny(d,a);eb(a);Xa=c+16|0}



function CDa(a,b){a=a|0;b=b|0;var c=0;c=Xa-16|0;Xa=c;h[c+14>>1]=b;Ey(a+236|0,128,c+14|0);Xa=c+16|0}function uH(a){a=a|0;var b=0;b=i[a>>2];if(b){$a[i[i[b>>2]+8>>2]](b);i[a>>2]=0}a=a+4|0;Vr(a);qR(a)}function t0(a,b,c,d,e){b=Bh(b,c,d,e,2);c=i[d>>2];if(!(c&4|(b|0)>23)){i[a>>2]=b;return}i[d>>2]=c|4}function sxa(a,b,c){a=a|0;b=b|0;c=c|0;a=i[c+4>>2];i[b>>2]=i[c>>2];i[b+4>>2]=a;i[b+8>>2]=i[c+8>>2]}function p0(a,b,c,d,e){b=Bh(b,c,d,e,2);c=i[d>>2];if(!(c&4|(b|0)>59)){i[a>>2]=b;return}i[d>>2]=c|4}function oya(a,b){a=a|0;b=b|0;var c=0;c=Xa-16|0;Xa=c;NT(c,a);a=Xe(c,b);eb(c);Xa=c+16|0;return a|0}function m0(a,b,c,d,e){b=Bh(b,c,d,e,2);c=i[d>>2];if(!(c&4|(b|0)>60)){i[a>>2]=b;return}i[d>>2]=c|4}function dg(a,b,c){a=a|0;b=b|0;c=c|0;ye(a,b);b=i[c+4>>2];i[a+4>>2]=i[c>>2];i[a+8>>2]=b;return a|0}function bfa(a,b){a=a|0;b=b|0;Hq(a);i[a>>2]=76848;Ab(a+32|0);i[a+48>>2]=b;i[a+44>>2]=0;return a|0}function Xra(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=n[b+8>>3];d=tv(n[b>>3]);e=Hh(c);cl(a,d*ee(c),d*e)}function XE(a){var b=0;b=+((a&2097151)>>>0);return p(yh(+p((a|0)>-1?b:-b),(a>>>21&1023)+ -788|0))}function Sg(a,b){var c=0;c=Xa-16|0;Xa=c;g[c+15|0]=j[a|0];g[a|0]=j[b|0];g[b|0]=j[c+15|0];Xa=c+16|0}function M0(a,b,c,d,e){b=Ch(b,c,d,e,2);c=i[d>>2];if(!(c&4|(b|0)>23)){i[a>>2]=b;return}i[d>>2]=c|4}function I0(a,b,c,d,e){b=Ch(b,c,d,e,2);c=i[d>>2];if(!(c&4|(b|0)>59)){i[a>>2]=b;return}i[d>>2]=c|4}function HMa(a,b){a=a|0;b=b|0;var c=0;c=Xa-16|0;Xa=c;lT(c+8|0,a);Dp(c+8|0,b);Xa=c+16|0;return a|0}function F0(a,b,c,d,e){b=Ch(b,c,d,e,2);c=i[d>>2];if(!(c&4|(b|0)>60)){i[a>>2]=b;return}i[d>>2]=c|4}function EGa(a,b){a=a|0;b=b|0;var c=0;c=Xa-16|0;Xa=c;lA(c,a);a=Xe(c,b);eb(c);Xa=c+16|0;return a|0}function yN(a){Iya(a,i[a+4>>2]);if(i[a>>2]){dy(i[a+16>>2],i[a>>2],(i[Mb(a)>>2]-i[a>>2]|0)/56|0)}}function nla(a){var b=0;a:{b=j[a|0];if(b>>>0<1){g[a|0]=1;return}if(b>>>0<=16){break a}g[a|0]=16}}function nI(a){uja(a,i[a+4>>2]);if(i[a>>2]){Xw(i[a+16>>2],i[a>>2],(i[Mb(a)>>2]-i[a>>2]|0)/52|0)}}function mO(a){var b=0,c=0;b=1;c=i[a>>2];a:{if((c|0)>=1){b=120;if((c|0)<121){break a}}i[a>>2]=b}}function l0(a,b,c,d,e){b=Bh(b,c,d,e,1);c=i[d>>2];if(!(c&4|(b|0)>6)){i[a>>2]=b;return}i[d>>2]=c|4}function Ys(a){GIa(a,i[a+4>>2]);if(i[a>>2]){cR(i[a+16>>2],i[a>>2],(i[Mb(a)>>2]-i[a>>2]|0)/48|0)}}function UM(a){var b=0;b=j[a+47|0];a=b>>>27|0;b=(b<<5)+259|0;if(b>>>0<259){a=a+1|0}_a=a;return b}function PT(a,b){a=a|0;b=b|0;var c=0;c=Xa-16|0;Xa=c;Dt(c+8|0,a);Dp(c+8|0,b);Xa=c+16|0;return a|0}function Nca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;$a[i[i[b>>2]+16>>2]](a,b,i[c+8>>2],i[c+12>>2],0,d)}function IT(a,b){a=a|0;b=b|0;var c=0;c=Xa-16|0;Xa=c;kA(c+8|0,a);Dp(c+8|0,b);Xa=c+16|0;return a|0}function IFa(a,b){var c=0;c=Xa-16|0;Xa=c;i[c+8>>2]=b;h[a>>1]=k[i[c+8>>2]>>1];Oc(a+4|0);Xa=c+16|0}function GP(a){cEa(a,i[a+4>>2]);if(i[a>>2]){EP(i[a+16>>2],i[a>>2],(i[Mb(a)>>2]-i[a>>2]|0)/33|0)}}function E0(a,b,c,d,e){b=Ch(b,c,d,e,1);c=i[d>>2];if(!(c&4|(b|0)>6)){i[a>>2]=b;return}i[d>>2]=c|4}function DI(a,b){var c=0;c=Xa-16|0;Xa=c;i[c+8>>2]=i[a>>2];vQ(c+8|0,b);Xa=c+16|0;return i[c+8>>2]}function zta(a){var b=0;b=Xa-16|0;Xa=b;i[b+8>>2]=i[a+4>>2];a=i[$L(b+8|0)>>2];Xa=b+16|0;return a}function vfa(a){a=a|0;var b=0,c=0;g[a+4202|0]=1;b=a,c=we(i[a+16>>2]),i[b+4256>>2]=c;fH(a);eH(a)}function uX(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;if(Nf(a,i[b+8>>2],f)){ru(b,c,d,e)}}function sra(a){var b=0;b=Xa-16|0;Xa=b;i[b+8>>2]=i[a+4>>2];a=i[hL(b+8|0)>>2];Xa=b+16|0;return a}function qKa(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;$a[i[i[b>>2]+16>>2]](a,b,c,d,e,f)}function q7(a,b){var c=0;c=i[a+4>>2];i[a+8>>2]=i[a+8>>2]-b;i[a>>2]=i[a>>2]+(o(b,c)<<1);return a}function nka(a,b,c){var d=0;d=Xa-16|0;Xa=d;i[d>>2]=b;i[d+8>>2]=a;Xja(a,yr(d,d+8|0),c);Xa=d+16|0}function lo(a,b,c){a=i[a>>2]+1074984|0;return i[(a+o(b,896)|0)+680>>2]>i[(a+o(c,896)|0)+680>>2]}function c7(a,b){var c=0;c=i[a+4>>2];i[a+8>>2]=i[a+8>>2]-b;i[a>>2]=i[a>>2]+(o(b,c)<<2);return a}function Vta(a,b){var c=0;c=Xa-16|0;Xa=c;i[c>>2]=b;i[c+8>>2]=a;a=Hs(c,c+8|0);Xa=c+16|0;return a}function Vga(a,b){a=a|0;b=b|0;b=Xa-16|0;Xa=b;ui(b,i[a+20>>2]+4|0);DH(a,td(b+8|0,b),0);Xa=b+16|0}function Pz(a,b){a=a|0;b=b|0;var c=0;a=Ep(a,b);if(!a){c=Xa-16|0;Xa=c;Tz(b);Xa=c+16|0}return a|0}function Nha(a){a=a|0;var b=0,c=0;g[a+4202|0]=1;b=a,c=we(i[a+16>>2]),i[b+4232>>2]=c;vr(a);RH(a)}function Ls(a){dFa(a,i[a+4>>2]);if(i[a>>2]){bt(i[a+16>>2],i[a>>2],(i[Mb(a)>>2]-i[a>>2]|0)/6|0)}}function LGa(a,b){a=a|0;b=b|0;var c=0;c=Xa-16|0;Xa=c;uQ(c,b);Lc(a,c);eb(c);Xa=c+16|0;return a|0}function FJa(a,b){var c=0;c=Xa-16|0;Xa=c;i[c>>2]=b;i[c+8>>2]=a;a=qp(c,c+8|0);Xa=c+16|0;return a}function CBa(a){var b=0,c=0;b=Xa-1024|0;Xa=b;if(fBa(a,b)){c=ry(b,0)>>>0<17}Xa=b+1024|0;return c}function Ala(a,b){a=a|0;b=b|0;kh(a);kh(a);a:{if(b>>>0>=60){Ib(a,4);break a}kh(a)}return kh(a)|0}function zE(a){var b=0;b=WMa(i[a>>2]+ -1|0);if(!b){a=WMa(i[a+4>>2]);return a?a+32|0:0}return b}function rha(a,b,c){var d=0;i[a>>2]=i[b>>2];d=i[b>>2];i[a+8>>2]=b;i[a+4>>2]=(c<<11)+d;return a}function pR(a,b){return(Eb((o(a>>>4|0,b)>>>0)/15|0,1,15)<<4|Eb((o(a&15,b)>>>0)/15|0,1,15))&255}function lFa(a,b,c){var d=0;i[a>>2]=i[b>>2];d=i[b>>2];i[a+8>>2]=b;i[a+4>>2]=o(c,48)+d;return a}function hr(a,b){a=a|0;b=b|0;b=Xa-16|0;Xa=b;i[b>>2]=a;a=i[13910];BE(a,34219,b);Nq(a);Xa=b+16|0}function gs(a,b){a=a|0;b=+b;var c=0,d=0,e=0;c=i[a+24>>2];d=a,e=Wj(zg(b)*+(c>>>0)),i[d+24>>2]=e}function fEa(a,b,c){var d=0;i[a>>2]=i[b>>2];d=i[b>>2];i[a+8>>2]=b;i[a+4>>2]=o(c,33)+d;return a}function Aja(a,b,c){var d=0;i[a>>2]=i[b>>2];d=i[b>>2];i[a+8>>2]=b;i[a+4>>2]=o(c,52)+d;return a}function uxa(a,b,c,d){a=c-b|0;c=i[d>>2]+o((a|0)/-12|0,12)|0;i[d>>2]=c;if((a|0)>=1){Tb(c,b,a)}}function rj(a){var b=0;b=Xa-16|0;Xa=b;a=i[yc(b+8|0,xb(a)+(lb(a)<<2)|0)>>2];Xa=b+16|0;return a}function qea(a,b){if(!i[a+4116>>2]){Rm(a+8|0,b,a+4104|0,a+4108|0)}i[a+4116>>2]=1;return a+8|0}function oka(a){var b=0,c=0;b=Xa-16|0;Xa=b;c=Jb(a);a=Kb(a);Tg(b+8|0);nka(c,a,b+8|0);Xa=b+16|0}function oAa(a,b,c){var d=0;i[a>>2]=i[b>>2];d=i[b>>2];i[a+8>>2]=b;i[a+4>>2]=(c<<3)+d;return a}function eFa(a,b,c){var d=0;i[a>>2]=i[b>>2];d=i[b>>2];i[a+8>>2]=b;i[a+4>>2]=o(c,6)+d;return a}function eEa(a,b,c,d){a=c-b|0;c=i[d>>2]+o((a|0)/-33|0,33)|0;i[d>>2]=c;if((a|0)>=1){Tb(c,b,a)}}function WM(a,b,c){var d=0;i[a>>2]=i[b>>2];d=i[b>>2];i[a+8>>2]=b;i[a+4>>2]=o(c,12)+d;return a}function Msa(a,b,c){var d=0;i[a>>2]=i[b>>2];d=i[b>>2];i[a+8>>2]=b;i[a+4>>2]=(c<<5)+d;return a}function Kta(a,b){if(a+ -1>>>0<=268435455){a=a+208|0;XMa(b,0,a,0);return _a?0:o(a,b)}return 0}function J3(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return $a[i[i[a>>2]+16>>2]](a,b,c,d,e)|0}function IIa(a,b,c,d){a=c-b|0;c=i[d>>2]+o((a|0)/-48|0,48)|0;i[d>>2]=c;if((a|0)>=1){Tb(c,b,a)}}function I3(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return $a[i[i[a>>2]+24>>2]](a,b,c,d,e)|0}function Fea(a){var b=0;b=i[19193];i[a>>2]=b;i[i[b+ -12>>2]+a>>2]=i[19196];gr(a+4|0);return a}function $X(a,b,c){a=a|0;b=b|0;c=c|0;if(ae(a,i[b+4>>2])){a=i[b>>2]==(c|0)}else{a=0}return a|0}function $W(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;a=$a[a|0](b,c,d,e)|0;ca(_a|0);return a|0}function xk(a,b,c){var d=0;d=Xa-16|0;Xa=d;Ob(d+8|0,jb(b),c);a=LR(a,d+8|0);Xa=d+16|0;return a}function wD(a){var b=0,c=0;c=a;while(1){b=c;c=b+4|0;if(i[b>>2]){continue}break}return b-a>>2}function vo(a,b,c){a=Zk(a)-i[a+1074392>>2]|0;if(a>>>0>=2){c=p(p(p(c-b)/p(a>>>0))+b)}return c}function via(a,b){var c=0;c=Xa-16|0;Xa=c;i[c+8>>2]=0;fo(a,c+8|0);m[b>>2]=m[c+8>>2];Xa=c+16|0}function tl(a,b,c){var d=0;i[a>>2]=i[b>>2];d=i[b>>2];i[a+8>>2]=b;i[a+4>>2]=(c<<1)+d;return a}function th(a,b,c){var d=0;i[a>>2]=i[b>>2];d=i[b>>2];i[a+8>>2]=b;i[a+4>>2]=(c<<2)+d;return a}function tC(a){a=a|0;var b=0;i[a>>2]=62436;b=i[a+8>>2];if(!(!b|!j[a+12|0])){Cb(b)}return a|0}function rT(a){var b=0;b=Xa-16|0;Xa=b;a=Bf(a,b+15|0);Xa=b+16|0;return(a?j[b+15|0]:0)<<24>>24}function gn(a,b,c){a=a|0;b=b|0;c=c|0;a=i[c+4>>2];i[b>>2]=i[c>>2];i[b+4>>2]=a;zl(b+8|0,c+8|0)}function g8(a,b,c,d){a=c-b|0;c=i[d>>2]+o((a|0)/-24|0,24)|0;i[d>>2]=c;if((a|0)>=1){Tb(c,b,a)}}function ep(a,b){var c=0;c=lb(a);if((c|0)==(lb(b)|0)){a=!xm(xb(a),xb(b),c)}else{a=0}return a}function eaa(a,b){a=a|0;b=b|0;var c=0;c=Xa-16|0;Xa=c;Jn(c+8|0,$g(c,b));Dn(a,c+8|0);Xa=c+16|0}function coa(a){a=a|0;var b=0;i[a>>2]=0;b=Xa-16|0;Xa=b;Yma(a+9|0);Xa=b+16|0;sg(a);return a|0}function cna(a){var b=0;b=Xa-16|0;Xa=b;i[b+12>>2]=0;Fr(b+12|0,a);Xa=b+16|0;return i[b+12>>2]}function Z7(a){var b=0;b=i[19239];i[a>>2]=b;i[i[b+ -12>>2]+a>>2]=i[19242];gr(a+8|0);return a}function Wda(a,b,c){a=a|0;b=b|0;c=c|0;_v(a);i[a+8>>2]=c;i[a+4>>2]=b;i[a>>2]=83484;return a|0}function WJ(a,b){a=a|0;b=b|0;QJ(a);QJ(a+368680|0);if(b){aJ(a,1);return a|0}Xla(a);return a|0}function Ria(a,b,c){a=a|0;b=b|0;c=c|0;if(!((c|0)!=-1?(c|0)!=4:0)){via(a,b);return}uia(a,b,c)}function Nna(a,b){if(b>>>0<=126){sg(((b<<5)+a|0)+480280|0);Pm((o(b,896)+a|0)+1074984|0,a,b)}}function Fga(a,b){var c=0;c=Xa-16|0;Xa=c;Jn(c+8|0,$g(c,b));a=xga(a,c+8|0);Xa=c+16|0;return a}function EB(a,b,c){var d=0;i[a>>2]=i[b>>2];d=i[b>>2];i[a+8>>2]=b;i[a+4>>2]=(c<<4)+d;return a}function E3(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=+e;return $a[i[i[a>>2]+32>>2]](a,b,c,d,e)|0}function Dk(a){var b=0;if(a>>>0>=11){b=a+16&-16;a=b+ -1|0;a=(a|0)==11?b:a}else{a=10}return a}function yI(a,b,c,d){a=c-b|0;if((a|0)>=1){Tb(i[d>>2],b,a);i[d>>2]=i[d>>2]+o((a>>>0)/6|0,6)}}function wia(a,b,c){if(b){while(1){m[a>>2]=m[c>>2];a=a+4|0;b=b+ -1|0;if(b){continue}break}}}function wb(a,b){a=a|0;b=b|0;var c=0;c=i[a>>2];return $a[i[i[c>>2]+36>>2]](c,i[a+8>>2],b)|0}function ur(a){pha(a,i[a+4>>2]);if(i[a>>2]){IH(i[a+16>>2],i[a>>2],i[Mb(a)>>2]-i[a>>2]>>11)}}function qx(a){var b=0;i[a+72>>2]=0;i[a+76>>2]=0;b=i[a+68>>2];i[a+80>>2]=b;i[a+84>>2]=b<<12}function jKa(a,b){a=a|0;b=b|0;var c=0;c=Xa-16|0;Xa=c;rg(c,1,a);rA(c,b);Xa=c+16|0;return a|0}function iKa(a,b){a=a|0;b=b|0;var c=0;c=Xa-16|0;Xa=c;it(c,1,a);rA(c,b);Xa=c+16|0;return a|0}function eDa(a,b,c){if(b){while(1){h[a>>1]=k[c>>1];a=a+2|0;b=b+ -1|0;if(b){continue}break}}}function cH(a,b){var c=0;c=i[a+12>>2];if((c|0)>=1){i[a+20>>2]=(i[a+16>>2]+(b+c|0)|0)%(c|0)}}function Xda(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;OG(a,b,c,d,e,0,0,f,g)}function Vz(a,b,c){a=a|0;b=b|0;c=c|0;b=Xa-16|0;Xa=b;g[b+15|0]=j[c|0];QH(a,b+15|0);Xa=b+16|0}function Vwa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Xa-16|0;Xa=d;So(a,b,c);Xa=d+16|0;return a|0}function VA(a){var b=0;xp(a);b=a;if(i[b>>2]){CB(b,i[b>>2]);Uf(fb(b),i[b>>2],xf(b))}return a}function QJ(a){i[a+20>>2]=0;g[a+16|0]=7;i[a+8>>2]=1889785610;i[a+12>>2]=1072630333;g[a|0]=3}function NA(a){a=a|0;var b=0;b=i[a>>2];return jb(($a[i[i[b>>2]+20>>2]](b)|0)+i[a+8>>2]|0)|0}function ui(a,b){a=a|0;b=b|0;var c=0,d=0;i[a>>2]=i[b>>2];c=a,d=i[b>>2]+rc(b)|0,i[c+4>>2]=d}function lja(a,b,c){var d=0;d=Xa-16|0;Xa=d;i[yc(d+8|0,fz(ll(a),ll(b),ll(c)))>>2];Xa=d+16|0}function gB(a,b){var c=0,d=0;op(a);i[a>>2]=77104;i[a+4>>2]=i[b>>2];c=a,d=Vg(b),i[c+8>>2]=d}function ej(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Xa-16|0;Xa=d;sJ(a,b,c);Xa=d+16|0;return a|0}function dO(a){nAa(a,i[a+4>>2]);if(i[a>>2]){Vt(i[a+16>>2],i[a>>2],i[Mb(a)>>2]-i[a>>2]>>3)}}function cka(a,b,c){a=a|0;b=b|0;c=c|0;if(!((c|0)!=-1?(c|0)!=4:0)){di(a,b);return}nD(a,b,c)}function bha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=Ji(a);if(a){$a[i[i[a>>2]+76>>2]](a,b,c,d)}}function aha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=Ji(a);if(a){$a[i[i[a>>2]+80>>2]](a,b,c,d)}}function _ga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=Ji(a);if(a){$a[i[i[a>>2]+84>>2]](a,b,c,d)}}function Yka(a,b){a=a|0;b=b|0;var c=0;c=a;a=b+38|0;Ic(c,(j[a|0]|j[a+1|0]<<8)&4?16:8,1,0,0)}function XD(a){var b=0;b=i[a>>2];if(b){if(!ae(jE(b),-1)){return!i[a>>2]}i[a>>2]=0}return 1}function VD(a){var b=0;b=i[a>>2];if(b){if(!ae(eE(b),-1)){return!i[a>>2]}i[a>>2]=0}return 1}function Uh(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Xa-16|0;Xa=d;VI(a,b,c);Xa=d+16|0;return a|0}function Tka(a,b){a=a|0;b=b|0;var c=0;c=a;a=b+40|0;Ic(c,(j[a|0]|j[a+1|0]<<8)&4?16:8,1,0,0)}function PP(a,b,c,d){a=c-b|0;c=i[d>>2]+o((a|0)/-6|0,6)|0;i[d>>2]=c;if((a|0)>=1){Tb(c,b,a)}}function xE(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=(b|0)/(c|0)|0;i[a>>2]=d;i[a+4>>2]=b-o(c,d)}function vMa(a,b,c){if(b){while(1){g[a|0]=j[c|0];a=a+1|0;b=b+ -1|0;if(b){continue}break}}}function nt(a){var b=0;b=Xa-16|0;Xa=b;a=JKa(a,b+15|0);Xa=b+16|0;return(a?j[b+15|0]:0)&255}function jHa(a,b){var c=0;a=gHa(a,b);if(!a){c=Xa-16|0;Xa=c;yb(b,0,384);Xa=c+16|0}return a}function eHa(a,b){var c=0;a=AFa(a,b);if(!a){c=Xa-16|0;Xa=c;yb(b,0,554);Xa=c+16|0}return a}function dd(a,b){var c=0;c=Xa-16|0;Xa=c;lj(c+8|0,a+24|0,b);a=ib(c+8|0);Xa=c+16|0;return a}function cX(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;$a[a|0](b,c,d,e,f,g)}function Uu(a,b,c,d){var e=0;e=Xa-16|0;Xa=e;i[e+12>>2]=d;a=uq(a,b,c,d);Xa=e+16|0;return a}function Jba(a,b){var c=0;c=Xa-16|0;Xa=c;i[c+8>>2]=b;Lc(a,i[c+8>>2]);Ab(a+12|0);Xa=c+16|0}function BHa(a,b){var c=0;a=yHa(a,b);if(!a){c=Xa-16|0;Xa=c;yb(b,0,771);Xa=c+16|0}return a}function A3(a,b,c){a=a|0;b=b|0;c=c|0;if(!((c|0)==1|(c|0)>256)){xu(a,c);return}Bb(a,56049)}function $v(a){a=a|0;var b=0;i[a>>2]=83556;b=i[a+4>>2];if(b){Cb(b);i[a+4>>2]=0}return a|0}function uHa(a,b){var c=0;a=rHa(a,b);if(!a){c=Xa-16|0;Xa=c;yb(b,0,62);Xa=c+16|0}return a}function id(a){var b=0;b=Xa-16|0;Xa=b;a=Bf(a,b+15|0);Xa=b+16|0;return(a?j[b+15|0]:0)&255}function hm(a,b,c){b=q7(b,c);c=i[b+4>>2];i[a>>2]=i[b>>2];i[a+4>>2]=c;i[a+8>>2]=i[b+8>>2]}function fo(a,b){var c=0;c=Xa-16|0;Xa=c;_g(c+8|0,b);Nia(a,c+8|0);_g(c,b);nb(c);Xa=c+16|0}function era(a,b,c){var d=0;d=Xa-16|0;Xa=d;if(!lt(a,b)){b=lt(c,a)?c:a}Xa=d+16|0;return b}function dha(a,b){a=a|0;b=b|0;a=Ji(a);if(!a){return 1}return $a[i[i[a>>2]+68>>2]](a,b)|0}function ao(a,b,c){b=c7(b,c);c=i[b+4>>2];i[a>>2]=i[b>>2];i[a+4>>2]=c;i[a+8>>2]=i[b+8>>2]}function aNa(a,b){var c=0,d=0;c=b&31;d=(-1>>>c&a)<<c;c=a;a=0-b&31;return d|(c&-1<<a)>>>a}function Ye(a){var b=0;b=Xa-16|0;Xa=b;a=i[yc(b+8|0,xb(a)+lb(a)|0)>>2];Xa=b+16|0;return a}function Ssa(a,b){Rsa(a,b);Lc(a+12|0,b+12|0);h[a+28>>1]=k[b+28>>1];i[a+24>>2]=i[b+24>>2]}function PMa(a){var b=0,c=0;b=Xa-16|0;Xa=b;if(Bf(a,b+8|0)){c=j[b+8|0]}Xa=b+16|0;return c}function Me(a){var b=0;b=a+24|0;while(1){b=eb(b+ -12|0);if((b|0)!=(a|0)){continue}break}}function Hl(a){var b=0;b=a+36|0;while(1){b=eb(b+ -12|0);if((b|0)!=(a|0)){continue}break}}function Hga(a,b,c){a=a|0;b=b|0;c=c|0;td(a,b);b=i[c+4>>2];i[a+8>>2]=i[c>>2];i[a+12>>2]=b}function AB(a){var b=0;b=a+48|0;while(1){b=eb(b+ -12|0);if((b|0)!=(a|0)){continue}break}}function yP(a,b,c){a=a|0;b=b|0;c=c|0;a=k[c>>1]|k[c+2>>1]<<16;h[b>>1]=a;h[b+2>>1]=a>>>16}function xD(a,b){var c=0;c=Xa-16|0;Xa=c;i[c+12>>2]=b;a=BD(a,62368,b);Xa=c+16|0;return a}function uZ(a){a=a|0;a=462216;while(1){a=eb(a+ -12|0);if((a|0)!=462048){continue}break}}function rZ(a){a=a|0;a=462392;while(1){a=nc(a+ -12|0);if((a|0)!=462224){continue}break}}function pK(a,b){var c=0;c=j[a+872|0];if(c&1){g[a+872|0]=c|8;i[a+876>>2]=i[a+876>>2]+b}}function oZ(a){a=a|0;a=462688;while(1){a=eb(a+ -12|0);if((a|0)!=462400){continue}break}}function lZ(a){a=a|0;a=462992;while(1){a=nc(a+ -12|0);if((a|0)!=462704){continue}break}}function hZ(a){a=a|0;a=463032;while(1){a=eb(a+ -12|0);if((a|0)!=463008){continue}break}}function eZ(a){a=a|0;a=463064;while(1){a=nc(a+ -12|0);if((a|0)!=463040){continue}break}}function cja(a,b){var c=0;c=Xa-16|0;Xa=c;i[yc(c+8|0,aja(a,i[yc(c,b)>>2]))>>2];Xa=c+16|0}function aj(a){g[a|0]=0;g[a+1|0]=0;g[a+2|0]=0;g[a+3|0]=0;g[a+4|0]=0;g[a+5|0]=0;return a}function TO(a,b){var c=0,d=0;i[a>>2]=i[b>>2];c=a,d=i[b>>2]+MO(b)|0,i[c+4>>2]=d;return a}function RU(a){a=a|0;var b=0;b=i[a+4>>2];return($a[i[i[b>>2]+20>>2]](b)|0)+i[a+12>>2]|0}function Nl(a){var b=0;if(a>>>0>=2){b=a+4&-4;a=b+ -1|0;a=(a|0)==2?b:a}else{a=1}return a}function He(a,b){var c=0;tk(a,b);c=i[b+12>>2];i[a+8>>2]=i[b+8>>2];i[a+12>>2]=c;return a}function Hb(a,b){var c=0,d=0;i[a>>2]=i[b>>2];c=a,d=i[b>>2]+nb(b)|0,i[c+4>>2]=d;return a}function Es(a,b,c){var d=0;i[a>>2]=i[b>>2];d=i[b>>2];i[a+8>>2]=b;i[a+4>>2]=c+d;return a}function El(a){var b=0;b=au(a+4|0);if((b|0)==-1){$a[i[i[a>>2]+8>>2]](a)}return(b|0)==-1}function Cr(a,b){if(!(i[a+480180>>2]==8?g[b+872|0]&1:0)){Rw(a,b,0);Rw(a,b,1);Rw(a,b,2)}}function Cd(a,b){var c=0;SV(a,b);c=i[b+12>>2];i[a+8>>2]=i[b+8>>2];i[a+12>>2]=c;return a}function AL(a,b){var c=0;b=jb(b);c=a;a=i[a>>2];i[c>>2]=a<<8^i[((b^a>>>24)<<2)+87568>>2]}function $g(a,b){var c=0,d=0;i[a>>2]=i[b>>2];c=a,d=i[b>>2]+Vg(b)|0,i[c+4>>2]=d;return a}function pQ(a){var b=0;b=Xa-16|0;Xa=b;i[b+12>>2]=-1;a=jGa(a,b+12|0);Xa=b+16|0;return a}function fC(a,b,c){a=a|0;b=b|0;c=c|0;if((a|0)==(b|0)){g[a+112|0]=0;return}bv(b,c<<2,4)}function cN(a){var b=0;b=44325e5/+(a>>>0);if(b<4294967296&b>=0){return~~b>>>0}return 0}function YFa(a){var b=0;b=Xa-16|0;Xa=b;a=Rp(a,b+8|0);Xa=b+16|0;return a?m[b+8>>2]:p(0)}function Xd(a){var b=0,c=0,d=0;b=Xa-16|0;Xa=b;c=i[vu(b,a)+8>>2],d=0,g[c|0]=d;Xa=b+16|0}function UJ(a){Oc(a);Oc(a+12|0);Oc(a+24|0);Oc(a+36|0);Oc(a+48|0);i[a+60>>2]=0;return a}function FL(a,b){return(a>>>0<=62?63-(o((b^-1)&63,(a?a+1|0:0)&255)>>>6|0)|b&192:b)&255}function Du(a,b){a=a|0;b=b|0;var c=0;c=Xa-16|0;Xa=c;jY(a,b,wD(b));Xa=c+16|0;return a|0}function Bb(a,b){a=a|0;b=b|0;var c=0;c=Xa-16|0;Xa=c;So(a,b,le(b));Xa=c+16|0;return a|0}function $R(a,b,c){g[a+2|0]=1;b=b&15;if(c){b=j[b+12336|0]}else{b=(b<<2)+4|0}g[a+4|0]=b}function $Ma(a){var b=0,c=0;while(1){c=b;if(a){a=a-1&a;b=b+1|0;continue}break}return c}function zG(a,b){a=a|0;b=b|0;var c=0;c=te(8);qG(c);i[c+4>>2]=b;i[c>>2]=83928;Eaa(a,c)}function wua(a){a=a+1|0;if((a&255)>>>0<=5){return i[(a<<24>>24<<2)+18424>>2]}return 0}function rs(a,b){a:{if(b){break a}if(a>>>0<=3){a=a|-16;break a}a=a>>>2|0}return a&255}function pj(a,b){a=a|0;b=b|0;g[a|0]=67109634;g[a+1|0]=262147;g[a+2|0]=1024;g[a+3|0]=4}function o5(a,b){a=a|0;b=b|0;a=k[a>>1];b=k[b>>1];return(a>>>0<b>>>0?-1:a>>>0>b>>>0)|0}function k9(a,b){a=a|0;b=b|0;var c=0;c=Xa-16|0;Xa=c;lT(c+8|0,b);Bt(a,c+8|0);Xa=c+16|0}function a0(a,b,c){a=a|0;b=b|0;c=c|0;c=gv(i[b>>2])<<24;i[a+4>>2]=i[b>>2];g[a|0]=c>>24}function _za(a,b){var c=0;c=Xa-16|0;Xa=c;a=YN(td(c+8|0,a),td(c,b));Xa=c+16|0;return a}function Naa(a,b){a=a|0;b=b|0;var c=0;c=Xa-16|0;Xa=c;lm(c,a);Maa(b,c);We(c);Xa=c+16|0}function $ga(a,b,c){var d=0;d=Xa-16|0;Xa=d;i[d+12>>2]=j[b|0];lw(a,d+12|0,c);Xa=d+16|0}function $4(a,b){a=a|0;b=b|0;a=i[a>>2];b=i[b>>2];return(a>>>0<b>>>0?-1:a>>>0>b>>>0)|0}function j_(a,b){a=a|0;b=b|0;if((b|0)>=0){b=i[kq()+((b&255)<<2)>>2]}return b<<24>>24}function h_(a,b){a=a|0;b=b|0;if((b|0)>=0){b=i[jq()+((b&255)<<2)>>2]}return b<<24>>24}function cf(a){a=a|0;var b=0;b=i[a>>2];return($a[i[i[b>>2]+24>>2]](b)|0)-i[a+8>>2]|0}function Tg(a){g[a|0]=0;g[a+1|0]=0;g[a+2|0]=0;g[a+3|0]=0;g[a+4|0]=0;g[a+5|0]=0;aj(a)}function Pe(a){a=a|0;var b=0;b=Xa-16|0;Xa=b;a=i[yc(b+8|0,a)>>2];Xa=b+16|0;return a|0}function Lda(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return HG(a,b,c,d,0,0,0,0,e)|0}function Jja(a,b,c){if(b){while(1){BI(a,c);a=a+52|0;b=b+ -1|0;if(b){continue}break}}}function G_(a,b){var c=0;c=Xa-16|0;Xa=c;i[c+12>>2]=b;ye(a,c+12|0);Xa=c+16|0;return a}function zMa(a,b){var c=0,d=0;c=Xa-16|0;Xa=c;d=vn(c+8|0,b,a);Xa=c+16|0;return d?b:a}function z1(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return y1(b,c,d,e,f)|0}function yka(a,b){a=a|0;b=b|0;if(b>>>0<=42){return j[i[a+84>>2]+b|0]!=63|0}return 0}function x1(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return w1(b,c,d,e,f)|0}function v1(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return u1(b,c,d,e,f)|0}function pEa(a,b){var c=0;a=bEa(a,b);if(!a){c=Xa-16|0;Xa=c;DP(b);Xa=c+16|0}return a}function oma(a,b,c,d){var e=0;e=Xa-16|0;Xa=e;i[e+8>>2]=d;lma(a,b,c,e+8|0);Xa=e+16|0}function o2(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return n2(b,c,d,e,f)|0}function lJa(a,b){a=a|0;b=b|0;cJa(a,b);g[a+16|0]=6;i[a+12>>2]=2015363072;return a|0}function lD(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return $a[i[i[a>>2]+32>>2]](a,b,c,d)|0}function l2(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return k2(b,c,d,e,f)|0}function kD(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return $a[i[i[a>>2]+48>>2]](a,b,c,d)|0}function i2(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return h2(b,c,d,e,f)|0}function f2(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return e2(b,c,d,e,f)|0}function d2(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return c2(b,c,d,e,f)|0}function b2(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return a2(b,c,d,e,f)|0}function Z1(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return Y1(b,c,d,e,f)|0}function YW(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=$a[a|0](b,c,d)|0;ca(_a|0);return a|0}function We(a){var b=0;qh(a);b=a;if(i[b>>2]){QF(b);uo(fb(b),i[b>>2],Be(b))}return a}function W1(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return V1(b,c,d,e,f)|0}function T1(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return S1(b,c,d,e,f)|0}function QV(a,b){var c=0;c=Xa-16|0;Xa=c;PV(c+8|0,b);Dl(a,c+8|0);hb(c+8|0);Xa=c+16|0}function NAa(a){var b=0;b=Xa-16|0;Xa=b;a=Ut(a,b+8|0);Xa=b+16|0;return a?n[b+8>>3]:0}function MY(a,b){if(!(j[a+112|0]|b>>>0>28)){g[a+112|0]=1;return a}return Yb(b<<2,4)}function M1(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return L1(b,c,d,e,f)|0}function LV(a,b){var c=0;c=Xa-16|0;Xa=c;i[c+8>>2]=b;gB(a,$g(c,i[c+8>>2]));Xa=c+16|0}function LLa(a){a=a|0;var b=0;b=Xa-16|0;Xa=b;ES(b+8|0,a);Xa=b+16|0;return i[b+8>>2]}function K1(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return J1(b,c,d,e,f)|0}function I1(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return H1(b,c,d,e,f)|0}function G1(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return E1(b,c,d,e,f)|0}function Dl(a,b){i[a>>2]=i[b>>2];i[a+4>>2]=i[b+4>>2];i[b>>2]=0;i[b+4>>2]=0;return a}function D1(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return C1(b,c,d,e,f)|0}function B1(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return A1(b,c,d,e,f)|0}function uha(a,b,c){i[a>>2]=b;b=i[b+4>>2];i[a+4>>2]=b;i[a+8>>2]=b+(c<<11);return a}function px(a,b){var c=0;g[a|0]=j[b|0];c=i[b+8>>2];i[a+4>>2]=i[b+4>>2];i[a+8>>2]=c}function lk(a,b){a=a|0;b=b|0;if(Wb(a)>>>0<=b>>>0){SB();x()}return i[a>>2]+(b<<1)|0}function iP(a){var b=0;b=Xa-16|0;Xa=b;a=i[yc(b+8|0,i[a>>2])>>2];Xa=b+16|0;return a}function iEa(a,b,c){i[a>>2]=b;b=i[b+4>>2];i[a+4>>2]=b;i[a+8>>2]=b+o(c,33);return a}function gba(a){var b=0;b=Xa-16|0;Xa=b;i[b+12>>2]=38187;Bb(a,i[b+12>>2]);Xa=b+16|0}function gU(a,b){var c=0,d=0;c=Xa-16|0;Xa=c;d=vn(c+8|0,a,b);Xa=c+16|0;return d?b:a}function Zx(a){if(i[a>>2]){ce(a,i[a>>2]);pxa(i[a>>2],(i[fb(a)>>2]-i[a>>2]|0)/9|0)}}function Zg(a){var b=0,c=0;b=Xa-16|0;Xa=b;c=b+8|0;hB(c,a);Xa=b+16|0;return i[c>>2]}function YE(a,b){b=i[a+32>>2]+b|0;i[a+32>>2]=b;if(b>>>0>=l[a+40>>2]){i[a+96>>2]=1}}function RBa(a,b,c){i[a>>2]=b;b=i[b+4>>2];i[a+4>>2]=b;i[a+8>>2]=b+o(c,20);return a}function PBa(a){var b=0,c=0;b=Xa-16|0;Xa=b;c=a;a=wh(b);XO(c,a,0,0);hb(a);Xa=b+16|0}function OK(a,b){var c=0;c=b&15;if(c){g[a+850|0]=c}b=b&240;if(b){g[a+849|0]=b>>>4}}function Ija(a,b,c){i[a>>2]=b;b=i[b+4>>2];i[a+4>>2]=b;i[a+8>>2]=b+o(c,52);return a}function II(a,b){a=a|0;b=b|0;if(b>>>0<=15){return j[i[a+88>>2]+b|0]!=63|0}return 0}function sza(a,b){a=a|0;b=b|0;if(i[a+4>>2]!=i[fb(a)>>2]){lza(a,b);return}kza(a,b)}function spa(a,b){a=a|0;b=b|0;if(i[a+4>>2]!=i[fb(a)>>2]){hpa(a,b);return}gpa(a,b)}function ska(a,b){var c=0;c=Xa-16|0;Xa=c;i[c+12>>2]=j[b|0];Aw(a,c+12|0);Xa=c+16|0}function qxa(a,b,c){i[a>>2]=b;b=i[b+4>>2];i[a+4>>2]=b;i[a+8>>2]=b+o(c,9);return a}function nga(a,b){a=a|0;b=b|0;if(i[a+4>>2]!=i[fb(a)>>2]){lga(a,b);return}kga(a,b)}function kB(a){var b=0;b=i[a>>2];i[a>>2]=0;if(b){a=Pb(a);Df(i[a>>2],b,i[a+4>>2])}}function gR(a,b,c){i[a>>2]=b;b=i[b+4>>2];i[a+4>>2]=b;i[a+8>>2]=b+o(c,48);return a}function fma(a,b){a=a|0;b=b|0;if(i[a+4>>2]!=i[fb(a)>>2]){dma(a,b);return}cma(a,b)}function fk(a,b,c){i[a>>2]=b;b=i[b+4>>2];i[a+4>>2]=b;i[a+8>>2]=b+o(c,24);return a}function aIa(a,b){a=a|0;b=b|0;if(i[a+4>>2]!=i[fb(a)>>2]){MHa(a,b);return}LHa(a,b)}function aGa(a,b){a=a|0;b=b|0;if(i[a+4>>2]!=i[fb(a)>>2]){QFa(a,b);return}OFa(a,b)}function Zxa(a,b){a=a|0;b=b|0;if(i[a+4>>2]!=i[fb(a)>>2]){Nxa(a,b);return}Mxa(a,b)}function Yx(a,b){a=Tb(a,b,34);h[a+34>>1]=k[b+34>>1];Tb(a+36|0,b+36|0,68);return a}function VF(a){var b=0;b=i[a>>2];i[a>>2]=0;if(b){a=Pb(a);dy(i[a>>2],b,i[a+4>>2])}}function St(a,b){var c=0;i[a>>2]=i[b>>2];c=a;a=i[b+4>>2];i[c+4>>2]=a;if(a){Fl(a)}}function RA(a){var b=0;b=i[a>>2];i[a>>2]=0;if(b){a=Pb(a);Xg(i[a>>2],b,i[a+4>>2])}}function Oia(a,b){a=a|0;b=b|0;if(i[a+4>>2]!=i[fb(a)>>2]){Mia(a,b);return}Lia(a,b)}function JG(a,b){var c=0;c=i[a>>2];i[a>>2]=b;if(c){if(c){$a[i[i[c>>2]+4>>2]](c)}}}function Ik(a,b,c){i[a>>2]=b;b=i[b+4>>2];i[a+4>>2]=b;i[a+8>>2]=b+o(c,12);return a}function Az(a,b,c){a=a|0;b=b|0;c=c|0;a=j[c|0]|j[c+1|0]<<8;g[b|0]=a;g[b+1|0]=a>>>8}function $A(a){var b=0;b=i[a>>2];i[a>>2]=0;if(b){a=Pb(a);wi(i[a>>2],b,i[a+4>>2])}}function yn(a,b,c){i[a>>2]=b;b=i[b+4>>2];i[a+4>>2]=b;i[a+8>>2]=b+(c<<5);return a}function yEa(a,b){a=a|0;b=b|0;if(l[a+4>>2]<l[fb(a)>>2]){XDa(a,b);return}WDa(a,b)}function vh(a,b,c){i[a>>2]=b;b=i[b+4>>2];i[a+4>>2]=b;i[a+8>>2]=b+(c<<1);return a}function uR(a,b){a=a|0;b=b|0;if(i[a+4>>2]!=i[fb(a)>>2]){fJa(a,b);return}eJa(a,b)}function u6(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=+d;e=+e;return lF(a+ -88|0,b,c,d,e)|0}function oza(a,b){a=a|0;b=b|0;if(l[a+4>>2]<l[fb(a)>>2]){Yya(a,b);return}Xya(a,b)}function nta(a,b){a=a|0;b=b|0;if(l[a+4>>2]<l[fb(a)>>2]){mta(a,b);return}lta(a,b)}function nS(a,b){a=a|0;b=b|0;if(i[a+4>>2]!=i[fb(a)>>2]){XKa(a,b);return}WKa(a,b)}function ld(a){var b=0;b=Xa-16|0;Xa=b;a=i[yc(b+8|0,xb(a))>>2];Xa=b+16|0;return a}function jp(a,b,c){i[a>>2]=b;b=i[b+4>>2];i[a+4>>2]=b;i[a+8>>2]=b+o(c,6);return a}function fi(a){var b=0;b=Xa-16|0;Xa=b;a=i[yc(b+8|0,Zi(a))>>2];Xa=b+16|0;return a}function fKa(a,b){a=a|0;b=b|0;if(l[a+4>>2]<l[fb(a)>>2]){TJa(a,b);return}SJa(a,b)}function dJa(a,b){a=a|0;b=b|0;if(l[a+4>>2]<l[fb(a)>>2]){FIa(a,b);return}EIa(a,b)}function dIa(a,b){a=a|0;b=b|0;if(l[a+4>>2]<l[fb(a)>>2]){WHa(a,b);return}VHa(a,b)}function Zi(a){var b=0;b=Xa-16|0;Xa=b;a=i[yc(b+8|0,Pb(a))>>2];Xa=b+16|0;return a}function Ywa(a,b){a=a|0;b=b|0;if(l[a+4>>2]<l[fb(a)>>2]){Qwa(a,b);return}Pwa(a,b)}function Yd(a,b,c){i[a>>2]=b;b=i[b+4>>2];i[a+4>>2]=b;i[a+8>>2]=b+(c<<2);return a}function XBa(a,b){var c=0;c=Xa-16|0;Xa=c;fq(a,i[b>>2],i[b>>2]+MO(b)|0);Xa=c+16|0}function Wm(a){var b=0;b=Xa-16|0;Xa=b;a=i[yc(b+8|0,iP(a))>>2];Xa=b+16|0;return a}function Ska(a,b){a=a|0;b=b|0;if(l[a+4>>2]<l[fb(a)>>2]){Jka(a,b);return}Hka(a,b)}function Raa(a,b){a=a|0;b=b|0;if(l[a+4>>2]<l[fb(a)>>2]){Paa(a,b);return}Oaa(a,b)}function Qp(a,b,c){i[a>>2]=b;b=i[b+4>>2];i[a+4>>2]=b;i[a+8>>2]=b+(c<<3);return a}function Nia(a,b){var c=0;c=Xa-16|0;Xa=c;cI(c+8|0,Hb(c,b));LR(a,c+8|0);Xa=c+16|0}function Kl(a,b,c){i[a>>2]=b;b=i[b+4>>2];i[a+4>>2]=b;i[a+8>>2]=b+(c<<4);return a}function Jia(a,b){var c=0;c=Xa-16|0;Xa=c;fq(a,i[b>>2],i[b>>2]+nb(b)|0);Xa=c+16|0}function Fna(a,b){a=a|0;b=b|0;if(l[a+4>>2]<l[fb(a)>>2]){Ana(a,b);return}zna(a,b)}function $aa(a,b){a=a|0;b=b|0;if(l[a+4>>2]<l[fb(a)>>2]){_aa(a,b);return}Zaa(a,b)}function zIa(a){var b=0;b=Xa-16|0;Xa=b;g[a|0]=0;g[a+1|0]=0;g[a+2|0]=0;Xa=b+16|0}function xO(a,b){var c=0;qBa(a,b);c=i[b+12>>2];i[a+8>>2]=i[b+8>>2];i[a+12>>2]=c}function vV(a){var b=0;b=Xa-16|0;Xa=b;uV(b+8|0);Dl(a,b+8|0);hb(b+8|0);Xa=b+16|0}function r2(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;b=Xa-16|0;Xa=b;oD(a,c,d);Xa=b+16|0}function cL(a,b){a=a|0;b=b|0;if(l[a+4>>2]<l[fb(a)>>2]){Wqa(a,b);return}Vqa(a,b)}function YH(a,b){a=a|0;b=b|0;if(l[a+4>>2]<l[fb(a)>>2]){eia(a,b);return}dia(a,b)}function XW(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;$a[a|0](b,c,d,e,f)}function Wx(a,b){a=a|0;b=b|0;if(l[a+4>>2]<l[fb(a)>>2]){Jva(a,b);return}yva(a,b)}function WR(a,b){a=a|0;b=b|0;return i[b+8>>2]==i[a+8>>2]&i[a+12>>2]==i[b+12>>2]}function TV(a,b){var c=0;c=Xa-16|0;Xa=c;fq(a,i[b>>2],i[b>>2]+PA(b)|0);Xa=c+16|0}function LX(a,b){var c=0;c=Xa-16|0;Xa=c;fq(a,i[b>>2],i[b>>2]+Vg(b)|0);Xa=c+16|0}function zl(a,b){var c=0;Dl(a,b);c=i[b+12>>2];i[a+8>>2]=i[b+8>>2];i[a+12>>2]=c}function vs(a){g[a|0]=0;g[a+1|0]=0;g[a+2|0]=0;g[a+3|0]=0;g[a+4|0]=0;g[a+5|0]=0}function qBa(a,b){var c=0;c=Xa-16|0;Xa=c;b=tk(c+8|0,b);lB(b,a);hb(b);Xa=c+16|0}function ppa(a){var b=0;if(!(j[a+2|0]|(j[a|0]|j[a+1|0]))){b=!j[a+3|0]}return b}function hs(a,b){return Wj(zg((+(a|0)*128+ +(b|0))*.0006510416666666666)*8363)}function _W(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return $a[a|0](b,c,d,e)|0}function XX(a,b,c){a=a|0;b=b|0;c=c|0;if((c|0)>=257){Bb(a,70513);return}xu(a,c)}function WU(a,b,c,d){op(a);i[a>>2]=77312;tk(a+4|0,b);i[a+16>>2]=d;i[a+12>>2]=c}function VX(a,b,c){a=a|0;b=b|0;c=c|0;if((c|0)>=257){Bb(a,70591);return}xu(a,c)}function Rea(a,b){a=a|0;b=b|0;return p((b|0)<=12?m[((b<<2)+a|0)+4208>>2]:p(0))}function Fxa(a,b){a=a|0;b=b|0;Hi(b);if(i[b>>2]){aN(b);dh(fb(b),i[b>>2],Rf(b))}}function EU(a,b){a=a|0;b=b|0;if(i[a+4>>2]!=i[fb(a)>>2]){AU(a,b);return}zU(a,b)}function BE(a,b,c){var d=0;d=Xa-16|0;Xa=d;i[d+12>>2]=c;EE(a,b,c,0,0);Xa=d+16|0}function $oa(a,b){var c=0;c=Xa-16|0;Xa=c;a=Aoa(Nr(a),Nr(b));Xa=c+16|0;return a}function z7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;Zq(b,c,d,m[a+24>>2]);HF(a,b,c,d)}function xfa(a,b){a=a|0;b=b|0;return p((b|0)<=4?m[((b<<2)+a|0)+4220>>2]:p(0))}function xea(a,b){a=a|0;b=b|0;return p((b|0)<=3?m[((b<<2)+a|0)+4208>>2]:p(0))}function wCa(a,b){var c=0,d=0;c=Xa-16|0;Xa=c;d=UO(a,b);Xa=c+16|0;return d?b:a}function vna(a,b){a=a|0;b=b|0;return(b>>>0<4e3?((b<<5)+a|0)+946300|0:20509)|0}function tk(a,b){i[a>>2]=i[b>>2];b=i[b+4>>2];i[a+4>>2]=b;if(b){Fl(b)}return a}function oY(a,b){var c=0;c=lb(a);if(c>>>0<b>>>0){qs(a,b-c|0,0);return}nY(a,b)}function lCa(a,b){var c=0,d=0;c=Xa-16|0;Xa=c;d=UO(b,a);Xa=c+16|0;return d?b:a}function j7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;Zq(b,c,d,m[a+24>>2]);EF(a,b,c,d)}function dna(a,b){var c=0,d=0;c=Xa-16|0;Xa=c;d=Zz(a,b);Xa=c+16|0;return d?b:a}function dga(a,b){a=a|0;b=b|0;return p((b|0)<=6?m[((b<<2)+a|0)+4208>>2]:p(0))}function dfa(a,b){a=a|0;b=b|0;return p((b|0)<=1?m[((b<<2)+a|0)+4208>>2]:p(0))}function a8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;Zq(b,c,d,m[a+28>>2]);MF(a,b,c,d)}function Zya(a,b){var c=0,d=0;c=Xa-16|0;Xa=c;d=NS(a,b);Xa=c+16|0;return d?b:a}function Yna(a){var b=0;b=Xa-16|0;Xa=b;a=i[vJ(b+8|0,a)>>2];Xa=b+16|0;return a}function VM(a){if((j[a+14|0]+ -49&255)>>>0<=3){return!Xc(a,17488,14)}return 0}function VKa(a,b){var c=0,d=0;c=Xa-16|0;Xa=c;d=lt(b,a);Xa=c+16|0;return d?b:a}function Sfa(a,b){a=a|0;b=b|0;return p((b|0)<=5?m[((b<<2)+a|0)+4208>>2]:p(0))}function SV(a,b){var c=0;c=Xa-16|0;Xa=c;b=Dl(c+8|0,b);lB(b,a);hb(b);Xa=c+16|0}function RKa(a,b){var c=0,d=0;c=Xa-16|0;Xa=c;d=lt(a,b);Xa=c+16|0;return d?b:a}function R4(a,b){a=a|0;b=b|0;if(l[a+4>>2]<l[fb(a)>>2]){p4(a,b);return}k4(a,b)}function Ofa(a,b){var c=0,d=0;c=Xa-16|0;Xa=c;d=tH(b,a);Xa=c+16|0;return d?b:a}function M7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;Zq(b,c,d,m[a+28>>2]);JF(a,b,c,d)}function Jh(a,b,c){if(i[a+80>>2]){i[a+92>>2]=i[a+92>>2]+(c+7&-8);return}Cb(b)}function Jga(a,b){var c=0,d=0;c=Xa-16|0;Xa=c;d=tH(a,b);Xa=c+16|0;return d?b:a}function Ffa(a,b){a=a|0;b=b|0;return p((b|0)<=4?m[((b<<2)+a|0)+4208>>2]:p(0))}function Eea(a,b){a=a|0;b=b|0;return p((b|0)<=2?m[((b<<2)+a|0)+4208>>2]:p(0))}function EMa(a,b){var c=0,d=0;c=Xa-16|0;Xa=c;d=Zz(b,a);Xa=c+16|0;return d?b:a}function CX(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;if(Nf(a,i[b+8>>2],0)){su(b,c,d)}}function CU(a,b){a=a|0;b=b|0;if(l[a+4>>2]<l[fb(a)>>2]){yU(a,b);return}xU(a,b)}function vi(a,b){a=a|0;b=b|0;if((a|0)!=(b|0)){a=ZN(a,xb(b),lb(b))}return a|0}function sV(a,b){var c=0,d=0;c=Xa-16|0;Xa=c;d=pd(b,a);Xa=c+16|0;return d?b:a}function pz(a){a=a+4|0;return j[a|0]|j[a+1|0]<<8|(j[a+2|0]<<16|j[a+3|0]<<24)}function oG(a,b,c,d){i[a+12>>2]=0;i[a+8>>2]=d;i[a+4>>2]=c;i[a>>2]=b;return a}function ll(a){var b=0;b=Xa-16|0;Xa=b;i[b+8>>2]=a;Xa=b+16|0;return i[b+8>>2]}function kn(a,b,c,d){a=c-b|0;if((a|0)>=1){Tb(i[d>>2],b,a);i[d>>2]=i[d>>2]+a}}function ki(a,b,c,d){a=c-b|0;c=i[d>>2]-a|0;i[d>>2]=c;if((a|0)>=1){Tb(c,b,a)}}function kW(a,b){var c=0,d=0;c=Xa-16|0;Xa=c;d=pd(a,b);Xa=c+16|0;return d?b:a}function bL(a){var b=0;b=Xa-16|0;Xa=b;hB(b+8|0,a);Xa=b+16|0;return i[b+8>>2]}function ad(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=i[b+8>>2];Ib(b,c);cu(a,b,d,c)}function VC(a,b){var c=0,d=0;de(a,sd(b));b=i[Pb(b)>>2];c=Pb(a),d=b,i[c>>2]=d}function VB(){a:{if(g[463664]&1){break a}if(!cd(463664)){break a}bd(463664)}}function R1(a,b){var c=0,d=0;c=Xa-16|0;Xa=c;d=WB(b,a);Xa=c+16|0;return d?b:a}function OT(a,b){var c=0,d=0;c=Xa-16|0;Xa=c;d=WB(a,b);Xa=c+16|0;return d?b:a}function vq(a,b,c,d,e,f,g,h){return $a[i[i[a>>2]+12>>2]](a,b,c,d,e,f,g,h)|0}function uB(a,b){a=a|0;b=b|0;var c=0;c=Xa-16|0;Xa=c;ai(a,c+8|0,b);Xa=c+16|0}function ql(a,b,c){i[a>>2]=b;b=i[b+4>>2];i[a+4>>2]=b;i[a+8>>2]=b+c;return a}function aS(a,b){a=a|0;b=b|0;a=i[a>>2];return $a[i[i[a>>2]+36>>2]](a,0,b)|0}function YF(a){var b=0;b=i[a>>2];i[a>>2]=0;if(b){a=Pb(a);a;WF(b,i[a+4>>2])}}function SM(a,b){wN(a,b);g[a+16|0]=j[b+16|0];i[a+12>>2]=i[b+12>>2];return a}function ND(a,b,c,d,e,f,g,h){return $a[i[i[a>>2]+16>>2]](a,b,c,d,e,f,g,h)|0}function Jn(a,b){a=a|0;b=b|0;var c=0;c=Xa-16|0;Xa=c;LX(a,$g(c,b));Xa=c+16|0}function HI(a,b){a=a|0;b=b|0;return(b>>>0<=15?g[i[a+88>>2]+b|0]:63)<<24>>24}function GI(a,b){a=a|0;b=b|0;return(b>>>0<=42?g[i[a+84>>2]+b|0]:63)<<24>>24}function AW(a,b){a=a|0;b=b|0;var c=0;c=Xa-16|0;Xa=c;Il(a,c+8|0,b);Xa=c+16|0}function xCa(a){a=a|0;C3(a,xH(i[i[a>>2]+ -12>>2]+a|0,10));Eq(a);return a|0}function vu(a,b){i[a+12>>2]=0;i[a+4>>2]=b;i[a>>2]=b;i[a+8>>2]=b+1;return a}function tg(a,b){var c=0;c=a;a=i[a+8>>2];b=a-b|0;i[c+8>>2]=b>>>0>a>>>0?0:b}function tGa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=c,e=YEa(a,b),i[d>>2]=e}function s_(a,b){a=a|0;b=b|0;if(b>>>0<=127){b=i[kq()+(b<<2)>>2]}return b|0}function qm(a,b){a=i[a+4276>>2];return(((a<<12&b>>31)+b|0)/4096|0)%(a|0)|0}function q_(a,b){a=a|0;b=b|0;if(b>>>0<=127){b=i[jq()+(b<<2)>>2]}return b|0}function qGa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=c,e=XEa(a,b),h[d>>1]=e}function pg(a,b){a=a|0;b=b|0;if(sp(a,b)){a=rh(se(a,b))}else{a=0}return a|0}function og(a,b,c){i[a+8>>2]=b;i[a+12>>2]=c;i[a>>2]=0;i[a+4>>2]=0;return a}function jsa(a){var b=0;b=Xa-288|0;Xa=b;a=tsa(a,DL(b));Xa=b+288|0;return a}function dL(a,b,c){var d=0;d=i[b+4>>2];i[a>>2]=i[b>>2];i[a+4>>2]=d;MM(a,c)}function xj(a,b,c){a=a|0;b=b|0;c=c|0;return $a[i[i[a>>2]+12>>2]](a,b,c)|0}function wl(a,b,c){a=a|0;b=b|0;c=c|0;return $a[i[i[a>>2]+48>>2]](a,b,c)|0}function wP(a){PDa(a,i[a+4>>2]);if(i[a>>2]){Df(i[a+16>>2],i[a>>2],ol(a))}}function vt(a){eLa(a,i[a+4>>2]);if(i[a>>2]){Uf(i[a+16>>2],i[a>>2],Qz(a))}}function tr(a){lha(a,i[a+4>>2]);if(i[a>>2]){xe(i[a+16>>2],i[a>>2],Wf(a))}}function tJ(a){Ima(a,i[a+4>>2]);if(i[a>>2]){xe(i[a+16>>2],i[a>>2],Wf(a))}}function rm(a){Fia(a,i[a+4>>2]);if(i[a>>2]){xe(i[a+16>>2],i[a>>2],Wf(a))}}function ns(a){txa(a,i[a+4>>2]);if(i[a>>2]){dh(i[a+16>>2],i[a>>2],Rn(a))}}function nr(a){iga(a,i[a+4>>2]);if(i[a>>2]){xe(i[a+16>>2],i[a>>2],Wf(a))}}function lA(a,b){var c=0;c=Xa-16|0;Xa=c;kA(c+8|0,b);Bt(a,c+8|0);Xa=c+16|0}function kk(a){xMa(a,i[a+4>>2]);if(i[a>>2]){un(i[a+16>>2],i[a>>2],tn(a))}}function jt(a){EJa(a,i[a+4>>2]);if(i[a>>2]){ln(i[a+16>>2],i[a>>2],tn(a))}}function ika(a,b,c){a=a|0;b=b|0;c=c|0;if(lb(b)>>>0>c>>>0){mm(b,c)}Lc(a,b)}function eL(a){hra(a,i[a+4>>2]);if(i[a>>2]){dh(i[a+16>>2],i[a>>2],Rn(a))}}function dP(a){VCa(a,i[a+4>>2]);if(i[a>>2]){Yi(i[a+16>>2],i[a>>2],Wf(a))}}function cs(a){Psa(a,i[a+4>>2]);if(i[a>>2]){Xg(i[a+16>>2],i[a>>2],Yt(a))}}function bR(a){BIa(a,i[a+4>>2]);if(i[a>>2]){Df(i[a+16>>2],i[a>>2],ol(a))}}function aK(a){uoa(a,i[a+4>>2]);if(i[a>>2]){zs(i[a+16>>2],i[a>>2],Yt(a))}}function _O(a){MCa(a,i[a+4>>2]);if(i[a>>2]){ln(i[a+16>>2],i[a>>2],tn(a))}}function ZI(a){Ula(a,i[a+4>>2]);if(i[a>>2]){xe(i[a+16>>2],i[a>>2],Wf(a))}}function XP(a){pFa(a,i[a+4>>2]);if(i[a>>2]){Yi(i[a+16>>2],i[a>>2],Wf(a))}}function XM(a){vxa(a,i[a+4>>2]);if(i[a>>2]){dh(i[a+16>>2],i[a>>2],Rn(a))}}function Wv(a,b){a=a|0;b=b|0;$a[b|0](i[i[a>>2]+ -12>>2]+a|0)|0;return a|0}function Wr(a){Qqa(a,i[a+4>>2]);if(i[a>>2]){dh(i[a+16>>2],i[a>>2],Rn(a))}}function WW(a,b,c){a=a|0;b=b|0;c=c|0;a=$a[a|0](b,c)|0;ca(_a|0);return a|0}function WH(a){_ha(a,i[a+4>>2]);if(i[a>>2]){xe(i[a+16>>2],i[a>>2],Wf(a))}}function Vs(a){HHa(a,i[a+4>>2]);if(i[a>>2]){wi(i[a+16>>2],i[a>>2],mu(a))}}function UQ(a){SHa(a,i[a+4>>2]);if(i[a>>2]){Df(i[a+16>>2],i[a>>2],ol(a))}}function Sna(a){_e(a);if(i[a>>2]){Rma(a,i[a>>2]);xe(fb(a),i[a>>2],gd(a))}}function Qj(a,b){var c=0;c=i[b+4>>2];i[a>>2]=i[b>>2];i[a+4>>2]=c;return a}function O3(a,b,c){a=a|0;b=b|0;c=c|0;return $a[i[i[a>>2]+32>>2]](a,b,c)|0}function Nj(a){cqa(a,i[a+4>>2]);if(i[a>>2]){xe(i[a+16>>2],i[a>>2],Wf(a))}}function NT(a,b){var c=0;c=Xa-16|0;Xa=c;Dt(c+8|0,b);Bt(a,c+8|0);Xa=c+16|0}function Mga(a,b){a=a|0;b=b|0;a=i[a+20>>2]+24|0;g[a|0]=j[a|0]&253|(b?2:0)}function LN(a){Hza(a,i[a+4>>2]);if(i[a>>2]){Yi(i[a+16>>2],i[a>>2],Wf(a))}}function LI(a){Fka(a,i[a+4>>2]);if(i[a>>2]){Df(i[a+16>>2],i[a>>2],ol(a))}}function KM(a){Ewa(a,i[a+4>>2]);if(i[a>>2]){Yi(i[a+16>>2],i[a>>2],Wf(a))}}function Ic(a,b,c,d,e){g[a+3|0]=e;g[a+2|0]=d;g[a+1|0]=c;g[a|0]=b;return a}function FO(a,b){g[a+6|0]=255;i[a+16>>2]=b;h[a+4>>1]=0;i[a>>2]=0;return a}function ER(a){MJa(a,i[a+4>>2]);if(i[a>>2]){Df(i[a+16>>2],i[a>>2],ol(a))}}function AS(a){CLa(a,i[a+4>>2]);if(i[a>>2]){ln(i[a+16>>2],i[a>>2],tn(a))}}function AN(a){Vya(a,i[a+4>>2]);if(i[a>>2]){Df(i[a+16>>2],i[a>>2],ol(a))}}function zc(a){if(-32768<=(a|0)){return 32767<(a|0)?32767:a}return-32768}function uz(a){qh(a);if(i[a>>2]){OIa(a,i[a>>2]);Df(fb(a),i[a>>2],Be(a))}}function uh(a){AT(a,i[a+4>>2]);if(i[a>>2]){yt(i[a+16>>2],i[a>>2],Wf(a))}}function tA(a){TT(a,i[a+4>>2]);if(i[a>>2]){un(i[a+16>>2],i[a>>2],tn(a))}}function sQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=c,e=jQ(a,b),i[d>>2]=e}function rGa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=c,e=jQ(a,b),g[d|0]=e}function qE(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;og(a,-1,-1)}function lW(a){var b=0;b=Xa-16|0;Xa=b;i[b+8>>2]=53;sW(a,b+8|0);Xa=b+16|0}function kz(a){qh(a);if(i[a>>2]){ZHa(a,i[a>>2]);Df(fb(a),i[a>>2],Be(a))}}function k0(a,b,c,d,e){b=Bh(b,c,d,e,4);if(!(j[d|0]&4)){i[a>>2]=b+ -1900}}function iw(a){_e(a);if(i[a>>2]){hga(a,i[a>>2]);xe(fb(a),i[a>>2],gd(a))}}function iE(a,b){b=!i[a+24>>2]|b;i[a+16>>2]=b;if(b&i[a+20>>2]){v3();x()}}function hl(a){Al(a);if(i[a>>2]){iBa(a,i[a>>2]);zs(fb(a),i[a>>2],Yg(a))}}function eC(a){GY(a,i[a+4>>2]);if(i[a>>2]){hC(i[a+16>>2],i[a>>2],Wf(a))}}function Tp(a){lV(a,i[a+4>>2]);if(i[a>>2]){Xg(i[a+16>>2],i[a>>2],Yt(a))}}function RF(a){k8(a,i[a+4>>2]);if(i[a>>2]){wi(i[a+16>>2],i[a>>2],mu(a))}}function Ql(a){UW(a,i[a+4>>2]);if(i[a>>2]){Uf(i[a+16>>2],i[a>>2],Qz(a))}}function Py(a,b){var c=0;c=Xa-16|0;Xa=c;Ob(a,i[b>>2],qb(b)<<2);Xa=c+16|0}function PF(a){f8(a,i[a+4>>2]);if(i[a>>2]){uo(i[a+16>>2],i[a>>2],ol(a))}}function Nw(a){_e(a);if(i[a>>2]){Wla(a,i[a>>2]);xe(fb(a),i[a>>2],gd(a))}}function Np(a){sU(a,i[a+4>>2]);if(i[a>>2]){xe(i[a+16>>2],i[a>>2],Wf(a))}}function NS(a,b){return(j[a|0]|j[a+1|0]<<8)>>>0<(j[b|0]|j[b+1|0]<<8)>>>0}function Ly(a){qh(a);if(i[a>>2]){ZDa(a,i[a>>2]);Df(fb(a),i[a>>2],Be(a))}}function IJ(a){_e(a);if(i[a>>2]){Kma(a,i[a>>2]);xe(fb(a),i[a>>2],gd(a))}}function HB(a){OW(a,i[a+4>>2]);if(i[a>>2]){wi(i[a+16>>2],i[a>>2],mu(a))}}function GN(a){DN(a);if(i[a>>2]){Uya(a,i[a>>2]);dy(fb(a),i[a>>2],Tm(a))}}function Fp(a){VT(a,i[a+4>>2]);if(i[a>>2]){Uf(i[a+16>>2],i[a>>2],Qz(a))}}function D0(a,b,c,d,e){b=Ch(b,c,d,e,4);if(!(j[d|0]&4)){i[a>>2]=b+ -1900}}function Cz(a){qh(a);if(i[a>>2]){UJa(a,i[a>>2]);Df(fb(a),i[a>>2],Be(a))}}function Bq(a){Q2(a,i[a+4>>2]);if(i[a>>2]){dh(i[a+16>>2],i[a>>2],Rn(a))}}function BS(a,b){var c=0;c=Xa-16|0;Xa=c;Ob(a,i[b>>2],Wb(b)<<1);Xa=c+16|0}function wC(a){h[a+12>>1]=0;i[a+8>>2]=-1;i[a>>2]=0;i[a+4>>2]=0;return a}function vv(a){return((lg(a)+(lg(a)<<8)|0)+(lg(a)<<16)|0)+(lg(a)<<24)|0}function vF(a){a=a|0;return+(+l[i[a+32>>2]+480240>>2]*152587890625e-16)}function nP(a){pk(a);if(i[a>>2]){$O(a,i[a>>2]);ln(fb(a),i[a>>2],zf(a))}}function lO(a){Vp(a);if(i[a>>2]){fO(a,i[a>>2]);Vt(fb(a),i[a>>2],ti(a))}}function jg(a,b,c){return(c|0)>=0?(k[i[a+8>>2]+((c&255)<<1)>>1]&b)!=0:0}function jP(a){_e(a);if(i[a>>2]){eP(a,i[a>>2]);Yi(fb(a),i[a>>2],gd(a))}}function ik(a){pk(a);if(i[a>>2]){CS(a,i[a>>2]);ln(fb(a),i[a>>2],zf(a))}}function gi(a){_e(a);if(i[a>>2]){YP(a,i[a>>2]);Yi(fb(a),i[a>>2],gd(a))}}function dx(a,b){a=a|0;b=b|0;i[a+1074368>>2]=b;dJ(a+1074328|0,b);Ona(a)}function bN(a){Hi(a);if(i[a>>2]){YM(a,i[a>>2]);dh(fb(a),i[a>>2],Rf(a))}}function Zb(a,b){var c=0,d=0;i[a>>2]=b;c=a,d=le(b),i[c+4>>2]=d;return a}function Xoa(a,b,c){a=a|0;b=b|0;c=c|0;Toa(a,b);i[a+112>>2]=0;return a|0}function Xm(a){IP(a);if(i[a>>2]){FP(a,i[a>>2]);EP(fb(a),i[a>>2],jl(a))}}function QL(a,b){i[a+4>>2]=0;i[a+8>>2]=0;i[a>>2]=b?b:49716;i[a+12>>2]=0}function Ok(a){Hi(a);if(i[a>>2]){B2(a,i[a>>2]);dh(fb(a),i[a>>2],Rf(a))}}function NZ(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return MZ(c,d,e)|0}function KO(a){i[a+8>>2]=0;i[a>>2]=0;i[a+4>>2]=40;h[a+12>>1]=0;return a}function KA(a){_e(a);if(i[a>>2]){tU(a,i[a>>2]);xe(fb(a),i[a>>2],gd(a))}}function HZ(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return GZ(c,d,e)|0}function Gu(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;i[e>>2]=c;return 3}function GL(a){if(a>>>0<=8){return j[a+20080|0]}return j[a+20071|0]|256}function DA(a){pk(a);if(i[a>>2]){ZT(a,i[a>>2]);un(fb(a),i[a>>2],zf(a))}}function xDa(a){var b=0;b=Xa-16|0;Xa=b;jDa(a,b+8|0);Xa=b+16|0;return a}function tx(a,b,c){a:{if(a<b){break a}b=c;if(a>b){break a}b=a}return b}function sja(a){var b=0;b=Xa-16|0;Xa=b;pja(a,b+8|0);Xa=b+16|0;return a}function qu(a,b,c){if(!(i[a+28>>2]==1|i[a+4>>2]!=(b|0))){i[a+28>>2]=c}}function npa(a){var b=0;b=Xa-16|0;Xa=b;bpa(a,b+8|0);Xa=b+16|0;return a}function ipa(a){var b=0;b=Xa-16|0;Xa=b;Hoa(a,b+8|0);Xa=b+16|0;return a}function iD(a,b,c){var d=0;d=Xa-16|0;Xa=d;dY(a,b,c);Xa=d+16|0;return a}function hc(a,b){if(qb(a)>>>0<=b>>>0){SB();x()}return i[a>>2]+(b<<2)|0}function gGa(a){var b=0;b=Xa-16|0;Xa=b;VFa(a,b+8|0);Xa=b+16|0;return a}function cd(a){var b=0;b=Xa-16|0;Xa=b;a=QX(vu(b,a));Xa=b+16|0;return a}function c4(a){a=a|0;i[a+16>>2]=i[a+16>>2]|1;if(g[a+20|0]&1){na();x()}}function bua(a){var b=0;b=Xa-16|0;Xa=b;_ta(a,b+8|0);Xa=b+16|0;return a}function _la(a){var b=0;b=Xa-16|0;Xa=b;Yla(a,b+8|0);Xa=b+16|0;return a}function T8(a,b){a=a|0;b=b|0;var c=0;c=Xa-16|0;Xa=c;ska(a,b);Xa=c+16|0}function Q8(a,b){a=a|0;b=b|0;var c=0;c=Xa-16|0;Xa=c;iia(a,b);Xa=c+16|0}function O8(a,b){a=a|0;b=b|0;var c=0;c=Xa-16|0;Xa=c;Tha(a,b);Xa=c+16|0}function NJ(a,b){var c=0;c=i[a>>2];i[a>>2]=b;if(c){if(c){$e(c);Cb(c)}}}function MA(a){i[a>>2]=0;i[a+4>>2]=0;i[a+8>>2]=0;i[a+12>>2]=0;return a}function LR(a,b){yj(a,jb(i[b>>2]),nb(b));a=i[a+4>>2];_a=a>>31;return a}function Jw(a,b){n[a>>3]=n[b>>3]+n[a>>3];n[a+8>>3]=n[b+8>>3]+n[a+8>>3]}function HGa(a){op(a);i[a>>2]=76456;ni(a+4|0);g[a+20|0]=0;i[a+16>>2]=0}function Fm(a,b,c){a:{if(a<b){break a}b=c;if(a>b){break a}b=a}return b}function yG(a,b){var c=0;c=i[a>>2];i[a>>2]=b;if(c){if(c){Cb(Una(c))}}}function xra(a,b){if(i[a+4>>2]!=i[fb(a)>>2]){rra(a,b);return}qra(a,b)}function rW(a,b){a=a|0;b=b|0;var c=0;c=Xa-16|0;Xa=c;BB(a,b);Xa=c+16|0}function pN(a){a=a+34|0;a=XMa(j[a|0]|j[a+1|0]<<8,0,80,0);return a}



function ju(a){a:{if(l[a+4>>2]<l[fb(a)>>2]){aW(a);break a}_V(a)}wg(a)}function iQ(a,b){var c=0;c=i[a>>2];i[a>>2]=b;if(c){if(c){Cb(EFa(c))}}}function dr(a,b){a=a|0;b=b|0;var c=0;c=Xa-16|0;Xa=c;kO(a,b);Xa=c+16|0}function ZK(a){if(357913941<a>>>0){ic(20256);x()}return Yb(o(a,12),4)}function ZFa(a,b){if(!ZEa(a,b)){a=Xa-16|0;Xa=a;yb(b,0,128);Xa=a+16|0}}function Yr(a){var b=0;b=Xa-16|0;Xa=b;Xqa(a,b+8|0);Xa=b+16|0;return a}function Yja(a,b,c){b=b-a|0;if(b){yi(c,a,b)}return o((b|0)/6|0,6)+c|0}function XJa(a,b){if(!VJa(a,b)){a=Xa-16|0;Xa=a;yb(b,0,136);Xa=a+16|0}}function RDa(a,b){i[a>>2]=i[b>>2];h[a+4>>1]=k[b+4>>1];zl(a+8|0,b+8|0)}function RB(a){return(i[a>>2]&-256)==1126902528&i[a+4>>2]==1129074247}function OJ(a,b){var c=0;c=i[a>>2];i[a>>2]=b;if(c){if(c){Cb(jga(c))}}}function Kna(a,b){var c=0;c=Xa-16|0;Xa=c;Nma(a,$g(c+8|0,b));Xa=c+16|0}function $h(a,b){return(i[a+4>>2]-i[b+4>>2]|0)+(i[a>>2]-i[b>>2]<<3)|0}function wla(a,b){var c=0;c=Xa-16|0;Xa=c;it(c,1,b);oc(a,c);Xa=c+16|0}function qoa(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;noa(b,i[d>>2])}function oI(a){if(82595524<a>>>0){ic(32319);x()}return Yb(o(a,52),4)}function oB(a,b){var c=0;c=i[a>>2];i[a>>2]=b;if(c){if(c){Cb(VA(c))}}}function iy(a,b){Gb(a,b);Gb(a+4|0,b+4|0);Gb(fb(a),fb(b));fb(a);fb(b)}function ioa(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;goa(b,i[d>>2])}function ZW(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return $a[a|0](b,c,d)|0}function YA(a,b){if(134217727<b>>>0){ic(11120);x()}return Yb(b<<5,4)}function TP(a){if(715827882<a>>>0){ic(14480);x()}return Yb(o(a,6),1)}function SF(a,b,c){a=a|0;b=b|0;c=c|0;i[b>>2]=i[c>>2];Lc(b+4|0,c+4|0)}function Nma(a,b){var c=0;c=Xa-16|0;Xa=c;gB(a,$g(c+8|0,b));Xa=c+16|0}function Lx(a,b){mn(a);Oc(a+12|0);h[a+28>>1]=0;i[a+24>>2]=b;return a}function Kba(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;Jba(b,i[d>>2])}function Hn(a,b,c,d,e){b=xa(a|0,b|0,c|0,d|0,e|0)|0;_a=A()|0;return b}function HCa(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;GCa(b,i[d>>2])}function Fk(a,b){return b?a<<8&16711680|a<<24|(a>>>8&65280|a>>>24):a}function D4(a,b){a=a|0;b=b|0;if(!i[114610]){i[114611]=b;i[114610]=a}}function A_(a){a=a|0;var b=0;b=i[115449]+1|0;i[115449]=b;i[a+4>>2]=b}function sBa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return rBa(a,b,c,d)|0}function qV(a,b,c){a=a|0;b=b|0;c=c|0;op(a);i[a>>2]=77208;return a|0}function qL(a){if(i[a>>2]){Gra(a,i[a>>2]);fb(a);Fra(i[a>>2],xh(a))}}function hd(a,b,c){if(a>>>0>=b>>>0){return a>>>0>c>>>0?c:a}return b}function hCa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return ZBa(a,b,c,d)|0}function gT(a){if(2147483647<a>>>0){ic(11932);x()}return Yb(a<<1,2)}function gQ(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;IFa(b,i[d>>2])}function gA(a){if(1073741823<a>>>0){ic(11804);x()}return Yb(a<<2,2)}function cT(a,b){if(!TLa(a,b)){a=Xa-16|0;Xa=a;yb(b,0,37);Xa=a+16|0}}function bu(a,b){var c=0;c=Xa-16|0;Xa=c;QV(a,$g(c+8|0,b));Xa=c+16|0}function bI(a){if(1073741823<a>>>0){ic(32446);x()}return Yb(a<<2,4)}function QQ(a){_a=0;a=a+47|0;a=(j[a|0]|j[a+1|0]<<8)+ -98|0;return a}function Pn(a,b,c){a=a|0;b=b|0;c=c|0;ye(a,b);ye(a+4|0,c);return a|0}function Om(a){var b=0;b=i[a+20>>2];if(b){Cb(b+ -64|0)}i[a+20>>2]=0}function NN(a){if(1073741823<a>>>0){ic(16695);x()}return Yb(a<<2,1)}function MJ(a,b,c,d){i[a+12>>2]=0;i[a+8>>2]=d;i[a+4>>2]=c;i[a>>2]=b}function KB(a,b,c,d,e,f,g){return wa(a|0,b|0,c|0,d|0,e|0,f|0,g|0)|0}function Iy(a){a=a|0;i[a>>2]=76400;ug(a+28|0);ug(a+12|0);return a|0}function I5(a){a=a|0;var b=0;b=i[a+100>>2];i[a+100>>2]=0;return b|0}function EFa(a){eQ(a+52|0);eb(a+40|0);uf(a+16|0);uf(a+4|0);return a}function Cx(a){if(i[a>>2]){Nra(a,i[a>>2]);fb(a);Mra(i[a>>2],ti(a))}}function Ak(a){if(1073741823<a>>>0){ic(68232);x()}return Yb(a<<2,4)}function $Da(a,b){if(l[a+4>>2]<l[fb(a)>>2]){zP(a,b);return}_Da(a,b)}function yS(a){if(268435455<a>>>0){ic(12065);x()}return Yb(a<<4,4)}function rD(a,b,c){a=a|0;b=b|0;c=c|0;return Qn(0,a,b,c?c:461600)|0}function oK(a,b){i[a+876>>2]=i[a+876>>2]+b;g[a+872|0]=j[a+872|0]|8}function m_(a,b,c){a=a|0;b=b|0;c=c|0;return(b>>>0<128?b:c)<<24>>24}function lC(a,b,c){a=a|0;b=b|0;c=c|0;ls(a);g[a+128|0]=0;return a|0}function kR(a){if(i[a>>2]){SIa(a,i[a>>2]);bt(fb(a),i[a>>2],hi(a))}}function im(a,b,c){return i[i[a>>2]+(b<<2)>>2]+(i[a+12>>2]+c<<1)|0}function dX(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return pca(a,b,c,d)|0}function YK(a){if(1073741823<a>>>0){ic(1447);x()}return Yb(a<<2,4)}function XIa(a){a=a|0;return i[a+16>>2]+(i[a+8>>2]-i[a+20>>2]|0)|0}function VL(a){if(134217727<a>>>0){ic(18632);x()}return Yb(a<<5,4)}function TF(a){if(268435455<a>>>0){ic(39453);x()}return Yb(a<<4,4)}function RO(a){if(i[a>>2]){UBa(a,i[a>>2]);Yi(fb(a),i[a>>2],gd(a))}}function RM(a,b){by(a,b);g[a+16|0]=j[b+16|0];i[a+12>>2]=i[b+12>>2]}function Qm(a,b,c){return i[i[a>>2]+(b<<2)>>2]+(i[a+12>>2]+c<<2)|0}function Qe(a,b,c){a=a|0;b=b|0;c=c|0;return uc(a,o(Hj(a),b)+c|0)|0}function PO(a){if(i[a>>2]){OBa(a,i[a>>2]);Xo(fb(a),i[a>>2],Wo(a))}}function Ej(a){var b=0;b=i[a>>2];i[a>>2]=0;if(b){if(b){Cb(We(b))}}}function Eb(a,b,c){if((a|0)>=(b|0)){return(a|0)>(c|0)?c:a}return b}function $J(a){if(134217727<a>>>0){ic(20368);x()}return Yb(a<<5,8)}function vJ(a,b){var c=0,d=0;c=a,d=F5(b),i[c>>2]=d;xo(a);return a}function tLa(a,b){a=a|0;b=b|0;a=NKa(a,b);if(!a){MKa(b)}return a|0}function ssa(a,b){a=a|0;b=b|0;a=isa(a,b);if(!a){hsa(b)}return a|0}function sF(a){a=a|0;return+(+i[i[a+32>>2]+1074444>>2]*.00390625)}function nB(a){if(i[a>>2]){hV(a,i[a>>2]);Vt(fb(a),i[a>>2],ti(a))}}function mo(a){a=a|0;return((a+ -65&255)>>>0<26?a+32|0:a)<<24>>24}function mJa(a,b){a=a|0;b=b|0;a=AIa(a,b);if(!a){zIa(b)}return a|0}function jIa(a,b){a=a|0;b=b|0;a=PHa(a,b);if(!a){OHa(b)}return a|0}function iJa(a,b){a=a|0;b=b|0;a=yIa(a,b);if(!a){xIa(b)}return a|0}function ah(a,b){var c=0,d=0;c=a,d=Ru(i[b>>2]),i[c>>2]=d;return a}function Vu(a,b){a=a|0;b=b|0;return(Hg(a)|0)!=0|(a|32)+ -97>>>0<6}function Vi(a){a=i[a+656>>2];if(!a){return 0}return i[a+44>>2]!=0}function TU(a){a=a|0;a=i[a+4>>2];return $a[i[i[a>>2]+12>>2]](a)|0}function TAa(a,b){a=a|0;b=b|0;a=xAa(a,b);if(!a){wAa(b)}return a|0}function SU(a){a=a|0;a=i[a+4>>2];return $a[i[i[a>>2]+16>>2]](a)|0}function RN(a){if(i[a>>2]){MN(a,i[a>>2]);Yi(fb(a),i[a>>2],gd(a))}}function QS(a){if(i[a>>2]){xS(a,i[a>>2]);wi(fb(a),i[a>>2],xh(a))}}function IA(a){if(i[a>>2]){uU(a,i[a>>2]);dh(fb(a),i[a>>2],Rf(a))}}function FEa(a,b){a=a|0;b=b|0;a=MDa(a,b);if(!a){LDa(b)}return a|0}function Dv(a){a=j[a+1|0];return(a&6)==6?384:1152>>>((a&14)==2)|0}function DG(a){if(i[a>>2]){p8(a,i[a>>2]);wi(fb(a),i[a>>2],xh(a))}}function CA(a){if(i[a>>2]){_T(a,i[a>>2]);Uf(fb(a),i[a>>2],xf(a))}}function A0(a,b){if(l[a+4>>2]<l[fb(a)>>2]){e0(a,b);return}_$(a,b)}function zLa(a,b){var c=0;c=Xa-16|0;Xa=c;mv(a,b,c+8|0);Xa=c+16|0}function ys(a,b){a=a|0;b=b|0;a=zAa(a,b);if(!a){yAa(b)}return a|0}function xL(a,b){b=1/(564505.8718779281/b+1);uL(a,b,0,0,b+ -1,0)}function uA(a){if(4294967295<a>>>0){ic(11736);x()}return Yb(a,1)}function rw(a){a=a|0;i[a>>2]=79416;uf(a+4208|0);ve(a);return a|0}function raa(a,b,c){a=a|0;b=b|0;c=c|0;return Y6(ll(a),ll(b),c)|0}function nsa(a,b){a=a|0;b=b|0;BL(a,i[b>>2],i[b+4>>2]);return a|0}function mr(a){a=a|0;i[a>>2]=80288;uf(a+4260|0);ve(a);return a|0}function kw(a){a=a|0;i[a>>2]=79620;ug(a+4208|0);ve(a);return a|0}function jb(a){a=a|0;var b=0;b=Xa-16|0;Xa=b;Xa=b+16|0;return a|0}function gw(a){a=a|0;i[a>>2]=80520;uf(a+4256|0);ve(a);return a|0}function ew(a){a=a|0;i[a>>2]=80928;uf(a+4208|0);ve(a);return a|0}function cI(a,b){var c=0;c=Xa-16|0;Xa=c;Jia(a,Hb(c,b));Xa=c+16|0}function Zda(a,b){a=a|0;b=b|0;if(!b){return 3}i[b>>2]=a;return 0}function Xx(a,b){var c=0;c=i[a>>2];i[a>>2]=b;if(c){if(c){Cb(c)}}}function UU(a){a=a|0;a=i[a+4>>2];return $a[i[i[a>>2]+8>>2]](a)|0}function LY(a){a=a|0;var b=0,c=0;b=a,c=Ud(),i[b>>2]=c;return a|0}function JQ(a){a=a|0;a=j[a|0];return Jd(a)^1|(a+ -49&255)>>>0<36}function Ir(a){eb(a+48|0);eb(a+36|0);eb(a+24|0);eb(a+12|0);eb(a)}function Em(a){var b=0;b=Xa-16|0;Xa=b;Xa=b+16|0;return a<<24>>24}function DDa(a,b){a=a|0;b=b|0;a=vP(a,b);if(!a){UCa(b)}return a|0}function uf(a){_e(a);if(i[a>>2]){dQ(a);xe(fb(a),i[a>>2],gd(a))}}function ss(a,b){a=a|0;b=b|0;a=Mza(a,b);if(!a){QN(b)}return a|0}function sX(a){a=a|0;if(!a){return 0}return(NB(a,72024)|0)!=0|0}function rr(a){_e(a);if(i[a>>2]){MH(a);xe(fb(a),i[a>>2],gd(a))}}function rS(a){if(4294967295<a>>>0){ic(1161);x()}return Yb(a,1)}function qr(a){JH(a);if(i[a>>2]){PH(a);IH(fb(a),i[a>>2],Fj(a))}}function qk(a,b){a=a|0;b=b|0;return $a[i[i[a>>2]+28>>2]](a,b)|0}function pL(a){Hi(a);if(i[a>>2]){gL(a);dh(fb(a),i[a>>2],Rf(a))}}function oS(a,b){a=a|0;b=b|0;a=HKa(a,b);if(!a){dS(b)}return a|0}function nH(a){a=a|0;return p(p(p(m[a+4228>>2]*p(198))+p(-99)))}function ir(a,b){a=a|0;b=b|0;t3(a,b);i[a+72>>2]=0;i[a+76>>2]=-1}function hj(a){a=a|0;a=i[a>>2];return $a[i[i[a>>2]+24>>2]](a)|0}function gl(a){qh(a);if(i[a>>2]){BN(a);Df(fb(a),i[a>>2],Be(a))}}function fx(a){dR(a);if(i[a>>2]){tR(a);cR(fb(a),i[a>>2],nl(a))}}function ex(a){yJ(a);if(i[a>>2]){xJ(a);Xw(fb(a),i[a>>2],Mi(a))}}function es(a){Al(a);if(i[a>>2]){_L(a);Xg(fb(a),i[a>>2],Yg(a))}}function eT(a){if(!Xc(a,12035,25)){return j[a+34|0]<65}return 0}function bx(a){Al(a);if(i[a>>2]){pB(a);Xg(fb(a),i[a>>2],Yg(a))}}function bX(a,b){a=a|0;b=b|0;a=$a[a|0](b)|0;ca(_a|0);return a|0}function an(a,b){a=a|0;b=b|0;a=iFa(a,b);if(!a){WP(b)}return a|0}function aT(a,b){a=a|0;b=b|0;a=QLa(a,b);if(!a){KS(b)}return a|0}function Xs(a,b){a=a|0;b=b|0;a=rIa(a,b);if(!a){_Q(b)}return a|0}function XO(a,b,c,d){He(a,b);h[a+18>>1]=d;h[a+16>>1]=c;return a}function Wk(a){qh(a);if(i[a>>2]){NI(a);Df(fb(a),i[a>>2],Be(a))}}function Vd(a,b,c,d){i[a+8>>2]=d;i[a+4>>2]=c;i[a>>2]=b;return a}function Um(a){_e(a);if(i[a>>2]){BP(a);yt(fb(a),i[a>>2],gd(a))}}function Rz(a,b){a=a|0;b=b|0;a=OKa(a,b);if(!a){hS(b)}return a|0}function PR(a){pk(a);if(i[a>>2]){JR(a);ln(fb(a),i[a>>2],zf(a))}}function Oz(a,b){a=a|0;b=b|0;a=QKa(a,b);if(!a){iS(b)}return a|0}function OM(a){_e(a);if(i[a>>2]){NM(a);Yi(fb(a),i[a>>2],gd(a))}}function Nu(a,b){a=a|0;b=b|0;return $a[i[i[a>>2]+12>>2]](a,b)|0}function JK(a){qh(a);if(i[a>>2]){eK(a);uo(fb(a),i[a>>2],Be(a))}}function Ii(a){if(4294967295<a>>>0){ic(1093);x()}return Yb(a,1)}function Ed(a){var b=0;b=In(le(a)+1|0,1);if(b){X4(b,a)}return b}function Aq(a,b){a=a|0;b=b|0;return $a[i[i[a>>2]+44>>2]](a,b)|0}function $y(a,b){a=(a+b|0)+ -1|0;return a-((a>>>0)%(b>>>0)|0)|0}function $i(a,b,c){a=a|0;b=b|0;c=c|0;return fz(ll(a),ll(b),c)|0}function wh(a){a=a|0;vV(a);i[a+8>>2]=0;i[a+12>>2]=0;return a|0}function rB(a,b){a=a|0;b=b|0;a=BV(a,b);if(!a){fB(b)}return a|0}function qB(a,b){a=a|0;b=b|0;a=AV(a,b);if(!a){dB(b)}return a|0}function py(a,b){var c=0;c=Xa-16|0;Xa=c;Ob(a,b,1024);Xa=c+16|0}function oc(a,b){a=a|0;b=b|0;yla(a,j[b+8|0],i[b>>2],i[b+4>>2])}function oM(a){var b=0;b=i[a>>2];i[a>>2]=0;if(b){Pta(Pb(a),b)}}function lp(a,b){a=a|0;b=b|0;a=Rp(a,b);if(!a){aR(b)}return a|0}function gu(a,b){a=a|0;b=b|0;a=jV(a,b);if(!a){iV(b)}return a|0}function gr(a){a=a|0;i[a>>2]=76848;eb(a+32|0);Kk(a);return a|0}function ff(a,b){return $a[i[i[a>>2]+36>>2]](a,i[a+12>>2],b)|0}function fQ(a){var b=0;b=i[a>>2];i[a>>2]=0;if(b){GFa(Pb(a),b)}}function aL(a){var b=0;b=i[a>>2];i[a>>2]=0;if(b){Rqa(Pb(a),b)}}function _J(a){var b=0;b=i[a>>2];i[a>>2]=0;if(b){moa(Pb(a),b)}}function ZR(a,b){var c=0;c=Xa-16|0;Xa=c;Ob(a,b,1954);Xa=c+16|0}function ZO(a){var b=0;b=i[a>>2];i[a>>2]=0;if(b){FCa(Pb(a),b)}}function YJ(a){var b=0;b=i[a>>2];i[a>>2]=0;if(b){foa(Pb(a),b)}}function Waa(a,b,c){a=a|0;b=b|0;c=c|0;HJ(a,0,Vy(i[b+24>>2]),c)}function WI(a){var b=0;b=i[a>>2];i[a>>2]=0;if(b){Ola(Pb(a),b)}}function Se(a,b){a=a|0;b=b|0;a=Ut(a,b);if(!a){TA(b)}return a|0}function S$(a,b,c){a=a|0;b=b|0;c=c|0;Ac(a,cE(i[b>>2]),i[b>>2])}function RHa(a,b){if(!Bf(a,b)){a=Xa-16|0;Xa=a;Ne(b);Xa=a+16|0}}function Qt(a,b){a=a|0;b=b|0;a=vU(a,b);if(!a){HA(b)}return a|0}function Oy(a,b){var c=0;c=Xa-16|0;Xa=c;Ob(a,b,4896);Xa=c+16|0}function Op(a){a=a|0;a=i[a>>2];return $a[i[i[a>>2]+8>>2]](a)|0}function Mna(a,b){a=a|0;b=b|0;yu(a,b);i[a>>2]=71468;return a|0}function Hp(a,b){var c=0;c=b+1|0;i[a>>2]=(c|0)<i[a>>2]?c:b+2|0}function BG(a,b,c,d){h[a+4>>1]=c;g[a+6|0]=b;i[a>>2]=d;return a}function $H(a){var b=0;b=i[a>>2];i[a>>2]=0;if(b){yia(Pb(a),b)}}function yR(a,b){var c=0;c=Xa-16|0;Xa=c;Ob(a,b,610);Xa=c+16|0}function w8(a){a=a|0;var b=0;b=Xa-16|0;Xa=b;WF(a,1);Xa=b+16|0}function td(a,b){i[a>>2]=i[b>>2];i[a+4>>2]=i[b+4>>2];return a}function tO(a,b){var c=0;c=Xa-16|0;Xa=c;Ob(a,b,130);Xa=c+16|0}function t6(a,b){a=a|0;b=b|0;yu(a,b);i[a>>2]=71524;return a|0}function rO(a,b){var c=0;c=Xa-16|0;Xa=c;Ob(a,b,600);Xa=c+16|0}function rN(a,b){var c=0;c=Xa-16|0;Xa=c;Ob(a,b,146);Xa=c+16|0}function rDa(a,b,c){a=a|0;b=b|0;c=c|0;Lc(a,aC(c,xb(b),lb(b)))}function r8(a){a=a|0;var b=0;b=Xa-16|0;Xa=b;zN(a,1);Xa=b+16|0}function pV(a){a=a|0;var b=0;b=Xa-16|0;Xa=b;DB(a,1);Xa=b+16|0}function nN(a,b){var c=0;c=Xa-16|0;Xa=c;Ob(a,b,608);Xa=c+16|0}function mt(a,b){var c=0;c=Xa-16|0;Xa=c;Ob(a,b,192);Xa=c+16|0}function jT(a,b){var c=0;c=Xa-16|0;Xa=c;Ob(a,b,497);Xa=c+16|0}function jL(a,b){return i[a>>2]==i[b>>2]&i[a+4>>2]==i[b+4>>2]}function iO(a,b){var c=0;c=Xa-16|0;Xa=c;Ob(a,b,126);Xa=c+16|0}function hta(a,b,c){a=a|0;b=b|0;c=c|0;return Rg(a,b,c,1186)|0}function gta(a,b,c){a=a|0;b=b|0;c=c|0;return Rg(a,b,c,1187)|0}function gX(a,b){a=a|0;b=b|0;yu(a,b);i[a>>2]=71576;return a|0}function eka(a,b,c){a=a|0;b=b|0;c=c|0;return Rg(a,b,c,1578)|0}function bta(a,b,c){a=a|0;b=b|0;c=c|0;return Rg(a,b,c,1192)|0}function au(a){var b=0;b=a;a=i[a>>2]+ -1|0;i[b>>2]=a;return a}function _P(a,b){var c=0;c=Xa-16|0;Xa=c;Ob(a,b,674);Xa=c+16|0}function ZM(a,b){var c=0;c=Xa-16|0;Xa=c;Ob(a,b,204);Xa=c+16|0}function YU(a){a=a|0;var b=0;b=Xa-16|0;Xa=b;WA(a,1);Xa=b+16|0}function Tia(a,b,c){a=a|0;b=b|0;c=c|0;return Rg(a,b,c,1614)|0}function Sia(a,b,c){a=a|0;b=b|0;c=c|0;return Rg(a,b,c,1615)|0}function MP(a,b){var c=0;c=Xa-16|0;Xa=c;Ob(a,b,128);Xa=c+16|0}function Ll(a,b){if(lb(a)>>>0<=b>>>0){Ml();x()}return Sb(a,b)}function LM(a,b){var c=0;c=Xa-16|0;Xa=c;Ob(a,b,263);Xa=c+16|0}function Ko(a,b){a=a|0;b=b|0;if(be(a)>>>0>b>>>0){g[a+16|0]=b}}function KV(a){a=a|0;var b=0;b=Xa-16|0;Xa=b;iB(a,1);Xa=b+16|0}function JB(a,b,c){b=ta(2078,a|0,b|0,c|0)|0;_a=A()|0;return b}function Iq(a,b){b=i[b>>2];i[a>>2]=b;i[a+4>>2]=b>>31;return a}function HQ(a,b){var c=0;c=Xa-16|0;Xa=c;Ob(a,b,157);Xa=c+16|0}function Gz(a,b){var c=0;c=Xa-16|0;Xa=c;Ob(a,b,512);Xa=c+16|0}function CQ(a,b){var c=0;c=Xa-16|0;Xa=c;Ob(a,b,576);Xa=c+16|0}function zL(a,b){var c=0;c=Xa-16|0;Xa=c;Ob(a,b,27);Xa=c+16|0}function yz(a,b){var c=0;c=Xa-16|0;Xa=c;Ob(a,b,64);Xa=c+16|0}function xF(a){a=a|0;return+(65536/+l[i[a+32>>2]+480244>>2])}function vO(a,b){var c=0;c=Xa-16|0;Xa=c;Ob(a,b,30);Xa=c+16|0}function sma(a,b){a=a|0;b=b|0;mma(ld(b),Ye(b),ld(b));Lc(a,b)}function rA(a,b){Ika(j[a+8|0],i[a>>2],i[a+4>>2],xb(b),lb(b))}function ow(a){a=a|0;i[a+32>>2]=0;i[a+28>>2]=i[a+28>>2]&-7|2}function nV(a,b){Lc(a,b);zl(a+12|0,b+12|0);mV(a+28|0,b+28|0)}function mGa(a,b,c){a=a|0;b=b|0;c=c|0;return Rg(a,b,c,712)|0}function lz(a,b){var c=0;c=Xa-16|0;Xa=c;Ob(a,b,12);Xa=c+16|0}function hO(a,b){var c=0;c=Xa-16|0;Xa=c;Ob(a,b,32);Xa=c+16|0}function gS(a,b){var c=0;c=Xa-16|0;Xa=c;Ob(a,b,11);Xa=c+16|0}function fP(a,b){var c=0;c=Xa-16|0;Xa=c;Ob(a,b,52);Xa=c+16|0}function eB(a,b){var c=0;c=Xa-16|0;Xa=c;Ob(a,b,10);Xa=c+16|0}function cB(a,b){var c=0;c=Xa-16|0;Xa=c;Ob(a,b,14);Xa=c+16|0}function _s(a,b){var c=0;c=Xa-16|0;Xa=c;Ob(a,b,66);Xa=c+16|0}function _R(a){var b=0;b=Xa-16|0;Xa=b;yb(a,0,1954);Xa=b+16|0}function Yga(a){a=a|0;a=Ji(a);if(a){$a[i[i[a>>2]+92>>2]](a)}}function VQ(a,b){var c=0;c=Xa-16|0;Xa=c;Ob(a,b,22);Xa=c+16|0}function VP(a,b){var c=0;c=Xa-16|0;Xa=c;Ob(a,b,80);Xa=c+16|0}function SJ(a){a=a|0;var b=0;b=Xa-16|0;Xa=b;Wna(a);Xa=b+16|0}function PN(a,b){var c=0;c=Xa-16|0;Xa=c;Ob(a,b,96);Xa=c+16|0}function PB(a){a=i[a>>2]+ -12|0;if((au(a+8|0)|0)<=-1){Cb(a)}}function NQ(a,b){var c=0;c=Xa-16|0;Xa=c;Ob(a,b,98);Xa=c+16|0}function Mp(a,b){var c=0;c=Xa-16|0;Xa=c;Ob(a,b,36);Xa=c+16|0}function LS(a,b){var c=0;c=Xa-16|0;Xa=c;Ob(a,b,38);Xa=c+16|0}function LQ(a,b){var c=0;c=Xa-16|0;Xa=c;Ob(a,b,48);Xa=c+16|0}function Ky(a,b){var c=0;c=Xa-16|0;Xa=c;Ob(a,b,33);Xa=c+16|0}function Jy(a,b){var c=0;c=Xa-16|0;Xa=c;Ob(a,b,18);Xa=c+16|0}function JS(a,b){var c=0;c=Xa-16|0;Xa=c;Ob(a,b,41);Xa=c+16|0}function JI(a,b){var c=0;c=Xa-16|0;Xa=c;Ob(a,b,24);Xa=c+16|0}function Ina(a,b,c){a=a|0;b=b|0;c=c|0;Mma(a,(b-a|0)/160|0,c)}function IS(a,b){var c=0;c=Xa-16|0;Xa=c;Ob(a,b,16);Xa=c+16|0}function Dy(a,b){var c=0;c=Xa-16|0;Xa=c;Ob(a,b,40);Xa=c+16|0}function Bn(a,b,c){if(!b){return 0}return Pq(a,cg(g[c|0]),b)}function zR(a){var b=0;b=Xa-16|0;Xa=b;yb(a,0,610);Xa=b+16|0}function uO(a){var b=0;b=Xa-16|0;Xa=b;yb(a,0,130);Xa=b+16|0}function sO(a){var b=0;b=Xa-16|0;Xa=b;yb(a,0,600);Xa=b+16|0}function sN(a){var b=0;b=Xa-16|0;Xa=b;yb(a,0,146);Xa=b+16|0}function psa(a,b){a=a|0;b=b|0;ksa(a,Jb(b),Kb(b));return a|0}function ok(a,b){var c=0;c=Xa-16|0;Xa=c;Ob(a,b,2);Xa=c+16|0}function oN(a){var b=0;b=Xa-16|0;Xa=b;yb(a,0,608);Xa=b+16|0}function kT(a){var b=0;b=Xa-16|0;Xa=b;yb(a,0,497);Xa=b+16|0}function jz(a,b){var c=0;c=Xa-16|0;Xa=c;Ob(a,b,6);Xa=c+16|0}function jO(a){var b=0;b=Xa-16|0;Xa=b;yb(a,0,126);Xa=b+16|0}function e_(a,b,c){a=a|0;b=b|0;c=c|0;return((b|0)>-1?b:c)|0}function eX(a,b){a=a|0;b=b|0;a=vca(a,b);ca(_a|0);return a|0}function bd(a){var b=0;b=Xa-16|0;Xa=b;OX(vu(b,a));Xa=b+16|0}function _g(a,b){var c=0;c=Xa-16|0;Xa=c;Ob(a,b,4);Xa=c+16|0}function _M(a){var b=0;b=Xa-16|0;Xa=b;yb(a,0,204);Xa=b+16|0}function ZP(a){var b=0;b=Xa-16|0;Xa=b;yb(a,0,192);Xa=b+16|0}function Xz(a,b){var c=0;c=Xa-16|0;Xa=c;Ob(a,b,3);Xa=c+16|0}function Vaa(a){a=a|0;CG(a,2,100);Ko(i[a+24>>2]+484360|0,0)}function Up(a){var b=0;b=Xa-16|0;Xa=b;i[b+8>>2]=a;Xa=b+16|0}function Tt(a,b){var c=0;c=Xa-16|0;Xa=c;Ob(a,b,8);Xa=c+16|0}function Pp(a,b){var c=0;c=Xa-16|0;Xa=c;Ob(a,b,1);Xa=c+16|0}function Kz(a,b){var c=0;c=Xa-16|0;Xa=c;Ob(a,b,5);Xa=c+16|0}function IQ(a){var b=0;b=Xa-16|0;Xa=b;yb(a,0,157);Xa=b+16|0}function Hz(a,b){var c=0;c=Xa-16|0;Xa=c;Ob(a,b,7);Xa=c+16|0}function DQ(a){var b=0;b=Xa-16|0;Xa=b;yb(a,0,576);Xa=b+16|0}function AI(a,b){if((a|0)!=(b|0)){aka(a,i[b>>2],i[b+4>>2])}}function zu(){var a=0;a=P(4)|0;zk(a);W(a|0,71348,2008);x()}function z9(a){a=a|0;return l[i[a+24>>2]+1074420>>2]/1e4|0}function sf(a,b){a=YMa(i[a>>2],i[a+4>>2],b,b>>31);return a}function r3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;_a=0;return 0}function pm(a,b,c,d){i[a+16>>2]=d;i[a+12>>2]=c;i[a+8>>2]=b}function lb(a){if(oe(a)){return i[a+4>>2]}return j[a+11|0]}function kp(a){if((a|0)>=1){return(a|0)<120?a:120}return 1}function iR(a){var b=0;b=Xa-16|0;Xa=b;yb(a,0,66);Xa=b+16|0}function gP(a){var b=0;b=Xa-16|0;Xa=b;yb(a,0,52);Xa=b+16|0}function aX(a,b,c){a=a|0;b=b|0;c=c|0;return $a[a|0](b,c)|0}function WP(a){var b=0;b=Xa-16|0;Xa=b;yb(a,0,80);Xa=b+16|0}function QN(a){var b=0;b=Xa-16|0;Xa=b;yb(a,0,96);Xa=b+16|0}function OQ(a){var b=0;b=Xa-16|0;Xa=b;yb(a,0,98);Xa=b+16|0}function MS(a){var b=0;b=Xa-16|0;Xa=b;yb(a,0,38);Xa=b+16|0}function MQ(a){var b=0;b=Xa-16|0;Xa=b;yb(a,0,48);Xa=b+16|0}function KS(a){var b=0;b=Xa-16|0;Xa=b;yb(a,0,41);Xa=b+16|0}function HA(a){var b=0;b=Xa-16|0;Xa=b;yb(a,0,36);Xa=b+16|0}function yDa(a,b,c){a=a|0;b=b|0;c=c|0;return kDa(a,b,c)|0}function wDa(a,b,c){a=a|0;b=b|0;c=c|0;return hDa(a,b,c)|0}function vKa(a,b,c){a=a|0;b=b|0;c=c|0;return dKa(a,b,c)|0}function rn(a,b,c){Ac(a,i[b>>2]+(c>>>3&536870908)|0,c&31)}function rf(a,b,c){return i[a>>2]+(o(i[a+4>>2],c)+b<<2)|0}function rLa(a,b,c){a=a|0;b=b|0;c=c|0;return jLa(a,b,c)|0}function qc(a){if(oe(a)){a=Jj(a)+ -1|0}else{a=10}return a}function qLa(a,b,c){a=a|0;b=b|0;c=c|0;return iLa(a,b,c)|0}function pt(a){if(i[a>>2]){GS(a);un(fb(a),i[a>>2],zf(a))}}function pLa(a,b,c){a=a|0;b=b|0;c=c|0;return hLa(a,b,c)|0}function oLa(a,b,c){a=a|0;b=b|0;c=c|0;return gLa(a,b,c)|0}function o9(a){a=a|0;return Ti(Db(i[a+24>>2]+484360|0))|0}function nKa(a,b,c){a=a|0;b=b|0;c=c|0;return bKa(a,b,c)|0}function mMa(a,b,c){a=a|0;b=b|0;c=c|0;return aMa(a,b,c)|0}function mLa(a,b,c){a=a|0;b=b|0;c=c|0;return fLa(a,b,c)|0}function lia(a,b,c){a=a|0;b=b|0;c=c|0;return jia(a,b,c)|0}function lMa(a,b,c){a=a|0;b=b|0;c=c|0;return _La(a,b,c)|0}function kU(a){a=a|0;mB(a,11650);i[a>>2]=77388;return a|0}function js(a){if(i[a>>2]){ZL(a);xe(fb(a),i[a>>2],gd(a))}}function ie(a){if(!i[a+20>>2]){return 0}return i[a>>2]!=0}function iT(a){if(i[a>>2]){VS(a);Uf(fb(a),i[a>>2],xf(a))}}function hba(a,b,c){a=a|0;b=b|0;c=c|0;Lc(a,aC(c,b,le(b)))}function gm(a,b,c){return i[a>>2]+(o(i[a+4>>2],c)+b<<1)|0}function gJa(a,b,c){a=a|0;b=b|0;c=c|0;return ZIa(a,b,c)|0}function eIa(a,b,c){a=a|0;b=b|0;c=c|0;return $Ha(a,b,c)|0}function dea(a){a=a|0;return Fd(i[i[a>>2]+ -12>>2]+a|0)|0}function cva(a,b,c){a=a|0;b=b|0;c=c|0;ypa(a,b);return a|0}function bya(a,b,c){a=a|0;b=b|0;c=c|0;return Qxa(a,b,c)|0}function axa(a,b,c){a=a|0;b=b|0;c=c|0;return Twa(a,b,c)|0}function aw(a,b,c){i[a+28>>2]=c;i[a+20>>2]=b;i[a+24>>2]=b}function Wwa(a,b,c){a=a|0;b=b|0;c=c|0;return Owa(a,b,c)|0}function WE(a){while(1){if((Sq(a)|0)!=-1){continue}break}}function Uga(a,b,c){a=a|0;b=b|0;c=c|0;return Tga(a,b,c)|0}function UV(a){a=a|0;mB(a,11072);i[a>>2]=77044;return a|0}function UGa(a,b,c){a=a|0;b=b|0;c=c|0;return AGa(a,b,c)|0}function Tza(a,b,c){a=a|0;b=b|0;c=c|0;return Oza(a,b,c)|0}function Td(a){if(i[a>>2]){xe(fb(a),i[a>>2],i[fb(a)>>2])}}function SAa(a,b,c){a=a|0;b=b|0;c=c|0;return JAa(a,b,c)|0}function RGa(a,b,c){a=a|0;b=b|0;c=c|0;return yGa(a,b,c)|0}function Qs(a){if(i[a>>2]){aQ(a);bt(fb(a),i[a>>2],hi(a))}}function Pi(a){a=i[a+656>>2];if(!a){return 0}return Xh(a)}function Ld(a,b,c){Ac(a,i[b>>2]+(c>>>3&536870908)|0,1<<c)}function Ip(a){if(i[a>>2]){yA(a);Uf(fb(a),i[a>>2],xf(a))}}function Ig(a,b,c){return i[a>>2]+(o(i[a+4>>2],c)+b<<3)|0}function IC(a){if(i[a>>2]){HC(a);hC(Ck(a),i[a>>2],Bk(a))}}function HJ(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;tna(a,b,c,d)}function FDa(a,b,c){a=a|0;b=b|0;c=c|0;return oDa(a,b,c)|0}function CEa(a,b,c){a=a|0;b=b|0;c=c|0;return rEa(a,b,c)|0}function BDa(a,b,c){a=a|0;b=b|0;c=c|0;return mDa(a,b,c)|0}function Av(a,b){return i[((a>>>24^b)<<2)+457312>>2]^a<<8}function vl(a,b,c){a=YMa(i[a>>2],i[a+4>>2],b,c);return a}function uC(a,b){Fl(i[b>>2]);El(i[a>>2]);i[a>>2]=i[b>>2]}function rQ(a,b,c){a=a|0;b=b|0;c=c|0;return WFa(a,b,c)|0}function pE(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;og(a,-1,-1)}function p6(a,b,c){a=a|0;b=b|0;c=c|0;return Zc(o(b,c))|0}function oC(a){a=a|0;i[a>>2]=62536;eb(a+12|0);return a|0}function nT(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;Ge(a,c,d,b)}function nGa(a,b){a=a|0;b=b|0;Bb(a,b?b:14548);return a|0}function nC(a){a=a|0;i[a>>2]=62576;eb(a+16|0);return a|0}function mE(a){a=a|0;return Fq(i[i[a>>2]+ -12>>2]+a|0)|0}function iq(a){if(oe(a)){a=Jj(a)+ -1|0}else{a=1}return a}function bW(a,b,c){a=a|0;b=b|0;c=c|0;cu(a,b,i[b+8>>2],c)}function bE(a){a=a|0;return Cq(i[i[a>>2]+ -12>>2]+a|0)|0}function afa(a){a=a|0;dH(a);g[a+4202|0]=1;i[a+4224>>2]=0}function _r(a,b,c){a=a|0;b=b|0;c=c|0;return era(a,b,c)|0}function ZS(a,b,c){a=a|0;b=b|0;c=c|0;return bMa(a,b,c)|0}function XF(a){a=a|0;i[a>>2]=83848;Iy(a+12|0);return a|0}function WGa(a,b,c){a=a|0;b=b|0;c=c|0;return Pq(a,b,c)|0}function UF(a){a=a|0;i[a>>2]=83888;Hy(a+12|0);return a|0}function Rq(a){if(!h5(a)){Lb(a,30);return 0}return TE(a)}function QA(a){a=a|0;i[a>>2]=77272;Rt(a+12|0);return a|0}function Oq(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;f4(a,b,c,d)}function LEa(a,b,c){a=a|0;b=b|0;c=c|0;return eS(a,b,c)|0}function Kh(a){return fe(a)|fe(a)<<8|fe(a)<<16|fe(a)<<24}function KEa(a,b,c){a=a|0;b=b|0;c=c|0;return fS(a,b,c)|0}function Is(a){Um(a+88|0);Um(a+68|0);Um(a+48|0);return a}function IB(a,b,c){b=qa(a|0,b|0,c|0)|0;_a=A()|0;return b}function Fz(a){g[a|0]=0;g[a+1|0]=0;g[a+2|0]=0;g[a+3|0]=0}function Ex(a,b){n[a>>3]=n[a>>3]*b;n[a+8>>3]=n[a+8>>3]*b}function EQ(a){a=a|0;if(!j[a|0]){return 1}return Jf(a)|0}function E7(a){a=a|0;return Ve(i[i[a>>2]+ -12>>2]+a|0)|0}function DU(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;cu(a,b,c,d)}function $Ea(a,b){a=a|0;b=b|0;return lI(a,xb(b),lb(b))|0}function yD(a){return(a|0)!=0&(a|0)!=57920&(a|0)!=57944}function xC(a){var b=0;b=i[a>>2];i[a>>2]=0;if(b){El(b)}}function uu(a){a=a|0;i[a>>2]=71368;PB(a+4|0);return a|0}function tpa(a,b){a=a|0;b=b|0;return l[a+12>>2]>b>>>0|0}function qS(a){if(j[a+1|0]==2){return j[a|0]<3}return 0}function pD(a,b,c,d){a=qD(a,b,c,0,-2147483648);return a}function hF(a,b,c){i[a+4>>2]=0;i[a>>2]=b;i[a+8>>2]=c<<3}function gq(a){a=a|0;i[a>>2]=71388;PB(a+4|0);return a|0}function fz(a,b,c){b=b-a|0;if(b){yi(c,a,b)}return b+c|0}function cr(a){a=a|0;i[a>>2]=83720;Vv(a+4|0);return a|0}function aH(a){return p(p(m[a+4208>>2]*p(1e4))+p(-1e4))}function ZC(a,b,c){a=a|0;b=b|0;c=c|0;return W$(a,b,c)|0}function Y$(a,b,c){a=a|0;b=b|0;c=c|0;return X$(a,b,c)|0}function Un(a){a=a|0;i[a>>2]=55792;ub(a+4|0);return a|0}function UC(a,b,c){a=a|0;b=b|0;c=c|0;return N$(a,b,c)|0}function Rt(a){a=a|0;i[a>>2]=77312;hb(a+4|0);return a|0}function Qq(a,b,c){return tE(xb(a),lb(a),xb(b),c,lb(b))}function P$(a,b,c){a=a|0;b=b|0;c=c|0;return O$(a,b,c)|0}function N2(a,b,c){a=a|0;b=b|0;c=c|0;return O2(a,b,c)|0}function Mz(a,b,c){a=a|0;b=b|0;c=c|0;return kS(a,b,c)|0}function Kk(a){a=a|0;i[a>>2]=55728;ub(a+4|0);return a|0}function KN(a,b,c){a=a|0;b=b|0;c=c|0;return qs(a,b,c)|0}function Hy(a){a=a|0;i[a>>2]=76456;ug(a+4|0);return a|0}function G2(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return d|0}function Fc(a,b,c){a=a|0;b=b|0;c=c|0;ye(a,b);return a|0}function Ez(a,b,c){a=a|0;b=b|0;c=c|0;return KR(a,b,c)|0}function $G(a){return p(p(m[a+4252>>2]*p(19980))+p(20))}function u2(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;Uh(a,c,d)}function qO(a){var b=0;b=Xa-16|0;Xa=b;bBa(a);Xa=b+16|0}function lg(a){var b=0;b=Sq(a);i[a+1396>>2]=0;return b}function lH(a){a=a|0;return _h(p(m[a+4224>>2]*p(4)))|0}function gO(a){var b=0;b=Xa-16|0;Xa=b;DAa(a);Xa=b+16|0}function _n(a){return j[a+2|0]&2?(j[a+1|0]&6)==6?4:1:0}function Yb(a,b){if(UE(b)){return wY(a,b)}return te(a)}function WMa(a){if(a){return 31-r(a+ -1^a)|0}return 32}function Pt(a,b){a=XMa(i[a>>2],i[a+4>>2],b,0);return a}function Pf(a,b){a=a|0;b=b|0;$a[i[i[b>>2]+20>>2]](a,b)}function OP(a){var b=0;b=Xa-16|0;Xa=b;_Ea(a);Xa=b+16|0}function M9(a,b){a=a|0;b=b|0;i[i[a+24>>2]+480272>>2]=b}function Lha(a,b,c){a=a|0;b=b|0;c=c|0;ml(a,b+4260|0,8)}function LL(a,b){h[a+20>>1]=k[a+20>>1]&768|b&255;Hx(a)}function Js(a){var b=0,c=0;b=a,c=hP(i[a>>2]),i[b>>2]=c}function Fg(a,b){a=a|0;b=b|0;$a[i[i[b>>2]+24>>2]](a,b)}function Ei(a,b){i[a+16>>2]=!i[a+24>>2]|(i[a+16>>2]|b)}function Eg(a,b){a=a|0;b=b|0;$a[i[i[b>>2]+28>>2]](a,b)}function y6(a,b,c){a=a|0;b=b|0;c=c|0;nF(a+ -88|0,b,c)}function vm(a){a=a|0;return $a[i[i[a>>2]+24>>2]](a)|0}function tW(a,b){a=a|0;b=b|0;i[a>>2]=b;i[a+4>>2]=b+36}function sp(a,b){a=a|0;b=b|0;return ke(a)>>>0>b>>>0|0}function sC(a){var b=0;b=Xa-16|0;Xa=b;iZ(a);Xa=b+16|0}function oO(a,b){a=a|0;b=b|0;i[a>>2]=b;i[a+4>>2]=b+12}function n9(a){a=a|0;return tI(i[a+24>>2]+484344|0)|0}function kKa(a,b,c){a=a|0;b=b|0;c=c|0;CJa(a,b-a>>2,c)}function jMa(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0}function ima(a){a=a|0;m[a+12>>2]=1;dJ(a,4);return a|0}function eha(a){a=a|0;g[a+4202|0]=1;sr(a);mw(a);FH(a)}function eb(a){if(oe(a)){Uf(a,i[a>>2],Jj(a))}return a}function bc(a,b,c){a=a|0;b=b|0;c=c|0;ls(a);return a|0}function aia(a,b){a=a|0;b=b|0;G3(a,i[b>>2],i[b+4>>2])}function aR(a){var b=0;b=Xa-16|0;Xa=b;Fz(a);Xa=b+16|0}function aO(a,b){a=a|0;b=b|0;i[a>>2]=b;i[a+4>>2]=b+24}function _A(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return 0}function X6(a,b){a=a|0;b=b|0;cL(i[a>>2],b);return a|0}function Wfa(a){a=a|0;return p(p(m[a+4232>>2]*p(20)))}function TA(a){var b=0;b=Xa-16|0;Xa=b;yl(a);Xa=b+16|0}function Sl(a,b){return $a[i[i[a>>2]+36>>2]](a,b,0)|0}function Rl(a,b){return $a[i[i[a>>2]+52>>2]](a,b,0)|0}function Gia(a,b,c){a=a|0;b=b|0;c=c|0;m[b>>2]=m[c>>2]}function Ge(a,b,c,d){g[a+8|0]=d;i[a+4>>2]=c;i[a>>2]=b}function GW(a,b){a=a|0;b=b|0;i[a>>2]=b;i[a+4>>2]=b+48}function Eh(a){a=a|0;return $a[i[i[a>>2]+12>>2]](a)|0}function Dh(a){a=a|0;return $a[i[i[a>>2]+16>>2]](a)|0}function Dba(a){a=a|0;a=i[a+4>>2];return(a?a:38121)|0}function B6(a,b,c){a=a|0;b=b|0;c=c|0;pF(a+ -88|0,b,c)}function zn(a){a=a|0;a=a+12|0;$a[i[i[a>>2]>>2]](a)|0}function z6(a,b){a=a|0;b=b|0;return oF(a+ -88|0,b)|0}function x6(a,b){a=a|0;b=b|0;return mF(a+ -88|0,b)|0}function w9(a){a=a|0;return i[i[a+24>>2]+1074424>>2]}function up(a,b,c){a=a|0;b=b|0;c=c|0;h[b>>1]=k[c>>1]}function nHa(a){a=a|0;return FI(j[a+3|0],j[a+5|0])|0}function mH(a){a=a|0;return p(p(m[a+4216>>2]*p(10)))}function hfa(a){a=a|0;return p(p(m[a+4232>>2]*p(4)))}function dka(a,b){a=a|0;b=b|0;a=a+24|0;AI(a,b);Zw(a)}function bGa(a,b){a=a|0;b=b|0;return lI(a,b,le(b))|0}function YQ(a){a=a|0;return i[bIa(i[a>>2],XQ(a))>>2]}function XU(a,b,c,d){yc(a,b);yc(a+4|0,c);yc(a+8|0,d)}function Jm(a,b,c){a=a|0;b=b|0;c=c|0;i[b>>2]=i[c>>2]}function D6(a,b,c){a=a|0;b=b|0;c=+c;rF(a+ -88|0,b,c)}function A9(a){a=a|0;return i[i[a+24>>2]+1074416>>2]}function xm(a,b,c){if(!c){return 0}return Xc(a,b,c)}function vL(a,b){i[a+8>>2]=0;i[a+12>>2]=0;n[a>>3]=b}function v9(a){a=a|0;return k[i[a+24>>2]+480214>>1]}function tc(a,b){a=a|0;b=b|0;return ZN(a,b,le(b))|0}function sx(a){a=a|0;return Pr(j[a+2|0],j[a+4|0])|0}function sd(a){var b=0;b=i[a>>2];i[a>>2]=0;return b}function rG(a,b){Rv(i[i[a>>2]+ -12>>2]+a|0,i[b>>2])}function qy(a,b){a=a|0;b=b|0;return Gn(a,b,le(b))|0}function nc(a){if(oe(a)){Ln(i[a>>2],Jj(a))}return a}function ml(a,b,c){i[a>>2]=b;i[a+4>>2]=b+c;return a}function kb(a,b,c){Ac(a,(c>>>3&536870908)+b|0,1<<c)}function jka(a,b){a=a|0;b=b|0;vi(a+36|0,b);return 1}function ar(a){a=a|0;return k[i[a+24>>2]+480190>>1]}function XK(a,b){return RV(xb(a),lb(a),xb(b),lb(b))}function Sr(a){a=a|0;return Pr(j[a+3|0],j[a+5|0])|0}function Rk(a){a=a|0;return k[i[a+24>>2]+480188>>1]}function RC(a,b,c){a=a|0;b=b|0;c=c|0;xb(b);return-1}function Qk(a){a=a|0;return k[i[a+24>>2]+480192>>1]}function Ora(a,b){a=a|0;b=b|0;i[b>>2]=0;i[b+4>>2]=0}function OC(a){a=a|0;lq(a);i[a>>2]=63548;return a|0}function Nn(a,b){b=i[b>>2];i[a>>2]=b;Fl(b);return a}function NC(a){a=a|0;lq(a);i[a>>2]=63644;return a|0}function Mta(a){a=a|0;$e(85352);$e(85344);eb(85332)}function L9(a){a=a|0;return i[i[a+24>>2]+480272>>2]}function Jq(a){if(!a){return 0}i[114584]=a;return-1}function Gl(a,b){He(a,b);yb(a+16|0,0,1040);return a}function Fd(a){a=a|0;a=Fea(a);kg(a+56|0);return a|0}function $M(a,b){return eW(xb(a),lb(a),xb(b),lb(b))}function yta(a,b){a=a|0;b=b|0;return Tb(a,b,116)|0}function qza(a,b,c){a=a|0;b=b|0;c=c|0;Ge(a,c,33,b)}function qz(a,b,c){ml(a,i[b+28>>2]+(c<<12)|0,4096)}function pH(a){a=a|0;if(a){$a[i[i[a>>2]+4>>2]](a)}}function nu(a,b,c){a=a|0;b=b|0;c=c|0;g[b|0]=j[c|0]}function iz(a,b,c){return a>>>0<c>>>0&b>>>0<=a>>>0}function hb(a){a=i[a+4>>2];if(a){if(El(a)){AY(a)}}}function hG(a,b){fG(a,74);i[a+4>>2]=i[a+4>>2]|b&74}function gza(a,b,c){a=a|0;b=b|0;c=c|0;Ge(a,c,24,b)}function ci(a,b,c){i[a>>2]=i[b>>2];g[a+4|0]=j[c|0]}function _k(a){Wh(a+724|0);Wh(a+736|0);Wh(a+748|0)}function Yra(a){a=a|0;return+Q4(n[a>>3],n[a+8>>3])}function Vx(a,b,c){a=a|0;b=b|0;c=c|0;MM(td(a,b),c)}function Ve(a){a=a|0;a=Z7(a);kg(a+60|0);return a|0}function Ts(a){return(i[a+480180>>2]&740327453)!=0}function QO(a,b,c){a=a|0;b=b|0;c=c|0;Lc(a,qy(b,c))}function NK(a){return i[a+16>>2]!=(0-i[a+20>>2]|0)}function Gp(a,b,c){a=a|0;b=b|0;c=c|0;Lc(a,yO(b,c))}function EEa(a,b,c){a=a|0;b=b|0;c=c|0;Ge(a,c,16,b)}function C6(a,b){a=a|0;b=b|0;return+qF(a+ -88|0,b)}function ADa(a,b){a=a|0;b=b|0;lDa(a,i[b>>2],XQ(b))}function zza(a,b,c){a=a|0;b=b|0;c=c|0;Ge(a,c,9,b)}function yg(a,b){if(oe(a)){ce(a,b);return}Te(a,b)}function xz(a,b){a=MIa(a,b);if(!a){iR(b)}return a}function wR(a,b){a=NIa(a,b);if(!a){iR(b)}return a}function vy(a,b){a=jBa(a,b);if(!a){uO(b)}return a}function sP(a,b){a=cDa(a,b);if(!a){gP(b)}return a}function rg(a,b,c){a=a|0;b=b|0;c=c|0;Ge(a,c,32,b)}function oz(a,b){a=sIa(a,b);if(!a){_Q(b)}return a}function on(a,b,c){a=a|0;b=b|0;c=c|0;Ge(a,c,22,b)}function ol(a){return(i[Mb(a)>>2]-i[a>>2]|0)/24|0}function nl(a){return(i[fb(a)>>2]-i[a>>2]|0)/48|0}function nLa(a,b){a=a|0;b=b|0;return xr(a,b,11)|0}function jl(a){return(i[fb(a)>>2]-i[a>>2]|0)/33|0}function it(a,b,c){a=a|0;b=b|0;c=c|0;Ge(a,c,64,b)}function ib(a){return(i[a+4>>2]&i[i[a>>2]>>2])!=0}function gz(a,b){a=xHa(a,b);if(!a){MQ(b)}return a}function gN(a,b){a=fya(a,b);if(!a){MQ(b)}return a}function en(a,b,c){a=a|0;b=b|0;c=c|0;Ge(a,c,20,b)}function cl(a,b,c){n[a+8>>3]=c;n[a>>3]=b;return a}function bk(a,b,c){a=a|0;b=b|0;c=c|0;Ge(a,c,12,b)}function ae(a,b){a=a|0;b=b|0;return(a|0)==(b|0)|0}function XN(a,b){a=Nza(a,b);if(!a){QN(b)}return a}function Ws(a,b,c){a=a|0;b=b|0;c=c|0;Ge(a,c,28,b)}function Wo(a){return(i[fb(a)>>2]-i[a>>2]|0)/20|0}function Tm(a){return(i[fb(a)>>2]-i[a>>2]|0)/56|0}function SR(a,b,c){a=a|0;b=b|0;c=c|0;Ge(a,c,30,b)}function SA(a,b){tk(a,b);i[a+12>>2]=0;i[a+8>>2]=0}function Rn(a){return(i[Mb(a)>>2]-i[a>>2]|0)/12|0}function Rf(a){return(i[fb(a)>>2]-i[a>>2]|0)/12|0}function PQ(a,b,c){a=a|0;b=b|0;c=c|0;Ge(a,c,40,b)}function OF(a,b,c,d){pua(a,b,c,oh(p(d*p(65536))))}function Mi(a){return(i[fb(a)>>2]-i[a>>2]|0)/52|0}function IO(a,b){a=kBa(a,b);if(!a){wO(b)}return a}function H_(){z$();i[115443]=463392;return 461772}function GF(a,b,c){i[a>>2]=b;i[a+4>>2]=c;return a}function GE(a,b){if(!a){return 0}return Aj(a,b,0)}function Et(a,b,c){a=a|0;b=b|0;c=c|0;Ge(a,c,26,b)}function Ef(a,b){return tE(xb(a),lb(a),b,0,le(b))}function EDa(a,b){a=a|0;b=b|0;return $a[b|0](a)|0}function Be(a){return(i[fb(a)>>2]-i[a>>2]|0)/24|0}function BEa(a,b){a=a|0;b=b|0;return xr(a,b,17)|0}function Ac(a,b,c){i[a+4>>2]=c;i[a>>2]=b;return a}function xb(a){if(oe(a)){return i[a>>2]}return a}function tBa(a,b){a=a|0;b=b|0;return pn(a,b,2)|0}function rsa(a){a=a|0;i[a>>2]=0;msa();return a|0}function qQ(a,b){a=a|0;b=b|0;return xr(a,b,32)|0}function pM(a,b){yc(a,i[b>>2]);g[a+4|0]=j[b+4|0]}function nh(a){return i[a+8>>2]!=0|i[a+12>>2]!=0}function kCa(a,b,c){a=a|0;b=b|0;c=c|0;$Ba(a,b,c)}function jfa(a){a=a|0;return m[a+4212>>2]<p(1)|0}function hi(a){return(i[fb(a)>>2]-i[a>>2]|0)/6|0}function fj(a,b){a=JU(a,b);if(!a){TA(b)}return a}function bv(a,b,c){a=a|0;b=b|0;c=c|0;UE(c);Cb(a)}function bs(a){return(a>>>0<9?a:a+ -9|256)&65535}function ap(a,b,c){g[a+2|0]=c;h[a>>1]=b;return a}function ZGa(a,b){a=a|0;b=b|0;return pn(a,b,3)|0}function Yw(a){i[a+4>>2]=0;i[a+8>>2]=-1;g[a|0]=0}function Yfa(a){a=a|0;return m[a+4220>>2]<p(1)|0}function Yda(a){a=a|0;PG(i[i[a>>2]+ -12>>2]+a|0)}function Wg(a){return(Re(a)|0)!=(0-Re(a+12|0)|0)}function Pja(a,b){a=a|0;b=b|0;return xr(a,b,1)|0}function LIa(a,b,c){a=a|0;b=b|0;c=c|0;Tb(b,c,48)}function LA(a,b){a=wU(a,b);if(!a){HA(b)}return a}function Hx(a){i[a+24>>2]=k[a+20>>1]<<k[a+22>>1]}function Gm(a){i[a>>2]=0;i[a+4>>2]=0;i[a+8>>2]=0}function Eja(a,b){a=a|0;b=b|0;XS(a,b);return a|0}function EI(a,b,c){g[a|0]=j[b|0];g[a+1|0]=j[c|0]}function Dj(a){return(i[a+4>>2]+i[a>>2]|0)+ -1|0}function CR(a,b){g[a|0]=j[b|0];g[a+1|0]=j[b+1|0]}function zp(a,b){a=a|0;b=b|0;return Qe(a,b,0)|0}function zj(a){a=a|0;return jE(i[a>>2])<<24>>24}function yCa(a,b){a=a|0;b=b|0;return gCa(a,b)|0}function x$(a,b){a=a|0;b=b|0;vd(a,b,qd(461604))}function wJa(a,b){a=a|0;b=b|0;return vJa(a,b)|0}function w$(a,b){a=a|0;b=b|0;vd(a,b,qd(461612))}function vT(a,b){a=a|0;b=b|0;sl(a,b);return a|0}function v7(a){a=a|0;KF(i[i[a>>2]+ -12>>2]+a|0)}function v$(a,b){a=a|0;b=b|0;vd(a,b,qd(461808))}function u$(a,b){a=a|0;b=b|0;vd(a,b,qd(461800))}function t$(a,b){a=a|0;b=b|0;vd(a,b,qd(461816))}function sh(a,b){a=a|0;b=b|0;return pn(a,b,4)|0}function r$(a,b){a=a|0;b=b|0;vd(a,b,qd(461824))}function qsa(a,b){a=a|0;b=b|0;return lsa(a,b)|0}function q$(a,b){a=a|0;b=b|0;vd(a,b,qd(461832))}function ps(a,b){a=a|0;b=b|0;return(b-a|0)/12|0}function o$(a,b){a=a|0;b=b|0;vd(a,b,qd(461840))}function nd(a){return(i[a+4>>2]-i[a>>2]|0)/24|0}function n$(a,b){a=a|0;b=b|0;vd(a,b,qd(461848))}function mj(a){return $a[i[i[a>>2]+36>>2]](a)|0}function m$(a,b){a=a|0;b=b|0;vd(a,b,qd(461856))}function lIa(a,b){a=a|0;b=b|0;return cIa(a,b)|0}function lE(a){a=a|0;hv(i[i[a>>2]+ -12>>2]+a|0)}function l$(a,b){a=a|0;b=b|0;vd(a,b,qd(461620))}function k$(a,b){a=a|0;b=b|0;vd(a,b,qd(461628))}function jX(a){a=a|0;a=Xa-a&-16;Xa=a;return a|0}function j$(a,b){a=a|0;b=b|0;vd(a,b,qd(461636))}function il(a,b,c){a=a|0;b=b|0;c=c|0;return a|0}function ii(a){return(i[a+4>>2]-i[a>>2]|0)/48|0}function iMa(a,b){a=a|0;b=b|0;return ZLa(a,b)|0}function i$(a,b){a=a|0;b=b|0;vd(a,b,qd(461644))}function g$(a,b){a=a|0;b=b|0;vd(a,b,qd(461684))}function fMa(a,b){a=a|0;b=b|0;return WLa(a,b)|0}function f$(a,b){a=a|0;b=b|0;vd(a,b,qd(461692))}function e$(a,b){a=a|0;b=b|0;vd(a,b,qd(461700))}function ds(a,b){a=a|0;b=b|0;Kf(a,b);return a|0}function d$(a,b){a=a|0;b=b|0;vd(a,b,qd(461708))}function cc(a){return(i[a+4>>2]-i[a>>2]|0)/12|0}function bf(a){return(i[a+4>>2]-i[a>>2]|0)/52|0}function b$(a,b){a=a|0;b=b|0;vd(a,b,qd(461716))}function ag(a,b){a=a|0;b=b|0;iE(a,i[a+16>>2]|b)}function aE(a){a=a|0;dv(i[i[a>>2]+ -12>>2]+a|0)}function Zs(a,b,c){b=b-a|0;if(b){yi(c-b|0,a,b)}}function Zl(a){return $a[i[i[a>>2]+28>>2]](a)|0}function Z_(a,b){a=a|0;b=b|0;vd(a,b,qd(461732))}function Yj(a){return(i[a+4>>2]-i[a>>2]|0)/33|0}function Xh(a){return(j[a+31|0]+ -1&255)>>>0<17}function X_(a,b){a=a|0;b=b|0;vd(a,b,qd(461740))}function W_(a,b){a=a|0;b=b|0;vd(a,b,qd(461652))}function V_(a,b){a=a|0;b=b|0;vd(a,b,qd(461660))}function Tj(a){return(i[a+4>>2]-i[a>>2]|0)/56|0}function T_(a,b){a=a|0;b=b|0;vd(a,b,qd(461668))}function R_(a,b){a=a|0;b=b|0;vd(a,b,qd(461676))}function Qu(a,b,c,d){a=qD(a,b,c,-1,-1);return a}function Q9(a,b){a=a|0;b=b|0;O9(a,P9(te(12),b))}function Pfa(a){a=a|0;g[a+4202|0]=1;jH(a);kH(a)}function Pea(a){a=a|0;bH(a);dw(a);g[a+4202|0]=1}function P_(a,b){a=a|0;b=b|0;vd(a,b,qd(461748))}function PGa(a,b){a=a|0;b=b|0;return wGa(a,b)|0}function Oda(a,b){a=a|0;b=b|0;return Mda(a,b)|0}function O_(a,b){a=a|0;b=b|0;vd(a,b,qd(461756))}function OGa(a,b){a=a|0;b=b|0;return vGa(a,b)|0}function OAa(a,b){a=a|0;b=b|0;return MAa(a,b)|0}function Li(a,b,c){a=a|0;b=b|0;c=c|0;Hma(a,b,c)}function Dr(a,b,c){a=a|0;b=b|0;c=c|0;_ma(a,b,c)}function Dfa(a){a=a|0;g[a+4202|0]=1;hH(a);gH(a)}function De(a,b,c){a=a|0;b=b|0;c=c|0;KLa(a,b,c)}function $_(a,b){a=a|0;b=b|0;vd(a,b,qd(461724))}function $N(a,b){a=a|0;b=b|0;return pn(a,b,8)|0}function $Ka(a,b){a=a|0;b=b|0;return YKa(a,b)|0}function zoa(a,b,c){a=a|0;b=b|0;c=c|0;voa(b,c)}function yr(a,b){return(i[a>>2]-i[b>>2]|0)/6|0}function wf(a,b){a=a|0;b=b|0;return RKa(a,b)|0}function ue(a,b,c){if(!(j[a|0]&32)){ou(b,c,a)}}function nO(a,b){a=a|0;b=b|0;return LAa(a,b)|0}function gIa(a){a=a|0;oJa(a);return i[a+12>>2]}function ef(a,b){a=a|0;b=b|0;return zMa(a,b)|0}function bz(a){a=a|0;return(j[a+1|0]==1?1:2)|0}function bY(a,b,c){a=a|0;b=b|0;c=c|0;Ac(a,c,b)}function Zj(a,b){g[a+4|0]=0;i[a>>2]=b;return a}function YS(a,b){a=a|0;b=b|0;return XLa(a,b)|0}function XQ(a){return i[a>>2]+(i[a+4>>2]<<2)|0}function Wsa(a,b,c){a=a|0;b=b|0;c=c|0;Vsa(b,c)}function Uo(a,b){return(o(b,104)+a|0)+484380|0}function Sya(a,b,c){a=a|0;b=b|0;c=c|0;Oya(b,c)}function Ob(a,b,c){a=a|0;b=b|0;c=c|0;ml(a,b,c)}function OR(a,b){a=a|0;b=b|0;return ZJa(a,b)|0}function OL(a,b){JL(i[a>>2],b);JL(i[a+4>>2],b)}function Nd(a,b){a=a|0;b=b|0;return VKa(a,b)|0}function If(a){return(i[a+4>>2]-i[a>>2]|0)/6|0}function Hja(a,b,c){a=a|0;b=b|0;c=c|0;Gja(b,c)}function DL(a){CL(a);yb(a+27|0,0,255);return a}function An(a){jB(a);i[a+8>>2]=0;i[a>>2]=68436}function $z(a,b){a=a|0;b=b|0;return EMa(a,b)|0}function $m(a,b){a=a|0;b=b|0;return $Fa(a,b)|0}function $S(a,b){a=a|0;b=b|0;return dMa(a,b)|0}function $8(a,b,c){a=a|0;b=b|0;c=c|0;_8(a,b,c)}function ywa(a){a=a|0;Tx(a+288|0);Ro(a+800|0)}function xt(a,b){a=a|0;b=b|0;return bA(a,b)|0}function xs(a,b){a=a|0;b=b|0;return yO(a,b)|0}function xP(a,b,c){a=a|0;b=b|0;c=c|0;RDa(b,c)}function wj(a,b){a=a|0;b=b|0;return fE(a,b)|0}function tf(a){i[a>>2]=0;i[a+4>>2]=0;return a}function ri(a,b){a=a|0;b=b|0;return gU(a,b)|0}function rb(a,b){a=a|0;b=b|0;return sV(a,b)|0}function pi(a,b){a=a|0;b=b|0;return fT(a,b)|0}function pb(a,b){a=a|0;b=b|0;return al(a,b)^1}function nR(a){g[a+12|0]=j[a+12|0]|2;return a}function lu(a,b){a=a|0;b=b|0;return qy(a,b)|0}function kc(a,b){if(l[a>>2]>b>>>0){i[a>>2]=b}}function eta(a,b,c){a=a|0;b=b|0;c=c|0;x2(a,b)}function ei(a,b){a=a|0;b=b|0;return pb(a,b)|0}function eO(a,b,c){a=a|0;b=b|0;c=c|0;hha(a,c)}function _v(a){a=a|0;i[a>>2]=83588;return a|0}function _Ma(a,b,c,d){a=VMa(a,b,c,d);return a}function YMa(a,b,c,d){a=TMa(a,b,c,d);return a}function Y3(a,b){a=a|0;b=b|0;return X3(a,b)|0}function Xj(a,b){if(i[a>>2]>(b|0)){i[a>>2]=b}}function Xb(a,b){a=a|0;b=b|0;return R1(a,b)|0}function XMa(a,b,c,d){a=SMa(a,b,c,d);return a}function W3(a,b){a=a|0;b=b|0;return V3(a,b)|0}function VK(a,b){if(!(m[a>>2]<=b)){m[a>>2]=b}}function Ug(a,b){a=a|0;b=b|0;return OT(a,b)|0}function UL(a,b,c){a=a|0;b=b|0;c=c|0;Ssa(b,c)}function Tn(a,b){a=a|0;b=b|0;return kE(a,b)^1}function T3(a,b){a=a|0;b=b|0;return S3(a,b)|0}function R3(a,b){a=a|0;b=b|0;return Q3(a,b)|0}function ON(a,b){a=a|0;b=b|0;return Yc(a,b)|0}function LP(a,b,c){a=a|0;b=b|0;c=c|0;return 0}function KK(a){JK(a+20|0);fK(a+8|0);$e(a+4|0)}function KHa(a,b,c){a=a|0;b=b|0;c=c|0;He(b,c)}function Jc(a,b){a=a|0;b=b|0;return kW(a,b)|0}function Il(a,b,c){a=a|0;b=b|0;c=c|0;oha(a,c)}function Fj(a){return i[fb(a)>>2]-i[a>>2]>>11}function Fi(a,b){a=a|0;b=b|0;return kE(a,b)|0}function Dq(a,b){a=a|0;b=b|0;return fE(a,b)^1}function DFa(a){a=a|0;lQ(a);return i[a+16>>2]}function Ag(a,b){if(k[a>>1]>b>>>0){h[a>>1]=b}}function $3(a,b){a=a|0;b=b|0;return _3(a,b)|0}function zf(a){return i[fb(a)>>2]-i[a>>2]>>1}function yaa(a){a=a|0;fG(a,16384);return a|0}function y9(a){a=a|0;return dG(i[a+24>>2])|0}function xh(a){return i[fb(a)>>2]-i[a>>2]>>4}function tn(a){return i[Mb(a)>>2]-i[a>>2]>>1}function ti(a){return i[fb(a)>>2]-i[a>>2]>>3}function qaa(a){a=a|0;Rv(a,16384);return a|0}function pw(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0}function nfa(a,b){a=a|0;b=b|0;return Ii(b)|0}function mu(a){return i[Mb(a)>>2]-i[a>>2]>>4}function mFa(a,b){a=a|0;b=b|0;mp(yb(b,0,48))}function ifa(a){a=a|0;return p(m[a+4220>>2])}function gd(a){return i[fb(a)>>2]-i[a>>2]>>2}function fw(a){return p(p(a*p(7900))+p(100))}function fv(a,b,c){a=a|0;b=b|0;c=c|0;Lc(b,c)}function az(a,b,c){a=a|0;b=b|0;c=c|0;gI(a,c)}function ai(a,b,c){a=a|0;b=b|0;c=c|0;ts(a,c)}function Yt(a){return i[Mb(a)>>2]-i[a>>2]>>5}function Yg(a){return i[fb(a)>>2]-i[a>>2]>>5}function Xfa(a){a=a|0;return p(m[a+4212>>2])}function XH(a,b,c){a=a|0;b=b|0;c=c|0;dp(b,c)}function XA(a,b,c){a=a|0;b=b|0;c=c|0;nV(b,c)}function Wf(a){return i[Mb(a)>>2]-i[a>>2]>>2}function Ry(a,b,c){a=a|0;b=b|0;c=c|0;Kf(b,c)}function Pg(a){return i[i[a+8>>2]>>2]==(a|0)}function HFa(a){a=a|0;lQ(a);return i[a+4>>2]}function H4(a){a=a|0;return Ma(i[a+60>>2])|0}function Bk(a){return i[hq(a)>>2]-i[a>>2]>>2}function ze(a,b){if(j[a|0]>b>>>0){g[a|0]=b}}function xf(a){return i[fb(a)>>2]-i[a>>2]|0}function r6(a,b){a=a|0;b=b|0;kF(a+ -88|0,b)}function oH(a){a=a|0;return p(m[a+4208>>2])}function jr(a){YG(a);i[a>>2]=56252;return a}function hL(a){i[a>>2]=i[a>>2]+ -4;return a}function fG(a,b){i[a+4>>2]=i[a+4>>2]&(b^-1)}function eja(a,b){a=a|0;b=b|0;K3(a,h[b>>1])}function eg(a,b,c){return ya(a|0,b|0,c|0)|0}function _l(a){a=a|0;cE(i[a>>2]);return a|0}function Tja(a,b){a=a|0;b=b|0;H3(a,i[b>>2])}function Rh(a,b){a=a|0;b=b|0;return p(p(0))}function Re(a){return i[a+4>>2]-i[a>>2]>>11}function Qz(a){return i[Mb(a)>>2]-i[a>>2]|0}function QG(a){return oh(p(SG(a)*p(32768)))}function QD(a){YG(a);i[a>>2]=56324;return a}function Pia(a,b){a=a|0;b=b|0;cv(a,k[b>>1])}function NL(a,b){h[a+22>>1]=b&7;Hx(a);Ix(a)}function Mha(a,b){a=a|0;b=b|0;D3(a,n[b>>3])}function M6(a,b){a=a|0;b=b|0;AF(a+ -88|0,b)}function M4(a,b){a=a|0;b=b|0;return Hg(a)|0}function K6(a,b){a=a|0;b=b|0;zF(a+ -88|0,b)}function Jk(a){a=a|0;gv(i[a>>2]);return a|0}function Fha(a,b){a=a|0;b=b|0;g[a+4201|0]=b}function EY(a,b){a=a|0;b=b|0;return Ak(b)|0}function Cga(a,b,c){a=a|0;b=b|0;c=c|0;tf(a)}function C_(){Nn(461784,yC());return 461784}function CJ(a){return 251<=a>>>0&a>>>0<=255}function $q(a){return 0<=(a|0)&65535>=(a|0)}function $L(a){i[a>>2]=i[a>>2]+ -2;return a}function xG(a){return(xb(a)+lb(a)|0)+ -1|0}function tha(a,b){a=a|0;b=b|0;yb(b,0,2048)}function tKa(a,b){a=a|0;b=b|0;vi(a+12|0,b)}function sD(){return(i[i[21199]>>2]?4:1)|0}function rja(a,b){a=a|0;b=b|0;cv(a,j[b|0])}function qp(a,b){return i[a>>2]-i[b>>2]>>1}function qb(a){return i[a+4>>2]-i[a>>2]>>2}function oj(a,b){$a[i[i[b>>2]+44>>2]](a,b)}function nj(a,b){$a[i[i[b>>2]+32>>2]](a,b)}function mq(a,b){$a[i[i[b>>2]+40>>2]](a,b)}function jna(a,b){a=a|0;b=b|0;vi(a+40|0,b)}function gy(a){Td(a+24|0);Md(a+12|0);Md(a)}function fba(a,b){a=a|0;b=b|0;eba(a,b+4|0)}function ev(a){a=a|0;return Dg(a,461800)|0}function bg(a){return i[a+4>>2]-i[a>>2]>>3}function be(a){return i[a+4>>2]-i[a>>2]>>5}function b4(a){a=a|0;return Dg(a,461620)|0}function aI(a,b){a=a|0;b=b|0;cv(a,i[b>>2])}function Zu(a){a=a|0;return Dg(a,461816)|0}function Zt(a){Xp(a+28|0);hb(a+12|0);eb(a)}function Yu(a){a=a|0;return Dg(a,461824)|0}function Yl(a){return(a|0)==32|a+ -9>>>0<5}function Yk(a){eb(a+36|0);Sd(a+24|0);kl(a)}function Wc(a){return i[a+4>>2]-i[a>>2]>>4}function Wb(a){return i[a+4>>2]-i[a>>2]>>1}function WG(a){return p(p(a*p(96))+p(-96))}function W8(a,b){a=a|0;b=b|0;return b-a>>3}function Q6(a){a=a|0;return Hv(a+ -88|0)|0}function Ou(a){a=a|0;return Dg(a,461848)|0}function Ot(a){a=a|0;return Dg(a,461808)|0}function Nja(a,b){a=a|0;b=b|0;Oea(a,b+4|0)}function Mpa(a){a=p(a);return Epa(Qd(a))|0}function Mja(a,b){a=a|0;b=b|0;Kf(a,b+36|0)}function ML(a,b){g[a+21|0]=b&3;Hx(a);Ix(a)}function Lu(a){a=a|0;return Dg(a,461856)|0}function L3(a){a=a|0;return Dg(a,461636)|0}function Jj(a){return i[a+8>>2]&2147483647}function JV(a){a=a|0;return i[a+4>>2]!=0|0}function J6(a,b){a=a|0;b=+b;yF(a+ -88|0,b)}function Hs(a,b){return i[a>>2]-i[b>>2]>>2}function H6(a,b){a=a|0;b=+b;wF(a+ -88|0,b)}function F6(a,b){a=a|0;b=+b;uF(a+ -88|0,b)}function B9(a){a=a|0;return+GJ(i[a+24>>2])}function zy(a,b){return i[a>>2]+o(b,20)|0}function yO(a,b){return Gn(a,xb(b),lb(b))}function wr(a,b,c){return h[b>>1]<h[c>>1]}function wc(a,b){return i[a>>2]+o(b,24)|0}function vn(a,b,c){return k[b>>1]<k[c>>1]}function ul(a,b){return i[a>>2]+(b<<11)|0}function sm(a){return i[i[a+48>>2]+12>>2]}function se(a,b){return i[a>>2]+o(b,52)|0}function rc(a){return i[a+4>>2]-i[a>>2]|0}function he(a){i[a>>2]=i[a>>2]+2;return a}function fl(a,b){return i[a>>2]+o(b,56)|0}function fc(a,b){a=a|0;b=b|0;Nn(a,b+28|0)}function bn(a){return 3999>k[a+480190>>1]}function bG(a,b){a=a|0;b=b|0;Kf(a,b+12|0)}function Yc(a,b){return i[a>>2]+o(b,12)|0}function Xr(a,b,c){return Dwa(b,c)>>>31|0}function Xha(a){a=a|0;NR(a,80,150,80,255)}function XI(a,b,c){return Pla(b,c)>>>31|0}function VG(a){a=a|0;yb(a+4296|0,0,81928)}function UI(a,b){cl(a,n[b>>3],-n[b+8>>3])}function Ol(a,b,c){Uh(a,b,b+c|0);return a}function Kea(a){a=a|0;return i[a+4260>>2]}function JP(a,b){return i[a>>2]+o(b,33)|0}function J5(a){a=a|0;if(a){_E(a);Dd(a,a)}}function Hv(a){a=a|0;br(a+8|0);return a|0}function Gk(a){a=a|0;return eE(i[a>>2])|0}function Gd(a){i[a>>2]=i[a>>2]+4;return a}function Fq(a){a=a|0;kg(a+8|0);return a|0}function En(a,b){return i[a>>2]-i[b>>2]|0}function EA(a){return(j[a+24|0]&16)>>>4|0}function Cq(a){a=a|0;kg(a+4|0);return a|0}function BZ(a,b){a=a|0;b=b|0;Kf(a,b+16|0)}function Au(a){a=a|0;OY(a+8|0);return a|0}function Ad(a,b){i[a>>2]=i[b>>2];return a}function zZ(a,b){a=a|0;b=b|0;Du(a,62616)}function yZ(a,b){a=a|0;b=b|0;Bb(a,62636)}function yH(a){return(j[a+24|0]&8)>>>3|0}function xza(a,b){a=a|0;b=b|0;Ac(a,b,10)}function xn(a){return o(Kp(a),$d(a))&255}function xZ(a,b){a=a|0;b=b|0;Du(a,62644)}function vb(a,b){return i[a>>2]+(b<<2)|0}function uk(a,b){return i[a>>2]+(b<<3)|0}function uc(a,b){return i[a>>2]+o(b,6)|0}function sb(a){i[i[a>>2]+4>>2]=i[a+4>>2]}function lfa(a){a=a|0;if(a){mr(a);Cb(a)}}function lB(a,b){Gb(a,b);Gb(a+4|0,b+4|0)}function jB(a){i[a+4>>2]=0;i[a>>2]=68380}function hf(a){a=a|0;return!i[a+16>>2]|0}function fr(a,b){i[a+24>>2]=i[a+24>>2]+b}function fg(a,b){i[a+8>>2]=b|-2147483648}function er(a){if(ae(a,-1)){a=0}return a}function bea(a){a=a|0;return(a|0)==277|0}function bNa(a){return a<0?v(a):u(a)}



function al(a,b){return i[a>>2]==i[b>>2]}function _z(a,b){return i[a>>2]+(b<<5)|0}function _b(a,b){return i[a>>2]+(b<<4)|0}function Uc(a){return i[a>>2]==i[a+4>>2]}function Saa(a){a=a|0;hG(a,2);return a|0}function LJa(a,b){a=a|0;b=b|0;Ac(a,b,44)}function Ks(a){a=a|0;return i[a>>2]+14|0}function Kaa(a){a=a|0;hG(a,8);return a|0}function KKa(a,b){a=a|0;b=b|0;Ac(a,b,11)}function Jpa(a){a=+a;return Dpa(xd(a))|0}function Jf(a){a=a|0;return Jd(j[a|0])|0}function Jd(a){return(a+ -1&255)>>>0<120}function JDa(a,b){a=a|0;b=b|0;Ac(a,b,17)}function I6(a){a=a|0;return+xF(a+ -88|0)}function Hj(a){return k[sm(a)+480188>>1]}function G6(a){a=a|0;return+vF(a+ -88|0)}function FC(){rd(463248);i[115812]=65768}function Eha(a){a=a|0;return j[a+4201|0]}function EC(){rd(463280);i[115820]=66264}function E6(a){a=a|0;return+sF(a+ -88|0)}function Dm(a){a=a|0;return IK(j[a|0])|0}function Dha(a){a=a|0;return j[a+4202|0]}function DC(){rd(463288);i[115822]=66428}function CC(){rd(463296);i[115824]=66592}function BC(){rd(463304);i[115826]=66756}function AZ(a,b){a=a|0;b=b|0;Bb(a,62608)}function AC(){rd(463376);i[115844]=66920}function $b(a,b){return i[a>>2]+(b<<1)|0}function vQ(a,b){i[a>>2]=i[a>>2]+o(b,6)}function uea(a){a=a|0;return-2013527448}function tH(a,b){return m[a>>2]<m[b>>2]}function rca(a){a=a|0;return i[a+16>>2]}function pd(a,b){return l[a>>2]<l[b>>2]}function nA(a,b){a=a|0;b=b|0;return b|0}function lt(a,b){return i[a>>2]<i[b>>2]}function kr(a){a=a|0;if(a){ve(a);Cb(a)}}function hh(a,b,c){Lc(a,b);Lc(a+12|0,c)}function ft(a){a=a|0;return sz(Wb(a))|0}function ey(a,b,c){if(b){yb(a,cg(c),b)}}function cP(a,b){i[a>>2]=i[a>>2]+(b<<2)}function _ya(a,b){a=a|0;b=b|0;Ac(a,b,5)}function _C(a,b){a=a|0;b=b|0;iD(a,1,45)}function XJ(a,b){return n[a>>3]<n[b>>3]}function Wh(a){i[a+4>>2]=0;i[a+8>>2]=-1}function MLa(a,b){a=a|0;b=b|0;h[b>>1]=0}function Hra(a,b){a=a|0;b=b|0;cl(b,0,0)}function Gs(a){a=+a;return dDa(xd(a))|0}function Dt(a,b){a=a|0;b=b|0;Ac(a,b,32)}function Dd(a,b){if(!i[a+80>>2]){Cb(b)}}function DK(a,b){return(Sj(a,b)|0)!=255}function $C(a,b){a=a|0;b=b|0;ej(a,1,45)}function zwa(a){a=a|0;HM(a);return a|0}function x_(a){a=a|0;FY(i[i[a>>2]>>2])}function wg(a){return i[a+4>>2]+ -32|0}function uQ(a,b){a=a|0;b=b|0;Dr(a,0,b)}function tfa(a){a=a|0;if(a){Cb(ew(a))}}function sfa(a){a=a|0;return-281111764}function sEa(a){a=a|0;return j[a+40|0]}function q4(a){a=a|0;return i[a+20>>2]}function mB(a,b){dC(a,b);i[a>>2]=71628}function kfa(a){a=a|0;return-271958638}function hk(a){return o(i[a>>2],xn(a))}function hU(a){a=a|0;return i[a+24>>2]}function gsa(a){a=a|0;esa();return a|0}function fy(a){return i[a+4>>2]+ -24|0}function fsa(a){a=a|0;_ra();return a|0}function fIa(a,b){a=a|0;b=b|0;GHa(b,a)}function fA(a){fb(a);return 2147483647}function eG(a){return i[a+4>>2]+ -48|0}function dM(a,b){i[a+4>>2]=b;i[a>>2]=b}function ac(a){i[i[a+8>>2]>>2]=i[a>>2]}function aG(a){return i[a+4>>2]+ -12|0}function _fa(a){a=a|0;return-270114148}function _da(a,b){a=a|0;b=b|0;return 2}function _Fa(a){a=a|0;return p(YFa(a))}function ZF(a){return a?(a|0)==2?3:2:1}function Uma(a,b){a=a|0;b=b|0;Ila(a,b)}function Rza(a,b){a=a|0;b=b|0;Fza(b,a)}function Rv(a,b){i[a+4>>2]=i[a+4>>2]|b}function Rga(a){a=a|0;if(a){Cb(kw(a))}}function Qga(a){a=a|0;return 542066252}function Nr(a){return(a|0)<=-1?0-a|0:a}function Mfa(a){a=a|0;if(a){Cb(gw(a))}}function Mea(a){a=a|0;if(a){Cb(cw(a))}}function Lfa(a){a=a|0;return-285139079}function Lea(a){a=a|0;return-275227023}function Kr(a){a=a|0;return 2147483647}function Ki(a,b){return xb(a)+(b<<2)|0}function K9(a){a=a|0;return+n[a+16>>3]}function Iha(a){a=a|0;if(a){Cb(rw(a))}}function HN(a){return i[a+4>>2]+ -56|0}function GU(a){a=a|0;return i[a+12>>2]}function Eta(a,b){a=a|0;b=b|0;rta(a,b)}function Bra(a,b){a=a|0;b=b|0;zra(a,b)}function Bfa(a){a=a|0;return-284078960}function Bea(a){a=a|0;return 302837129}function Aba(a,b){a=a|0;b=b|0;wba(a,b)}function $ea(a){a=a|0;return-620920304}function $da(a,b){a=a|0;b=b|0;return 3}function $d(a){return j[a+34|0]&64?2:1}function wu(a){a=a|0;gq(a);return a|0}function wt(a,b){a=a|0;b=b|0;wMa(b,a)}function rt(a,b){a=a|0;b=b|0;OLa(b,a)}function rM(a){a=a|0;gO(a);return a|0}function qw(a,b){a=a|0;b=b|0;return 1}function qCa(a){a=a|0;return NBa(a)|0}function pga(a,b){a=a|0;b=b|0;ds(a,b)}function oe(a){return j[a+11|0]>>>7|0}function oIa(a){a=a|0;return j[a+8|0]}function oA(a){return j[a+22|0]>>>7|0}function nz(a){a=a|0;return i[a+8>>2]}function nn(a,b){a=a|0;b=b|0;SLa(b,a)}function kt(a){return(j[a+16|0]&5)!=0}function kg(a){a=a|0;iv(a);return a|0}function kE(a,b){return XD(a)^XD(b)^1}function jua(a){a=a|0;return $ta(a)|0}function gt(a){a=a|0;return i[a+4>>2]}function g3(a){a=a|0;return OD(a,0)|0}function fE(a,b){return VD(a)^VD(b)^1}function f3(a){a=a|0;return OD(a,1)|0}function dG(a){return k[a+1074438>>1]}function cn(a,b){h[a+8>>1]=b;return a}function c3(a){a=a|0;return LD(a,0)|0}function boa(a){a=a|0;return Yna(a)|0}function b3(a){a=a|0;return LD(a,1)|0}function Zf(a,b){a=a|0;b=b|0;CMa(a,b)}function ZMa(a,b,c){return UMa(a,b,c)}function YD(a){a=a|0;wu(a);return a|0}function Wy(a,b){a=a|0;b=b|0;cFa(a,b)}function WB(a,b){return j[a|0]<j[b|0]}function Vy(a){return i[a+1304496>>2]}function Tu(a){a=a|0;if(yD(a)){Cb(a)}}function Qi(a){return i[a+4>>2]+ -4|0}function Px(a,b,c,d,e){vua(a,b,c,d,e)}function NG(a,b){a=a|0;b=b|0;return 0}function Ms(a){a=a|0;return wb(a,1)^1}function Kp(a){return g[a+34|0]&1?2:1}function Gq(a,b){a=a|0;b=b|0;return-1}function Ee(a,b){i[a+4>>2]=b;return a}function Db(a){return _z(a,j[a+16|0])}function DO(a,b){if(!pBa(a,b)){wO(b)}}function Ct(a){return j[a+21|0]>>>7|0}function CF(a){i[a>>2]=84536;return a}function Bga(a,b,c){a=a|0;b=b|0;c=c|0}function $o(a){a=a|0;Js(a);return a|0}function $j(a){a=a|0;Ss(a);return a|0}function $B(a){return lY(xb(a),lb(a))}function wp(a,b){Wb(a);hT(a,b);vp(a)}function wT(a){a=a|0;return PMa(a)|0}function wI(a,b){bf(a);wJ(a,b);sI(a)}function vw(a,b){qb(a);cQ(a,b);vg(a)}function us(a){return i[fb(a)>>2]<<5}function uKa(a){a=a|0;return pp(a)|0}function ts(a,b){a=a|0;b=b|0;Kf(a,b)}function sj(a,b){a=a|0;b=b|0;W0(a,b)}function rKa(a){a=a|0;return Op(a)|0}function oKa(a){a=a|0;return Bz(a)|0}function mm(a,b){a=a|0;b=b|0;oY(a,b)}function lGa(a){a=a|0;return Vy(a)|0}function jR(a,b){rc(a);OS(a,b);Yo(a)}function bQ(a,b){qb(a);PL(a,b);vg(a)}function bM(a,b){be(a);YL(a,b);du(a)}function _ea(a){a=a|0;i[a+4224>>2]=0}function Xy(a,b){If(a);$P(a,b);QP(a)}function UN(a,b){a=a|0;b=b|0;Kt(a,b)}function TG(a){i[a>>2]=0;i[a+4>>2]=0}function QBa(a,b){a=a|0;b=b|0;PBa(b)}function Pc(a,b){return ul(a+12|0,b)}function Oqa(a){a=a|0;return hj(a)|0}function On(a,b){a=a|0;b=b|0;V0(a,b)}function Jt(a,b){rc(a);xA(a,b);Yo(a)}function IK(a){return(a+5&255)>>>0<2}function Hla(a){a=a|0;return kh(a)|0}function Ft(a,b){qb(a);iA(a,b);vg(a)}function Fl(a){i[a+4>>2]=i[a+4>>2]+1}function ES(a,b){a=a|0;b=b|0;DS(a,b)}function DZ(a){a=a|0;return g[a+8|0]}function CZ(a){a=a|0;return g[a+9|0]}function Bw(a,b,c){return Yja(a,b,c)}function Axa(a,b){a=a|0;b=b|0;yxa(b)}function $ya(a){a=a|0;return S8(a)|0}function yv(a){return!Xc(a,84612,6)}function yc(a,b){i[a>>2]=b;return a}function yY(a){a=a|0;return te(a)|0}function we(a){return i[a+24620>>2]}function tM(a,b){return Oo(a,0-b|0)}function qA(a){return j[a+21|0]&127}function pra(a,b){a=a|0;b=b|0;Td(b)}function pA(a){return j[a+22|0]&127}function lP(a){a=a|0;return Ks(a)|0}function jra(a,b){a=a|0;b=b|0;ws(b)}function ji(a,b){return o(b,12)+a|0}function jh(a,b,c){if(c){Tb(a,b,c)}}function hEa(a,b){a=a|0;b=b|0;DP(b)}function hA(a){g[a+2|0]=0;h[a>>1]=0}function g9(a){a=a|0;return kt(a)|0}function dc(a,b){return i[a>>2]+b|0}function dW(a){a=a|0;return Cf(a)|0}function dA(a){a=a|0;return rT(a)|0}function Zm(a,b,c){return vn(a,b,c)}function Xsa(a,b){a=a|0;b=b|0;dl(b)}function Uqa(a,b){a=a|0;b=b|0;Im(b)}function Tya(a,b){a=a|0;b=b|0;gy(b)}function Sma(a,b){a=a|0;b=b|0;Yk(b)}function RAa(a){a=a|0;return+NAa(a)}function Qma(a,b){a=a|0;b=b|0;Hf(b)}function Ps(a){a=a|0;return Qg(a)|0}function PC(a,b){sl(i[a>>2],g[b|0])}function Or(a){return xo(a)<<24>>24}function Oe(a,b,c){return fz(a,b,c)}function OB(a){a=a|0;return i[a>>2]}function N4(a){a=a|0;return t8(a)|0}function LU(a){a=a|0;return id(a)|0}function Kb(a){return Pe(i[a+4>>2])}function Hg(a){return a+ -48>>>0<10}function DW(a){a=a|0;return cG(a)|0}function Cl(a,b,c){if(c){yi(a,b,c)}}function BLa(a,b){a=a|0;b=b|0;wh(b)}function BA(a){a=a|0;return _f(a)|0}function zk(a){nm(a);i[a>>2]=71260}function zV(a,b){a=a|0;b=b|0;xV(b)}function zS(a,b){a=a|0;b=b|0;Tz(b)}function xc(a,b){ls(a);yc(a+4|0,b)}function wS(a,b){a=a|0;b=b|0;hb(b)}function rd(a){jB(a);i[a>>2]=62964}function qj(a,b){a=a|0;b=b|0;Ab(a)}function o6(a,b){a=a|0;b=b|0;Cb(b)}function nq(a,b){a=a|0;b=b|0;Ke(a)}function mh(a,b){Ac(a,xb(b),lb(b))}function lq(a){rd(a);i[a>>2]=63432}function km(a,b){i[a+1304560>>2]=b}function ig(a,b){i[a>>2]=i[a>>2]|b}function hn(a,b){a=a|0;b=b|0;re(b)}function Yh(a,b){return(b<<13)+a|0}function XC(a){return Dg(a,461692)}function WC(a){return Dg(a,461684)}function Ux(a,b){a=a|0;b=b|0;ls(b)}function Uj(a,b){rn(a,b,i[b+4>>2])}function UA(a,b){a=a|0;b=b|0;yl(b)}function Tz(a){g[a|0]=0;g[a+1|0]=0}function Ty(a,b){a=a|0;b=b|0;Os(b)}function TC(a){return Dg(a,461708)}function SC(a){return Dg(a,461700)}function RK(a,b,c){epa(a,b-a>>2,c)}function Qr(a){return a>>>27^a}



function Qh(a){a=a|0;g[a+4202|0]=0}function Qg(a){return i[a>>2]+16|0}function PW(a,b){a=a|0;b=b|0;wC(b)}function Ns(a,b){a=a|0;b=b|0;Fz(b)}function Mh(a){return Uc(a+36|0)^1}function Gv(a){a=a|0;g[a+6152|0]=0}function Fy(a,b){a=a|0;b=b|0;Ne(b)}function EW(a){a=a|0;$p(a,1,10956)}function CV(a,b){a=a|0;b=b|0;Zt(b)}function CT(a,b){a=a|0;b=b|0;hA(b)}function AD(a,b){a=a|0;b=b|0;ob(b)}function wm(a){ug(a+4|0);return a}function vf(a){i[a>>2]=i[a>>2]+16}function vS(a,b){return Iz(a,b,7)}function uS(a){return j[a+1|0]==1}function tza(a){a=a|0;oP(a,65535)}function sS(a,b){return pn(a,b,7)}function sDa(a){a=a|0;Iy(a);Cb(a)}function qe(a){return i[Pb(a)>>2]}function ofa(a){a=a|0;mr(a);Cb(a)}function ny(a,b){Lc(a,b);return a}function nDa(a){a=a|0;Hy(a);Cb(a)}function mi(a){i[a>>2]=1;return a}function kj(a,b,c){L_(a+24|0,b,c)}function ke(a){return bf(a)&65535}function kN(a,b){return Iz(a,b,4)}function gk(a,b){He(a,b);return a}function dn(a){i[a>>2]=2;return a}function dk(a){i[a>>2]=i[a>>2]+24}function bl(a){h[a>>1]=0;return a}function ak(a){i[a>>2]=0;return a}function _m(a){i[a>>2]=i[a>>2]+12}function Zq(a,b,c,d){oua(a,b,c,d)}function Yv(a,b){return $I(a,b)^1}function YX(a){a=a|0;return 70505}function WX(a){a=a|0;return 70584}function Us(a,b){return Bd(a,b)^1}function Sb(a,b){return xb(a)+b|0}function Rm(a,b,c,d){rua(a,b,c,d)}function Qv(a){return a+1304500|0}function P6(a){a=a|0;BF(a+ -88|0)}function Nt(a){return g[a+24|0]&1}function Nba(a){a=a|0;_v(a);Cb(a)}function Mc(a,b){return(b<<1)+a|0}function Kx(a){i[a>>2]=i[a>>2]+32}function Jb(a){return Pe(i[a>>2])}function IX(a){a=a|0;return 71235}function HX(a){a=a|0;return 71272}function GO(a,b){return pn(a,b,5)}function EX(a){a=a|0;return 71784}function Bx(a){i[a>>2]=i[a>>2]+52}function B3(a){a=a|0;return 56040}function Ar(a,b,c){xka(a,b-a|0,c)}function Am(a){return a+1074324|0}function Ae(a,b){return(b<<2)+a|0}function AO(a,b){return(b<<4)+a|0}function AH(a){return a+1074328|0}function zz(a,b){return FJa(a,b)}function zr(a){return CJ(j[a|0])}function zC(a){Bk(a);qb(a);Bk(a)}function ye(a,b){i[a>>2]=i[b>>2]}function yQ(a,b){return wCa(a,b)}function yJ(a){Mi(a);bf(a);Mi(a)}function xp(a){xf(a);rc(a);xf(a)}function wz(a){ii(a);tR(a);sR(a)}function wk(a){xh(a);Wc(a);xh(a)}function ux(a){g[a|0]=0;return a}function tu(a){a=a|0;uu(a);Cb(a)}function rp(a){Wb(a);GS(a);vp(a)}function qh(a){Be(a);nd(a);Be(a)}function pk(a){zf(a);Wb(a);zf(a)}function pP(a,b){Tb(a,b+4|0,256)}function ot(a,b){return TKa(a,b)}function oh(a){return zpa(Qd(a))}function mp(a){return yb(a,0,48)}function lr(a){a=a|0;ve(a);Cb(a)}function jw(a,b){return Jga(a,b)}function jv(){return(Ka()|0)>0|0}function jk(a){i[a>>2]=i[a>>2]+6}function jQ(a,b){return WEa(a,b)}function jN(a){return j[a|0]<129}function hK(a){return Koa(Qd(a))}function gb(a){M(a|0)|0;KX();x()}function dz(a,b){return lCa(a,b)}function dR(a){nl(a);ii(a);nl(a)}function cA(a,b){return QMa(a,b)}function _h(a){return iua(Qd(a))}function _e(a){gd(a);qb(a);gd(a)}function ZJ(a,b){return ooa(a,b)}function Yp(a){be(a);pB(a);du(a)}function Wj(a){return YBa(xd(a))}function WO(a){Wo(a);Wo(a);PO(a)}function Vr(a){rc(a);VS(a);Yo(a)}function Vp(a){ti(a);bg(a);ti(a)}function VH(a){Re(a);PH(a);OH(a)}function Tf(a){i[a>>2]=i[a>>2]+1}function TH(a){qb(a);MH(a);vg(a)}function Sk(a,b){return Ofa(a,b)}function Sh(a){qb(a);dQ(a);vg(a)}function Rc(a,b){return RMa(a,b)}function RX(a,b){a=a|0;b=b|0;x()}function RR(a){Wb(a);JR(a);vp(a)}function PD(a){a=a|0;Kk(a);Cb(a)}function MD(a){a=a|0;Un(a);Cb(a)}function JH(a){Fj(a);Re(a);Fj(a)}function IP(a){jl(a);Yj(a);jl(a)}function Hi(a){Rf(a);cc(a);Rf(a)}function FG(a){a=a|0;$v(a);Cb(a)}function Dx(a){i[a>>2]=i[a>>2]+8}function DN(a){Tm(a);Tj(a);Tm(a)}function CP(a){qb(a);BP(a);vg(a)}function CI(a){If(a);aQ(a);QP(a)}function Al(a){Yg(a);be(a);Yg(a)}function $t(a){a=a|0;gq(a);Cb(a)}function $s(a){hi(a);If(a);hi(a)}function $r(a){qb(a);ZL(a);vg(a)}function $c(a){return i[a>>2]!=0}function zh(a,b){return a>>>b&1}function yo(a){Sd(a+12|0);pL(a)}function ufa(a){a=a|0;Cb(ew(a))}function ud(a,b){return ul(a,b)}function ph(a){return be(a)&255}function pe(a,b){return Bf(a,b)}function oq(a){a=a|0;return 127}function om(a){return a<<24>>24}function oi(a,b,c){Ge(a,c,13,b)}function no(a){h[a+480214>>1]=0}function nk(a,b){return tT(a,b)}function lj(a,b,c){Ac(a,b,1<<c)}function kJ(a,b){return hJ(a,b)}function jC(a,b){return MY(a,b)}function iu(a){ZV(a,jD(te(12)))}function dl(a){eb(a+12|0);df(a)}function cZ(a){a=a|0;eb(461912)}function bi(a,b){return _z(a,b)}function aZ(a){a=a|0;nc(461928)}function _Y(a){a=a|0;eb(461944)}function YY(a){a=a|0;nc(461960)}function YN(a,b){return $h(b,a)}function Wd(a,b){return V4(a,b)}function WY(a){a=a|0;eb(461976)}function Vl(a,b){return s1(a,b)}function UY(a){a=a|0;nc(461992)}function Sga(a){a=a|0;Cb(kw(a))}function SY(a){a=a|0;eb(462008)}function QY(a){a=a|0;nc(462024)}function Pd(a){a=a|0;return a|0}function Oi(a){return!i[a+4>>2]}function Nfa(a){a=a|0;Cb(gw(a))}function Nea(a){a=a|0;Cb(cw(a))}function Mm(a){return Ui(xd(a))}function Jha(a){a=a|0;Cb(rw(a))}function Jea(a){a=a|0;return 13}function Jda(a){a=a|0;Cb(gr(a))}function Im(a){eb(a+12|0);eb(a)}function Ie(a){eb(a+20|0);eb(a)}function GR(a,b){return Ut(a,b)}function Fs(a,b){return aP(a,b)}function Fb(a,b){return se(a,b)}function Eu(a,b){return Xe(a,b)}function Eba(a){a=a|0;Cb($v(a))}function Ap(a,b){return sT(a,b)}function $fa(a){a=a|0;Cb(mr(a))}function y3(a){a=a|0;Cb(YD(a))}function xx(a,b){return b-a>>1}function x8(a){a=a|0;Cb(XF(a))}function w3(a){a=a|0;Cb(iv(a))}function s8(a){a=a|0;Cb(UF(a))}function rE(a){a=a|0;Cb(kg(a))}function qt(a){$La(a);return a}function o4(a){a=a|0;Cb(Kk(a))}function mC(a){a=a|0;Cb(Au(a))}function k_(a){a=a|0;Cb(tC(a))}function jJ(a,b,c){zx(a,b,c,1)}function j4(a){a=a|0;Cb(Un(a))}function hy(a){eza(a);return a}function hv(a){a=a|0;Cb(Fq(a))}function fp(a){BGa(a);return a}function dv(a){a=a|0;Cb(Cq(a))}function b_(a){a=a|0;Cb(MC(a))}function aP(a,b){return b-a>>2}function ZU(a){a=a|0;Cb(QA(a))}function Xv(a){Qaa(a);return a}function Wxa(a){a=a|0;return 9}function VU(a){a=a|0;Cb(Rt(a))}function UE(a){return a>>>0>16}function SX(a){a=a|0;Cb(wu(a))}function Rd(a,b){g[a|0]=j[b|0]}function Pr(a,b){return a<<8|b}function PG(a){a=a|0;Cb(Fd(a))}function My(a){wEa(a);return a}function Lb(a,b){i[a+100>>2]=b}function KF(a){a=a|0;Cb(Ve(a))}function Jfa(a){a=a|0;return 6}function Iw(a){Nka(a);return a}function I8(a){a=a|0;Cb(cr(a))}function Gj(a){qja(a);return a}function Gc(a,b){iY(a,b,wD(b))}function GX(a){a=a|0;Cb(uu(a))}function GM(a){return a+4896|0}function FZ(a){a=a|0;Cb(oC(a))}function FX(a){a=a|0;Cb(gq(a))}function E_(a){a=a|0;Cb(vC(a))}function EZ(a){a=a|0;Cb(nC(a))}function CH(a){Aga(a);return a}function Bba(){return 19465472}function BH(a){zga(a);return a}function BF(a){a=a|0;Cb(Hv(a))}function xq(a,b){i[a+72>>2]=b}function uv(a){B4(a);return a}function rk(a){return!i[a>>2]}function rh(a){return Uc(a)^1}function qn(a){return a>>>0<5}function qP(a){a=a|0;return 7}function oE(a){a=a|0;return-1}function ni(a){eA(a);return a}function ms(a){return a+256|0}function mn(a){Uz(a);return a}function lS(a,b,c){SKa(a,b,c)}function jW(a){a=a|0;return 3}function jD(a){l1(a);return a}function hx(a){Sm(a);return a}function gx(a){MA(a);return a}function gp(a){SS(a);return a}function fT(a,b){return b-a|0}function bj(a,b,c){vMa(a,b,c)}function aN(a){Exa(a,i[a>>2])}function _d(a){a=a|0;return 1}function Zp(a){a=a|0;return 4}function Zd(a){a=a|0;return 2}function Xk(a,b){i[a+32>>2]=b}function Uq(a,b,c){Kfa(a,b,c)}function Ss(a){ak(a);return a}function Sm(a){Qx(a);return a}function Si(a){return $c(a)^1}function Qb(a){a=a|0;return 0}function PI(a){a=a|0;return 5}function Nb(a,b){return a+b|0}function NM(a){Jwa(a,i[a>>2])}function NI(a){Kka(a,i[a>>2])}function Mt(a){Lt(a);return a}function Mg(a){$K(a);return a}function Lz(a,b,c){Zfa(a,b,c)}function Km(a,b){i[a+36>>2]=b}function JR(a){JJa(a,i[a>>2])}function Gw(a,b,c){Cfa(a,b,c)}function Fe(a,b){h[a+28>>1]=b}function Ey(a,b,c){eDa(a,b,c)}function BN(a){bza(a,i[a>>2])}function BM(a,b){yb(a,0,b<<2)}function yA(a){xA(a,i[a>>2])}function xg(a){return a+20|0}function xJ(a){wJ(a,i[a>>2])}function wq(a,b){Nn(a,b+4|0)}function uT(){L2();q3();_I()}function tR(a){hR(a,i[a>>2])}function qI(a,b){Mi(a);Mi(a)}function qG(a){i[a>>2]=83760}function pB(a){DV(a,i[a>>2])}function op(a){i[a>>2]=76688}function nm(a){i[a>>2]=71296}function nD(a,b,c){_1(a,b,c)}function ks(a,b){Xx(a,sd(b))}function ko(a,b){m[a+8>>2]=b}function io(a,b){m[a+4>>2]=b}function iC(a,b){Bk(a);Bk(a)}function hu(a,b){oB(a,sd(b))}function ht(a,b){Be(a);Be(a)}function hq(a){return a+16|0}function ho(a,b){g[a+36|0]=b}function gL(a){fL(a,i[a>>2])}function fq(a,b,c){Ac(a,b,c)}function fM(a,b){dM(a,Kb(b))}function el(a,b){fb(b);fb(a)}function ec(a,b){a=a|0;b=b|0}function eM(a,b){dM(a,Jb(b))}function eK(a){dK(a,i[a>>2])}function dQ(a){cQ(a,i[a>>2])}function ct(a,b){hi(a);hi(a)}function ce(a,b){i[a+4>>2]=b}function aQ(a){$P(a,i[a>>2])}function _q(a){i[a>>2]=84040}function _L(a){YL(a,i[a>>2])}function ZL(a){PL(a,i[a>>2])}function Ym(a,b){i[a+8>>2]=b}function YG(a){i[a>>2]=56152}function Wt(a,b){ti(a);ti(a)}function VS(a){OS(a,i[a>>2])}function Te(a,b){g[a+11|0]=b}function Sz(a,b){xf(a);xf(a)}function Sp(a,b){Yg(a);Yg(a)}function Sn(a,b){Rf(a);Rf(a)}function SO(a,b,c){lw(a,b,c)}function QF(a){j8(a,i[a>>2])}function Pw(a,b){g[a+37|0]=b}function PH(a){KH(a,i[a>>2])}function Ow(a,b){g[a+38|0]=b}function Mj(a,b){gd(a);gd(a)}function Mb(a){return a+12|0}function MH(a){HH(a,i[a>>2])}function KJ(a){return a+80|0}function Jl(a,b){xh(a);xh(a)}function It(a,b){zf(a);zf(a)}function HC(a){gC(a,i[a>>2])}function GS(a){hT(a,i[a>>2])}function EN(a,b){Ge(a,b,8,2)}function DF(a){i[a>>2]=84512}function Ck(a){return a+32|0}function Cba(){return 327683}function BP(a){iA(a,i[a>>2])}function zs(a,b,c){hBa(b,c)}function yf(a){return a+2|0}function xe(a,b,c){Esa(b,c)}function uza(){return 65534}function uo(a,b,c){Foa(b,c)}function so(a){yb(a,0,8192)}function ln(a,b,c){ILa(b,c)}function li(a){return a+3|0}function lT(a,b){Ac(a,b,20)}function kA(a,b){Ac(a,b,22)}function gg(){ic(70492);x()}function fb(a){return a+8|0}function cj(a,b){g[a+3|0]=b}function cg(a){return a&255}function cR(a,b,c){HIa(b,c)}function bt(a,b,c){RIa(b,c)}function Yi(a,b,c){wFa(b,c)}function Xw(a,b,c){Tma(b,c)}function Xo(a,b,c){SCa(b,c)}function TJ(a){yb(a,0,1024)}function SB(){zi(70909);x()}function Ro(a){yb(a,0,4096)}function QIa(){return 65535}function Pb(a){return a+4|0}function Nc(a){return a+1|0}function NX(){return 463668}function Ml(){zi(70492);x()}function Kc(){ic(70909);x()}function IH(a,b,c){qha(b,c)}function HE(){return 458336}function EP(a,b,c){dEa(b,c)}function Cc(a){return!lb(a)}function $x(a){i[a+12>>2]=0}function yt(a,b,c){BT(b,c)}function yW(a){a=a|0;vk(a)}function wi(a,b,c){DB(b,c)}function vp(a){zf(a);Wb(a)}function vg(a){gd(a);qb(a)}function un(a,b,c){YT(b,c)}function ug(a){xp(a);iT(a)}function ub(a){El(i[a>>2])}function sc(a){a=a|0;Cb(a)}function sR(a){nl(a);ii(a)}function sI(a){Mi(a);bf(a)}function pf(a){Vp(a);Cx(a)}function pc(a){i[a+8>>2]=0}function os(a){Rf(a);cc(a)}function maa(){return 2048}function mR(a){$s(a);kR(a)}function kl(a){$s(a);Qs(a)}function kQ(a){g[a+31|0]=0}function jo(a,b){m[a>>2]=b}function hQ(a){Qy(a,qe(a))}function gf(a,b){i[a>>2]=b}function fu(a){Vp(a);nB(a)}function fK(a){Jr(a,qe(a))}function eQ(a){Sy(a,qe(a))}function dy(a,b,c){zN(b,c)}function du(a){Yg(a);be(a)}function dh(a,b,c){U2(b,c)}function df(a){pk(a);pt(a)}function bJ(a){Lw(a,qe(a))}function _o(a){Cy(a,qe(a))}function Zo(a){By(a,qe(a))}function Yo(a){xf(a);rc(a)}function Xg(a,b,c){WA(b,c)}function Wi(a,b){rn(a,b,0)}function Vv(a){wk(a);DG(a)}function Vt(a,b,c){gV(b,c)}function VO(a){_e(a);RO(a)}function Uf(a,b,c){C4(b,c)}function Tx(a){yb(a,0,512)}function To(a){Be(a);nd(a)}function TN(a){_e(a);RN(a)}function Sd(a){_e(a);js(a)}function Sc(a){Hi(a);IA(a)}function Qc(a){wk(a);QS(a)}function QP(a){hi(a);If(a)}function Pj(a){wx(a,qe(a))}function OH(a){Fj(a);Re(a)}function Md(a){xp(a);Ip(a)}function KC(a){zC(a);IC(a)}function Jp(a){xp(a);CA(a)}function HS(a,b){bj(a,2,b)}function Go(a){wk(a);qL(a)}function GC(a){Bk(a);qb(a)}function FK(a){ix(a,qe(a))}function FB(a){xh(a);Wc(a)}function F2(){return 58224}function E2(){return 59008}function Df(a,b,c){iB(b,c)}function D2(){return 60560}function tF(a){yb(a,0,44)}function mb(a,b){oBa(a,b)}function lX(){return Xa|0}function kX(a){a=a|0;Xa=a}function jA(a){g[a+1|0]=3}function i3(a){a=a|0;j3()}function bS(a,b){DKa(a,b)}function Wz(a,b){rMa(a,b)}function RD(a){Rv(a,8192)}function LO(a,b){LBa(a,b)}function FN(a,b){aza(a,b)}function DP(a){yb(a,0,33)}function BO(a,b){ABa(a,b)}function xu(a,b){_X(a,b)}function re(a){hb(a+8|0)}function p$(){lq(463144)}function mz(a){g[a|0]=16}function mS(a,b){QH(a,b)}function ls(a){i[a>>2]=0}function kO(a,b){Aw(a,b)}function jn(a,b){iE(a,b)}function jc(a){ug(a+8|0)}function iL(a,b){eM(a,b)}function hB(a,b){yc(a,b)}function bh(a,b){Bg(a,b)}function SL(a,b){af(a,b)}function Os(a){eb(a+4|0)}function Og(a){a=a|0;x()}function Ln(a,b){NY(a,b)}function Ah(a,b){M$(a,b)}function Ne(a){g[a|0]=0}function qJ(a){aJ(a,0)}function lc(a){de(a,0)}function ih(a){yG(a,0)}function Xp(a){oB(a,0)}function Hr(a){OJ(a,0)}function Hf(a){iQ(a,0)}function Gr(a){NJ(a,0)}function Ec(a){JG(a,0)}function $e(a){Xx(a,0)}function ob(a){eb(a)}function me(a){a=a|0}function WS(a){Gd(a)}function s$(){K_()}function h$(){FC()}function c$(){EC()}function a$(){DC()}function __(){CC()}function Y_(){BC()}function U_(){J_()}function S_(){I_()}function Q_(){AC()}function JX(){x()}
// EMSCRIPTEN_END_FUNCS
var $a=cNa([null,il,Bb,Gp,Kf,kMa,TR,kHa,bGa,Li,$Ea,EDa,xCa,Dr,il,d4,cV,xl,ag,c4,O,Ot,qk,t6,uu,bv,ae,hU,wl,pi,nfa,bc,ec,rb,pi,NJa,BR,xR,Fy,oT,aA,WCa,Iy,Og,_d,_d,oIa,gIa,gt,_Ha,AP,TDa,KDa,JX,Hy,Og,_d,Qb,_d,HFa,DFa,yFa,rFa,jFa,sDa,JEa,nDa,sEa,jEa,Pd,Og,oO,QAa,UN,ON,xs,KN,eO,aO,ps,uya,na,hya,Fc,Fc,Bb,vY,Wx,Lwa,Fwa,Fc,nva,cva,AM,bc,Jm,Lg,Fc,tY,jua,Nya,Mta,Rta,Eta,yta,me,Xoa,ec,fsa,AM,sl,Kt,YB,fY,il,Noa,Uma,mo,sl,gla,Kf,Qka,yC,Zja,Tja,Nja,mfa,bfa,x3,Vea,rja,eja,Pia,aI,aI,aia,Mha,pr,Gp,or,Dga,uga,or,Saa,Kaa,yaa,qaa,or,or,mm,il,Fd,PG,dea,Yda,Cq,dv,bE,aE,gr,Jda,ec,il,zda,Nca,Qb,Qb,n4,Cca,m4,gca,l4,Fba,Y3,g9,m8,d8,$3,T3,R3,Wv,W3,T7,Ve,KF,E7,v7,Fq,hv,mE,lE,s6,xs,j6,g6,aF,Gn,il,E4,Oq,ts,R4,N4,bc,fv,$D,AD,bc,bc,aA,nu,RW,QW,MW,gX,ec,PW,ec,Fy,JBa,LW,KW,JW,IW,ai,GW,z5,s5,FW,yB,xB,EW,Oq,DW,AW,lu,yW,vi,tc,uW,Il,tW,rW,xW,qW,pW,CW,GBa,zW,vB,oW,nW,uB,mW,Se,hj,vc,Wp,wb,bW,gj,Wp,XV,WV,UV,gq,zV,yV,Fc,bc,UA,OB,fV,NV,dg,MV,CV,wh,Fc,rV,dg,qV,Fc,ec,eV,aV,dg,$U,pi,$t,gt,Pd,sc,zn,NG,KV,sc,JV,_d,_d,gt,nz,IV,AP,HV,GV,Pd,sc,zn,pV,sc,Qb,_d,_d,Qb,Qb,_A,QA,ZU,zn,YU,Rt,VU,UU,TU,SU,RU,rca,QU,PU,OU,Kn,FU,Ala,EU,zla,DU,Op,Ib,Hla,aB,ad,CU,Lg,kY,bc,Jm,XA,AD,ec,NA,oU,kU,$t,bc,bc,bc,BA,aU,$T,ec,ec,ec,WT,aA,Fy,nu,DT,Lg,PT,IT,CT,ec,BA,xt,wT,dA,vT,HMa,yMa,Yz,up,ec,oMa,_S,nMa,kd,LU,ZS,mMa,dW,Xb,Jc,lMa,iMa,hMa,YS,XS,gMa,fMa,Xf,Gf,Sf,eMa,US,TS,YLa,RS,tp,bc,NLa,Jm,LLa,jb,nT,oc,bc,bc,BLa,bc,MLa,JLa,ec,DLa,Yz,zS,wS,vLa,tLa,sLa,rLa,qLa,sg,pLa,oLa,nLa,mLa,Sv,HJ,jb,EM,lLa,pg,kLa,Vz,oS,Vc,md,vi,Ni,bLa,aLa,ri,Ug,zJ,$Ka,_Ka,Oz,gc,gu,ZKa,nS,Nd,Mz,Rz,Mo,jb,Ht,ST,KKa,Dp,Qe,rt,xKa,XR,rB,Vh,ef,tb,ng,wKa,Ez,vKa,tc,uKa,ota,VR,tKa,sKa,Ko,rKa,UR,SR,pKa,oKa,nKa,jka,zp,yp,Vk,Cw,FI,mKa,OR,uH,kKa,jKa,iKa,ck,Dz,hKa,gKa,Dt,MR,fKa,_Ja,HR,oO,YJa,LJa,bc,Az,Az,IJa,UN,ON,xs,KN,hn,gn,np,bc,ec,ps,yJa,xJa,wJa,pJa,nJa,vz,lp,mJa,Se,lJa,ft,kJa,Lo,jJa,cf,Rx,iJa,hJa,gJa,tz,dJa,wf,Jf,bJa,aJa,$Ia,LIa,KIa,VIa,UIa,Ht,at,lR,XIa,bc,TIa,ec,nu,hn,ec,gn,np,bc,Xi,ip,uIa,Ws,tIa,mIa,XR,hp,lIa,Xs,Sx,UR,kIa,on,jIa,iIa,YQ,Lf,hIa,fIa,xE,nn,As,eIa,BAa,MR,dIa,aIa,qg,SQ,hn,gn,np,bc,KHa,JHa,SQ,JQ,II,yka,Fw,EQ,oHa,nHa,sh,bHa,aHa,gna,ZGa,YGa,XGa,WGa,Et,VGa,UGa,rb,TGa,Se,GT,SGa,xwa,ywa,RGa,QGa,fHa,an,JT,PGa,No,HT,xQ,OGa,NGa,Rna,Jc,MGa,LGa,cz,KGa,MMa,JGa,IGa,GGa,wQ,FGa,ay,EGa,DGa,FT,uR,cHa,CGa,uQ,xGa,az,aO,vA,Bp,tGa,sGa,jm,Zma,rGa,qGa,sQ,sQ,oQ,Yy,Ek,nGa,y_,mGa,lGa,kGa,iGa,Rg,kta,Rg,Kja,hGa,ria,nQ,bc,nFa,Wp,$m,_Fa,hFa,ES,Jn,Uh,bc,UP,gFa,fFa,mQ,fGa,eGa,af,dGa,ei,Ps,tia,lna,fia,aGa,Gp,UFa,TFa,SFa,Fc,$j,Fc,Ry,Pd,gQ,dg,Ty,Pd,Ty,ec,BFa,ec,ec,qFa,Lg,Ns,mFa,OEa,NEa,MEa,rg,en,LEa,KEa,IEa,qB,HEa,GEa,FEa,EEa,DEa,CEa,BEa,zEa,yEa,bc,NDa,JDa,lEa,kEa,hEa,ec,yP,hn,xP,SDa,bc,rP,an,GDa,FDa,DDa,CDa,Yta,Se,BDa,ADa,zDa,yDa,PQ,qM,pb,Ks,Gy,hz,Vc,dA,wDa,vDa,oP,uDa,VR,lp,sz,tDa,ej,rDa,Gp,Se,Pz,Se,Qt,wt,qDa,ei,lP,vta,ww,kP,$o,bc,$j,Fc,bc,ec,XCa,Lg,Ns,ec,Pd,ec,ec,NCa,Yz,zS,HCa,dg,CCa,ui,BCa,ACa,Ay,Ds,zCa,yCa,vCa,uCa,tCa,sCa,aT,rCa,qCa,jb,pCa,oCa,nCa,mCa,twa,dra,_A,kCa,jb,Cs,x5,Wy,G5,Cs,jCa,iCa,I5,J5,$ma,hCa,rQ,qQ,uM,ai,eCa,dCa,bCa,aCa,bc,Ns,bc,QBa,pi,ec,wS,et,Bs,_i,Uh,Se,ip,tBa,sBa,KBa,Ms,ec,_Aa,oS,jS,ZAa,bna,YAa,XAa,uI,$m,WAa,nO,VAa,UAa,At,zt,ys,Bpa,TAa,SAa,gs,RAa,sp,PAa,OAa,ly,ut,bc,ec,qAa,pAa,UA,Se,fAa,Zf,eAa,Fc,dAa,cAa,_N,Fc,Cp,bAa,Tza,Sza,bk,Nm,ys,Rza,uka,Pza,SN,bc,Ns,ec,Iza,Lg,Cza,Bza,vz,$N,IN,Rz,Aza,zza,xza,wza,vza,QIa,uza,tza,sza,ss,rza,qza,ss,pza,aS,tz,oza,MT,bc,$ya,Sya,Pya,ip,hza,gza,fza,bc,hn,_ya,gn,np,Tya,xN,wN,cy,bc,Cya,an,Bya,vya,HM,nO,an,gra,fra,oya,cya,bya,gu,aya,$xa,_xa,Zxa,Yxa,Gs,Xxa,Vxa,Uxa,Oxa,Kxa,bc,Cxa,Bxa,sxa,Fxa,ec,Axa,bc,bc,QO,ixa,ky,gxa,fxa,xta,bxa,axa,lla,$wa,_wa,Zwa,jla,Ywa,kla,mla,Xwa,Wwa,Vwa,HW,BB,Fta,ty,rna,ona,Vx,Swa,Rwa,bc,Ux,Hwa,Lg,ec,IM,Awa,rwa,qwa,pwa,owa,nwa,lwa,kwa,jwa,iwa,hwa,gwa,fwa,ewa,dwa,cwa,bwa,awa,$va,_va,Zva,Yva,Xva,Wva,Vva,Uva,Tva,Sva,Rva,Qva,Pva,Ova,Nva,Mva,Lva,Kva,Iva,Hva,Gva,Fva,Eva,Dva,Cva,Bva,Ava,zva,xva,wva,vva,uva,tva,sva,rva,qva,pva,ova,mva,lva,kva,jva,iva,hva,gva,fva,eva,dva,bva,ava,$ua,_ua,Zua,Yua,Xua,Wua,Vua,Uua,Sua,Rua,Qua,Pua,Oua,Nua,Mua,Lua,Kua,Jua,Iua,Hua,Gua,Fua,Eua,Dua,Cua,Bua,Aua,zua,yua,xua,gua,fua,Wta,rM,aua,$j,Fc,bc,up,dg,Ysa,lk,Bta,Dta,FS,cM,sta,bc,Wsa,nta,UL,Tsa,jta,hta,gta,fta,eta,aM,bta,ata,$sa,_sa,mQ,ds,Nsa,Xsa,WL,bc,IL,Fc,Lsa,Fc,ssa,rsa,qsa,BL,psa,DS,nsa,OB,gsa,yL,Nla,asa,$ra,Br,Lla,Yra,Kla,Jla,Xra,Ura,Tra,Pra,Jra,Ira,bc,bc,Ora,ec,bc,Hra,ec,Ri,bc,lra,kra,pra,jra,Gv,k6,_r,cra,mna,$i,Ota,Mx,$qa,HR,up,up,xs,uB,$j,Fc,fv,$D,Pd,Uqa,dg,bc,bz,Hd,$S,bU,De,UKa,Pqa,Oqa,jb,YIa,Nqa,Mqa,Lqa,Kqa,Jqa,Iqa,Hqa,Gqa,Fqa,Eqa,Dqa,Cqa,Bqa,Aqa,zqa,yqa,xqa,wqa,vqa,uqa,tqa,sqa,rqa,qqa,pqa,oqa,nqa,mqa,lqa,kqa,jqa,iqa,hqa,gqa,fqa,eqa,dqa,bqa,aqa,$pa,_pa,Zpa,Ypa,Xpa,Wpa,Vpa,Upa,Tpa,Spa,Rpa,Qpa,Ppa,Opa,Npa,Mpa,Lpa,Kpa,Jpa,Ipa,Hpa,Gpa,Fpa,wpa,Era,vpa,upa,tpa,lL,kL,spa,rpa,Dm,Sr,sx,qpa,TK,is,xM,Do,SK,nJ,AJ,Uw,Co,Rr,Bo,opa,MK,mpa,lpa,ei,Ps,$o,HL,ei,lP,kpa,$o,Bra,bc,zoa,woa,$j,Fc,Fc,$j,Fc,bc,ec,Pd,ec,bK,qoa,dg,Pd,ec,ioa,dg,coa,uta,zwa,VJ,kM,boa,ima,aoa,SJ,te,Fc,Fc,bc,Tna,Mna,gW,NU,IU,rU,Ina,pU,MU,fW,HU,wga,Fna,JJ,dx,xla,bc,Dsa,bc,Jm,Lg,Fc,qna,nna,dja,tja,jna,jja,Yia,Fc,Fc,qy,hna,sM,bc,bc,Sma,Qma,ec,dxa,cxa,$Ga,_Ga,xya,wya,jya,iya,IDa,HDa,mAa,lAa,QEa,PEa,zKa,yKa,FHa,DHa,xLa,wLa,dLa,cLa,hAa,gAa,Eya,Dya,oxa,mxa,rJa,qJa,wIa,vIa,uMa,tMa,qMa,pMa,Eza,Dza,jza,iza,aBa,$Aa,TEa,LP,wHa,vHa,qHa,pHa,AJa,zJa,pIa,nIa,Wza,Vza,ila,hla,Pka,Oka,vBa,uBa,rya,qya,eya,dya,MBa,zBa,xBa,LMa,KMa,FKa,EKa,ECa,DCa,FBa,BBa,fma,bc,Jm,Lg,Zla,$j,Fc,WJ,ec,AD,Ry,dg,IM,Mla,Kw,qs,Bla,Dla,cL,fla,ela,vz,dla,it,cla,IN,bla,ala,$ka,ip,_ka,Yka,Se,Xka,Wka,Vka,Uka,Tka,tz,Ska,q6,m6,l6,bc,hn,gn,np,tka,rka,pka,UP,ika,bka,Rg,fka,eka,Rg,_y,dka,hf,Bg,Hk,cka,Wja,Uja,Hja,Qja,mka,Pja,Cja,Bja,Lja,gka,Eja,zw,bc,mI,bc,$j,Fc,Hia,Lg,Dia,tw,ei,Ps,gja,sma,Gia,Wia,Via,Rg,Uia,Tia,Sia,jI,nja,go,aM,Ria,af,iI,Oia,jj,Bg,Ux,gQ,dg,pia,oia,nia,mia,lia,kia,Ai,gia,YH,Qia,Xia,XH,bia,Yha,Xha,Wha,Oga,Vha,Uha,NH,zha,LH,Lg,hI,wha,mha,tha,ec,Ux,ec,rw,Jha,Iha,Hha,Qb,me,Qb,Qb,Qb,ec,Zp,Oha,Pha,Rha,Qha,Sha,Rh,qw,qw,pw,pw,pw,jMa,me,LP,Gha,Fha,Eha,Dha,Nha,Qh,RH,Mga,Qb,Qb,_d,ow,Zd,Zd,_d,Lha,Kha,ec,me,ec,me,jha,Uga,kw,Sga,Rga,Qga,Qb,me,Qb,Qb,Qb,ec,Wxa,GH,fha,Wga,Vga,iha,Rh,dha,cha,bha,aha,_ga,Zga,Yga,Xga,eha,Qh,FH,Qb,Qb,_d,Zd,Zd,_d,EH,DH,ui,Hga,Gga,wH,bc,bc,ve,Og,Iga,vH,Lga,Qb,Cga,Bga,sga,ts,qga,pga,oga,nga,Fc,Lg,ds,bc,Jm,ec,gga,Vfa,Ifa,Afa,rfa,gfa,Xea,Iea,Aea,Zha,kha,qH,mr,$fa,pH,_fa,Qb,me,Qb,Qb,Qb,ec,qP,cga,dga,fga,Rh,bga,Qh,aga,Qb,Qb,_d,Zd,Zd,ec,me,oH,Yfa,Xfa,nH,Wfa,mH,lH,Ufa,gw,Nfa,Mfa,Lfa,Qb,me,Qb,Qb,Qb,ec,Jfa,Qfa,Sfa,Tfa,Rh,Pfa,Qh,jH,Qb,Qb,_d,Zd,Zd,Hfa,lr,kr,Bfa,Qb,me,Qb,Qb,Qb,ec,PI,Efa,Ffa,Gfa,Rh,Dfa,Qh,gH,Qb,Qb,_d,Zd,Zd,zfa,ew,ufa,tfa,sfa,Qb,me,Qb,Qb,Qb,ec,PI,wfa,xfa,yfa,Rh,vfa,Qh,eH,Qb,Qb,_d,Zd,Zd,qfa,ofa,lfa,kfa,qP,pfa,oH,jfa,ifa,nH,hfa,mH,lH,ffa,lr,kr,$ea,Qb,me,Qb,Qb,Qb,ec,Zd,cfa,dfa,efa,Rh,afa,Qh,_ea,Qb,Qb,_d,Zd,Zd,Wea,Zea,cw,Nea,Mea,Lea,Qb,me,Qb,Qb,Kea,ec,Jea,Qea,Rea,Uea,Rh,Pea,Qh,dw,Qb,Qb,_d,Zd,Zd,ec,me,Hea,lr,kr,Bea,Qb,me,Qb,Qb,Qb,ec,jW,Dea,Eea,Gea,Rh,Cea,Qh,ZG,Qb,Qb,_d,Zd,Zd,zea,lr,kr,uea,Qb,me,Qb,Qb,Qb,ec,Zp,wea,xea,yea,Rh,vea,Qh,VG,Qb,Qb,_d,Zd,Zd,Cba,hea,Pba,Yaa,Bba,Aba,saa,lu,paa,hr,KG,laa,Xda,Wda,Fc,Fc,maa,iaa,haa,gaa,Pd,W,Pda,Oda,KG,faa,daa,GG,Ida,$v,gG,nz,M9,L9,R9,J9,K9,N9,bw,caa,rda,CG,$9,_9,Z9,Y9,X9,W9,V9,U9,T9,S9,I9,bw,C9,B9,A9,z9,y9,x9,w9,v9,u9,t9,s9,r9,q9,p9,Rk,o9,n9,Qk,ar,m9,dC,l9,j9,i9,h9,f9,e9,d9,Pv,b9,a9,Z8,Y8,X8,V8,U8,R8,P8,N8,Iaa,vG,uG,tG,sG,T6,R6,GG,bw,hca,fca,eca,dca,cca,bca,aca,$ba,_ba,Zba,Yba,Xba,Wba,Vba,Uba,Tba,Sba,Rba,Kba,_v,Nba,Mba,FG,Dba,FG,Eba,TR,wB,dr,hba,Zqa,_p,cba,bba,bc,q8,$aa,SF,n8,Tr,Raa,bc,bK,h8,doa,Gaa,XB,QO,Fc,Fc,Fc,T8,M8,Q8,O8,Jna,Naa,fba,Xaa,_t,ei,Ps,$o,$z,Baa,Ema,gma,raa,AG,zG,naa,oaa,Fc,D8,B8,Laa,lG,Daa,Vaa,Fc,Fc,Fc,jb,Ob,eaa,Q9,Fc,Fc,FJ,H9,G9,F9,V6,una,vna,Waa,fna,E9,D9,lm,bG,Mja,k9,Ti,tI,$8,Qe,BJ,HI,GI,W8,bc,dg,z8,dg,v8,Ty,ec,X6,bc,Og,cr,I8,aba,Pd,Og,Pd,sc,G8,F8,Og,XF,x8,zn,w8,UF,s8,zn,r8,sc,c8,Pd,sc,b8,a8,sc,NF,MF,Og,sc,N7,M7,sc,LF,JF,sc,A7,z7,sc,IF,HF,sc,k7,j7,sc,FF,EF,Hv,BF,O6,N6,AF,zF,yF,xF,wF,vF,uF,sF,rF,qF,pF,oF,nF,mF,lF,kF,Q6,P6,M6,K6,J6,I6,H6,G6,F6,E6,D6,C6,B6,z6,y6,x6,u6,r6,Pd,Og,Pd,Og,p6,o6,o5,$4,J4,I4,H4,F4,G4,La,HE,TB,y4,v4,r4,sE,vm,b4,Z3,q4,a4,U3,F3,P3,gv,O3,qKa,lKa,WR,N3,vm,ag,L3,J3,I3,F3,E3,_D,me,z3,YD,Kk,o4,qE,pE,oE,Gq,Gq,Un,j4,ec,il,qE,pE,Qb,Qb,i4,oE,h4,Gq,g4,Gq,Fq,hv,mE,lE,Cq,dv,bE,aE,Pd,sc,B3,bY,aY,$X,A3,y3,iv,w3,kg,rE,kg,rE,s3,Qb,r3,p3,i3,ir,ir,Zu,Yu,Eq,hE,PD,h3,g3,f3,e3,MD,d3,c3,b3,a3,PD,$2,KD,_2,Z2,MD,Y2,KD,X2,W2,N2,I2,Ou,Fg,Eg,tq,Cb,zu,Tn,Fi,zj,Nu,Jk,Pn,vj,m2,je,Dh,Pf,j2,g2,mD,mD,$1,sq,X1,lD,Eh,U1,Q1,fc,Ud,O1,J2,Ru,ev,Lu,Fg,Eg,rq,Dq,wj,Gk,qk,_l,uj,Dh,Pf,qq,kD,Eh,p1,sj,j1,i1,Pn,H2,Vu,M4,ZD,c1,Aq,On,wl,Z0,Tl,Pn,Su,me,c0,Pl,b0,a0,ZC,$$,YC,Pn,Y$,Gn,U$,T$,xj,S$,UC,YC,P$,eY,K$,J$,G$,F$,Pe,QC,G2,QC,OC,B$,NC,Pe,A$,Tu,y$,x$,w$,v$,u$,t$,s$,r$,q$,p$,o$,n$,m$,l$,k$,j$,i$,h$,g$,f$,e$,d$,c$,b$,a$,$_,__,Z_,Y_,X_,W_,V_,U_,T_,S_,R_,Q_,P_,O_,M_,JC,lC,Ux,A_,F_,LY,H_,IY,HY,Pd,C_,B_,x_,F2,E2,D2,vD,Aj,uD,Qn,WZ,VZ,tD,sD,rD,vZ,uZ,sZ,rZ,pZ,oZ,mZ,lZ,jZ,hZ,fZ,eZ,cZ,Du,aZ,_Y,YY,WY,UY,SY,QY,fC,ec,vC,E_,pH,tC,k_,j_,i_,h_,g_,nA,f_,e_,d_,MC,b_,a_,_Z,YZ,XZ,Qb,UZ,SZ,oC,FZ,DZ,CZ,bG,AZ,yZ,nC,EZ,nz,GU,BZ,zZ,xZ,Pd,sc,sc,w_,v_,u_,t_,s_,r_,q_,o_,nA,n_,m_,l_,sc,rC,rC,Gu,_d,_d,c_,_d,sc,RZ,PZ,Gu,Qb,Qb,NZ,Zp,sc,LZ,JZ,Gu,Qb,Qb,HZ,Zp,sc,sc,Pd,sc,v2,u2,t2,Pd,sc,s2,r2,q2,sc,p2,o2,l2,i2,f2,d2,b2,Z1,W1,T1,P1,sc,N1,M1,K1,I1,G1,D1,B1,z1,x1,v1,t1,sc,r1,q1,o1,n1,m1,k1,h1,g1,sc,f1,e1,b1,a1,$0,_0,Y0,X0,Pd,sc,Zd,U0,T0,S0,R0,P0,O0,wZ,qZ,kZ,XY,TY,dZ,$Y,Pd,sc,Zd,B0,z0,y0,x0,w0,v0,tZ,nZ,gZ,VY,RY,bZ,ZY,Au,mC,i0,Au,mC,h0,sc,oq,oq,qj,qj,qj,$C,Qb,pj,pj,sc,oq,oq,qj,qj,qj,$C,Qb,pj,pj,sc,Kr,Kr,qj,nq,nq,_C,Qb,pj,pj,sc,Kr,Kr,qj,nq,nq,_C,Qb,pj,pj,sc,d0,Z$,sc,V$,R$,sc,L$,I$,sc,H$,E$,sc,RC,D$,ec,sc,RC,C$,ec,Pd,Og,Og,Qb,Qb,Qb,yY,sY,bC,cC,EY,aF,TX,rY,UB,wu,sc,YX,XX,sc,WX,UX,VX,SX,MX,NX,RX,sc,HX,sc,IX,GX,gt,FX,tu,tu,tu,$t,sc,EX,Pd,sc,me,me,DX,uX,xX,CX,sc,vX,yX,BX,sc,wX,zX,AX]);function kNa(){return f.byteLength/65536|0}function lNa(vNa){vNa=vNa|0;var ab=kNa()|0;var bb=ab+vNa|0;if(ab<bb&&bb<65536){var cb=new ArrayBuffer(o(bb,65536));var db=new tNa.Int8Array(cb);db.set(g);g=db;g=new tNa.Int8Array(cb);h=new tNa.Int16Array(cb);i=new tNa.Int32Array(cb);j=new tNa.Uint8Array(cb);k=new tNa.Uint16Array(cb);l=new tNa.Uint32Array(cb);m=new tNa.Float32Array(cb);n=new tNa.Float64Array(cb);f=cb;e.buffer=cb}return ab}return{"ya":$a,"za":uT,"Aa":iea,"Ba":gea,"Ca":sc,"Da":Cb,"Ea":fea,"Fa":eea,"Ga":cea,"Ha":hr,"Ia":ec,"Ja":bea,"Ka":aea,"La":$da,"Ma":qw,"Na":_da,"Oa":NG,"Pa":Zda,"Qa":Pd,"Ra":MG,"Sa":LG,"Ta":MG,"Ua":Uda,"Va":iX,"Wa":hX,"Xa":fX,"Ya":Qda,"Za":IG,"_a":Lda,"$a":HG,"ab":Kda,"bb":Hda,"cb":Gda,"db":Fda,"eb":Eda,"fb":Dda,"gb":Cda,"hb":Bda,"ib":Ada,"jb":yda,"kb":xda,"lb":wda,"mb":vda,"nb":uda,"ob":tda,"pb":sda,"qb":qda,"rb":pda,"sb":oda,"tb":nda,"ub":mda,"vb":lda,"wb":kda,"xb":jda,"yb":ida,"zb":hda,"Ab":gda,"Bb":fda,"Cb":eda,"Db":dda,"Eb":cda,"Fb":bda,"Gb":ada,"Hb":$ca,"Ib":_ca,"Jb":Zca,"Kb":Yca,"Lb":Xca,"Mb":Wca,"Nb":Vca,"Ob":Uca,"Pb":Tca,"Qb":Sca,"Rb":Rca,"Sb":Qca,"Tb":Pca,"Ub":Oca,"Vb":Mca,"Wb":Lca,"Xb":Kca,"Yb":Jca,"Zb":Ica,"_b":Hca,"$b":Gca,"ac":Fca,"bc":Eca,"cc":Dca,"dc":Bca,"ec":Aca,"fc":zca,"gc":yca,"hc":xca,"ic":wca,"jc":eX,"kc":uca,"lc":tca,"mc":sca,"nc":qca,"oc":dX,"pc":oca,"qc":nca,"rc":mca,"sc":lca,"tc":kca,"uc":jca,"vc":ica,"wc":Zc,"xc":HE,"yc":lX,"zc":kX,"Ac":jX,"Bc":D4,"Cc":jv,"Dc":tX,"Ec":sX,"Fc":cX,"Gc":bX,"Hc":aX,"Ic":$W,"Jc":VW,"Kc":_W,"Lc":ZW,"Mc":YW,"Nc":XW,"Oc":WW,"Pc":VW}}return jNa({"Int8Array":Int8Array,"Int16Array":Int16Array,"Int32Array":Int32Array,"Uint8Array":Uint8Array,"Uint16Array":Uint16Array,"Uint32Array":Uint32Array,"Float32Array":Float32Array,"Float64Array":Float64Array,"NaN":NaN,"Infinity":Infinity,"Math":Math},mNa,nNa.buffer)}


// EMSCRIPTEN_END_ASM




)(asmLibraryArg, wasmMemory);
  },

  instantiate: /** @suppress{checkTypes} */ function(binary, info) {
    return {
      then: function(ok) {
        var module = new WebAssembly.Module(binary);
        ok({
          'instance': new WebAssembly.Instance(module)
        });
      }
    };
  },

  RuntimeError: Error
};

// We don't need to actually download a wasm binary, mark it as present but empty.
wasmBinary = [];


